package fr.unedic.cali.asu.antecedent;

import fr.unedic.cali.asu.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.DureeProlongation;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.calcul.FacadeCalculProduitFactory;
import fr.unedic.cali.calcul.FacadeCalculProduitPeriodiqueSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDernierJourAvant;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.MontantBaseAbstrait;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class GestionAntecedentCalculAsu
  implements GestionAntecedentCalculAsuSpec
{
  public static GestionAntecedentCalculAsuSpec getInstance()
  {
    return new GestionAntecedentCalculAsu();
  }
  
  public void alimenterGrapheCalcul(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec antecedent = (AttributionAssuranceSpec)p_attribution;
    SaisieAntecedent saisieAntecedent = ((Antecedent)antecedent).getSaisieAntecedent();
    
    alimenterCalendrierExecutionCalculAvant(antecedent, saisieAntecedent);
    
    alimenterCalendrierExecutionCalculPendant(antecedent, saisieAntecedent);
  }
  
  protected void alimenterCalendrierExecutionCalculAvant(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    CalendrierExecutionAvant calendrierAvant = new CalendrierExecutionAvant();
    calendrierAvant.setPremierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    calendrierAvant.setDernierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    EtatAuDernierJourAvant etatAuDernierJourAvant = new EtatAuDernierJourAvant();
    calendrierAvant.setEtatAuDernierJourAvant(etatAuDernierJourAvant);
    p_antecedent.setCalendrierExecutionAvant(calendrierAvant);
    
    alimenterEtatAuDernierJourAvant(calendrierAvant, p_saisieAntecedent);
  }
  
  protected void alimenterCalendrierExecutionCalculPendant(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    CalendrierExecutionCalculPeriodique calendrierPendant = instancierCalendrierExecutionCalcul();
    calendrierPendant.setEtatAttribution(3);
    calendrierPendant.setPremierJourIndemnisable(p_saisieAntecedent.getDateDernierJourCalcule());
    calendrierPendant.setDernierJourIndemnisable(p_saisieAntecedent.getDateDernierJourCalcule());
    
    p_antecedent.setCalendrierExecutionCalcul(calendrierPendant);
    
    alimenterEtatAuDJI(p_antecedent, p_saisieAntecedent);
  }
  
  protected void alimenterEtatAuDJI(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    EtatAuDjiGamme etatAuDJI = new EtatAuDjiGamme();
    p_antecedent.getCalendrierExecutionCalcul().setEtatAuDJI(etatAuDJI);
    if (p_saisieAntecedent.getCumulMoisActiviteReduite() != null) {
      etatAuDJI.setCumulMoisActiviteReduite(p_saisieAntecedent.getCumulMoisActiviteReduite().intValue());
    }
    if (p_saisieAntecedent.getNombreJourIndemniseARE() != null) {
      etatAuDJI.setCumulJoursIndemnise(p_saisieAntecedent.getNombreJourIndemniseARE().intValue());
    }
    if (p_saisieAntecedent.getNombreJourIndemniseAREF() != null) {
      etatAuDJI.setNbJourAREF(p_saisieAntecedent.getNombreJourIndemniseAREF().intValue());
    }
    if (p_saisieAntecedent.getReliquatDuree() != null)
    {
      etatAuDJI.setReliquatDureeIndemnisation(p_saisieAntecedent.getReliquatDuree());
      etatAuDJI.setReliquatDureeIndemnisationAvecMaintien(p_saisieAntecedent.getReliquatDuree());
    }
    if (p_saisieAntecedent.getNombreMoisIndemnisationAssurance() != null)
    {
      etatAuDJI.setNbMoisIndemniseAsu(p_saisieAntecedent.getNombreMoisIndemnisationAssurance().intValue());
      etatAuDJI.setEstNbMoisIndemniseAsu(true);
    }
    etatAuDJI.setReliquatDureeProlongation(new Quantite(p_saisieAntecedent.getReliquatDureeAllongementAREF(), DureeProlongation.UNITE_DEFAUT));
    etatAuDJI.setCumulMoisnonIndemnise(p_saisieAntecedent.getNbMoisCivilsNonPayes());
    etatAuDJI.setMontant(determinerMontant(p_antecedent, p_saisieAntecedent));
  }
  
  protected void alimenterEtatAuDernierJourAvant(CalendrierExecutionAvant p_calendrierAvant, SaisieAntecedent p_saisieAntecedent)
  {
    EtatAuDernierJourAvant etatAuDernierJourAvant = p_calendrierAvant.getEtatAuDernierJourAvant();
    int etat = 0;
    if ((p_saisieAntecedent.getDateFinPMC() != null) && (p_saisieAntecedent.getDateFinPMC().estApres(p_saisieAntecedent.getDateDernierJourCalcule())))
    {
      int reliquatPMC = p_saisieAntecedent.getDateFinPMC().joursEntre(p_saisieAntecedent.getDateDernierJourCalcule());
      etatAuDernierJourAvant.setReliquatPMC(new Integer(reliquatPMC));
      etatAuDernierJourAvant.setPeriodeApplicationPMC(p_calendrierAvant.getPeriode());
      etatAuDernierJourAvant.setDureeInitialePMC(etatAuDernierJourAvant.getReliquatPMC());
      etat = 1;
    }
    if ((p_saisieAntecedent.getReliquatJoursICCP() != null) && (p_saisieAntecedent.getReliquatJoursICCP().intValue() > 0))
    {
      etatAuDernierJourAvant.setReliquatICCP(p_saisieAntecedent.getReliquatJoursICCP());
      etatAuDernierJourAvant.setDureeInitialeICCP(p_saisieAntecedent.getReliquatJoursICCP());
      etatAuDernierJourAvant.setPeriodeApplicationICCP(p_calendrierAvant.getPeriode());
      etat = 1;
    }
    if ((p_saisieAntecedent.getReliquatJoursISLR() != null) && (p_saisieAntecedent.getReliquatJoursISLR().intValue() > 0))
    {
      etatAuDernierJourAvant.setReliquatISLR(p_saisieAntecedent.getReliquatJoursISLR());
      etatAuDernierJourAvant.setDureeInitialeISLR(p_saisieAntecedent.getReliquatJoursISLR());
      etatAuDernierJourAvant.setPeriodeApplicationISLR(p_calendrierAvant.getPeriode());
      etat = 1;
    }
    if ((p_saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (p_saisieAntecedent.getReliquatJoursDelaiAttente().intValue() > 0))
    {
      etatAuDernierJourAvant.setReliquatDelaiAttente(p_saisieAntecedent.getReliquatJoursDelaiAttente());
      etatAuDernierJourAvant.setDureeInitialeDelaiAttente(p_saisieAntecedent.getReliquatJoursDelaiAttente());
      etatAuDernierJourAvant.setPeriodeApplicationDelaiAttente(p_calendrierAvant.getPeriode());
      etat = 1;
    }
    if (((p_saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (p_saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(new Integer(7)) < 0)) && (p_saisieAntecedent.isDelaiAttente()))
    {
      etatAuDernierJourAvant.setDelaiAttenteEntame(true);
    }
    else
    {
      etatAuDernierJourAvant.setPeriodeApplicationDelaiAttente(null);
      etatAuDernierJourAvant.setDelaiAttenteEntame(false);
    }
    etatAuDernierJourAvant.setEtat(etat);
  }
  
  protected MontantBaseAbstrait determinerMontant(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    MontantBaseAbstrait montant = null;
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    FacadeCalculProduitPeriodiqueSpec facade = null;
    String codeFormuleMontant = null;
    try
    {
      facade = (FacadeCalculProduitPeriodiqueSpec)FacadeCalculProduitFactory.getInstance().getInstanceGestionnaireCalculProduit(p_antecedent.getProduitExecution());
      if (p_saisieAntecedent.isEstEnFormationAuDJC()) {
        codeFormuleMontant = "2";
      } else {
        codeFormuleMontant = "1";
      }
      constituantsIndemnisation.setCodeFormuleMontant(codeFormuleMontant);
      
      boolean estAntecedentSP = (p_antecedent.getPji() == null) && (p_antecedent.getProduit().estCompetenceFinanciereSecteurPublic(p_antecedent));
      if (estAntecedentSP) {
        p_antecedent.setPjiEffectif(p_saisieAntecedent.getDateDernierJourCalcule());
      }
      facade.initialiseElementBaseIndemnisationCourante(constituantsIndemnisation, p_antecedent, new Periode(p_saisieAntecedent.getDateDernierJourCalcule()));
      facade.miseAJourConstituantsIndemnisation(null, p_antecedent, constituantsIndemnisation, p_saisieAntecedent.getDateDernierJourCalcule(), new Periode(p_saisieAntecedent.getDateDernierJourCalcule(), p_saisieAntecedent.getDateDernierJourCalcule()));
      if (estAntecedentSP) {
        p_antecedent.setPjiEffectif(null);
      }
      montant = (MontantBaseAbstrait)facade.calculMontant(p_antecedent.getFormuleMontant(codeFormuleMontant), constituantsIndemnisation, p_saisieAntecedent.getDateDernierJourCalcule());
    }
    catch (CoucheLogiqueException e)
    {
      e.printStackTrace();
    }
    return montant;
  }
  
  protected CalendrierExecutionAvant alimenterUtAvant(SaisieAntecedent p_saisieAntecedent)
  {
    CalendrierExecutionAvant calendrierAvant = new CalendrierExecutionAvant();
    calendrierAvant.setPremierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    calendrierAvant.setDernierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    EtatAuDernierJourAvant etatAuDernierJourAvant = new EtatAuDernierJourAvant();
    calendrierAvant.setEtatAuDernierJourAvant(etatAuDernierJourAvant);
    
    alimenterEtatAuDernierJourAvant(calendrierAvant, p_saisieAntecedent);
    return calendrierAvant;
  }
  
  protected fr.unedic.cali.calcul.dom.UniteTraitement alimenterUtPendant(AttributionAssuranceSpec p_poursuite, SaisieAntecedent p_saisieAntecedent)
  {
    CalendrierExecutionCalculPeriodique calendrierPendant = instancierCalendrierExecutionCalcul();
    calendrierPendant.setEtatAttribution(1);
    calendrierPendant.setPremierJourIndemnisable(p_saisieAntecedent.getDateDernierJourCalcule());
    calendrierPendant.setDernierJourIndemnisable(p_saisieAntecedent.getDateDernierJourCalcule());
    p_poursuite.setCalendrierExecutionCalcul(calendrierPendant);
    
    fr.unedic.cali.calcul.dom.UniteTraitement utPendant = instancierUniteTraitement(Unite.get("jour"), new Periode(p_saisieAntecedent.getDateDernierJourCalcule(), p_saisieAntecedent.getDateDernierJourCalcule()));
    if (p_saisieAntecedent.getNombreJourIndemniseAREF() != null) {
      utPendant.setNbJoursFormationEnFinDUT(p_saisieAntecedent.getNombreJourIndemniseAREF().intValue());
    }
    if (p_saisieAntecedent.getNombreJourIndemniseARE() != null) {
      utPendant.setCumulJoursIndemnise(p_saisieAntecedent.getNombreJourIndemniseARE().intValue());
    }
    if (p_saisieAntecedent.getNombreMoisIndemnisationAssurance() != null) {
      utPendant.setNbMoisIndemniseAsu(p_saisieAntecedent.getNombreMoisIndemnisationAssurance().intValue());
    }
    if (p_saisieAntecedent.getCumulMoisActiviteReduite() != null)
    {
      ConstituantsCalculActiviteReduiteAsu ccar = new ConstituantsCalculActiviteReduiteAsu(p_saisieAntecedent.getCumulMoisActiviteReduite().intValue(), null, null);
      ccar.setCumulMoisNonIndemnise(p_saisieAntecedent.getNbMoisCivilsNonPayes());
      utPendant.setConstituantsCalculActiviteReduiteEnFinUT(ccar);
    }
    return utPendant;
  }
  
  protected CalendrierExecutionCalculPeriodique instancierCalendrierExecutionCalcul()
  {
    return new CalendrierExecutionCalcul();
  }
  
  protected fr.unedic.cali.calcul.dom.UniteTraitement instancierUniteTraitement(Unite p_uniteParDefautQuantites, Periode p_periode)
  {
    return new fr.unedic.cali.asu.calcul.dom.UniteTraitement(p_uniteParDefautQuantites, p_periode);
  }
}

/* Location:
 * Qualified Name:     GestionAntecedentCalculAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */