package fr.unedic.cali.asu.caa14.avant;

import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.cge01.avant.FacadeAvantLigneImpl;
import fr.unedic.cali.asu.cge01.avant.FacadeAvantLigneSansTrancheImpl;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.fabriques.FabriqueStrategieConvention2014;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.strategies.StrategieConventionARE14Spec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDsmTravailCalcul;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;

public class FacadeAvantLigneCAA14Impl
  extends FacadeAvantLigneImpl
{
  private static FacadeAvantLigneCAA14Impl s_instance = new FacadeAvantLigneCAA14Impl();
  
  public static FacadeAvantLigneCAA14Impl getInstance()
  {
    return s_instance;
  }
  
  public ResultatAvant executerAvant(AttributionSpec p_attribution, boolean p_avecPriseEnCompteEvenement, Damj p_dateEtude, boolean p_executionPersistante)
    throws CoucheLogiqueException
  {
    FabriqueStrategieConvention2014 fab = new FabriqueStrategieConvention2014();
    CritereStrategie cs = new CritereStrategie();
    cs.setDatePivot(p_attribution.getDateAttribution());
    StrategieConventionARE14Spec strat = (StrategieConventionARE14Spec)fab.getStrategie(cs);
    if (strat.estApresConventionARE14())
    {
      if (OutilsTrancheCalcul.estTrancheActive(p_attribution)) {
        return super.executerAvant(p_attribution, p_avecPriseEnCompteEvenement, p_dateEtude, p_executionPersistante);
      }
      return FacadeAvantLigneSansTrancheImpl.getInstance().executerAvant(p_attribution, p_avecPriseEnCompteEvenement, p_dateEtude, p_executionPersistante);
    }
    ResultatAvant resultatAvant = null;
    resultatAvant = new ResultatAvant(p_attribution.getDateAttribution(), new ArrayList(), false);
    resultatAvant.setDernierJourAvant(p_attribution.getDateAttribution());
    resultatAvant.setEtat(0);
    return resultatAvant;
  }
  
  public boolean doitExecuterAvant(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    FabriqueStrategieConvention2014 fab = new FabriqueStrategieConvention2014();
    CritereStrategie cs = new CritereStrategie();
    cs.setDatePivot(attribution.getDateAttribution());
    StrategieConventionARE14Spec strat = (StrategieConventionARE14Spec)fab.getStrategie(cs);
    if (strat.estApresConventionARE14()) {
      return true;
    }
    return false;
  }
  
  public Collection<?> recupererCarrence(AttributionSpec attribution)
  {
    if (!OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return FacadeAvantLigneSansTrancheImpl.getInstance().recupererCarrence(attribution);
    }
    return super.recupererCarrence(attribution);
  }
  
  public Damj rechercherPremierJourAvant(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    if (!OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return FacadeAvantLigneSansTrancheImpl.getInstance().rechercherPremierJourAvant(attribution);
    }
    return super.rechercherPremierJourAvant(attribution);
  }
  
  public boolean estUnContexteDeChomageEnCoursDeSuspensionAvecRupture(AttributionSpec attribution, Damj dateEtude)
  {
    if (!OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return FacadeAvantLigneSansTrancheImpl.getInstance().estUnContexteDeChomageEnCoursDeSuspensionAvecRupture(attribution, dateEtude);
    }
    return super.estUnContexteDeChomageEnCoursDeSuspensionAvecRupture(attribution, dateEtude);
  }
  
  public boolean estUnContexteDeChomageEnCoursDeSuspension(AttributionSpec attribution)
  {
    if (!OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return FacadeAvantLigneSansTrancheImpl.getInstance().estUnContexteDeChomageEnCoursDeSuspension(attribution);
    }
    return super.estUnContexteDeChomageEnCoursDeSuspension(attribution);
  }
  
  public QualificationPeriodes qualificationPeriodesPourAvant(ChronologiePeriodes chronologiePeriodes, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    Qualification qualification = new Qualification();
    return qualification.qualificationPeriodesPourAvant(chronologiePeriodes, attribution);
  }
  
  public void postTraitementQualification(UniteTraitementAvant ut, QualificationPeriodes qualificationPeriodes)
    throws CoucheLogiqueException
  {
    if (ut.getStatut() == 3)
    {
      FiltreNegation filtre = new FiltreNegation(new FiltreDsmTravailCalcul());
      qualificationPeriodes.setPeriodesSuspensives((ChronologiePeriodes)qualificationPeriodes.getPeriodesSuspensives().copier(filtre));
    }
    qualificationPeriodes.getPeriodesDecalantes().vider();
  }
}

/* Location:
 * Qualified Name:     FacadeAvantLigneCAA14Impl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */