package fr.unedic.cali.asu.caa14.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.antecedent.GestionAntecedentCalculAsuSpec;
import fr.unedic.cali.asu.caa14.antecedent.GestionAntecedentCalcul;
import fr.unedic.cali.asu.caa14.calcul.dom.DureeIndemnisation;
import fr.unedic.cali.asu.caa14.calcul.dom.FormuleMontantASPAREF;
import fr.unedic.cali.asu.caa14.calcul.dom.FormuleMontantRegimeGeneralASPARE;
import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.MajCi;
import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.MajCiTranche;
import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.PostTraitements;
import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels.TraitementActiviteReduite;
import fr.unedic.cali.asu.caa14.liquidation.outilsfonctionnels.RecuperationFormuleMontant;
import fr.unedic.cali.asu.calcul.FacadeCalculGammeImpl;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteGamme;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeDebutPec;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeFinDureeMaintienDroit;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetRevision;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.DefinitionStatutUtTraitementActiviteReduite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.fabriques.FabriqueStrategieConvention2014;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.strategies.StrategieConventionARE14Spec;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.outilsfonctionnels.RechercheDecisionsInterruptives;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.autresdoms.cohab.dom.PeriodeSousPensionInvaliditeChainee;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.calcul.OutillageCalculADate;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.TraitementPeriodes;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.EvenementChangementParametre;
import fr.unedic.cali.calcul.dom.EvenementFinPeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.EvenementLimiteIndemnisationPMVS;
import fr.unedic.cali.calcul.dom.EvenementMaintienEuropeenDJI;
import fr.unedic.cali.calcul.dom.EvenementPeriodesSuspensivesDisponibilite;
import fr.unedic.cali.calcul.dom.EvenementRejetDv;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.FinActionFormation;
import fr.unedic.cali.calcul.dom.periode.FinPeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.FinPeriodePensionInvaliditeChainee;
import fr.unedic.cali.calcul.dom.periode.PeriodeAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.PeriodeDisponibilite;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormationNonIndemniseeAbsenceHeure;
import fr.unedic.cali.calcul.dom.periode.PeriodeInterStageFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTEAvecImputation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnomalieI04;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoBlocageM12;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeBlocagePerteActiviteConservee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationASP;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationPMVS;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoRemplissage;
import fr.unedic.cali.calcul.outilsfonctionnels.DecoupageProratisation;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionForcage;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT.ElementContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ElementBaseIndemnisationFacade;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodesPriseEnCompte;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DureeIndemnisationAbstraite;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.Anomalie;
import fr.unedic.cali.outilsfonctionnels.GestionAnomalies;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDsmTravailCalcul;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreObjetChronoPeriodeCalculRemplissage;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravail;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.ResultatCalcul;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class FacadeCalculLigneCAA14Impl
  extends FacadeCalculGammeImpl
{
  private static final DureeCalendaire DUREE_6_MOIS = new DureeCalendaire(0, 6, 1);
  private static final int DUREE_PERTE_ACTIVITE_CONSERVE = 122;
  protected static final int DIX = 10;
  
  public int calculerCompteurNombreMoisIndemnisesSurUT(UniteTraitement ut, int nbMoisIndemniseEnDebutDUT)
  {
    int nbMoisIndemniseAsu = ut.getNbMoisIndemniseEnDebutDUT();
    
    Quantite quantiteIndemnise = ut.getQuantiteIndemnisee();
    if (quantiteIndemnise.getValeur().intValue() >= 1) {
      nbMoisIndemniseAsu += 1;
    }
    return nbMoisIndemniseAsu;
  }
  
  public int calculerCompteurNombreJoursIndemnisesSurUT(UniteTraitement ut, int cumulNombreJoursServi)
  {
    int nombreJourServiEnDebutUT = 0;
    nombreJourServiEnDebutUT = cumulNombreJoursServi + ut.getQuantiteIndemnisee().getValeur().intValue();
    ut.setEstCumulJoursIndemnise(true);
    return nombreJourServiEnDebutUT;
  }
  
  public void controleActiviteReduiteMaintienEuropeen(AttributionSpec attribution, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {}
  
  public ConstituantsCalculActiviteReduiteSpec creationConstituantsCalculActiviteReduite(AttributionSpec pAttribution, ContexteUT contexteUT, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    ConstituantsCalculActiviteReduiteAsu constituantsAR = new ConstituantsCalculActiviteReduiteAsu(0, null, null);
    
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
    if ((attribution instanceof RepriseSpec))
    {
      AttributionSpec attributionPrecedente = attribution.getAttributionPrecedente();
      if ((attributionPrecedente != null) && (attributionPrecedente.getCalendrierExecutionCalcul() != null) && (attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI() != null))
      {
        EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI();
        constituantsAR.setCumulJours(etatAuDji.getCumulJoursAR());
      }
    }
    else
    {
      constituantsAR.setCumulJours(0);
    }
    return constituantsAR;
  }
  
  public UniteTraitement creerUT(Periode periodeUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
    return produit.creerUT(periodeUT, attribution);
  }
  
  public ChronologiePeriodes decoupageEtProratisationPeriodesActivites(PeriodesPriseEnCompte periodesPriseEnCompte, int typePeriodeDeReference, ChronologiePeriodes chronologieDePeriodesAProratiser, Periode periodeUT)
    throws CoucheLogiqueException
  {
    Periode periodeDeReference = null;
    Iterator iterator = null;
    ChronologiePeriodes chronologie = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    iterator = periodesPriseEnCompte.getPeriodesParTypologie(typePeriodeDeReference).iterer();
    chronologie = new ChronologiePeriodes();
    while (iterator.hasNext())
    {
      objetChronoPeriode = (ObjetChronoPeriode)iterator.next();
      periodeDeReference = new Periode(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateFin());
      chronologie.ajouter(DecoupageProratisation.decoupageEtProratisationPeriodesActivites(periodeDeReference, chronologieDePeriodesAProratiser));
    }
    return chronologie;
  }
  
  public void determinerStatutUT(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    boolean absenceAuPointage = false;
    if (ut.getQualificationPeriodes().getPeriodesSuspensives() != null)
    {
      ChronologiePeriodes periodesSuspensives = ut.getQualificationPeriodes().getPeriodesSuspensives();
      periodesSuspensives.iterer();
      while (periodesSuspensives.encoreSuivant()) {
        if ((periodesSuspensives.elementSuivant() instanceof PeriodeAbsenceAuPointage))
        {
          ut.setStatut(6);
          absenceAuPointage = true;
        }
      }
    }
    if (!absenceAuPointage) {
      if (!GestionForcage.appliquerForcageStatut(attribution.getDemande(), ut)) {
        ut.setStatut(DefinitionStatutUtTraitementActiviteReduite.definirStatutUt(attribution, periodesDecalantes, ((ConstituantsCalculActiviteReduiteGamme)constituantsCalculActiviteReduite).getNbMoisEnPPA(), estEnFormation(ut), ut, arretProduitAvecRaison, this));
      }
    }
  }
  
  private boolean estEnFormation(UniteTraitement ut)
  {
    ChronologiePeriodes periodesSegmentantes = ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodesSegmentantes.iterer();
    while (periodesSegmentantes.encoreSuivant()) {
      if ((periodesSegmentantes.elementSuivant() instanceof PeriodeFormation)) {
        return true;
      }
    }
    return false;
  }
  
  public boolean epuisementQuantiteDroit(Damj dateEpuisementQuantite, AttributionSpec attribution, QuantiteDroitSpec quantiteDroitEpuisee, ConstituantsIndemnisation constituantsIndemnisation, UniteTraitement ut)
    throws ApplicativeException
  {
    return true;
  }
  
  public Damj getDateFinQuantiteDroit(Periode periode, AttributionSpec attribution, QuantiteDroitSpec quantiteDroit, ChronologiePeriodes chronologieRemplissage, Quantite quantiteAImputer, Damj dateDebutQuantiteDroit)
  {
    return OutillageCalculADate.remplirTrousChronologieParIndemnisation(chronologieRemplissage, quantiteAImputer, periode);
  }
  
  public Collection getEvtsChangementParametre(ConstituantsIndemnisation constituantsIndemnisation, Damj date)
  {
    List evtsRetour = new ArrayList();
    EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(date);
    Sjr sjr = ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getSjr();
    if ((evtParam.isNouveauRevalorisationSjr()) && 
      (!sjr.getDateDepart().deplacerVersAvant(DUREE_6_MOIS).estApres(date)))
    {
      EvenementChangementParametre evt = new EvenementChangementParametre("REVALORISATION", evtParam.getDateEvenement());
      
      evtsRetour.add(evt);
    }
    return evtsRetour;
  }
  
  public Quantite getQuantiteIndemnisableTheorique(Periode periode, AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, ContexteUT contexteUt)
  {
    return new QuantiteJour(new BigDecimal(periode.getDuree()));
  }
  
  public void imputerAvant(ObjetChronoPeriode periode, ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution)
    throws CoucheLogiqueException
  {}
  
  public void imputerQuantiteIndemnisationDuAuxSanctions(AttributionSpec attribution, UniteTraitement ut, PeriodeSuspensionDDTEAvecImputation periodeSuspensionDDTEAvecImputation, ConstituantsIndemnisation constituantsIndemnisation, ArretProduitAvecRaison arretProduitAvecRaison)
    throws ApplicativeException
  {}
  
  public void initialisationQuantitesIndemnisation(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution, Periode periodeUT)
    throws ApplicativeException
  {
    Collection collectionDurees = constituantsIndemnisation.getCollectionQuantiteDroit();
    if (collectionDurees != null)
    {
      Iterator iterator = collectionDurees.iterator();
      while (iterator.hasNext())
      {
        QuantiteDroitSpec duree = (QuantiteDroitSpec)iterator.next();
        if ((duree instanceof DureeIndemnisation))
        {
          duree.activer();
          initialiseElementBaseIndemnisationCourante(constituantsIndemnisation, attribution, periodeUT);
        }
      }
    }
  }
  
  public void initialiseElementBaseIndemnisationCourante(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec pAttribution, Periode periodeUT)
    throws CoucheLogiqueException
  {
    if (OutilsTrancheCalcul.estTrancheActive(pAttribution))
    {
      initialiseElementBaseIndemnisationCouranteTranche(constituantsIndemnisation, pAttribution, periodeUT);
    }
    else if (constituantsIndemnisation.getElementBaseIndemnisationCourant() == null)
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
      ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisationAREF();
      ElementBaseIndemnisation ebiAttrib = attribution.getElementBaseIndemnisation();
      
      Reglement reglementApplicable = ebiAttrib.getReglementApplicable();
      if (reglementApplicable != null) {
        elementBaseIndemnisationCourant.setReglementApplicable(reglementApplicable);
      }
      Quantite affiliationRequisePourPRA = ebiAttrib.getAffiliationRequisePourPRA();
      if (affiliationRequisePourPRA != null) {
        elementBaseIndemnisationCourant.setAffiliationRequisePourPRA(affiliationRequisePourPRA);
      }
      SalaireReference salaireReference = ebiAttrib.getSalaireReference();
      if (salaireReference != null) {
        elementBaseIndemnisationCourant.setSalaireReference(salaireReference);
      }
      BigDecimal nombreHeureTravaillesEtendu = ebiAttrib.getNombreHeureTravaillesEtendu();
      if (nombreHeureTravaillesEtendu != null) {
        elementBaseIndemnisationCourant.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtendu);
      }
      BigDecimal nombreHeuresTravailleesPlafonnees = ebiAttrib.getNombreHeuresTravailleesPlafonnees();
      if (nombreHeuresTravailleesPlafonnees != null) {
        elementBaseIndemnisationCourant.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonnees);
      }
      Periode prc = ebiAttrib.getPrc();
      if (prc != null) {
        elementBaseIndemnisationCourant.setPrc(prc);
      }
      elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(ebiAttrib.getNbJoursEmploiSurPrc());
      elementBaseIndemnisationCourant.setCoefficientHoraireJour(ebiAttrib.getCoefficientHoraireJour());
      if (attribution.getElementBaseIndemnisation().getCoefficientSaisonnier() != null) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(attribution.getElementBaseIndemnisation().getCoefficientSaisonnier());
      } else {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1"));
      }
      if (attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel() != null) {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel());
      } else {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(new BigDecimal("1"));
      }
      elementBaseIndemnisationCourant.setTypeCaractereSaisonnierRetenu(ebiAttrib.getTypeCaractereSaisonnierRetenu());
      
      elementBaseIndemnisationCourant.setIsConditionCaractereSaisonnierParRythme(ebiAttrib.isConditionCaractereSaisonnierParRythme());
      
      elementBaseIndemnisationCourant.setSjr(ebiAttrib.getSjr());
      
      elementBaseIndemnisationCourant.setListePensionInvalidite(ebiAttrib.getListePensionInvalidite());
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, attribution.getDemandeur(), attribution.getPji().veille(), attribution.getDateAttribution()));
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("1"));
      
      elementBaseIndemnisationCourant.setSjc(new Sjc(new BigDecimal("0")));
      elementBaseIndemnisationCourant.setProduitMontantRetenu(attribution.getProduitMontantRetenu());
      elementBaseIndemnisationCourant.setProduitAreActif(ebiAttrib.getProduitAreActif());
      
      elementBaseIndemnisationCourant.setDateMaintienEuropeen(OutilsMaintienEuropeenEessiASU.rechercherDateMaintienEuropeen(pAttribution, periodeUT, constituantsIndemnisation));
      
      elementBaseIndemnisationCourant.setContextePAPPresent(ebiAttrib.isContextePAPPresent());
      
      elementBaseIndemnisationCourant.setContextePapParlementaire(ebiAttrib.isContextePapParlementaire());
      if (ebiAttrib.isContextePAPPresent())
      {
        elementBaseIndemnisationCourant.setSjrInitial(ebiAttrib.getSjr());
        
        PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(attribution.getDemandeur(), recupererPremierJourExecutableNcp(attribution));
        
        BigDecimal montantAV = BigDecimal.ZERO;
        Damj dateRevalorisation = attribution.getDateAttribution();
        if (periodeAvCourante != null)
        {
          montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
          elementBaseIndemnisationCourant.setDateEffetAV(recupererPremierJourExecutableNcp(attribution));
          dateRevalorisation = Damj.max(attribution.getDateAttribution(), periodeAvCourante.getDateDebut());
        }
        Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(ebiAttrib.getSjr(), dateRevalorisation);
        BigDecimal coeffAV = montantAV.divide(sjrrp.getSalaire(), 10, 4);
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
        elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrrp.getSalaire()));
      }
      constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    }
  }
  
  public void initialiseElementBaseIndemnisationCouranteTranche(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec pAttribution, Periode periodeUT)
    throws CoucheLogiqueException
  {
    if (constituantsIndemnisation.getElementBaseIndemnisationCourant() == null)
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
      ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisationAREF();
      TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(pAttribution);
      
      Reglement reglementApplicable = tranche.getReglement();
      if (reglementApplicable != null) {
        elementBaseIndemnisationCourant.setReglementApplicable(reglementApplicable);
      }
      Quantite affiliationRequisePourPRA = tranche.getAffiliationRequisePourPRA();
      if (affiliationRequisePourPRA != null) {
        elementBaseIndemnisationCourant.setAffiliationRequisePourPRA(affiliationRequisePourPRA);
      }
      SalaireReference salaireReference = tranche.getSalaireReferenceInitialSpectacle();
      if (salaireReference != null) {
        elementBaseIndemnisationCourant.setSalaireReference(salaireReference);
      }
      BigDecimal nombreHeureTravaillesEtendu = tranche.getNombreHeuresTravailleesEtendu();
      if (nombreHeureTravaillesEtendu != null) {
        elementBaseIndemnisationCourant.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtendu);
      }
      BigDecimal nombreHeuresTravailleesPlafonnees = tranche.getNombreHeuresTravailleesPlafonne();
      if (nombreHeuresTravailleesPlafonnees != null) {
        elementBaseIndemnisationCourant.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonnees);
      }
      Periode prc = tranche.getPrc();
      if (prc != null) {
        elementBaseIndemnisationCourant.setPrc(prc);
      }
      elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(tranche.getNombreJoursEmploiDansPRC());
      elementBaseIndemnisationCourant.setCoefficientHoraireJour(tranche.getCoefficientHoraireJour());
      if (tranche.getCoefficientSaisonnier() != null) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(tranche.getCoefficientSaisonnier());
      } else {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1"));
      }
      if (tranche.getCoefficientTempsPartiel() != null) {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(tranche.getCoefficientTempsPartiel());
      } else {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(new BigDecimal("1"));
      }
      elementBaseIndemnisationCourant.setTypeCaractereSaisonnierRetenu(tranche.getNatureCoefficientSaisonnier());
      
      elementBaseIndemnisationCourant.setIsConditionCaractereSaisonnierParRythme(tranche.isA3ansActiviteEn5ans());
      
      elementBaseIndemnisationCourant.setSjr(tranche.getSjr());
      
      elementBaseIndemnisationCourant.setListePensionInvalidite(tranche.getListePensionsInvalidites());
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, attribution.getDemandeur(), attribution.getPji().veille(), attribution.getDateAttribution()));
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("1"));
      
      elementBaseIndemnisationCourant.setSjc(new Sjc(new BigDecimal("0")));
      elementBaseIndemnisationCourant.setProduitMontantRetenu(attribution.getProduitMontantRetenu());
      elementBaseIndemnisationCourant.setProduitAreActif(tranche.getProduitAreActif());
      
      elementBaseIndemnisationCourant.setDateMaintienEuropeen(OutilsMaintienEuropeenEessiASU.rechercherDateMaintienEuropeen(pAttribution, periodeUT, constituantsIndemnisation));
      
      elementBaseIndemnisationCourant.setContextePAPPresent(tranche.isContextePAPPresent());
      
      elementBaseIndemnisationCourant.setContextePapParlementaire(tranche.estContextePapParlementaire());
      
      elementBaseIndemnisationCourant.setSjrInitial((Sjr)tranche.getSjr().copie());
      if (tranche.isContextePAPPresent())
      {
        PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(attribution.getDemandeur(), recupererPremierJourExecutableNcp(attribution));
        
        BigDecimal montantAV = BigDecimal.ZERO;
        Damj dateRevalorisation = tranche.getDateAttribution();
        if (periodeAvCourante != null)
        {
          montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
          elementBaseIndemnisationCourant.setDateEffetAV(recupererPremierJourExecutableNcp(attribution));
          dateRevalorisation = Damj.max(tranche.getDateAttribution(), periodeAvCourante.getDateDebut());
        }
        Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(tranche.getSjr(), dateRevalorisation);
        BigDecimal coeffAV = montantAV.divide(sjrrp.getSalaire(), 10, 4);
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
        elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrrp.getSalaire()));
      }
      constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    }
  }
  
  public int initialiserCompteurFormation(AttributionSpec attribution)
  {
    return 0;
  }
  
  public int initialiserCumulNombreJoursServi(AttributionSpec pAttribution)
    throws CoucheLogiqueException
  {
    int cumulNombreJoursServi = 0;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
    if (((attribution instanceof RepriseSpec)) || ((attribution instanceof RevisionSpec))) {
      if ((attribution.getAttributionPrecedente() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI() != null))
      {
        EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI();
        cumulNombreJoursServi = etatAuDji.getCumulJoursIndemnise();
      }
    }
    return cumulNombreJoursServi;
  }
  
  public int initialiserNombreMoisIndemnise(AttributionSpec pAttribution, UniteTraitement ut, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    int nbMoisIndemniseAsu = 0;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
    if (((attribution instanceof RepriseSpec)) && 
      (attribution.getAttributionPrecedente() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI() != null))
    {
      EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI();
      if (etatAuDji.isEstNbMoisIndemniseAsu()) {
        nbMoisIndemniseAsu = etatAuDji.getNbMoisIndemniseAsu();
      }
      if ((attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getDernierJourIndemnisable() != null) && (ut.getPeriode().contient(attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getDernierJourIndemnisable()))) {
        if (attribution.getAttributionPrecedente().estNeutralise())
        {
          nbMoisIndemniseAsu--;
        }
        else
        {
          ContexteUT.ElementContexteUT elementContexteUT = contexteUT.getElementContexteUT(attribution.getAttributionPrecedente());
          if ((elementContexteUT.getQuantiteIndemnisee() != null) && (elementContexteUT.getQuantiteIndemnisee().getValeur() != null) && (elementContexteUT.getQuantiteIndemnisee().getValeur().intValue() > 0) && (ut.getQuantiteIndemnisee() != null) && (ut.getQuantiteIndemnisee().getValeur() != null) && (ut.getQuantiteIndemnisee().getValeur().intValue() > 0)) {
            nbMoisIndemniseAsu--;
          }
        }
      }
    }
    return nbMoisIndemniseAsu;
  }
  
  public ElementBaseIndemnisationFacade mapperUTVersElementBaseIndemnisation(UniteTraitement ut, AttributionSpec attribution)
  {
    ElementBaseIndemnisationFacade elt = new ElementBaseIndemnisationFacade();
    ElementBaseIndemnisation eltBase = null;
    eltBase = (ElementBaseIndemnisation)ut.getConstituantsIndemnisationEnFinUT().getElementBaseIndemnisationCourant();
    if (eltBase.getCoefficientSaisonnier() != null) {
      elt.setCoefficientSaisonnier(eltBase.getCoefficientSaisonnier().toString());
    }
    if (eltBase.getCoefficientTempsPartiel() != null) {
      elt.setCoefficientTempsPartiel(eltBase.getCoefficientTempsPartiel().toString());
    }
    if (eltBase.getMontantPensionInvaliditeADeduire() != null) {
      elt.setMontantPensionInvaliditeADeduire(eltBase.getMontantPensionInvaliditeADeduire().toString());
    }
    if ((eltBase.getSjr() != null) && (eltBase.getSjr().getSalaire() != null)) {
      elt.setSjr(eltBase.getSjr().getSalaire().toString());
    }
    return elt;
  }
  
  public ConstituantsIndemnisation miseAJourConstituantsIndemnisation(UniteTraitement ut, AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour, Periode periode)
    throws CoucheLogiqueException
  {
    if (OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return MajCiTranche.miseAJourConstituantsIndemnisation(attribution, constituantsIndemnisation, dateDeMiseAjour);
    }
    return MajCi.miseAJourConstituantsIndemnisation(attribution, constituantsIndemnisation, dateDeMiseAjour);
  }
  
  public void miseAJourConstituantsIndemnisationADate(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj date, ChronologiePeriodes chronologiePeriodesSanctions)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation elementBaseIndemnisationCourant = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, attribution.getDemandeur(), date.veille(), attribution.getDateAttribution()));
    if (elementBaseIndemnisationCourant.isContextePAPPresent())
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(BigDecimal.ZERO);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(BigDecimal.ZERO);
      
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(((Attribution)attribution).getDemandeur(), date.veille());
      if (periodeAvCourante != null)
      {
        Damj dateDepart = Damj.max(attribution.getDateAttribution(), periodeAvCourante.getDateDebut());
        
        Sjr sjrDepart = RevalorisationSalaire.revaloriserSjrTranche((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant(), dateDepart);
        
        BigDecimal coeffAV = periodeAvCourante.getQuantiteEuro().getValeur().divide(sjrDepart.getSalaire(), 10, 4);
        
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
        
        Sjr sjrCourant = RevalorisationSalaire.revaloriserSjrTranche((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant(), date.veille());
        
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
        elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrCourant.getSalaire()));
        
        elementBaseIndemnisationCourant.setDateEffetAV(date.veille());
      }
      else
      {
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(BigDecimal.ZERO);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("1.00"));
    }
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAJourCumulAR(UniteTraitement ut, AttributionSpec attribution, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, ContexteUT contexteUT, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    return constituantsCalculActiviteReduite;
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAjourConstituantsCalculActiviteReduite(AttributionSpec attribution, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, Damj dateDeMiseAjour, ConstituantsIndemnisation constituantIndemnisation)
    throws CoucheLogiqueException
  {
    return constituantsCalculActiviteReduite;
  }
  
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes chronologiePeriodes, AttributionSpec attribution, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    return new Qualification().qualificationPeriodes(chronologiePeriodes, attribution);
  }
  
  public void realiserDetectionFinDeProduitPourSuivi(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    ArretProduitAvecRaison arretProduitAvecRaison = ut.getArretProduitAvecRaison();
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(contexteUT.getPeriodeUT().getDebut());
    FabriqueStrategieConvention2014 fabriqueAre14 = FabriqueStrategieConvention2014.getInstance();
    StrategieConventionARE14Spec strategieARE14 = (StrategieConventionARE14Spec)fabriqueAre14.getStrategie(critere);
    if ((strategieARE14.estApresConventionARE14()) && (attribution.getDateAttribution().estApresOuCoincideAvec(FabriqueStrategieConvention2014.DATE_APPLICATION)))
    {
      genererEnquetesFinDeDroit(attribution, ut, contexteUT, arretProduitAvecRaison);
    }
    else if ((strategieARE14.estApresConventionARE14()) && (attribution.getDateAttribution().estAvant(FabriqueStrategieConvention2014.DATE_APPLICATION)))
    {
      genererEnquetesFinDeDroit(attribution, ut, contexteUT, arretProduitAvecRaison);
      genererEnquetesFinDeDroitAsp(attribution, ut, contexteUT, arretProduitAvecRaison);
    }
    else
    {
      genererEnquetesFinDeDroitAsp(attribution, ut, contexteUT, arretProduitAvecRaison);
    }
  }
  
  private void genererEnquetesFinDeDroit(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    Damj finDeProduit = null;
    if ((arretProduitAvecRaison.isRaisonsContientRaison(1)) && 
      (!arretProduitAvecRaison.getLendemainFinQuantiteIndemnisationArretCalcul().isEmpty()))
    {
      finDeProduit = ((Temporel)arretProduitAvecRaison.getLendemainFinQuantiteIndemnisationArretCalcul().iterator().next()).getDateDebut().veille();
      if (!contexteUT.existeAERenFinASU(finDeProduit))
      {
        GestionSuivi.enregistrerEnquetePbjcNcp(attribution, finDeProduit, 38, 0, true, null, this, ut.getConstituantsIndemnisationEnFinUT());
        
        GestionSuivi.enregistrerEnquetePbjcNcp(attribution, finDeProduit, 5, 0, true, null, this, ut.getConstituantsIndemnisationEnFinUT());
      }
    }
  }
  
  private void genererEnquetesFinDeDroitAsp(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    if ((arretProduitAvecRaison.isRaisonsContientRaison(1)) || (arretProduitAvecRaison.isRaisonsContientRaison(4))) {
      GestionSuivi.enregistrerEnquetePbjcNcp(attribution, arretProduitAvecRaison.recupereLendemainDateArret().veille(), 36, 0, true, null, this, ut.getConstituantsIndemnisationEnFinUT());
    }
  }
  
  protected void genererEnquetesFinASP(AttributionSpec attribution, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison)
  {
    Iterator it = ut.getConstituantsIndemnisationEnFinUT().getCollectionQuantiteDroit().iterator();
    while (it.hasNext())
    {
      QuantiteDroit duree = (QuantiteDroit)it.next();
      if ((duree instanceof DureeIndemnisation)) {
        if ((duree.getQuantiteCourante() == null) || (duree.getQuantiteCourante().getValeurEntiere() == 0)) {
          GestionSuivi.enregistrerEnquetePbjcNcp(attribution, arretProduitAvecRaison.recupereLendemainDateArret().veille(), 35, 0, true, null, this, ut.getConstituantsIndemnisationEnFinUT());
        } else if ((duree.getQuantiteCourante() != null) || (duree.getQuantiteCourante().getValeurEntiere() > 0)) {
          GestionSuivi.enregistrerEnquetePbjcNcp(attribution, arretProduitAvecRaison.recupereLendemainDateArret().veille(), 34, 0, true, null, this, ut.getConstituantsIndemnisationEnFinUT());
        }
      }
    }
  }
  
  public AttributionSpec rechercherAttributionPrecedenteSurLUT(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    return ((AttributionAssuranceSpec)p_attribution).getAttributionPrecedente();
  }
  
  public boolean recuperationAlimentationNombreMoisIndemnise(AttributionSpec p_attribution)
  {
    return false;
  }
  
  public ChronologiePeriodes recupererPeriodesLieesAuContexte(ContexteUT p_contexteUT, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePeriodes = new ChronologiePeriodes();
    
    Collection collectionPeriode = p_contexteUT.getPeriodesInterProduitsSurUTDateDepartAttributionPourGamme(p_attribution, "ASU");
    
    chronologiePeriodes.ajouter(collectionPeriode);
    
    Collection periodesInterProduitOdASU = p_contexteUT.getPeriodesInterProduitsSurUTDateDepartAttributionPourGamme(p_attribution, "ASU");
    
    chronologiePeriodes.ajouter(periodesInterProduitOdASU);
    
    chronologiePeriodes.ajouter(RechercheDecisionsInterruptives.rechercher(p_attribution.getDemandeur(), OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(p_attribution), p_attribution));
    
    chronologiePeriodes.ajouter(OutilsMaintienEuropeenEessiASU.getListesPeriodesMaintienEuropeen(p_attribution));
    if (p_contexteUT.getPeriodeUT().getDebut().estApresOuCoincideAvec(FabriqueStrategieConvention2014.DATE_APPLICATION))
    {
      Iterator ite = ((AttributionAssuranceSpec)p_attribution).getListeActiviteConservee().iterer();
      while (ite.hasNext())
      {
        TravailSpec activite = (TravailSpec)ite.next();
        if (activite.getDateFin().estContenueDans(p_contexteUT.getPeriodeUT()))
        {
          boolean estSup122jours = activite.getPeriode().getDuree() >= 122;
          if ((estSup122jours) && (RechercheConditionChomageInvolontaire.getInstance().determinerChomageNonLegitime(activite)))
          {
            if (!estDecisionneeSuiteActiviteConserveePerdue(activite, p_attribution))
            {
              chronologiePeriodes.ajouter(new ObjetChronoBlocageM12(activite.getDateFin(), p_attribution.getRsod()));
              chronologiePeriodes.ajouter(new ObjetChronoPeriodeBlocagePerteActiviteConservee(activite.getDateFin().lendemain(), p_attribution.getRsod()));
              
              genererEnqueteSuiteOrdonnancementExamen(p_attribution, activite.getDateFin());
            }
          }
          else if ((!estDecisionneeSuiteActiviteConserveePerdue(activite, p_attribution)) && (!estDemandeApresActiviteConserveePerdue(activite.getDateFin(), p_attribution)) && (!genererEnqueteSuiteOrdonnancementExamen(p_attribution, activite.getDateFin()))) {
            chronologiePeriodes.ajouter(new ObjetChronoAnomalieI04(activite.getDateFin(), p_attribution.getRsod()));
          }
        }
      }
    }
    return chronologiePeriodes;
  }
  
  private boolean genererEnqueteSuiteOrdonnancementExamen(AttributionSpec attribution, Damj dateFCT)
    throws CoucheLogiqueException
  {
    boolean resultat = false;
    if (dateFCT.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Ordonnancement examen")))
    {
      GestionSuivi.enregistrerEnquetePbjcNcp(attribution, dateFCT, 48, 0, true, null, this, null);
      
      resultat = true;
    }
    return resultat;
  }
  
  public boolean estDecisionneeSuiteActiviteConserveePerdue(TravailSpec p_activite, AttributionSpec p_attribution)
  {
    Map<TravailSpec, DemandeSpec> maps = OutilsRevisions.getMapFctsAssociees(p_attribution.getDemandeur());
    DemandeSpec demande = (DemandeSpec)maps.get(p_activite);
    return (demande != null) && (demande.estDecisionnee());
  }
  
  private boolean estDemandeApresActiviteConserveePerdue(Damj dateFct, AttributionSpec attribution)
  {
    return OutilRecherche.rechercherDemandeSuivante(attribution.getDemande().getChronologieDemandesAssuranceSansCourante(), dateFct.veille(), new FiltreDemandePourERE("ASU_28")) != null;
  }
  
  public EtatAuDji renseignerEtatAuDji(UniteTraitement p_derniereUT, CalendrierExecutionCalculPeriodique p_calendrier, AttributionSpec p_attribution, EtatAuDji p_etatAuDji)
    throws CoucheLogiqueException
  {
    int reliquatCumulAR = 0;
    EtatAuDjiGamme etatAuDji = new EtatAuDjiGamme();
    Quantite reliquatDureeIndemnisation = null;
    etatAuDji.setMontant(p_etatAuDji.getMontant());
    reliquatCumulAR = ((ConstituantsCalculActiviteReduiteGamme)p_derniereUT.getConstituantsCalculActiviteReduiteEnFinUT()).getCumul();
    etatAuDji.setCumulMoisActiviteReduite(reliquatCumulAR);
    reliquatDureeIndemnisation = recupererReliquatDureeIndemnisation(p_derniereUT);
    if (reliquatDureeIndemnisation != null)
    {
      etatAuDji.setReliquatDureeIndemnisation(new Quantite(reliquatDureeIndemnisation.getValeur().setScale(0), reliquatDureeIndemnisation.getUnite()));
      
      etatAuDji.setReliquatDureeIndemnisationAvecMaintien(etatAuDji.getReliquatDureeIndemnisation());
    }
    etatAuDji.setCumulJoursAR(((ConstituantsCalculActiviteReduiteAsu)p_derniereUT.getConstituantsCalculActiviteReduiteEnFinUT()).getCumulJours());
    etatAuDji.setCumulJoursIndemnise(p_derniereUT.getCumulJoursIndemnise());
    etatAuDji.setNbJourAREF(p_derniereUT.getNbJoursFormationEnFinDUT());
    etatAuDji.setNbMoisIndemniseAsu(p_derniereUT.getNbMoisIndemniseAsu());
    etatAuDji.setEstNbMoisIndemniseAsu(p_derniereUT.isEstNbMoisIndemniseAsu());
    return etatAuDji;
  }
  
  private Quantite recupererReliquatDureeIndemnisation(UniteTraitement p_derniereUT)
  {
    Quantite reliquatDureeIndemnisation = null;
    Collection collectionQuantiteDroit = p_derniereUT.getConstituantsIndemnisationEnFinUT().getCollectionQuantiteDroit();
    QuantiteIndemnisationSpec quantiteIndemnisation = null;
    if (collectionQuantiteDroit != null)
    {
      Iterator iterator = collectionQuantiteDroit.iterator();
      while (iterator.hasNext())
      {
        QuantiteDroitSpec quantiteDroit = (QuantiteDroitSpec)iterator.next();
        if ((quantiteDroit instanceof QuantiteIndemnisationSpec))
        {
          quantiteIndemnisation = (QuantiteIndemnisationSpec)quantiteDroit;
          if (quantiteDroit.getEtat() == 1) {
            break;
          }
        }
      }
    }
    if (quantiteIndemnisation != null)
    {
      if (quantiteIndemnisation.getEtat() == 1) {
        reliquatDureeIndemnisation = quantiteIndemnisation.getQuantiteCourante();
      } else if (quantiteIndemnisation.getEtat() == 2) {
        reliquatDureeIndemnisation = new QuantiteJour(BigDecimal.ZERO);
      }
    }
    else {
      reliquatDureeIndemnisation = new QuantiteJour(BigDecimal.ZERO);
    }
    return reliquatDureeIndemnisation;
  }
  
  public void traitementPeriodeSegmentante(AttributionSpec p_attribution, ObjetChronoPeriode p_periode, ConstituantsIndemnisation p_constituantsIndemnisation, UniteTraitement p_ut, PeriodeAnalyseSpec p_pa, ArretProduitAvecRaison p_arretProduitAvecRaison, ChronologiePeriodes p_periodesAnalyses)
    throws ApplicativeException
  {
    if (((p_periode instanceof PeriodeSousPensionInvaliditeChainee)) && (p_periode.getDateDebut().estApresOuCoincideAvec(p_attribution.getPji())))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().add(((PeriodeSousPensionInvaliditeChainee)p_periode).getMontant().getValeur()));
    }
    else if (((p_periode instanceof FinPeriodePensionInvaliditeChainee)) && (((p_pa != null) && (p_pa.getDateDebut().equals(p_periode.getDateDebut()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().subtract(((FinPeriodePensionInvaliditeChainee)p_periode).getQuantiteEuro().getValeur()));
      
      p_ut.ajouterEvenement(new EvenementFinPeriodePensionInvalidite(p_periode.getDateDebut().veille()));
    }
    else if ((p_periode instanceof PeriodeFormation))
    {
      if (((PeriodeFormation)p_periode).estEffective()) {
        passerEnIndemnisationAvecFormation(p_periode, p_constituantsIndemnisation);
      } else {
        passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
      }
    }
    else if (((p_periode instanceof PeriodeInterStageFormation)) || ((p_periode instanceof FinActionFormation)))
    {
      passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
    }
    else if ((p_periode instanceof ObjetChronoPeriodeDebutPec))
    {
      OutilsMaintienEuropeenEessiASU.controlerEtEmettreEnqueteMaintienEuropeen(p_attribution, p_constituantsIndemnisation, p_periode.getDateDebut(), this, null, p_ut);
      passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
    }
    else if (((p_periode instanceof PeriodeAvantageVieillesse)) && (p_periode.getDateDebut().estApresOuCoincideAvec(p_attribution.getPji())))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      BigDecimal montantAv = null;
      if ((elementBaseIndemnisation.getDateEffetAV() == null) || (elementBaseIndemnisation.getDateEffetAV().estAvant(p_periode.getDateDebut())))
      {
        montantAv = ((PeriodeAvantageVieillesse)p_periode).getQuantiteEuro().getValeur();
        elementBaseIndemnisation.setDateEffetAV(p_periode.getDateDebut());
      }
      else if (elementBaseIndemnisation.getDateEffetAV().coincideAvec(p_periode.getDateDebut()))
      {
        montantAv = elementBaseIndemnisation.getMontantAvantageVieillesse().add(((PeriodeAvantageVieillesse)p_periode).getQuantiteEuro().getValeur());
      }
      if (montantAv != null)
      {
        elementBaseIndemnisation.setMontantAvantageVieillesse(montantAv);
        if ((elementBaseIndemnisation.getSjr() != null) && (elementBaseIndemnisation.getSjr().getSalaire() != null) && (!elementBaseIndemnisation.getSjr().getSalaire().equals(new BigDecimal("0.00"))))
        {
          BigDecimal coeffAV = montantAv.divide(elementBaseIndemnisation.getSjr().getSalaire(), 10, 4);
          
          elementBaseIndemnisation.setCoefficientAvantageVieillesse(coeffAV);
        }
      }
    }
    else if (((p_periode instanceof FinPeriodeAvantageVieillesse)) && (((p_pa != null) && (p_pa.getDateDebut().equals(p_periode.getDateDebut()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      elementBaseIndemnisation.setCoefficientAvantageVieillesse(new BigDecimal("0"));
      elementBaseIndemnisation.setMontantAvantageVieillesse(new BigDecimal("0"));
    }
  }
  
  public void traitementPeriodesAlertantes(AttributionSpec p_attribution, ObjetChronoPeriode p_periode, ConstituantsIndemnisation p_constituantsIndemnisation, UniteTraitement p_ut, PeriodeAnalyseSpec p_pa, ArretProduitAvecRaison p_arretProduitAvecRaison)
    throws ApplicativeException
  {
    if (((p_periode instanceof ObjetChronoBlocageM12)) && ((p_periode.getDateDebut().estAvant(p_pa.getDateFin())) || ((p_periode.getDateDebut().coincideAvec(p_pa.getDateFin())) && (p_arretProduitAvecRaison.getPeriodesInterruptivesDefinitives().size() == 1) && (estBlocageM12(p_arretProduitAvecRaison)) && (p_periode.getDateDebut().lendemain().coincideAvec(p_arretProduitAvecRaison.recupereLendemainDateArret())) && ((p_arretProduitAvecRaison.recupererLendemainDateArretIndemnisation() == null) || (!p_periode.getDateDebut().lendemain().coincideAvec(p_arretProduitAvecRaison.recupererLendemainDateArretIndemnisation())))))) {
      GestionAnomalies.ajouteAnomalie(new Anomalie("M12", p_periode.getDateDebut(), ""), p_attribution.getDemandeur());
    } else if (((p_periode instanceof ObjetChronoAnomalieI04)) && ((p_periode.getDateDebut().estAvant(p_pa.getDateFin())) || ((p_periode.getDateDebut().coincideAvec(p_pa.getDateFin())) && (p_arretProduitAvecRaison.getPeriodesInterruptivesDefinitives().isEmpty()) && (!p_arretProduitAvecRaison.isRaisonsContientRaison(1)) && (!p_arretProduitAvecRaison.isRaisonsContientRaison(2))))) {
      GestionAnomalies.ajouteAnomalie(new Anomalie("I04", p_periode.getDateDebut(), ""), p_attribution.getDemandeur());
    }
  }
  
  private boolean estBlocageM12(ArretProduitAvecRaison p_arretProduitAvecRaison)
  {
    for (Object o : p_arretProduitAvecRaison.getPeriodesInterruptivesDefinitives()) {
      if ((o instanceof ObjetChronoPeriodeBlocagePerteActiviteConservee)) {
        return true;
      }
    }
    return false;
  }
  
  public void traitementPeriodesDecalantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduiteSpec, UniteTraitement p_ut, ConstituantsIndemnisation p_constituantsIndemnisation, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    TraitementActiviteReduite.traitementPeriodesDecalantes(p_periodes, p_ut);
  }
  
  public void traitementPeriodesGelantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduiteSpec, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {}
  
  public void traitementPeriodesSuspensives(AttributionSpec p_attribution, ChronologiePeriodes p_periodes, PeriodeAnalyseSpec p_pa)
    throws CoucheLogiqueException
  {
    Quantite quantiteSuspensive = TraitementPeriodes.getQuantiteSuspensive(p_pa.getPeriode(), p_pa.getQuantiteIndemnisable(), p_periodes);
    
    p_pa.setQuantiteNonIndemnisee(p_pa.getQuantiteNonIndemnisee().ajouter(quantiteSuspensive));
  }
  
  public void traiterPeriodeInterruptiveDefinitive(AttributionSpec attribution, UniteTraitement ut, ObjetChronoPeriode objetChronoPeriode, ArretProduitAvecRaison arretProduitAvecRaison, CalendrierExecutionCalculPeriodique calendrier)
    throws CoucheLogiqueException
  {
    if ((objetChronoPeriode instanceof PeriodeFormationNonIndemniseeAbsenceHeure))
    {
      GestionAnomalies.ajouteAnomalie(new Anomalie("M06", objetChronoPeriode.getDateDebut(), ""), attribution.getDemandeur());
    }
    else if ((objetChronoPeriode instanceof ObjetChronoPeriodeFinDureeMaintienDroit))
    {
      ut.ajouterEvenement(new EvenementMaintienEuropeenDJI(objetChronoPeriode.getDateDebut().veille()));
    }
    else if ((objetChronoPeriode instanceof ObjetChronoPeriodeLimiteIndemnisationPMVS))
    {
      ut.ajouterEvenement(new EvenementLimiteIndemnisationPMVS(objetChronoPeriode.getDateDebut().veille()));
    }
    else if ((objetChronoPeriode instanceof PeriodeDisponibilite))
    {
      ut.ajouterEvenement(new EvenementPeriodesSuspensivesDisponibilite(objetChronoPeriode.getDateDebut().veille(), ((PeriodeDisponibilite)objetChronoPeriode).getLibelle()));
      if (((PeriodeDisponibilite)objetChronoPeriode).doitCreerEnquete()) {
        GestionSuivi.enregistrerEnquetePbjcNcp(attribution, objetChronoPeriode.getDateDebut().veille(), 50, 0, true, null, this, null);
      }
    }
    else if (((objetChronoPeriode instanceof ObjetChronoPeriodeRejetRevision)) && 
      (((ObjetChronoPeriodeRejetRevision)objetChronoPeriode).isEstRejetDV()))
    {
      ut.ajouterEvenement(new EvenementRejetDv(objetChronoPeriode.getDateDebut()));
    }
  }
  
  public boolean verifierConditionExecutionEtEventuelAbandon(AttributionSpec attribution, ContexteUT contexteUT, Periode periodeUT, CalendrierExecutionCalculSpec calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    if (!attribution.estPjiEffectif())
    {
      calendrierExecutionCalcul.setEtatAttribution(4);
      return false;
    }
    return true;
  }
  
  public boolean verifierImputationDuree(UniteTraitement p_ut, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    return true;
  }
  
  public MontantBaseSpec calculMontant(FormuleMontantSpec p_formuleMontant, ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    return p_formuleMontant.calculer(p_constituantsIndemnisation, p_dateCalcul);
  }
  
  public ConstituantsIndemnisation creationConstituantsIndemnisation(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    Collection collectionDurees = null;
    collectionDurees = new ArrayList(((AttributionAssuranceSpec)p_attribution).getListeDurees());
    convertirDureeIndemnisationEnAsp(collectionDurees);
    constituantsIndemnisation.setCollectionQuantiteDroit(collectionDurees);
    return constituantsIndemnisation;
  }
  
  private void convertirDureeIndemnisationEnAsp(Collection p_collection)
  {
    Iterator ite = p_collection.iterator();
    Collection collectionDureeAsp = new ArrayList();
    while (ite.hasNext())
    {
      QuantiteDroitSpec duree = (QuantiteDroitSpec)ite.next();
      if ((duree instanceof DureeIndemnisationAbstraite))
      {
        DureeIndemnisation dureeAsp = new DureeIndemnisation(duree.getQuantiteInitial().getValeurEntiere());
        dureeAsp.setCodeFormuleMontant(FormuleMontantRegimeGeneralASPARE.getCode());
        collectionDureeAsp.add(dureeAsp);
        ite.remove();
      }
    }
    p_collection.addAll(collectionDureeAsp);
  }
  
  public CalendrierExecutionCalculSpec creerCalendrierExecutionCalcul(AttributionSpec p_attribution)
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)p_attribution.getProduit();
    return produit.creerCalendrierCalcul();
  }
  
  public boolean enregistrerDroitPBJCNCP(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    return true;
  }
  
  public boolean enregistrerEnquetePBJCNCP()
  {
    return true;
  }
  
  public boolean estEnActiviteConservee(AttributionSpec p_attribution, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    if (((AttributionAssuranceSpec)p_attribution).getListeActiviteConservee() != null)
    {
      Iterator ite = ((AttributionAssuranceSpec)p_attribution).getListeActiviteConservee().iterer();
      boolean aUneActiviteEncoreConserve = false;
      while (ite.hasNext())
      {
        TravailSpec activite = (TravailSpec)ite.next();
        if (activite.getDateFin().estApresOuCoincideAvec(p_ut.getDateDebut())) {
          aUneActiviteEncoreConserve = true;
        }
      }
      return (!((AttributionAssuranceSpec)p_attribution).getListeActiviteConservee().estVide()) && (aUneActiviteEncoreConserve);
    }
    return false;
  }
  
  public Damj getDjiMaintienEuropeenDuDroit(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    return OutilsMaintienEuropeenEessiASU.getDjiMaintienEuropeenDuDroit(p_attribution, this);
  }
  
  public FormuleMontantSpec getFormuleMontant(String p_code)
  {
    return RecuperationFormuleMontant.getInstanceFormuleMontant(p_code);
  }
  
  public Damj getIdeMaintienEuropeenDuDroit(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    return OutilsMaintienEuropeenEessiASU.getIdeMaintienEuropeenDuDroit(p_attribution);
  }
  
  public Damj getPjiMaintienEuropeenDuDroit(AttributionSpec p_attribution)
  {
    return OutilsMaintienEuropeenEessiASU.getPjiMaintienEuropeenDuDroit(p_attribution);
  }
  
  public boolean neutralisationApplicableRetourUL961()
  {
    return false;
  }
  
  private void passerEnIndemnisationSansFormation(ConstituantsIndemnisation p_constituantsIndemnisation)
  {
    QuantiteIndemnisationSpec duree = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_constituantsIndemnisation.getCollectionQuantiteDroit());
    if (duree != null) {
      duree.setCodeFormuleMontant(FormuleMontantRegimeGeneralASPARE.getCode());
    } else {
      p_constituantsIndemnisation.setCodeFormuleMontant(FormuleMontantRegimeGeneralASPARE.getCode());
    }
    ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant().copie();
    p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisation);
  }
  
  private void passerEnIndemnisationAvecFormation(ObjetChronoPeriode p_periode, ConstituantsIndemnisation p_constituantsIndemnisation)
  {
    QuantiteIndemnisationSpec duree = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_constituantsIndemnisation.getCollectionQuantiteDroit());
    if (duree != null) {
      duree.setCodeFormuleMontant(FormuleMontantASPAREF.getCode());
    } else {
      p_constituantsIndemnisation.setCodeFormuleMontant(FormuleMontantASPAREF.getCode());
    }
    ElementBaseIndemnisationAREF elementBaseIndemnisationASPF = new ElementBaseIndemnisationAREF((ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant());
    if ((p_periode instanceof PeriodeFormation)) {
      elementBaseIndemnisationASPF.setEffectif(((PeriodeFormation)p_periode).estEffective());
    }
    p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationASPF);
  }
  
  public ResultatCalcul postTraitementResultatDetaille(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    return PostTraitements.postTraitementResultatDetaille(p_attribution, (CalendrierExecutionCalcul)p_calendrierExecutionCalcul);
  }
  
  public ResultatCalcul postTraitementResultatDetailleNotification(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    return PostTraitements.postTraitementResultatDetailleNotification(p_attribution, (CalendrierExecutionCalcul)p_calendrierExecutionCalcul);
  }
  
  public ResultatCalcul postTraitementResultatDeterminationEtatDroit(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul, Damj p_dateEtatDroit)
    throws CoucheLogiqueException
  {
    return PostTraitements.postTraitementResultatDeterminationEtatDroit(p_attribution, (CalendrierExecutionCalcul)p_calendrierExecutionCalcul, p_dateEtatDroit);
  }
  
  public ResultatCalcul postTraitementResultatMigrationCalcul(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Damj recupererDateFinDroitTheorique(CalendrierExecutionCalculSpec p_calendrierExecutionCalcul, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Damj dateFinDroitTheorique = null;
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)p_calendrierExecutionCalcul.getEtatAuDJI();
    BigDecimal reliquatDureeIndemnisation = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_attribution.getDemande(), 2)) {
      return ((AttributionAssuranceSpec)p_attribution).getDateLimiteIndemnisation();
    }
    if (etatAuDji != null)
    {
      if ((etatAuDji.getReliquatDureeIndemnisation() != null) && (etatAuDji.getReliquatDureeIndemnisation().getValeur() != null))
      {
        reliquatDureeIndemnisation = etatAuDji.getReliquatDureeIndemnisation().getValeur();
        dateFinDroitTheorique = p_calendrierExecutionCalcul.getDernierJourIndemnisable().deplacerVersAvant(new DureeCalendaire(0, 0, reliquatDureeIndemnisation.intValue()));
      }
      else
      {
        dateFinDroitTheorique = p_calendrierExecutionCalcul.getDernierJourIndemnisable();
      }
    }
    else
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)p_attribution;
      dateFinDroitTheorique = p_attribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeIndemnisationTheorique().getValeurEntiere() - 1));
    }
    return dateFinDroitTheorique;
  }
  
  public ChronologiePeriodes recupererPeriodesProduit(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePeriodes = new ChronologiePeriodes();
    IndividuSpec individu = p_attribution.getDemandeur();
    
    chronologiePeriodes.ajouter(OutillagePeriodes.genererPeriodeRetraite(individu));
    if ((((AttributionAssuranceSpec)p_attribution).getContexteDateLimiteIndemnisation() != null) && (((AttributionAssuranceSpec)p_attribution).getContexteDateLimiteIndemnisation().equals("CRSPMVS")))
    {
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_attribution.getDemande(), 2)) {
        chronologiePeriodes.ajouter(new ObjetChronoPeriodeLimiteIndemnisationPMVS(((AttributionAssuranceSpec)p_attribution).getDateLimiteIndemnisation().lendemain(), p_attribution.getRsod()));
      }
    }
    else {
      chronologiePeriodes.ajouter(new ObjetChronoPeriodeLimiteIndemnisationASP(((AttributionAssuranceSpec)p_attribution).getDateLimiteIndemnisation().lendemain(), p_attribution.getRsod()));
    }
    if (individu.getDernierJourAtteste() != null) {
      chronologiePeriodes.ajouter(OutillagePeriodes.genererLendemainDja(individu));
    }
    return chronologiePeriodes;
  }
  
  public void postTraitementQualification(UniteTraitement p_ut, QualificationPeriodes p_qualificationPeriodes)
    throws CoucheLogiqueException
  {
    if (p_ut.getStatut() == 3)
    {
      FiltreNegation filtre = new FiltreNegation(new FiltreDsmTravailCalcul());
      p_qualificationPeriodes.setPeriodesSuspensives((ChronologiePeriodes)p_qualificationPeriodes.getPeriodesSuspensives().copier(filtre));
    }
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAJourCumulActivite(UniteTraitement p_ut, AttributionSpec p_attribution, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    ConstituantsCalculActiviteReduiteAsu constituantsCalculActiviteReduite = (ConstituantsCalculActiviteReduiteAsu)p_constituantsCalculActiviteReduite;
    int cumulActivite = constituantsCalculActiviteReduite.getCumulJours();
    int cumulActiviteSurMois = 0;
    FiltresTemporel filtres = new FiltresTemporel();
    FiltreTravail filtreTravail = new FiltreTravail();
    filtres.ajouterFiltre(filtreTravail);
    Chronologie chronoPeriode = null;
    Chronologie chronoPeriodeTrie = null;
    
    chronoPeriode = OutillageCalculADate.boucheLesTrous((ChronologiePeriodes)p_ut.getQualificationPeriodes().getPeriodesSuspensives().copier(filtres), ObjetChronoRemplissage.class, p_ut.getDateDebut(), p_ut.getDateFin());
    
    chronoPeriodeTrie = (ChronologiePeriodes)chronoPeriode.copier(new FiltreObjetChronoPeriodeCalculRemplissage());
    
    Iterator iterateurPeriode = chronoPeriodeTrie.iterer();
    while (iterateurPeriode.hasNext())
    {
      ObjetChronoPeriode periodeActivite = (ObjetChronoPeriode)iterateurPeriode.next();
      cumulActiviteSurMois += periodeActivite.getDuree();
    }
    constituantsCalculActiviteReduite.setCumulJours(p_ut.getDuree() - cumulActiviteSurMois + cumulActivite);
    if (p_ut.getSyntheseARsurUT() != null) {
      p_ut.getSyntheseARsurUT().setCumulActivite(constituantsCalculActiviteReduite.getCumulJours());
    }
    return constituantsCalculActiviteReduite;
  }
  
  public void alimenterGrapheAntecedentCalcul(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    GestionAntecedentCalcul.getInstance().alimenterGrapheCalcul(p_attribution);
  }
  
  public fr.unedic.cali.calcul.dom.EvenementFinQuantiteDroit creerEvenementFinQuantiteDroit(Damj p_dateEffet, QuantiteDroitSpec p_quantiteDroit)
  {
    return new fr.unedic.cali.asu.calcul.dom.EvenementFinQuantiteDroit(p_dateEffet, p_quantiteDroit);
  }
  
  public fr.unedic.cali.calcul.dom.periode.DsmTravail convertirDsmTravailVersDsmTravailProduit(fr.unedic.cali.calcul.dom.periode.DsmTravail p_dsmTravail)
  {
    return new fr.unedic.cali.asu.calcul.dom.periode.DsmTravail(p_dsmTravail);
  }
  
  public String recupererCategorieAttribution(AttributionSpec p_attribution, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    return ((AttributionAssuranceSpec)p_attribution).determinerCodeSousProduitPourSigma();
  }
  
  public boolean enregistrerDispositifPBJCNCP(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return false;
  }
  
  public boolean verifierEligibilitePaiementParAvance(UniteTraitement ut)
  {
    ut.setRaisonStatut(1);
    return false;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculLigneCAA14Impl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */