package fr.unedic.cali.asu.caa14.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.caa14.p01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieConstitutionProduitResultant;
import fr.unedic.cali.asu.caa14.p01.liquidation.outilsfonctionnels.strategies.spec.StrategieConstitutionProduitResultantSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;

public class ConstitutionProduitResultant
  extends ParcoursCali
{
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    Resultat resultat = new Resultat(0);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    int contexteExamen = getContexteExamen(p_contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    dossierExamen.createConstitutionProduitResultant();
    
    alimentationCapitalDroitCourant(demandeCourante);
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demandeCourante.getDateFaitGenerateurOuDernierSinistre());
    StrategieConstitutionProduitResultantSpec strategie = (StrategieConstitutionProduitResultantSpec)FabriqueStrategieConstitutionProduitResultant.getInstance().getStrategie(critere);
    
    Parcours parcours = strategie.getParcoursProduitResultant(contexteExamen, demandeCourante);
    if (parcours != null)
    {
      JustificationDroitResultant justif = new JustificationDroitResultant();
      dossierExamen.getConstitutionProduitResultant().setJustificationDroitResultant(justif);
      resultat = parcours.effectuerParcours(p_contexte);
    }
    if (dossierExamen.getCompetence().getCompetenceFinanciere() == 2) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A14MB2", new String[] { ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionProduitResultant().getCapitalDroitPrecedent().toString(), ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionMontantsBruts().getCapitalInitialBrut().toString() });
    }
    return resultat;
  }
  
  protected int getContexteExamen(Contexte p_contexte)
  {
    return ((DomLiquidationAssurance)p_contexte.getDonnees()).getContexteExamen();
  }
  
  protected void alimentationCapitalDroitCourant(Demande p_demande)
    throws ApplicativeException
  {
    Attribution attribution = (Attribution)p_demande.getDossierExamen();
    ConstitutionMontantsBruts cepMontant = attribution.getConstitutionMontantsBruts();
    
    Quantite nbJourIndemnisesTheorique = attribution.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attribution, cepMontant.getMontantAAttribution(), attribution.getDateAttribution(), nbJourIndemnisesTheorique);
    
    cepMontant.setCapitalInitialBrut(capitalProduitCourant);
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */