package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.autresdoms.cohab.dom.DonneesMoisMandate;
import fr.unedic.cali.calcul.FacadeCalculProduitSpec;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeFinPec;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRadiation;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCES;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class VerificationEligibilitePaiementParAvance
{
  private static final BigDecimal TRENTE_ET_UN_JOUR = new BigDecimal("31.00");
  
  public static boolean verifierEligibilitePaiementParAvance(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, int nbMoisEnPPA, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison, FacadeCalculProduitSpec facadeCalculProduit)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    
    boolean verificationParProduit = facadeCalculProduit.verifierEligibilitePaiementParAvance(ut);
    if (!verificationParProduit) {
      return false;
    }
    int population = attribution.getDemandeur().determinerPopulationIndividu(ut.getPeriode().getDebut());
    switch (population)
    {
    case 0: 
      retour = verifierEligibilitePaiementParAvanceCasGeneral(attribution, periodesDecalantes, nbMoisEnPPA, ut, arretProduitAvecRaison, facadeCalculProduit);
      
      break;
    case 1: 
      retour = verifierEligibilitePaiementParAvanceCasA8A10(attribution, ut, arretProduitAvecRaison);
      
      break;
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_STATUT_UT_POPULATION_INATTENDUE", "Population de l'individu inattendue pour la définition du statut de l'UT", null);
    }
    return retour;
  }
  
  private static boolean verifierEligibilitePaiementParAvanceCasGeneral(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, int nbMoisEnPPA, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison, FacadeCalculProduitSpec facadeCalculProduit)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    if ((attribution.getDateAttribution().estContenueDans(ut.getPeriode())) && (attribution.getDateAttribution().estApres(ut.getDateDebut().getDebutMois())))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    if ((individu.getContexteService() != null) && 
      (individu.getDernierJourAtteste() != null) && 
      (individu.getDernierJourAtteste().estApres(ut.getDateFin())))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    if ((individu.estBeneficiaireSapa()) || (individu.estExclusionIndividuelle()) || (individu.estAcompteNonSolde()))
    {
      boolean moisMandatePP = false;
      
      Collection donneesMoisActualisation = individu.getListeDonneesMoisActualisation();
      if (donneesMoisActualisation != null)
      {
        Iterator iterateurDonneesMoisActualisation = donneesMoisActualisation.iterator();
        while (iterateurDonneesMoisActualisation.hasNext())
        {
          DonneesMoisMandate donneesMoisMandate = (DonneesMoisMandate)iterateurDonneesMoisActualisation.next();
          if ((ut.getPeriode().chevauche(new Periode(donneesMoisMandate.getDateDebut(), donneesMoisMandate.getDateFin()))) && (donneesMoisMandate.getTopMandatement().equals("P"))) {
            moisMandatePP = true;
          }
        }
      }
      if (!moisMandatePP)
      {
        ut.setRaisonStatut(1);
        return false;
      }
    }
    if ((individu.getDateDispenseRechercheEmploi() != null) && (individu.getDateDispenseRechercheEmploi().estAvantOuCoincideAvec(ut.getDateFin())))
    {
      ut.setRaisonStatut(1);
      return false;
    }
    int population = individu.determinerPopulationIndividu(ut.getPeriode().getDebut());
    if ((population == 0) && 
      (nbMoisEnPPA != 0))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    if (!periodesDecalantes.copier(new FiltrePeriodeTravailCalculCES()).estVide())
    {
      ut.setRaisonStatut(1);
      return false;
    }
    ConventionGestionSpec convention = null;
    if (OutilsTrancheCalcul.estTrancheActive(attribution))
    {
      ElementBaseIndemnisation ebiCalcul = OutilsTrancheCalcul.recupererEBICalcul(ut.getConstituantsIndemnisationEnDebutUT());
      if (((attribution instanceof AttributionAssuranceSpec)) && (ebiCalcul.getCompetenceFinanciere() == 2) && (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, ebiCalcul.getConventionGestion())))
      {
        ut.setRaisonStatut(1);
        return false;
      }
      if ((attribution instanceof AttributionAssuranceSpec)) {
        convention = ebiCalcul.getConventionGestion();
      }
    }
    else
    {
      if (((attribution instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)attribution).getCompetenceFinanciere() == 2) && (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, ((AttributionAssuranceSpec)attribution).getConventionGestion())))
      {
        ut.setRaisonStatut(1);
        return false;
      }
      if ((attribution instanceof AttributionAssuranceSpec)) {
        convention = ((AttributionAssuranceSpec)attribution).getConventionGestion();
      }
    }
    if (estExcluPpEnConventionGestion(convention, ut))
    {
      ut.setRaisonStatut(1);
      return false;
    }
    if ((individu.getDateBlocageIndemnisation() != null) && (individu.getDateBlocageIndemnisation().estContenueDans(ut.getPeriode())))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    Chronologie radiations = OutillagePeriodes.recupererRadiations(attribution.getDemandeur());
    
    Iterator iterateurRadiations = radiations.iterer();
    while (iterateurRadiations.hasNext())
    {
      ObjetChronoPeriodeRadiation objetChronoPeriodeRadiation = (ObjetChronoPeriodeRadiation)radiations.elementSuivant();
      Damj dateRadiation = objetChronoPeriodeRadiation.getDateDebut();
      if ((dateRadiation.estApresOuCoincideAvec(ut.getDateDebut())) && (!dateRadiation.coincideAvec(Damj.FIN_DES_TEMPS)))
      {
        ut.setRaisonStatut(3);
        return false;
      }
    }
    if (!((AttributionAssuranceSpec)attribution).estMaintenue())
    {
      QuantiteIndemnisationSpec quantiteIndemnisation = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(ut.getConstituantsIndemnisationEnDebutUT().getCollectionQuantiteDroit());
      if ((quantiteIndemnisation != null) && (quantiteIndemnisation.getQuantiteCourante().getValeur().compareTo(TRENTE_ET_UN_JOUR) < 0))
      {
        ut.setRaisonStatut(3);
        return false;
      }
    }
    if (verificationMandatementDefinitif(ut, individu)) {
      return false;
    }
    if (facadeCalculProduit.estEnActiviteConservee(attribution, ut)) {
      return false;
    }
    return true;
  }
  
  private static boolean verifierEligibilitePaiementParAvanceCasA8A10(AttributionSpec attribution, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    if ((attribution.getDateAttribution().estContenueDans(ut.getPeriode())) && (attribution.getDateAttribution().estApres(ut.getDateDebut().getDebutMois())))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    if (individu.estBeneficiaireSapa())
    {
      boolean moisMandatePP = false;
      
      Collection donneesMoisActualisation = individu.getListeDonneesMoisActualisation();
      if (donneesMoisActualisation != null)
      {
        Iterator iterateurDonneesMoisActualisation = donneesMoisActualisation.iterator();
        while (iterateurDonneesMoisActualisation.hasNext())
        {
          DonneesMoisMandate donneesMoisMandate = (DonneesMoisMandate)iterateurDonneesMoisActualisation.next();
          if ((ut.getPeriode().chevauche(new Periode(donneesMoisMandate.getDateDebut(), donneesMoisMandate.getDateFin()))) && (donneesMoisMandate.getTopMandatement().equals("P"))) {
            moisMandatePP = true;
          }
        }
      }
      if (!moisMandatePP)
      {
        ut.setRaisonStatut(1);
        return false;
      }
    }
    if ((individu.getDateBlocageIndemnisation() != null) && (individu.getDateBlocageIndemnisation().estContenueDans(ut.getPeriode())))
    {
      ut.setRaisonStatut(3);
      return false;
    }
    if (arretProduitAvecRaison.isRaisonsContientRaison(4))
    {
      Iterator iterateurPeriodesInterruptives = arretProduitAvecRaison.getPeriodesInterruptivesDefinitives().iterator();
      while (iterateurPeriodesInterruptives.hasNext())
      {
        ObjetChronoPeriode objetChronoPeriode = (ObjetChronoPeriode)iterateurPeriodesInterruptives.next();
        if ((((objetChronoPeriode instanceof ObjetChronoPeriodeRadiation)) || ((objetChronoPeriode instanceof ObjetChronoPeriodeFinPec))) && (objetChronoPeriode.getDateDebut().estContenueDans(ut.getPeriode())))
        {
          ut.setRaisonStatut(3);
          return false;
        }
      }
    }
    if (verificationMandatementDefinitif(ut, individu)) {
      return false;
    }
    return true;
  }
  
  private static boolean verificationMandatementDefinitif(UniteTraitement ut, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    boolean resultatMandatementDefinitif = false;
    Collection<?> donneesMoisActualisation = individu.getListeDonneesMoisActualisation();
    if (donneesMoisActualisation != null)
    {
      Iterator<?> iterateurDonneesMoisActualisation = donneesMoisActualisation.iterator();
      while (iterateurDonneesMoisActualisation.hasNext())
      {
        DonneesMoisMandate donneesMoisMandate = (DonneesMoisMandate)iterateurDonneesMoisActualisation.next();
        if ((ut.getPeriode().chevauche(new Periode(donneesMoisMandate.getDateDebut(), donneesMoisMandate.getDateFin()))) && (donneesMoisMandate.getTopMandatement().equals("D")))
        {
          ut.setRaisonStatut(2);
          resultatMandatementDefinitif = true;
        }
      }
    }
    return resultatMandatementDefinitif;
  }
  
  public static boolean estExcluPpEnConventionGestion(ConventionGestionSpec conventionAttributionAssuranceSpec, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    if ((OutilConventionGestion.estConventionGestionFraisReel(conventionAttributionAssuranceSpec)) && (ut.getDateDebut().estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Application du droit aux paiements provisoires pour ARE CG")))) {
      return true;
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     VerificationEligibilitePaiementParAvance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */