package fr.unedic.cali.asu.cge01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantAREF;
import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.ActiviteReduite;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.DeterminationReliquat;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.OutilsMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantRfp;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantSpectacle;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.TracesBouchon;
import fr.unedic.cali.parcours.DomAvantPilotage;
import fr.unedic.cali.parcours.DomCalculPilotage;
import fr.unedic.cali.parcours.ParcoursAvantPilotageElementsIndemnisation;
import fr.unedic.cali.parcours.ParcoursCalculPilotageDeterminationEtatDroit;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.cali.parcours.ResultatPilotage;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.List;

public class FacadeCalculLignePourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final int CINQUANTE_ANS = 50;
  private static final int DIX = 10;
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneral();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantAREF();
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pattribution;
    
    return (attribution.getCompetenceFinanciere() == 2) && ((attribution.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)pattribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)pattribution).getConventionGestion().estPrecompteCRC())));
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    
    BigDecimal capital = BigDecimal.ZERO;
    
    Damj pji = pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, false);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return DeterminationReliquat.determinerDureeEffectiveReliquat(quantiteInitiale, nbHeuresFormation);
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    Damj pjeNcp = null;
    Damj dateConditionNombreJoursIndemnisesMaintien = null;
    CalendrierExecutionCalculPeriodique calendrier = null;
    if (attribution == null) {
      return null;
    }
    if (dateConditionNombreJoursIndemnisesMaintien == null)
    {
      calendrier = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
      if (calendrier != null) {
        dateConditionNombreJoursIndemnisesMaintien = OutilsMaintien.determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(calendrier);
      }
    }
    if (dateConditionNombreJoursIndemnisesMaintien == null)
    {
      ResultatDeterminationEtatDroitProduit resultat = null;
      
      Damj dateEtude = Damj.FIN_DES_TEMPS;
      List listeAttributions = attribution.getDemandeur().getListeAttributionsExecutablesAvant(attribution.getDateEffet());
      if (!listeAttributions.isEmpty())
      {
        AppelAvant.executerAvant(listeAttributions, dateEtude);
        pjeNcp = OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(attribution);
        if ((dateEtude.estApresOuCoincideAvec(pjeNcp)) && ((attribution == null) || (listeAttributions.contains(attribution))))
        {
          DomCalculPilotage domCalcul = new DomCalculPilotage();
          domCalcul.setIndividu(attribution.getDemandeur());
          domCalcul.setListeAttributions(listeAttributions);
          domCalcul.setAttributionAEtudier(attribution);
          domCalcul.setDateEtatDroit(dateEtude);
          domCalcul.setDateDebutExecution(pjeNcp);
          domCalcul.setContexteService(domCalcul.getIndividu().getContexteService());
          
          Contexte contexteCalcul = new Contexte();
          contexteCalcul.setDonnees(domCalcul);
          
          Parcours parcours = new ParcoursCalculPilotageDeterminationEtatDroit();
          ResultatPilotage resultatPilotage = (ResultatPilotage)parcours.effectuerParcours(contexteCalcul);
          
          resultat = (ResultatDeterminationEtatDroitProduit)resultatPilotage.getResultatDetaille(attribution);
        }
      }
      if (resultat != null) {
        calendrier = (CalendrierExecutionCalculPeriodique)resultat.getCalendrierExecutionCalcul();
      }
      if (calendrier != null) {
        dateConditionNombreJoursIndemnisesMaintien = OutilsMaintien.determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(calendrier);
      }
    }
    return dateConditionNombreJoursIndemnisesMaintien;
  }
  
  protected ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    Damj dateAttribution = null;
    DonneesCalculMontant donneesCalculMontantAssocie = null;
    DonneesCalculMontant donneesCalculMontant = null;
    DonneesCalculMontantSpectacle donneesCalculMontantSpectacle = null;
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    boolean droitAssocieExiste = donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie() != null;
    
    donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    donneesCalculMontantSpectacle = donneesEntreesRecuperationMontant.getDonneesCalculMontantSpectacle();
    if (droitAssocieExiste) {
      donneesCalculMontantAssocie = donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontant();
    }
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourantDroitAssocie = null;
    if (droitAssocieExiste)
    {
      elementBaseIndemnisationCourantDroitAssocie = new ElementBaseIndemnisation();
      elementBaseIndemnisationCourant.setElementBaseIndemnisationDroitAssocie(elementBaseIndemnisationCourantDroitAssocie);
    }
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    if (donneesCalculMontant.getSalaireJournalier() != null) {
      elementBaseIndemnisationCourant.setSalaireJournalier(donneesCalculMontant.getSalaireJournalier());
    } else {
      elementBaseIndemnisationCourant.setSalaireJournalier(new Sjr(donneesEntreesRecuperationMontant.getDonneesCalculMontantRfp().getSjrInitialForce(), donneesEntreesRecuperationMontant.getDonneesCalculMontantRfp().getDateEntreeEnStage(), null));
    }
    if (droitAssocieExiste) {
      if (donneesCalculMontantAssocie.getSalaireJournalier() != null) {
        elementBaseIndemnisationCourantDroitAssocie.setSalaireJournalier(donneesCalculMontantAssocie.getSalaireJournalier());
      } else {
        elementBaseIndemnisationCourantDroitAssocie.setSalaireJournalier(new Sjr(donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontantRfp().getSjrInitialForce(), donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontantRfp().getDateEntreeEnStage(), null));
      }
    }
    Sjr sjr = OutilMappingSjmSjr.convertirSjr(elementBaseIndemnisationCourant.getSalaireJournalier());
    elementBaseIndemnisationCourant.setSjr(sjr);
    if (droitAssocieExiste)
    {
      Sjr sjrDroitAssocie = OutilMappingSjmSjr.convertirSjr(elementBaseIndemnisationCourantDroitAssocie.getSalaireJournalier());
      elementBaseIndemnisationCourantDroitAssocie.setSjr(sjrDroitAssocie);
    }
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourant, ProduitAsuCge01P04.getInstance(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorise);
    if (droitAssocieExiste)
    {
      Sjr sjrRevaloriseDroitAssocie = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourantDroitAssocie, ProduitAsuCge01P04.getInstance(), dateCalcul);
      elementBaseIndemnisationCourantDroitAssocie.setSjr(sjrRevaloriseDroitAssocie);
    }
    if (donneesCalculMontant.getCoefficientSaisonnier() != null) {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
    } else {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(BigDecimal.ONE);
    }
    if ((elementBaseIndemnisationCourant.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
      if ((donneesCalculMontant.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontant.isConditionCaractereSaisonnierParRythme())) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(BigDecimal.ONE);
      }
    }
    if (droitAssocieExiste)
    {
      if (donneesCalculMontantAssocie.getCoefficientSaisonnier() != null) {
        elementBaseIndemnisationCourantDroitAssocie.setCoefficientSaisonnier(donneesCalculMontantAssocie.getCoefficientSaisonnier());
      }
      if ((elementBaseIndemnisationCourantDroitAssocie.getCoefficientSaisonnier() != null) && (elementBaseIndemnisationCourantDroitAssocie.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
        if ((donneesCalculMontantAssocie.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontantAssocie.isConditionCaractereSaisonnierParRythme())) {
          elementBaseIndemnisationCourantDroitAssocie.setCoefficientSaisonnier(BigDecimal.ONE);
        }
      }
    }
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    } else {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(BigDecimal.ONE);
    }
    if ((droitAssocieExiste) && (donneesCalculMontantAssocie.getCoefficientTempsPartiel() != null)) {
      elementBaseIndemnisationCourantDroitAssocie.setCoefficientTempsPartiel(donneesCalculMontantAssocie.getCoefficientTempsPartiel());
    }
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      if (individu != null)
      {
        Boolean gerePensionInvalidite = donneesCalculMontant.getEstProduitGerantPensionInvalidite();
        if ((gerePensionInvalidite != null) && (gerePensionInvalidite.booleanValue()))
        {
          elementBaseIndemnisationCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
          elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, individu, dateCalcul, dateAttribution));
        }
        else
        {
          determinerMontantPensionInvaliditeADeduire(elementBaseIndemnisationCourant, individu, dateCalcul);
        }
      }
      else
      {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(donneesCalculMontant.getMontantPensionInvaliditeADeduire());
      }
      if (droitAssocieExiste) {
        if (individu != null)
        {
          elementBaseIndemnisationCourantDroitAssocie.setListePensionInvalidite(donneesCalculMontantAssocie.getListePensionInvalidite());
          
          determinerMontantPensionInvaliditeADeduire(elementBaseIndemnisationCourantDroitAssocie, individu, dateCalcul);
        }
        else
        {
          elementBaseIndemnisationCourantDroitAssocie.setMontantPensionInvaliditeADeduire(donneesCalculMontantAssocie.getMontantPensionInvaliditeADeduire());
        }
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(BigDecimal.ZERO);
      if (droitAssocieExiste) {
        elementBaseIndemnisationCourantDroitAssocie.setMontantPensionInvaliditeADeduire(BigDecimal.ZERO);
      }
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = null;
      DureeCalendaire ageALaDate = null;
      PeriodeAvantageVieillesse periodeAvCouranteDroitAssocie = null;
      DureeCalendaire ageALaDateDroitAssocie = null;
      if (individu != null)
      {
        periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
        ageALaDate = individu.getAgeALaDate(dateCalcul);
        if (droitAssocieExiste)
        {
          periodeAvCouranteDroitAssocie = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
          ageALaDateDroitAssocie = individu.getAgeALaDate(dateCalcul);
        }
      }
      else
      {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(donneesCalculMontant.getMontantPensionInvaliditeADeduire());
        periodeAvCourante = donneesCalculMontant.getPeriodeAvantageVieillesse();
        ageALaDate = donneesEntreesRecuperationMontant.getAgeFinMoisDateAttribution();
        if (droitAssocieExiste)
        {
          elementBaseIndemnisationCourantDroitAssocie.setMontantPensionInvaliditeADeduire(donneesCalculMontantAssocie.getMontantPensionInvaliditeADeduire());
          periodeAvCouranteDroitAssocie = donneesCalculMontantAssocie.getPeriodeAvantageVieillesse();
          ageALaDateDroitAssocie = donneesEntreesRecuperationMontant.getAgeFinMoisDateAttribution();
        }
      }
      if (periodeAvCourante != null)
      {
        BigDecimal montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
        BigDecimal coeffAV = BigDecimal.ZERO;
        if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(BigDecimal.ZERO))) {
          coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
        }
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
        elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
      }
      else
      {
        elementBaseIndemnisationCourant.setDateEffetAV(donneesCalculMontant.getDateEffetAV());
        elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(donneesCalculMontant.getCoefficientAvantageVieillesse());
        elementBaseIndemnisationCourant.setMontantAvantageVieillesse(donneesCalculMontant.getMontantAvantageVieillesse());
      }
      if (droitAssocieExiste) {
        if (periodeAvCouranteDroitAssocie != null)
        {
          BigDecimal montantAV = periodeAvCouranteDroitAssocie.getQuantiteEuro().getValeur();
          
          elementBaseIndemnisationCourantDroitAssocie.setDateEffetAV(dateCalcul);
          BigDecimal coeffAV = BigDecimal.ZERO;
          if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(BigDecimal.ZERO))) {
            coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
          }
          elementBaseIndemnisationCourantDroitAssocie.setCoefficientAvantageVieillesse(coeffAV);
          elementBaseIndemnisationCourantDroitAssocie.setMontantAvantageVieillesse(montantAV);
        }
        else
        {
          elementBaseIndemnisationCourantDroitAssocie.setDateEffetAV(donneesCalculMontantAssocie.getDateEffetAV());
          elementBaseIndemnisationCourantDroitAssocie.setCoefficientAvantageVieillesse(donneesCalculMontantAssocie.getCoefficientAvantageVieillesse());
          elementBaseIndemnisationCourantDroitAssocie.setMontantAvantageVieillesse(donneesCalculMontantAssocie.getMontantAvantageVieillesse());
        }
      }
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(ageALaDate);
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
      if (droitAssocieExiste)
      {
        BigDecimal tauxavantageVieillesseDroitAssocie = parametresIndemnisation.getTauxAvantageViellesse(ageALaDateDroitAssocie);
        if (tauxavantageVieillesseDroitAssocie != null) {
          elementBaseIndemnisationCourantDroitAssocie.setTauxAvantageVieillesse(tauxavantageVieillesseDroitAssocie);
        }
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(BigDecimal.ZERO);
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(BigDecimal.ZERO);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(BigDecimal.ZERO);
      if (droitAssocieExiste)
      {
        elementBaseIndemnisationCourantDroitAssocie.setCoefficientAvantageVieillesse(BigDecimal.ZERO);
        elementBaseIndemnisationCourantDroitAssocie.setTauxAvantageVieillesse(BigDecimal.ZERO);
        elementBaseIndemnisationCourantDroitAssocie.setMontantAvantageVieillesse(BigDecimal.ZERO);
      }
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(BigDecimal.ONE);
    if (droitAssocieExiste) {
      elementBaseIndemnisationCourantDroitAssocie.setCoefficientSanctionReduction(BigDecimal.ONE);
    }
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else if (donneesEntreesRecuperationMontant.getCompetences() == null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.TRUE);
    } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.FALSE);
    }
    if (droitAssocieExiste)
    {
      elementBaseIndemnisationCourantDroitAssocie.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
      if (donneesCalculMontantAssocie.getAvecPrecompteCRC() != null) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(donneesCalculMontantAssocie.getAvecPrecompteCRC());
      } else if (donneesEntreesRecuperationMontant.getCompetences() == null) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(Boolean.TRUE);
      } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(Boolean.FALSE);
      }
    }
    if ((donneesCalculMontant.getProduit() != null) && ((donneesCalculMontant.getProduit() instanceof ProduitAsuSpec))) {
      elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    }
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
      if (droitAssocieExiste)
      {
        ElementBaseIndemnisationAREF ebiAREFDroitAssocie = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourantDroitAssocie);
        ebiAREF.setElementBaseIndemnisationDroitAssocie(ebiAREFDroitAssocie);
      }
    }
    Reglement reglementApplicable = donneesCalculMontantSpectacle.getReglementApplicable();
    if (reglementApplicable != null) {
      elementBaseIndemnisationCourant.setReglementApplicable(reglementApplicable);
    }
    Quantite affiliationRequisePourPRA = donneesCalculMontantSpectacle.getAffiliationRequisePourPRA();
    if (affiliationRequisePourPRA != null) {
      elementBaseIndemnisationCourant.setAffiliationRequisePourPRA(affiliationRequisePourPRA);
    }
    SalaireReference salaireReference = (SalaireReference)donneesCalculMontantSpectacle.getSalaireReference();
    if (salaireReference != null) {
      elementBaseIndemnisationCourant.setSalaireReference(salaireReference);
    }
    BigDecimal nombreHeureTravaillesEtendu = donneesCalculMontantSpectacle.getNombreHeureTravaillesEtendu();
    if (nombreHeureTravaillesEtendu != null) {
      elementBaseIndemnisationCourant.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtendu);
    }
    BigDecimal nombreHeuresTravailleesPlafonnees = donneesCalculMontantSpectacle.getNombreHeuresTravailleesPlafonnees();
    if (nombreHeuresTravailleesPlafonnees != null) {
      elementBaseIndemnisationCourant.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonnees);
    }
    Periode prc = donneesCalculMontantSpectacle.getPrc();
    if (prc != null) {
      elementBaseIndemnisationCourant.setPrc(prc);
    }
    elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(donneesCalculMontantSpectacle.getNbJoursEmploiSurPrc());
    elementBaseIndemnisationCourant.setCoefficientHoraireJour(donneesCalculMontantSpectacle.getCoefficientHoraireJour());
    
    elementBaseIndemnisationCourant.setExpatrieApresConvention17(donneesCalculMontant.isExpatrieApresConvention17());
    if (droitAssocieExiste)
    {
      DonneesCalculMontantSpectacle donneesCalculMontantSpecAssocie = donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontantSpectacle();
      
      Reglement reglementApplicableDass = donneesCalculMontantSpecAssocie.getReglementApplicable();
      if (reglementApplicableDass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setReglementApplicable(reglementApplicableDass);
      }
      Quantite affiliationRequisePourPRADass = donneesCalculMontantSpecAssocie.getAffiliationRequisePourPRA();
      if (affiliationRequisePourPRADass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setAffiliationRequisePourPRA(affiliationRequisePourPRADass);
      }
      SalaireReference salaireReferenceDass = (SalaireReference)donneesCalculMontantSpecAssocie.getSalaireReference();
      if (salaireReferenceDass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setSalaireReference(salaireReferenceDass);
      }
      BigDecimal nombreHeureTravaillesEtenduDass = donneesCalculMontantSpecAssocie.getNombreHeureTravaillesEtendu();
      if (nombreHeureTravaillesEtenduDass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtenduDass);
      }
      BigDecimal nombreHeuresTravailleesPlafonneesDass = donneesCalculMontantSpecAssocie.getNombreHeuresTravailleesPlafonnees();
      if (nombreHeuresTravailleesPlafonneesDass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonneesDass);
      }
      Periode prcDass = donneesCalculMontantSpecAssocie.getPrc();
      if (prcDass != null) {
        elementBaseIndemnisationCourantDroitAssocie.setPrc(prcDass);
      }
      elementBaseIndemnisationCourantDroitAssocie.setNbJoursEmploiSurPrc(donneesCalculMontantSpecAssocie.getNbJoursEmploiSurPrc());
      elementBaseIndemnisationCourantDroitAssocie.setCoefficientHoraireJour(donneesCalculMontantSpecAssocie.getCoefficientHoraireJour());
    }
    return constituantsIndemnisation;
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    DomAvantPilotage domAvantPilotage = null;
    Contexte contexteCalcul = null;
    Parcours parcoursAvant = null;
    ResultatAvant resultat = null;
    Damj premierJourAvantPourLiquidation = null;
    
    domAvantPilotage = new DomAvantPilotage(attribution);
    domAvantPilotage.setAvecPriseEnCompteEvenement(true);
    contexteCalcul = new Contexte();
    contexteCalcul.setDonnees(domAvantPilotage);
    
    parcoursAvant = new ParcoursAvantPilotageElementsIndemnisation();
    
    resultat = (ResultatAvant)parcoursAvant.effectuerParcours(contexteCalcul);
    
    premierJourAvantPourLiquidation = resultat.getPremierJourAvant();
    if ((premierJourAvantPourLiquidation != null) && (premierJourAvantPourLiquidation.estAvant(attribution.getDateAttribution()))) {
      premierJourAvantPourLiquidation = attribution.getDateAttribution();
    }
    if ((premierJourAvantPourLiquidation == null) || (resultat.getDernierJourAvant() == null) || (resultat.getDernierJourAvant().estAvant(premierJourAvantPourLiquidation))) {
      return null;
    }
    return new Periode(premierJourAvantPourLiquidation, resultat.getDernierJourAvant());
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec pattribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)pattribution;
    BigDecimal sjr = ((ProduitAsuSpec)pattribution.getProduit()).getSalaireJournalier(pattribution, dateCalcul).getSalaire();
    
    boolean apprenti = ((Attribution)pattribution).isTopContratsRemuneresBaseSmic();
    Chronologie chronoPeriodesConserveesLiq = attribution.getListeActiviteConservee();
    boolean estAvecSjc = false;
    
    BigDecimal sjc = BigDecimal.ZERO;
    
    TracesBouchon.ecrireTrace("Bug, le SJC n'est jamais présent sur l'EBI, à voir si on corrige : Pb Reprise de stock");
    
    boolean presencePansConservee = !chronoPeriodesConserveesLiq.copier(new FiltrePeriodePANSConservee()).estVide();
    return ActiviteReduite.calculerSeuilMensuel(dateCalcul, sjr, sjc, apprenti, estAvecSjc, BigDecimal.ZERO, presencePansConservee);
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec formuleMontant = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      formuleMontant = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      formuleMontant = getFormuleMontantEnFormation();
    } else {
      formuleMontant = getFormuleMontant();
    }
    return formuleMontant.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  protected void determinerMontantPensionInvaliditeADeduire(ElementBaseIndemnisation ebi, IndividuSpec individu, Damj date)
    throws CoucheLogiqueException
  {
    ebi.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, date));
  }
  
  public Damj recupererDateDrv(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CalendrierExecutionAvant calAvant = (CalendrierExecutionAvant)attribution.getCalendrierExecutionAvant();
    CalendrierExecutionCalculPeriodique calPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    Damj dateDrv = null;
    if ((calAvant != null) && (calAvant.getDateDrv() != null)) {
      dateDrv = calAvant.getDateDrv();
    } else if (calPeriodique != null) {
      dateDrv = calPeriodique.getDateDrv();
    }
    return dateDrv;
  }
  
  public Damj recupererDateEpuisementDuree(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CalendrierExecutionCalculPeriodique calPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    Damj dateEpuisementDuree = null;
    if (calPeriodique != null) {
      dateEpuisementDuree = calPeriodique.getDateEpuisementDuree();
    }
    return dateEpuisementDuree;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculLignePourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */