package fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaireMayotte;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public final class MajCi
{
  private static final int CINQUANTE_ANS = 50;
  private static final int UN = 1;
  
  public static ConstituantsIndemnisation miseAJourConstituantsIndemnisation(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    QuantiteDroitSpec dureeDroit = null;
    Collection collectionDurees = null;
    Iterator iterator = null;
    String codeFormuleMontant = null;
    
    codeFormuleMontant = constituantsIndemnisation.getCodeFormuleMontant();
    if (codeFormuleMontant != null) {
      miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
    }
    collectionDurees = constituantsIndemnisation.getCollectionQuantiteDroit();
    if (collectionDurees != null)
    {
      iterator = collectionDurees.iterator();
      while (iterator.hasNext())
      {
        dureeDroit = (QuantiteDroitSpec)iterator.next();
        if ((dureeDroit instanceof QuantiteIndemnisationSpec)) {
          miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
        }
      }
    }
    return constituantsIndemnisation;
  }
  
  private static void miseAJourParametres(AttributionSpec pattribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    ParametresIndemnisation parametresIndemnisation = null;
    BigDecimal tauxAvantageViellesse = null;
    ElementBaseIndemnisation elementBaseIndemnisation = null;
    Sjr nouveauSjr = null;
    Sjc nouveauSjc = null;
    Attribution attribution = (Attribution)pattribution;
    
    parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    elementBaseIndemnisation = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    tauxAvantageViellesse = parametresIndemnisation.getTauxAvantageViellesse(pattribution.getDemandeur().getAgeALaDate(dateDeMiseAjour));
    if (tauxAvantageViellesse != null) {
      ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).setTauxAvantageVieillesse(tauxAvantageViellesse);
    }
    if ((attribution.getProduitExecution().getNomUnique().equals("ASU_MAY17_02")) || (attribution.getProduitExecution().getNomUnique().equals("ASU_MAY17_03"))) {
      nouveauSjr = RevalorisationSalaireMayotte.revaloriserSjrMayotte(attribution, dateDeMiseAjour);
    } else {
      nouveauSjr = RevalorisationSalaire.revaloriserSjr(attribution, dateDeMiseAjour);
    }
    nouveauSjc = RevalorisationSalaire.revaloriserSjc(attribution.getSJC(), dateDeMiseAjour);
    if (nouveauSjr.getSalaire().doubleValue() != elementBaseIndemnisation.getSjr().getSalaire().doubleValue()) {
      elementBaseIndemnisation.setMontantAvantageVieillesse(elementBaseIndemnisation.getCoefficientAvantageVieillesse().multiply(nouveauSjr.getSalaire()));
    }
    elementBaseIndemnisation.getSjr().setSalaire(nouveauSjr.getSalaire());
    
    elementBaseIndemnisation.getSjc().setSalaire(nouveauSjc.getSalaire());
    if ((verifieCoefSaisonnier(elementBaseIndemnisation)) && (pattribution.getDemandeur().getAgeALaDate(dateDeMiseAjour).getAnnees() >= 50) && (verifieCaractereSaisonnierParRythme(elementBaseIndemnisation))) {
      elementBaseIndemnisation.setCoefficientSaisonnier(BigDecimal.ONE);
    }
    if ((elementBaseIndemnisation.getAvecPrecompteCRC() == null) && (attribution.getCompetenceFinanciere() == 2) && (verifierCompetenceAdministrativeEtConventionGestion(attribution))) {
      elementBaseIndemnisation.setAvecPrecompteCRC(Boolean.FALSE);
    }
  }
  
  private static boolean verifieCoefSaisonnier(ElementBaseIndemnisation elementBaseIndemnisation)
  {
    return (elementBaseIndemnisation.getCoefficientSaisonnier() != null) && (elementBaseIndemnisation.getCoefficientSaisonnier().intValue() != 1);
  }
  
  private static boolean verifieCaractereSaisonnierParRythme(ElementBaseIndemnisation elementBaseIndemnisation)
  {
    return (elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 1) && (elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme());
  }
  
  private static boolean verifierCompetenceAdministrativeEtConventionGestion(Attribution attribution)
  {
    return (attribution.getCompetenceAdministrative() != 1) || ((attribution.getConventionGestion() != null) && (!attribution.getConventionGestion().estPrecompteCRC()));
  }
}

/* Location:
 * Qualified Name:     MajCi
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */