package fr.unedic.cali.asu.cge01.calcul.pbjc;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Poursuite;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.EvenementChangementParametre;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.calcul.pbjc.dom.PbjcNcp;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.Iterator;

public class FacadePBJCLigneSansTrancheImpl
  extends FacadePBJCLigneImpl
{
  private static FacadePBJCLigneSansTrancheImpl s_instance = new FacadePBJCLigneSansTrancheImpl();
  
  public static FacadePBJCLigneSansTrancheImpl getInstance()
  {
    return s_instance;
  }
  
  public void positionnerJustificationOuverturePJI(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    if ((p_attribution instanceof RepriseSpec))
    {
      AttributionAssuranceSpec reprise = (AttributionAssuranceSpec)p_attribution;
      if ("ASU_27".equals(reprise.getTypeExamen())) {
        p_pbjcNcp.ajouterComplementDeJustification("FE");
      }
      p_pbjcNcp.ajouterComplementDeJustification("BP");
      if (reprise.getDateAttribution().coincideAvec(reprise.getPji()))
      {
        AttributionAssuranceSpec assurancePrecedente = ((AttributionAssuranceSpec)p_attribution).getAttributionPrecedente();
        if ((assurancePrecedente != null) && (OutilDemande.estUneDemandeFinDroitAsr(assurancePrecedente.getDemande()))) {
          p_pbjcNcp.ajouterComplementDeJustification("BV");
        }
      }
      Collection collectionEvtsChangementParametre = null;
      Iterator iterateur = null;
      EvenementChangementParametre evenementChangementParametre = null;
      
      Damj dateDerniereRevalorisationAvantCessation = Damj.NUIT_DES_TEMPS;
      Damj dateDerniereRevalorisationAvantReprise = Damj.NUIT_DES_TEMPS;
      
      CalendrierExecutionCalculSpec calendrier = reprise.getAttributionPrecedente().getCalendrierExecutionCalcul();
      Damj dateFinAttributionPrecedente;
      Damj dateFinAttributionPrecedente;
      if ((calendrier != null) && (calendrier.getEtatAttribution() != 4)) {
        dateFinAttributionPrecedente = calendrier.getDernierJourIndemnisable();
      } else {
        dateFinAttributionPrecedente = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(reprise.getAttributionPrecedente());
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantCessation = evenementChangementParametre.getDateEffet();
          }
        }
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente, p_attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable(), p_attribution);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantReprise = evenementChangementParametre.getDateEffet();
          }
        }
      }
      Damj dateSjrAttributionPrecedente = reprise.getAttributionPrecedente().getElementBaseIndemnisation().getSjr().getDateDepart();
      if ((dateDerniereRevalorisationAvantCessation.estAvant(dateDerniereRevalorisationAvantReprise)) && (RevalorisationSalaire.verifierDureePourReval(dateSjrAttributionPrecedente, dateDerniereRevalorisationAvantReprise))) {
        p_pbjcNcp.ajouterComplementDeJustification("CD");
      }
    }
    else if ((p_attribution instanceof ReadmissionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("BH");
    }
    else if ((p_attribution instanceof RevisionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("CX");
    }
    else
    {
      p_pbjcNcp.ajouterComplementDeJustification("BD");
    }
    if ((OutilsMaintienEuropeenEessiASU.getPjiMaintienEuropeenDuDroit(p_attribution) != null) && (p_pbjcNcp.getDateDebut().equals(OutilsMaintienEuropeenEessiASU.getPjiMaintienEuropeenDuDroit(p_attribution)))) {
      p_pbjcNcp.ajouterComplementDeJustification("CY");
    }
    if ((p_attribution instanceof Poursuite)) {
      p_pbjcNcp.ajouterComplementDeJustification("I2");
    }
  }
  
  public void positionnerJustificationOuverturePJITrancheExecutable(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    super.positionnerJustificationOuverturePJI(p_pbjcNcp, p_attribution);
  }
}

/* Location:
 * Qualified Name:     FacadePBJCLigneSansTrancheImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */