package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.fabriques.FabriqueStrategiePlafonnementAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategiePlafonnementAffiliationSpec;
import fr.unedic.cali.asu.dom.ActiviteProratisee;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.PeriodeElementaire;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.ParametresCalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.QuantitesAppartenanceSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreFinAvantDate;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.cali.outilsfonctionnels.strategies.CriteresStrategiePlafonnementAffiliation;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedList;

public class CalculAppartenance
  implements CalculAppartenanceSpec
{
  public static CalculAppartenance getInstance()
  {
    return new CalculAppartenance();
  }
  
  public QuantitesAppartenanceSpec calculer(DemandeSpec p_demande, Periode p_periode, Chronologie p_passeProfessionnel, Reglement p_reglement, ParametresCalculAppartenanceSpec p_parametresCalculAppartenance)
    throws ApplicativeException
  {
    ParametresCalculAppartenance parametresCalculAppartenance = (ParametresCalculAppartenance)p_parametresCalculAppartenance;
    
    JustificationAffiliation justificationAffiliation = new JustificationAffiliation();
    
    Quantite quantiteAffiliationForcee = ((Demande)p_demande).getDonneesTemporaires().getQuantiteAffiliation();
    QuantitesAppartenance quantitesAppartenance;
    if ((quantiteAffiliationForcee != null) && (parametresCalculAppartenance.isPrendreEnCompteDonneesForcees()))
    {
      QuantitesAppartenance quantitesAppartenance = new QuantitesAppartenance();
      quantitesAppartenance.putQuantiteAffiliation(quantiteAffiliationForcee);
      quantitesAppartenance.putQuantiteAssimilation(new Quantite(new BigDecimal(0), quantiteAffiliationForcee.getUnite()));
      
      justificationAffiliation.setAppartenanceCalculee(quantiteAffiliationForcee);
      justificationAffiliation.setPeriodePraRetenue((Pra)p_periode);
      
      quantitesAppartenance.putJustificationAffiliation(justificationAffiliation, quantiteAffiliationForcee.getUnite());
    }
    else
    {
      quantitesAppartenance = calculer(p_demande, justificationAffiliation, p_periode, p_passeProfessionnel, p_reglement, parametresCalculAppartenance.isNePasSanctionnerPnds());
      
      Enumeration enumeration = quantitesAppartenance.getListUnitesCalculees();
      while (enumeration.hasMoreElements())
      {
        Unite unite = (Unite)enumeration.nextElement();
        quantitesAppartenance.putJustificationAffiliation(justificationAffiliation, unite);
      }
      if (quantitesAppartenance.getUniteAppartenanceSecondaire() != null) {
        quantitesAppartenance.putJustificationAffiliation(justificationAffiliation, quantitesAppartenance.getUniteAppartenanceSecondaire());
      }
    }
    return quantitesAppartenance;
  }
  
  public QuantitesAppartenance calculer(DemandeSpec p_demande, JustificationAffiliation p_justificationAffi, Periode p_periode, Chronologie p_passeProfessionnel, Reglement p_reglement)
    throws ApplicativeException
  {
    return calculer(p_demande, p_justificationAffi, p_periode, p_passeProfessionnel, p_reglement, false);
  }
  
  public QuantitesAppartenance calculer(DemandeSpec p_demande, JustificationAffiliation p_justificationAffi, Periode p_periode, Chronologie p_passeProfessionnel, Reglement p_reglement, boolean pndsNonPrisesEnCompte)
    throws ApplicativeException
  {
    Damj dateExamen = null;
    if (p_demande != null) {
      dateExamen = p_demande.getDateExamen();
    }
    Chronologie pnds = null;
    Collection listePNDS = null;
    boolean activiteEnConflit = false;
    Chronologie passeProfessionnel = null;
    Chronologie listeActivitesSalariees = null;
    Chronologie listeActivitesSalarieesSansConflit = null;
    Chronologie listeActivitesAssimilables = null;
    Chronologie listeActivitesAssimilablesSansConflit = null;
    Chronologie listeActivitesParticipantesSansConflit = null;
    if ((p_demande != null) && (!pndsNonPrisesEnCompte)) {
      pnds = ((Demande)p_demande).getChronologiePNDS(p_periode);
    }
    if ((pnds != null) && (!pnds.estVide())) {
      leverAlerteA11MNB9SurPresencePNDS(p_demande, pnds);
    }
    passeProfessionnel = p_passeProfessionnel.copier(new FiltreChevauchePeriode(p_periode));
    if (dateExamen != null) {
      passeProfessionnel = passeProfessionnel.copier(new FiltreFinAvantDate(dateExamen));
    }
    FiltreNegation filtreActiviteSalarieeSansSuspensionRCT = new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    passeProfessionnel = passeProfessionnel.copier(filtreActiviteSalarieeSansSuspensionRCT);
    
    listeActivitesSalariees = passeProfessionnel.copier(new FiltreActiviteSalarie());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesQualifiables());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesLiquidables());
    listeActivitesSalarieesSansConflit = listeActivitesSalariees.copier(new FiltrePeriodesSansConflit());
    
    listeActivitesAssimilables = passeProfessionnel.copier(new FiltrePeriodeFormationAssimilable());
    listeActivitesAssimilablesSansConflit = listeActivitesAssimilables.copier(new FiltrePeriodesSansConflit());
    
    activiteEnConflit = (listeActivitesAssimilables.getTaille() != listeActivitesAssimilablesSansConflit.getTaille()) || (listeActivitesSalariees.getTaille() != listeActivitesSalarieesSansConflit.getTaille());
    
    Chronologie listePeriodesElementaires = constituerPeriodesElementaires(listeActivitesSalarieesSansConflit, p_periode, pnds);
    
    determinerPeriodesAffiliationPourAlimentationBasePivot(p_demande, listeActivitesSalarieesSansConflit, listeActivitesAssimilablesSansConflit);
    
    Chronologie listePeriodesElementairesAvecPlafonnement = null;
    if (listePeriodesElementaires.estVide())
    {
      listePeriodesElementairesAvecPlafonnement = listePeriodesElementaires;
    }
    else
    {
      CriteresStrategiePlafonnementAffiliation critereStrategie = new CriteresStrategiePlafonnementAffiliation();
      
      ActiviteSalarie dernierSinistre = null;
      if ((p_demande != null) && (p_demande.getDossierAffectation() != null) && (p_demande.getDossierAffectation().getProduit() != null))
      {
        critereStrategie.setProduit(p_demande.getDossierAffectation().getProduit());
      }
      else
      {
        if (dernierSinistre == null)
        {
          listeActivitesSalarieesSansConflit.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
          dernierSinistre = (ActiviteSalarie)listeActivitesSalarieesSansConflit.premierElement();
        }
        critereStrategie.setProduit(dernierSinistre.getReglement().getProduit());
      }
      StrategiePlafonnementAffiliationSpec StrategiePlafonnementAffiliationCourante = (StrategiePlafonnementAffiliationSpec)FabriqueStrategiePlafonnementAffiliation.getInstance().getStrategie(critereStrategie);
      
      listePeriodesElementairesAvecPlafonnement = StrategiePlafonnementAffiliationCourante.plafonnerAffiliation(p_periode, listePeriodesElementaires, p_justificationAffi);
    }
    listeActivitesParticipantesSansConflit = new ChronologiePeriodes();
    listeActivitesParticipantesSansConflit.ajouter(listePeriodesElementairesAvecPlafonnement);
    listeActivitesParticipantesSansConflit.ajouter(listeActivitesAssimilablesSansConflit);
    
    QuantitesAppartenance quantitesAppartenance = OutilCalculAffiliation.calculer(p_periode, listeActivitesParticipantesSansConflit, p_reglement, p_justificationAffi);
    if (p_justificationAffi != null) {
      topageZmePnds(p_justificationAffi.getChronoZmes(), listePNDS);
    }
    quantitesAppartenance.setEnConflit(activiteEnConflit);
    
    return quantitesAppartenance;
  }
  
  public Quantite calculerAppartenancePRS(DemandeSpec p_demande, Periode p_periode, Chronologie p_passeProfessionnel)
  {
    Damj dateExamen = p_demande.getDateExamen();
    Chronologie passeProfessionnel = null;
    Chronologie listeActivitesSalariees = null;
    Chronologie listeActivitesSalarieesSansConflit = null;
    
    passeProfessionnel = p_passeProfessionnel.copier(new FiltreChevauchePeriode(p_periode));
    if (dateExamen != null) {
      passeProfessionnel = passeProfessionnel.copier(new FiltreFinAvantOuCoincideAvecDate(dateExamen));
    }
    FiltreNegation filtreActiviteSalarieeSansSuspensionRCT = new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    passeProfessionnel = passeProfessionnel.copier(filtreActiviteSalarieeSansSuspensionRCT);
    
    listeActivitesSalariees = passeProfessionnel.copier(new FiltreActiviteSalarie());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesQualifiables());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesLiquidables());
    listeActivitesSalarieesSansConflit = listeActivitesSalariees.copier(new FiltrePeriodesSansConflit());
    
    Chronologie listePeriodesElementaires = constituerPeriodesElementaires(listeActivitesSalarieesSansConflit, p_periode, null);
    listePeriodesElementaires = listePeriodesElementaires.copier(new FiltreChevauchePeriode(p_periode));
    
    ChronologiePeriodes chronoPeriodeActivite = new ChronologiePeriodes();
    Iterator iterChrono = listePeriodesElementaires.iterer();
    while (iterChrono.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)iterChrono.next();
      chronoPeriodeActivite.ajouter(new ObjetChronoPeriodeConcrete(periodeElementaire.getPeriode()));
    }
    if (chronoPeriodeActivite.contientChevauchementElements()) {
      chronoPeriodeActivite = chronoPeriodeActivite.fusionnerChevauchementPeriodes();
    }
    Iterator iter = chronoPeriodeActivite.iterer();
    
    int nbJour = 0;
    while (iter.hasNext())
    {
      ObjetChronoPeriode periode = (ObjetChronoPeriode)iter.next();
      nbJour += periode.getDuree();
    }
    return new Quantite(new BigDecimal(nbJour), Unite.get("jour d'affiliation"));
  }
  
  private void determinerPeriodesAffiliationPourAlimentationBasePivot(DemandeSpec p_demande, Chronologie p_listeActivitesSalarieesSansConflit, Chronologie p_listeActivitesAssimilablesSansConflit)
  {
    if (p_demande != null)
    {
      Chronologie listePeriodesAffiliation = new ChronologiePeriodes();
      if ((p_listeActivitesSalarieesSansConflit != null) && (p_listeActivitesAssimilablesSansConflit != null))
      {
        listePeriodesAffiliation.ajouter(p_listeActivitesSalarieesSansConflit);
        listePeriodesAffiliation.ajouter(p_listeActivitesAssimilablesSansConflit);
      }
      ((Demande)p_demande).setPeriodesAffiliation(listePeriodesAffiliation);
    }
  }
  
  public Chronologie determinerActivitesParticipantes(Periode p_periode, Chronologie p_passeProfessionnel, Chronologie p_pnds)
    throws CoucheLogiqueException
  {
    FiltreTemporel filtre = new FiltreChevauchePeriode(p_periode);
    Chronologie passeProfessionnel = p_passeProfessionnel.copier(filtre);
    
    filtre = new FiltreActiviteSalarie();
    Chronologie listeActivitesSalariees = passeProfessionnel.copier(filtre);
    
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesQualifiables());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesLiquidables());
    
    Chronologie listePeriodesElementaires = constituerPeriodesElementaires(listeActivitesSalariees, p_periode, p_pnds);
    
    filtre = new FiltrePeriodeFormationAssimilable();
    Chronologie listeActivitesAssimilables = passeProfessionnel.copier(filtre);
    
    Chronologie listeActivitesParticipantes = new ChronologiePeriodes();
    listeActivitesParticipantes.ajouter(listePeriodesElementaires);
    listeActivitesParticipantes.ajouter(listeActivitesAssimilables);
    return listeActivitesParticipantes;
  }
  
  private Chronologie constituerPeriodesElementaires(Chronologie p_listeActivitesSalariees, Periode p_periode, Chronologie p_pnds)
  {
    Chronologie listePeriodesElementaires = new ChronologiePeriodes();
    for (Iterator iter = p_listeActivitesSalariees.iterer(); iter.hasNext();)
    {
      ActiviteSalarie periodeActiviteSalarie = (ActiviteSalarie)iter.next();
      Chronologie periodesSuspension = periodeActiviteSalarie.getListePeriodesIncident().copier(new FiltreIncident());
      Chronologie tmp = ConstitutionPeriodesElementaires.constituer(periodeActiviteSalarie, p_periode, p_pnds, periodesSuspension);
      listePeriodesElementaires.ajouter(tmp);
    }
    return listePeriodesElementaires;
  }
  
  protected void topageZmePnds(Chronologie p_chronoZme, Collection p_listePNDS)
  {
    Iterator iterZme;
    if (p_listePNDS != null) {
      for (iterZme = p_chronoZme.iterer(); iterZme.hasNext();)
      {
        zme = (ZoneMemeExercice)iterZme.next();
        for (iterPnds = p_listePNDS.iterator(); iterPnds.hasNext();)
        {
          PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)iterPnds.next();
          if (prendreEnComptePNDSPourZME(zme, pnds))
          {
            zme.setChevauchePnds(true);
            break;
          }
        }
      }
    }
    ZoneMemeExercice zme;
    Iterator iterPnds;
  }
  
  private boolean prendreEnComptePNDSPourZME(ZoneMemeExercice p_zme, PeriodeNonDeclareeSanction p_pnds)
  {
    if (p_pnds != null)
    {
      boolean activitePriseEnCompte = false;
      boolean presencePNDSSurPeriodeZME = false;
      if (p_pnds.getPeriodeActivite() == null)
      {
        activitePriseEnCompte = true;
      }
      else
      {
        Iterator itActivitesProratisees = p_zme.getListeActivitesProratisees().iterator();
        while (itActivitesProratisees.hasNext())
        {
          ActiviteProratisee activiteProratisee = (ActiviteProratisee)itActivitesProratisees.next();
          if (activiteProratisee.getPeriodeOrigine().equals(p_pnds.getPeriodeActivite())) {
            activitePriseEnCompte = true;
          }
        }
      }
      presencePNDSSurPeriodeZME = p_zme.inter(p_pnds.getChronoPeriodePNDS()) > 0;
      
      return (activitePriseEnCompte) && (presencePNDSSurPeriodeZME);
    }
    return false;
  }
  
  private void leverAlerteA11MNB9SurPresencePNDS(DemandeSpec p_demande, Chronologie p_pnds)
  {
    String codeAlerteNonBloquante = "A11MNB9";
    
    Collection listePnds = new ArrayList();
    for (Iterator iterPnds = p_pnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
}

/* Location:
 * Qualified Name:     CalculAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */