package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class DernierJourFevrier
{
  private static final Unite UNITE_JOUR = UniteAffiliation.get("jour d'affiliation");
  private static final Unite UNITE_HEURE = UniteAffiliation.get("heure de travail");
  private static final Unite UNITE_JOUR_EMBARQUEMENT = UniteAffiliation.get("embarquement administratif");
  
  public static Hashtable calculerAffiliation(Periode p_periode, List p_listeZMEs)
  {
    int fevrier = 2;
    Hashtable tableQuantites = new Hashtable();
    
    boolean bTrouve = false;
    for (int annee = p_periode.getDebut().getAnnee(); annee <= p_periode.getFin().getAnnee(); annee++)
    {
      Damj dernierJourFevrier = new Damj(annee, 2, 1).getFinMois();
      Iterator iter = p_listeZMEs.iterator();
      Hashtable tableQuantitesParAnnee = new Hashtable();
      while ((!bTrouve) && (iter.hasNext()))
      {
        ZoneMemeExercice zme = (ZoneMemeExercice)iter.next();
        bTrouve = existeActiviteAssimilable(zme, dernierJourFevrier);
        if ((bTrouve) && (!zme.chevauchePnds()) && (zme.getListeActivitesAffiliation() != null) && (!zme.getListeActivitesAffiliation().isEmpty()))
        {
          ajouterQuantitesAssimilation(tableQuantitesParAnnee, zme.getListeReglementAssimilables());
          if (tableQuantitesParAnnee.size() > 0)
          {
            zme.ajouterAssimilationFevrier(tableQuantitesParAnnee);
            ajouterQuantiteDernierMoisFevrierParAnnee(tableQuantites, tableQuantitesParAnnee);
          }
        }
      }
      bTrouve = false;
    }
    return tableQuantites;
  }
  
  private static boolean existeActiviteAssimilable(ZoneMemeExercice p_zme, Damj p_dernierJourFevrier)
  {
    return new Periode(p_zme.getDateDebut(), p_zme.getDateFin()).contient(p_dernierJourFevrier);
  }
  
  private static void ajouterQuantitesAssimilation(Hashtable p_tableQuantites, Collection p_listeReglements)
  {
    ajouterQuantitesAssimilationClassique(p_tableQuantites, p_listeReglements);
  }
  
  protected static void ajouterQuantitesAssimilationCSA06P03Beta(Hashtable p_tableQuantites, Reglement p_rechercheRecheche)
  {
    if (p_rechercheRecheche.estNomReglementIdentique("RG"))
    {
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR);
      ajouterQuantite(p_tableQuantites, "10", UNITE_HEURE);
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR_EMBARQUEMENT);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("OP"))
    {
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR);
      ajouterQuantite(p_tableQuantites, "8.7", UNITE_HEURE);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A1"))
    {
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A2a"))
    {
      ajouterQuantite(p_tableQuantites, "14", UNITE_HEURE);
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR_EMBARQUEMENT);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A2b"))
    {
      ajouterQuantite(p_tableQuantites, "2", UNITE_JOUR_EMBARQUEMENT);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A5"))
    {
      ajouterQuantite(p_tableQuantites, "10", UNITE_HEURE);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A9A"))
    {
      ajouterQuantite(p_tableQuantites, "3", UNITE_JOUR);
      ajouterQuantite(p_tableQuantites, "15", UNITE_HEURE);
    }
    else if (p_rechercheRecheche.estNomReglementIdentique("A9B"))
    {
      ajouterQuantite(p_tableQuantites, "3", UNITE_JOUR);
    }
  }
  
  private static void ajouterQuantitesAssimilationClassique(Hashtable p_tableQuantites, Collection p_listeReglements)
  {
    Hashtable tableQuantitesMax = new Hashtable();
    Iterator it = p_listeReglements.iterator();
    while (it.hasNext())
    {
      Reglement reglementCourant = (Reglement)it.next();
      if (reglementCourant.estNomReglementIdentique("RG"))
      {
        conserverQuantiteMax(tableQuantitesMax, "2", UNITE_JOUR);
        conserverQuantiteMax(tableQuantitesMax, "10", UNITE_HEURE);
      }
      else if (reglementCourant.estNomReglementIdentique("OP"))
      {
        conserverQuantiteMax(tableQuantitesMax, "2", UNITE_JOUR);
        conserverQuantiteMax(tableQuantitesMax, "8.7", UNITE_HEURE);
      }
      else if (reglementCourant.estNomReglementIdentique("A1"))
      {
        conserverQuantiteMax(tableQuantitesMax, "2", UNITE_JOUR);
      }
      else if (reglementCourant.estNomReglementIdentique("A2a"))
      {
        conserverQuantiteMax(tableQuantitesMax, "14", UNITE_HEURE);
        conserverQuantiteMax(tableQuantitesMax, "2", UNITE_JOUR_EMBARQUEMENT);
      }
      else if (reglementCourant.estNomReglementIdentique("A2b"))
      {
        conserverQuantiteMax(tableQuantitesMax, "2", UNITE_JOUR_EMBARQUEMENT);
      }
      else if (reglementCourant.estNomReglementIdentique("A5"))
      {
        conserverQuantiteMax(tableQuantitesMax, "10", UNITE_HEURE);
      }
    }
    if (!tableQuantitesMax.isEmpty())
    {
      ajouterQuantiteMaxConservee(p_tableQuantites, tableQuantitesMax, UNITE_JOUR);
      ajouterQuantiteMaxConservee(p_tableQuantites, tableQuantitesMax, UNITE_HEURE);
      ajouterQuantiteMaxConservee(p_tableQuantites, tableQuantitesMax, UNITE_JOUR_EMBARQUEMENT);
    }
  }
  
  private static void ajouterQuantite(Hashtable p_tableQuantites, String p_valeur, Unite p_unite)
  {
    Quantite qte = (Quantite)p_tableQuantites.get(p_unite);
    if (qte == null) {
      qte = new Quantite(p_valeur, p_unite);
    } else {
      qte = qte.ajouter(new Quantite(p_valeur, p_unite));
    }
    p_tableQuantites.put(p_unite, qte);
  }
  
  private static void conserverQuantiteMax(Hashtable p_tableQuantites, String p_valeur, Unite p_unite)
  {
    Quantite qteExistante = (Quantite)p_tableQuantites.get(p_unite);
    Quantite qteAExaminer = new Quantite(p_valeur, p_unite);
    if ((qteExistante == null) || (qteExistante.getValeur().compareTo(qteAExaminer.getValeur()) < 0)) {
      p_tableQuantites.put(p_unite, qteAExaminer);
    }
  }
  
  private static void ajouterQuantiteMaxConservee(Hashtable p_tableQuantites, Hashtable p_tableQuantitesMaxConservee, Unite p_unite)
  {
    Quantite qteGlobale = new Quantite(0, p_unite);
    Quantite qteExistante = (Quantite)p_tableQuantites.get(p_unite);
    Quantite qteMaxConservee = (Quantite)p_tableQuantitesMaxConservee.get(p_unite);
    if ((qteExistante != null) && (qteMaxConservee != null)) {
      qteGlobale = qteExistante.ajouter(qteMaxConservee);
    } else if (qteMaxConservee != null) {
      qteGlobale = qteMaxConservee;
    }
    p_tableQuantites.put(p_unite, qteGlobale);
  }
  
  private static void ajouterQuantiteDernierMoisFevrierParAnnee(Hashtable p_tableQuantiteTotale, Hashtable p_tableQuantiteAnnee)
  {
    cumulQuantiteAffiliationDernierFevrier(p_tableQuantiteTotale, p_tableQuantiteAnnee, UniteAffiliation.get("jour d'affiliation"));
    
    cumulQuantiteAffiliationDernierFevrier(p_tableQuantiteTotale, p_tableQuantiteAnnee, UniteAffiliation.get("heure de travail"));
    
    cumulQuantiteAffiliationDernierFevrier(p_tableQuantiteTotale, p_tableQuantiteAnnee, UniteAffiliation.get("embarquement administratif"));
  }
  
  private static void cumulQuantiteAffiliationDernierFevrier(Hashtable p_tableQuantiteTotale, Hashtable p_tableQuantiteAnnee, Unite p_unite)
  {
    Quantite quantite = (Quantite)p_tableQuantiteTotale.get(p_unite);
    if (quantite != null)
    {
      if (p_tableQuantiteAnnee.get(p_unite) != null) {
        p_tableQuantiteTotale.put(p_unite, quantite.ajouter((Quantite)p_tableQuantiteAnnee.get(p_unite)));
      }
    }
    else {
      p_tableQuantiteTotale.put(p_unite, p_tableQuantiteAnnee.get(p_unite));
    }
  }
}

/* Location:
 * Qualified Name:     DernierJourFevrier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */