package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.ConstitutionPeriodesElementaires;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategiePlafonnementAffiliationSpec;
import fr.unedic.cali.asu.dom.PlafonnementAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltrePeriodeElementairePlafonnementAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.dom.PeriodeElementaire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;

public class StrategiePlafonnementAffiliationApres
  implements StrategiePlafonnementAffiliationSpec
{
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static final BigDecimal UN = new BigDecimal("1");
  
  public Chronologie plafonnerAffiliation(Periode p_pra, Chronologie p_chronoPeriodesElementaires, JustificationAffiliation p_justificationAffiliation)
  {
    Chronologie chronoPeriodesElementairesResultat = new ChronologiePeriodes();
    
    Chronologie chronoPeriodesElementairesParticipantesPlafonnement = p_chronoPeriodesElementaires.copier(new FiltrePeriodeElementairePlafonnementAffiliation());
    if (chronoPeriodesElementairesParticipantesPlafonnement.estVide())
    {
      chronoPeriodesElementairesResultat = p_chronoPeriodesElementaires;
    }
    else
    {
      Chronologie chronoPeriodesElementairesNonParticipantes = p_chronoPeriodesElementaires.copier(new FiltreNegation(new FiltrePeriodeElementairePlafonnementAffiliation()));
      
      chronoPeriodesElementairesResultat.ajouter(chronoPeriodesElementairesNonParticipantes);
    }
    Chronologie chronoPeriodesElementairesParticipantesProratiseesParMois = determinerChronoPeriodesElementairesProratiseesParMois(chronoPeriodesElementairesParticipantesPlafonnement);
    
    ArrayList listeMoisCivils = p_pra.decouperEnMoisCivils();
    PeriodeElementaire periodeElementaireCourante = null;
    Periode moisCivilCourant = null;
    Chronologie chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant = null;
    Quantite quantiteHeuresActiviteCourante = null;
    Quantite quantiteHeuresSuspensionCourante = null;
    BigDecimal cumulMensuelHeuresActivite = null;
    BigDecimal cumulMensuelHeuresSuspension = null;
    for (Iterator iterateurMoisCivils = listeMoisCivils.iterator(); iterateurMoisCivils.hasNext();)
    {
      moisCivilCourant = (Periode)iterateurMoisCivils.next();
      
      cumulMensuelHeuresActivite = ZERO;
      cumulMensuelHeuresSuspension = ZERO;
      
      chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant = chronoPeriodesElementairesParticipantesProratiseesParMois.copier(new FiltreChevauchePeriode(moisCivilCourant));
      
      chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant.iterer();
      while (chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant.encoreSuivant())
      {
        periodeElementaireCourante = (PeriodeElementaire)chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant.elementSuivant();
        
        quantiteHeuresActiviteCourante = periodeElementaireCourante.donnerQuantiteHeuresActiviteSelonPresenceSuspension();
        if (quantiteHeuresActiviteCourante != null) {
          cumulMensuelHeuresActivite = cumulMensuelHeuresActivite.add(quantiteHeuresActiviteCourante.getValeur());
        }
        quantiteHeuresSuspensionCourante = periodeElementaireCourante.getQuantiteHeuresSuspension();
        if (quantiteHeuresSuspensionCourante != null) {
          cumulMensuelHeuresSuspension = cumulMensuelHeuresSuspension.add(quantiteHeuresSuspensionCourante.getValeur());
        }
      }
      traiterPlafonnementMensuel(moisCivilCourant, chronoPeriodesElementairesParticipantesPlafonnementMoisCivilCourant, cumulMensuelHeuresActivite, cumulMensuelHeuresSuspension, chronoPeriodesElementairesResultat, p_justificationAffiliation);
    }
    return chronoPeriodesElementairesResultat;
  }
  
  private Chronologie determinerChronoPeriodesElementairesProratiseesParMois(Chronologie p_chronoPeriodesElementairesParticipantes)
  {
    Chronologie chronoPeriodesElementairesParticipantesProratiseesParMois = new ChronologiePeriodes();
    PeriodeElementaire periodeElementaireCourante = null;
    PeriodeElementaire periodeElementaireProratiseeCourante = null;
    ArrayList listeMoisCivils = null;
    Periode moisCivilCourant = null;
    p_chronoPeriodesElementairesParticipantes.iterer();
    Iterator iterateurMoisCivils;
    while (p_chronoPeriodesElementairesParticipantes.encoreSuivant())
    {
      periodeElementaireCourante = (PeriodeElementaire)p_chronoPeriodesElementairesParticipantes.elementSuivant();
      
      listeMoisCivils = periodeElementaireCourante.decouperEnMoisCivils();
      for (iterateurMoisCivils = listeMoisCivils.iterator(); iterateurMoisCivils.hasNext();)
      {
        moisCivilCourant = (Periode)iterateurMoisCivils.next();
        
        periodeElementaireProratiseeCourante = ConstitutionPeriodesElementaires.proratiseAffiliationSurPeriode(periodeElementaireCourante, moisCivilCourant);
        
        chronoPeriodesElementairesParticipantesProratiseesParMois.ajouter(periodeElementaireProratiseeCourante);
      }
    }
    return chronoPeriodesElementairesParticipantesProratiseesParMois;
  }
  
  private void traiterPlafonnementMensuel(Periode p_moisCivil, Chronologie p_chronoPeriodesElementairesParticipantes, BigDecimal p_cumulMensuelHeuresActivite, BigDecimal p_cumulMensuelHeuresSuspension, Chronologie p_chronoPeriodesElementairesResultat, JustificationAffiliation p_justificationAffiliation)
  {
    PeriodeElementaire periodeElementaireCourante = null;
    Quantite quantiteHeuresActiviteCourante = null;
    Quantite quantiteHeuresSuspensionCourante = null;
    PlafonnementAffiliation plafonnementAffiliationMoisCivilCourant = null;
    BigDecimal plafondMensuel = ZERO;
    BigDecimal reliquatPlafondMensuel = ZERO;
    BigDecimal coefficientReducteur = UN;
    BigDecimal nombreHeuresReduitesCourante = ZERO;
    
    plafonnementAffiliationMoisCivilCourant = new PlafonnementAffiliation(p_moisCivil);
    plafonnementAffiliationMoisCivilCourant.setPlafondMensuel(new Quantite(260, Unite.getParCode("18")));
    if (p_justificationAffiliation != null) {
      p_justificationAffiliation.ajouterPlafonnementAffiliation(plafonnementAffiliationMoisCivilCourant);
    }
    plafondMensuel = plafonnementAffiliationMoisCivilCourant.getPlafondMensuel().getValeur();
    
    p_cumulMensuelHeuresActivite = Mathematiques.arrondiASup(p_cumulMensuelHeuresActivite, 0);
    p_cumulMensuelHeuresSuspension = Mathematiques.arrondiASup(p_cumulMensuelHeuresSuspension, 0);
    if (p_cumulMensuelHeuresActivite.compareTo(plafondMensuel) > 0)
    {
      coefficientReducteur = Mathematiques.diviseParDefaut(plafondMensuel, p_cumulMensuelHeuresActivite);
      
      p_chronoPeriodesElementairesParticipantes.iterer();
      while (p_chronoPeriodesElementairesParticipantes.encoreSuivant())
      {
        periodeElementaireCourante = (PeriodeElementaire)p_chronoPeriodesElementairesParticipantes.elementSuivant();
        
        quantiteHeuresActiviteCourante = periodeElementaireCourante.donnerQuantiteHeuresActiviteSelonPresenceSuspension();
        nombreHeuresReduitesCourante = quantiteHeuresActiviteCourante.getValeur().multiply(coefficientReducteur);
        
        quantiteHeuresActiviteCourante = new Quantite(nombreHeuresReduitesCourante, UniteAffiliation.HEURE_TRAVAIL);
        periodeElementaireCourante.ajouterQuantiteAffiliation(quantiteHeuresActiviteCourante);
        p_chronoPeriodesElementairesResultat.ajouter(periodeElementaireCourante);
      }
      plafonnementAffiliationMoisCivilCourant.setCoefficientReducteurAffiliation(coefficientReducteur);
    }
    else
    {
      reliquatPlafondMensuel = plafondMensuel.subtract(p_cumulMensuelHeuresActivite);
      if (p_cumulMensuelHeuresSuspension.compareTo(reliquatPlafondMensuel) <= 0)
      {
        p_chronoPeriodesElementairesResultat.ajouter(p_chronoPeriodesElementairesParticipantes);
      }
      else
      {
        coefficientReducteur = Mathematiques.diviseParDefaut(reliquatPlafondMensuel, p_cumulMensuelHeuresSuspension);
        
        p_chronoPeriodesElementairesParticipantes.iterer();
        while (p_chronoPeriodesElementairesParticipantes.encoreSuivant())
        {
          periodeElementaireCourante = (PeriodeElementaire)p_chronoPeriodesElementairesParticipantes.elementSuivant();
          
          quantiteHeuresSuspensionCourante = periodeElementaireCourante.getQuantiteHeuresSuspension();
          nombreHeuresReduitesCourante = quantiteHeuresSuspensionCourante.getValeur().multiply(coefficientReducteur);
          
          quantiteHeuresSuspensionCourante = new Quantite(nombreHeuresReduitesCourante, UniteAffiliation.HEURE_TRAVAIL);
          quantiteHeuresActiviteCourante = periodeElementaireCourante.donnerQuantiteHeuresActiviteSelonPresenceSuspension();
          periodeElementaireCourante.ajouterQuantiteAffiliation(quantiteHeuresActiviteCourante.ajouter(quantiteHeuresSuspensionCourante));
          
          p_chronoPeriodesElementairesResultat.ajouter(periodeElementaireCourante);
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     StrategiePlafonnementAffiliationApres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */