package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDeterminationDebutPRA;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationDebutPRA;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreTypeRechargementSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilAdhesionVolontaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConstructionPRASpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class ConstructionPra
  implements OutilFonctionnel
{
  public static int ORDRE_REGLEMENT_APPLICABLE = 1;
  public static int ORDRE_QUANTITE_APPARTENANCE = 2;
  
  public static Collection<Pra> determinerListePra(DonneesEntreeDeterminationListePra p_donneesEntreeDeterminationListePra)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_donneesEntreeDeterminationListePra.getDemande();
    
    Collection<Pra> listePra = null;
    ActiviteSalarie periodeFctForcee = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenir();
    Quantite quantiteAffiliationForcee = demande.getDonneesTemporaires().getQuantiteAffiliation();
    TravailSpec dernierSinistre = ((DossierAffectation)demande.getDossierAffectation()).getSinistre();
    DureeCalendaire age = demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin());
    if (periodeFctForcee != null)
    {
      p_donneesEntreeDeterminationListePra.setActiviteSalarie(periodeFctForcee);
      if (quantiteAffiliationForcee != null)
      {
        listePra = new ArrayList();
        Damj dateDernierSinistre = ((DossierAffectation)demande.getDossierAffectation()).getSinistre().getDateFin();
        DureeCalendaire ageAllocataireAuDernierSinistre = demande.getDemandeur().getAgeALaDate(dateDernierSinistre);
        p_donneesEntreeDeterminationListePra.setAgeIndividu(ageAllocataireAuDernierSinistre);
        listePra.add(determinerPraForceeRa(p_donneesEntreeDeterminationListePra));
      }
      else
      {
        p_donneesEntreeDeterminationListePra.setAgeIndividu(age);
        listePra = determinerListePraPrive(p_donneesEntreeDeterminationListePra);
      }
    }
    else
    {
      p_donneesEntreeDeterminationListePra.setAgeIndividu(age);
      listePra = determinerListePraPrive(p_donneesEntreeDeterminationListePra);
    }
    return listePra;
  }
  
  public static Pra determinerPram(ActiviteSalarie p_activiteSalarieSpec, Demande p_demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)p_activiteSalarieSpec.getReglement().getProduit();
    
    ConstructionPRASpec outilConstructionPra = produit.getOutilConstructionPRA();
    if (outilConstructionPra == null) {
      outilConstructionPra = ((ProduitAsuSpec)p_demande.getDossierAffectation().getProduit()).getOutilConstructionPRA();
    }
    boolean estEnContexteDeRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE");
    if (estEnContexteDeRechargement)
    {
      EreTypeRechargementSpec ereTypeRechargement = (EreTypeRechargementSpec)p_demande.getEvenementReferenceExamen();
      Reglement reglementForce = ereTypeRechargement.getReglementForcePourRechargement();
      
      p_activiteSalarieSpec.initialiserReglementForce(reglementForce);
      
      produit = (ProduitAsuSpec)reglementForce.getProduit();
    }
    Pra pram = (Pra)outilConstructionPra.determinerPram(determinerReglementPeriode(p_activiteSalarieSpec));
    
    pram = determinerPeriode(p_activiteSalarieSpec, p_demande, pram, null);
    if (estEnContexteDeRechargement) {
      p_activiteSalarieSpec.supprimerReglementForce();
    }
    return pram;
  }
  
  public static Pra determinerPraDv(Demande p_demande, Damj p_fctDV, Reglement p_reglement)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)p_reglement.getProduit();
    
    Pra pra = (Pra)produit.getOutilConstructionPRA().determinerPraPourDV(p_reglement.getNomReglement());
    
    Damj dateFinPra = p_demande.getDateFaitGenerateurOuDernierSinistre();
    pra.setDebut(p_fctDV.lendemain());
    pra.setFin(dateFinPra);
    
    return pra;
  }
  
  private static Collection<Pra> determinerListePraPrive(DonneesEntreeDeterminationListePra p_donneesEntreeDeterminationListePra)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_donneesEntreeDeterminationListePra.getDemande();
    ActiviteSalarie activiteSalarie = p_donneesEntreeDeterminationListePra.getActiviteSalarie();
    ProduitAsuSpec produit = (ProduitAsuSpec)activiteSalarie.getReglement().getProduit();
    
    boolean estEnContexteDeRechargement = p_donneesEntreeDeterminationListePra.isForcerReglementRecharge();
    if (estEnContexteDeRechargement)
    {
      EreTypeRechargementSpec ereTypeRechargement = (EreTypeRechargementSpec)p_donneesEntreeDeterminationListePra.getDemande().getEvenementReferenceExamen();
      Reglement reglementForce = ereTypeRechargement.getReglementForcePourRechargement();
      
      activiteSalarie.initialiserReglementForce(reglementForce);
      
      produit = (ProduitAsuSpec)reglementForce.getProduit();
    }
    Collection<Pra> listePra = null;
    listePra = produit.getOutilConstructionPRA().determinerListePraQuantiteAppartenance(p_donneesEntreeDeterminationListePra);
    if (listePra != null)
    {
      Iterator<Pra> it = listePra.iterator();
      while (it.hasNext())
      {
        Pra pra = (Pra)it.next();
        determinerPeriode(activiteSalarie, demande, pra, p_donneesEntreeDeterminationListePra.getDateBornePRA());
      }
    }
    if (estEnContexteDeRechargement) {
      activiteSalarie.supprimerReglementForce();
    }
    return listePra;
  }
  
  private static Pra determinerPeriode(ActiviteSalarie p_activiteSalarieSpec, Demande p_demande, Pra p_pra, Damj p_dateBorneDebutPRA)
    throws CoucheLogiqueException
  {
    Quantite quantite = p_pra.getDureeInitiale();
    DureeCalendaire duree = DureeCalendaire.depuisQuantite(quantite);
    
    Damj terme = p_activiteSalarieSpec.getDateFin();
    
    Damj dateFgOdPrecedent = determinerDateFaitGenerateurOdPrecedente(p_demande);
    
    StrategieDeterminationDebutPRA strategie = FabriqueStrategieDeterminationDebutPRA.getInstance().getStrategie(p_activiteSalarieSpec);
    
    Damj depart = strategie.determinerDebutPRA(p_activiteSalarieSpec, terme, duree);
    if ((p_dateBorneDebutPRA != null) && (p_dateBorneDebutPRA.estApres(depart)) && (p_dateBorneDebutPRA.estAvant(terme))) {
      depart = p_dateBorneDebutPRA;
    }
    if ((dateFgOdPrecedent == null) || (dateFgOdPrecedent.estAvant(depart)))
    {
      p_pra.setDebut(depart);
      p_pra.setFin(terme);
    }
    else
    {
      p_pra.setDebut(dateFgOdPrecedent.lendemain());
      p_pra.setFin(terme);
    }
    return p_pra;
  }
  
  private static Damj determinerDateFaitGenerateurOdPrecedente(Demande p_demande)
  {
    Damj dateFaitGenerateurOdPrecedente = null;
    ContexteDemande contexteDemandeAspVol = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(p_demande.getListContexteDemande(), "ADHVOLARE");
    ContexteDemande contexteAreSousJacentRevision = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(p_demande.getListContexteDemande(), "ARESJREV");
    if (contexteAreSousJacentRevision != null)
    {
      dateFaitGenerateurOdPrecedente = null;
    }
    else if (contexteDemandeAspVol != null)
    {
      OutilAdhesionVolontaire.trouverOdAreAdhesionVolontaire(p_demande);
      dateFaitGenerateurOdPrecedente = determinerDateFaitGenerateurOdPrecedente((Demande)contexteDemandeAspVol.getAttributionAreAdhesionVolontaire().getDemande());
    }
    else if (p_demande.estEnContexteDroitAnterieurSecteurPublic())
    {
      dateFaitGenerateurOdPrecedente = p_demande.getDonneesTemporaires().getDateFgDroitAnterieurSp();
    }
    else
    {
      FiltreET filtres = new FiltreET();
      filtres.ajouterFiltre(new FiltreNegation(new FiltreDecisionPourLigne(LigneAsuSsp07.getInstance().getNomUnique())));
      filtres.ajouterFiltre(new FiltreNegation(new FiltreDecisionPourLigne(LigneAsuFds12.getInstance().getNomUnique())));
      filtres.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
      filtres.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, true, true, false, p_demande));
      if (p_demande.getDonneesTemporaires().isEstIgnorerAttribPrecCSR())
      {
        FiltreOU filtreCsr = new FiltreOU();
        filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("CSRSUSP"));
        filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("RUPCTRSUSP"));
        FiltreNegation filtreNonCsr = new FiltreNegation(filtreCsr);
        filtres.ajouterFiltre(filtreNonCsr);
      }
      AttributionSpec attributionPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getDemandeur().getChronoDemandesNonTriees(), p_demande, filtres);
      if (attributionPrecedente != null) {
        dateFaitGenerateurOdPrecedente = ((DemandeAssuranceSpec)attributionPrecedente.getDemande()).getFaitGenerateur().getDateFaitGenerateur();
      }
    }
    return dateFaitGenerateurOdPrecedente;
  }
  
  private static String determinerReglementPeriode(ActiviteSalarie p_activiteSalarieSpec)
  {
    String reglementPeriodeEtudiee = p_activiteSalarieSpec.getReglement().getNomReglement();
    return reglementPeriodeEtudiee;
  }
  
  private static Pra determinerPraForceeRa(DonneesEntreeDeterminationListePra p_donneesEntreeDeterminationListePra)
    throws CoucheLogiqueException
  {
    Pra praCourante = null;
    Demande demandeAssuranceCourante = (Demande)p_donneesEntreeDeterminationListePra.getDemande();
    
    Quantite quantiteAffiliationForcee = demandeAssuranceCourante.getDonneesTemporaires().getQuantiteAffiliation();
    Unite uniteQuantiteAffiliationForcee = quantiteAffiliationForcee.getUnite();
    ActiviteSalarie periodeFctForcee = (ActiviteSalarie)demandeAssuranceCourante.getDonneesTemporaires().getPeriodeFctARetenir();
    
    p_donneesEntreeDeterminationListePra.setActiviteSalarie(periodeFctForcee);
    
    Collection<Pra> listePraPossibles = determinerListePraPrive(p_donneesEntreeDeterminationListePra);
    
    Quantite quantiteAffiliationRequiseCourante = null;
    Iterator<Pra> it = listePraPossibles.iterator();
    while (it.hasNext())
    {
      praCourante = (Pra)it.next();
      quantiteAffiliationRequiseCourante = praCourante.getQuantiteAffiliationRequise(uniteQuantiteAffiliationForcee);
      if ((quantiteAffiliationRequiseCourante != null) && (quantiteAffiliationForcee.compareTo(quantiteAffiliationRequiseCourante) >= 0)) {
        break;
      }
    }
    return praCourante;
  }
  
  public static Pra determinerPraLaPlusLongue(DemandeSpec p_demandeCourante, ActiviteSalarie p_periodeFctCourante)
    throws CoucheLogiqueException
  {
    Pra praLaPlusLongue = null;
    
    IndividuSpec individu = p_demandeCourante.getDemandeur();
    
    Demande demande = (Demande)p_demandeCourante;
    
    Damj dateFG = null;
    if (demande.getFaitGenerateur() != null)
    {
      dateFG = demande.getFaitGenerateur().getDateFaitGenerateur();
    }
    else
    {
      fr.unedic.cali.asu.dom.AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      if (odOrigine != null) {
        dateFG = ((Demande)odOrigine.getDemande()).getFaitGenerateur().getDateFaitGenerateur();
      }
    }
    if (dateFG == null) {
      dateFG = p_periodeFctCourante.getDateFin();
    }
    boolean contexteRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_demandeCourante, "RECHARGE");
    
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setActiviteSalarie(p_periodeFctCourante);
    donneesEntreeDeterminationListePra.setDemande(demande);
    donneesEntreeDeterminationListePra.setAgeIndividu(individu.getAgeALaDate(dateFG));
    donneesEntreeDeterminationListePra.setOrdreTriListe(ORDRE_REGLEMENT_APPLICABLE);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(contexteRechargement);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(contexteRechargement);
    Collection<Pra> listePra = determinerListePraPrive(donneesEntreeDeterminationListePra);
    if ((listePra != null) && (!listePra.isEmpty())) {
      praLaPlusLongue = (Pra)listePra.toArray()[(listePra.size() - 1)];
    }
    return praLaPlusLongue;
  }
}

/* Location:
 * Qualified Name:     ConstructionPra
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */