package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateFinCoincideAvecDate;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;

public class DeterminationCarenceIccpA4
  implements OutilFonctionnel
{
  public static DeterminationCarenceIccpA4 getInstance()
  {
    return new DeterminationCarenceIccpA4();
  }
  
  public BigDecimal proratiserMontantICCP(BigDecimal p_montantAProratiser, Periode p_periode, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente)
  {
    Damj dateFinPeriodeAttributionPrecedente = null;
    BigDecimal montant = p_montantAProratiser;
    if (p_finPeriodeAttributionAsuPrecedente != null) {
      dateFinPeriodeAttributionPrecedente = p_finPeriodeAttributionAsuPrecedente;
    }
    if (p_finPeriodeAttributionAssPrecedente != null) {
      dateFinPeriodeAttributionPrecedente = p_finPeriodeAttributionAssPrecedente;
    }
    if (dateFinPeriodeAttributionPrecedente != null)
    {
      if ((p_periode.getDebut().estAvantOuCoincideAvec(dateFinPeriodeAttributionPrecedente)) && (p_periode.getFin().estApres(dateFinPeriodeAttributionPrecedente)))
      {
        Periode periodeBornee = new Periode(dateFinPeriodeAttributionPrecedente.lendemain(), p_periode.getFin());
        montant = Mathematiques.proratiser(p_montantAProratiser, new BigDecimal(Integer.toString(periodeBornee.getDuree())), new BigDecimal(Integer.toString(p_periode.getDuree())));
      }
      if ((p_periode.getDebut().estAvant(dateFinPeriodeAttributionPrecedente)) && (p_periode.getFin().estAvantOuCoincideAvec(dateFinPeriodeAttributionPrecedente))) {
        montant = new BigDecimal("0");
      }
    }
    return montant;
  }
  
  public Salaire determinePresenceSalaireSurFCT(ActiviteSalarie p_periodeActiviteSalarie)
  {
    Salaire periodeSalaire = null;
    Chronologie chronoPeriodesSalaireCourante = p_periodeActiviteSalarie.getListeSalaires();
    Damj dateFCT = p_periodeActiviteSalarie.getDateFin();
    
    FiltreDateFinCoincideAvecDate filtre = new FiltreDateFinCoincideAvecDate(dateFCT);
    
    Chronologie chronoPeriodesSalaire = chronoPeriodesSalaireCourante.copier(filtre);
    if (chronoPeriodesSalaire.getTaille() > 0) {
      periodeSalaire = (Salaire)chronoPeriodesSalaire.premierElement();
    }
    return periodeSalaire;
  }
  
  public BigDecimal determinerMontantIccpOdA4Avant(ActiviteSalarie p_periodeActiviteSalarie, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente, boolean p_estUneChronoPendantAttribution)
  {
    QuantiteEuro quantiteEuroIccpCourante = p_periodeActiviteSalarie.getQuantiteEuroIccp();
    Damj dateFinPeriodeAttributionPrecedente = null;
    BigDecimal montant = null;
    if (p_finPeriodeAttributionAsuPrecedente != null) {
      dateFinPeriodeAttributionPrecedente = p_finPeriodeAttributionAsuPrecedente;
    }
    if (p_finPeriodeAttributionAssPrecedente != null) {
      dateFinPeriodeAttributionPrecedente = p_finPeriodeAttributionAssPrecedente;
    }
    if ((quantiteEuroIccpCourante != null) && (quantiteEuroIccpCourante.getValeurMontant().compareTo(new BigDecimal("0")) > 0)) {
      if (dateFinPeriodeAttributionPrecedente != null)
      {
        if (dateFinPeriodeAttributionPrecedente.estApresOuCoincideAvec(p_periodeActiviteSalarie.getDateFin()))
        {
          montant = p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant();
        }
        else
        {
          Salaire periodeSalaire = determinePresenceSalaireSurFCT(p_periodeActiviteSalarie);
          if (periodeSalaire != null)
          {
            montant = proratiserMontantICCP(p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant(), periodeSalaire.getPeriode(), p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
          }
          else
          {
            Damj dateDebut = Damj.max(p_periodeActiviteSalarie.getDateFin().getDebutMois(), p_periodeActiviteSalarie.getDateDebut());
            dateDebut = Damj.max(dateDebut, p_periodeActiviteSalarie.getListeSalaires().dernierElement().getDateFin().lendemain());
            Periode periodeConstruite = new Periode(dateDebut, p_periodeActiviteSalarie.getDateFin());
            montant = proratiserMontantICCP(p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant(), periodeConstruite, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
          }
        }
      }
      else {
        montant = p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant();
      }
    }
    return montant;
  }
  
  public BigDecimal determinerMontantIccpOdA4Apres(ActiviteSalarie p_periodeActiviteSalarie, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente, boolean p_estUneChronoPendantAttribution)
  {
    BigDecimal montantICCPProratise = null;
    if (!p_estUneChronoPendantAttribution)
    {
      QuantiteEuro quantiteEuroIccpCourante = p_periodeActiviteSalarie.getQuantiteEuroIccp();
      if ((quantiteEuroIccpCourante != null) && (quantiteEuroIccpCourante.getValeurMontant().compareTo(new BigDecimal("0")) > 0))
      {
        Salaire periodeSalaire = determinePresenceSalaireSurFCT(p_periodeActiviteSalarie);
        if (periodeSalaire != null)
        {
          montantICCPProratise = proratiserMontantICCP(p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant(), periodeSalaire.getPeriode(), p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
        }
        else
        {
          Damj dateDebut = Damj.max(p_periodeActiviteSalarie.getDateFin().getDebutMois(), p_periodeActiviteSalarie.getDateDebut());
          dateDebut = Damj.max(dateDebut, p_periodeActiviteSalarie.getListeSalaires().dernierElement().getDateFin().lendemain());
          Periode periodeConstruite = new Periode(dateDebut, p_periodeActiviteSalarie.getDateFin());
          montantICCPProratise = proratiserMontantICCP(p_periodeActiviteSalarie.getQuantiteEuroIccp().getValeurMontant(), periodeConstruite, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
        }
      }
    }
    return montantICCPProratise;
  }
}

/* Location:
 * Qualified Name:     DeterminationCarenceIccpA4
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */