package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDelaisReports;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.asu.produits.liquidation.dom.Readmission;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.List;

public class DeterminationProduitResultant
  implements OutilFonctionnel
{
  public static DeterminationProduitResultant getInstance()
  {
    return new DeterminationProduitResultant();
  }
  
  public Quantite determinationDureeProduitResultant(Od read, MontantAsuSpec montantResultant, Damj pointDepartUnique, Quantite capitalProduitResultant, boolean bornerRetraite)
    throws CoucheLogiqueException
  {
    Quantite montant = null;
    QuantiteJour duree = null;
    
    montant = montantResultant.getMontantPrecompteEffectif();
    if (montant.getValeur().doubleValue() == 0.0D)
    {
      duree = new QuantiteJour("0");
    }
    else
    {
      BigDecimal dureeTemp = Mathematiques.diviseParDefaut(capitalProduitResultant.getValeur(), montant.getValeur());
      dureeTemp = dureeTemp.setScale(0, 0);
      duree = new QuantiteJour(dureeTemp);
    }
    if (bornerRetraite) {
      return determinerDuree(duree.getNombreJours(), pointDepartUnique, read);
    }
    return new QuantiteJour(Integer.toString(duree.getNombreJours()));
  }
  
  public void constitutionMontantCepa15(MontantAsuSpec montantRetenu, Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    if (montantRetenu != null)
    {
      cepa15.setMontantJournalierBrut(montantRetenu.getMontantPrecompteEffectif());
      cepa15.setMontantBrutSansDeduction(montantRetenu.getMontantBrut());
      cepa15.setPensionInvaliditeADeduirePriseEnCompte(montantRetenu.getPensionInvaliditeADeduirePriseEnCompte());
      cepa15.setMontantJournalierAvantageVieillesseDeduit(montantRetenu.getMontantJournalierAvantageVieillesseDeduit());
      cepa15.setCrc(montantRetenu.getCrc());
    }
  }
  
  public Damj determinerPointDepartUnique(Demande demandeCourante, MontantAsuSpec montantCourant, MontantAsuSpec montantPrecedant)
    throws CoucheLogiqueException, ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
    
    Sjr sjrMontantMax = obtenirSjrDuMontantMax(attributionCourante, attributionPrecedente, montantCourant, montantPrecedant);
    
    return determinerPointDepart(attributionCourante, sjrMontantMax);
  }
  
  private Sjr obtenirSjrDuMontantMax(AttributionAssuranceSpec attributionCourante, AttributionAssuranceSpec attributionPrecedente, MontantAsuSpec montantCourant, MontantAsuSpec montantPrecedent)
    throws CoucheLogiqueException
  {
    Sjr sjrMontantMax = null;
    CompetenceSpec competenceDroitPrecedent = null;
    CompetenceSpec competenceDroitCourant = attributionCourante.getCompetence();
    if (attributionPrecedente != null) {
      competenceDroitPrecedent = attributionPrecedente.getCompetence();
    }
    if ((attributionPrecedente == null) || (((Demande)attributionCourante.getDemande()).getDonneesTemporaires().getSjrSP() != null))
    {
      if (montantCourant.getMontantBrut().compareTo(montantPrecedent.getMontantBrut()) >= 0)
      {
        if (((ProduitAsuSpec)attributionCourante.getProduit()).estTrancheActivee(attributionCourante.getDemande()))
        {
          TrancheExecutable tranche = (TrancheExecutable)((Attribution)attributionCourante).getListTranchesExecutables().get(0);
          sjrMontantMax = tranche.getSjr();
        }
        else
        {
          sjrMontantMax = attributionCourante.getElementBaseIndemnisation().getSjr();
        }
      }
      else
      {
        Demande demandeCourante = (Demande)attributionCourante.getDemande();
        ContexteDemande contexte = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demandeCourante, new String[] { "AREMAYOTTE" });
        
        String contexteDemande = null;
        if (contexte != null) {
          contexteDemande = contexte.getTypeContexteDemande();
        }
        Sjr sjrDonnesForcees = new Sjr(demandeCourante.getDonneesTemporaires().getSjrSP().getValeur(), demandeCourante.getDonneesTemporaires().getTermePrcSp(), contexteDemande);
        
        sjrMontantMax = sjrDonnesForcees;
      }
    }
    else if (((competenceDroitCourant.getCompetenceFinanciere() == 1) && (competenceDroitPrecedent.getCompetenceFinanciere() == 1)) || ((competenceDroitCourant.getCompetenceFinanciere() == 2) && (competenceDroitPrecedent.getCompetenceFinanciere() == 2) && (competenceDroitCourant.getNumeroConventionGestion() != null) && (competenceDroitPrecedent.getNumeroConventionGestion() != null) && (competenceDroitCourant.getNumeroConventionGestion().equalsIgnoreCase(competenceDroitPrecedent.getNumeroConventionGestion())) && (!competenceDroitCourant.getNumeroConventionGestion().equalsIgnoreCase("555"))))
    {
      if (montantCourant.getMontantPrecompte().compareTo(montantPrecedent.getMontantPrecompte()) >= 0) {
        sjrMontantMax = OutilMappingSjmSjr.convertirSjr(attributionCourante.getProduitMontantRetenu().getSalaireJournalier(attributionCourante, attributionCourante.getDateAttribution()));
      } else {
        sjrMontantMax = OutilMappingSjmSjr.convertirSjr(attributionPrecedente.getProduitMontantRetenu().getSalaireJournalier(attributionPrecedente, attributionCourante.getDateAttribution()));
      }
    }
    else if (montantCourant.getMontantBrut().compareTo(montantPrecedent.getMontantBrut()) >= 0) {
      sjrMontantMax = OutilMappingSjmSjr.convertirSjr(attributionCourante.getProduitMontantRetenu().getSalaireJournalier(attributionCourante, attributionCourante.getDateAttribution()));
    } else {
      sjrMontantMax = OutilMappingSjmSjr.convertirSjr(attributionPrecedente.getProduitMontantRetenu().getSalaireJournalier(attributionPrecedente, attributionCourante.getDateAttribution()));
    }
    return sjrMontantMax;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedent(DossierExamen dossierExamen, Demande demande)
    throws CoucheLogiqueException
  {
    MontantAsuSpec montant = null;
    AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
    Individu individu = (Individu)demande.getDemandeur();
    
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamen).getProduit();
    if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      montant = obtenirMontantDroitPrecedentSecteurPublic(demande, dossierExamen, individu, null);
    } else {
      montant = obtenirMontant(produitCourant, dossierExamen, attributionPrecedente, false);
    }
    return montant;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedentAvecCompetenceAServir(DossierExamen dossierExamenCourant, Demande demande)
    throws CoucheLogiqueException
  {
    MontantAsuSpec montant = null;
    
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamenCourant).getProduit();
    
    AttributionAssuranceSpec attributionPrecedente = dossierExamenCourant.getAttributionPrecedente();
    Competences competencesAServir = getConteneurCompetence((Competence)dossierExamenCourant.getCompetence());
    Individu individu = (Individu)demande.getDemandeur();
    if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      montant = obtenirMontantDroitPrecedentSecteurPublic(demande, dossierExamenCourant, individu, competencesAServir);
    } else {
      montant = obtenirMontant(produitCourant, dossierExamenCourant, attributionPrecedente, competencesAServir, false);
    }
    return montant;
  }
  
  public MontantAsuSpec obtenirMontantDroitCourant(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamen).getProduit();
    
    return obtenirMontant(produitCourant, dossierExamen, attributionCourante, estContexteFormation((Demande)dossierExamen.getDemande()));
  }
  
  public MontantAsuSpec obtenirMontantDroitCourantPourFinAsr(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamen).getProduit();
    
    return obtenirMontant(produitCourant, dossierExamen, attributionCourante, false);
  }
  
  public MontantAsuSpec obtenirMontantDroitCourantAvecCompetenceAServir(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamenCourant;
    Competences competencesAServir = getConteneurCompetence((Competence)dossierExamenCourant.getCompetence());
    
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamenCourant).getProduit();
    Demande demande = (Demande)dossierExamenCourant.getDemande();
    
    MontantAsuSpec montant = obtenirMontant(produitCourant, dossierExamenCourant, attributionCourante, competencesAServir, estContexteFormation(demande));
    
    return montant;
  }
  
  protected boolean estContexteFormation(Demande demande)
  {
    boolean estContexteFormation = false;
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "ARESJASPDC")) {
      estContexteFormation = true;
    }
    return estContexteFormation;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedentSecteurPublic(Demande demande, DossierExamen dossierExamen, IndividuSpec individu, Competences competences)
    throws CoucheLogiqueException
  {
    DonneesEntreesRecuperationMontant donneesEntrees = new DonneesEntreesRecuperationMontant();
    
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamen).getProduit();
    
    Boolean estProduitGerantPensionInvalidite = Boolean.valueOf(((ProduitAsuSpec)produitCourant).estProduitGerantPensionInvalidite(dossierExamen.getDemande()));
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateFinContrat(demande.getDonneesTemporaires().getDateFgDroitAnterieurSp());
    conteneur.setDateRecherche(demande.getDonneesTemporaires().getDateFgDroitAnterieurSp());
    conteneur.setBesoinCritereQualif(false);
    conteneur.setDemande(demande);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    
    ProduitAsuSpec produitPrecedent = null;
    if ((decorReglementaireDateExamen == null) && (demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().estAvant(ProduitAsuCge01P02.getInstance().getPeriodeValidite().getDebut()))) {
      produitPrecedent = ProduitAsuCge01P02.getInstance();
    } else {
      produitPrecedent = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    }
    ContexteDemande contexte = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, new String[] { "AREMAYOTTE" });
    
    String contexteDemande = null;
    if (contexte != null) {
      contexteDemande = contexte.getTypeContexteDemande();
    }
    donneesEntrees.getDonneesCalculMontant().setSalaireJournalier(new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getTermePrcSp(), contexteDemande));
    
    donneesEntrees.getDonneesCalculMontant().setCoefficientSaisonnier(demande.getDonneesTemporaires().getCoefficientSaisonnierSp());
    donneesEntrees.getDonneesCalculMontant().setCoefficientTempsPartiel(demande.getDonneesTemporaires().getCoefficientTempsPartielSp());
    
    donneesEntrees.getDonneesCalculMontant().setConditionCaractereSaisonnierParRythme(false);
    donneesEntrees.getDonneesCalculMontant().setTypeCaractereSaisonnierRetenu(-1);
    if (dossierExamen.getReglementApplicable() != null) {
      donneesEntrees.getDonneesCalculMontant().setReglementMontantRetenu(dossierExamen.getReglementApplicable().getReglement());
    }
    donneesEntrees.getDonneesCalculMontant().setEstProduitGerantPensionInvalidite(estProduitGerantPensionInvalidite);
    donneesEntrees.getDonneesCalculMontant().setListePensionInvalidite(((AttributionAssuranceSpec)dossierExamen).getListePensionInvalidite());
    if (competences == null)
    {
      competences = new Competences();
      competences.setCompetenceAdministrative(2);
      competences.setCompetenceFinanciere(2);
      if (demande.getDonneesTemporaires().isEstPCRCForceDroitPrecedent()) {
        donneesEntrees.getDonneesCalculMontant().setAvecPrecompteCRC(Boolean.TRUE);
      }
    }
    else if (competences.isEstPCRCForce())
    {
      donneesEntrees.getDonneesCalculMontant().setAvecPrecompteCRC(Boolean.TRUE);
    }
    Damj dateAttrib = dossierExamen.getDateAttribution();
    FormuleMontantSpec formule = produitPrecedent.getFormuleMontant("1");
    
    return obtenirMontant(produitCourant, produitPrecedent, individu, donneesEntrees, competences, formule, dateAttrib, false);
  }
  
  public MontantAsuSpec obtenirMontant(ProduitSpec pproduitCourant, DossierExamen dossierExamen, AttributionAssuranceSpec attribution, boolean estContexteFormation)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = attribution.getProduitMontantRetenu();
    IndividuSpec demandeur = attribution.getDemande().getDemandeur();
    
    GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
    DonneesEntreesRecuperationMontant donneesEntrees = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
    Competences competences = donneesEntrees.getCompetences();
    
    FormuleMontantSpec formule = attribution.getFormuleMontant("1");
    Damj dateCalcul = determinerDateCalcul(dossierExamen);
    
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    donneesEntrees.getDonneesCalculMontant().setListePensionInvalidite(attributionCourante.getListePensionInvalidite());
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)pproduitCourant;
    boolean estProduitGerantPensionInvalidite = produitCourant.estProduitGerantPensionInvalidite(dossierExamen.getDemande());
    donneesEntrees.getDonneesCalculMontant().setEstProduitGerantPensionInvalidite(Boolean.valueOf(estProduitGerantPensionInvalidite));
    return obtenirMontant(pproduitCourant, produit, demandeur, donneesEntrees, competences, formule, dateCalcul, estContexteFormation);
  }
  
  public MontantAsuSpec obtenirMontant(ProduitSpec produitCourant, DossierExamen dossierExamen, AttributionAssuranceSpec attribution, Competences competence, boolean estContexteFormation)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = attribution.getProduitMontantRetenu();
    IndividuSpec demandeur = attribution.getDemande().getDemandeur();
    
    GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
    DonneesEntreesRecuperationMontant donneesEntrees = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
    
    Boolean estProduitGerantPensionInvalidite = Boolean.valueOf(((ProduitAsuSpec)produitCourant).estProduitGerantPensionInvalidite(dossierExamen.getDemande()));
    AttributionAssuranceSpec attributionAssuranceCourante = (AttributionAssuranceSpec)dossierExamen;
    
    donneesEntrees.getDonneesCalculMontant().setEstProduitGerantPensionInvalidite(estProduitGerantPensionInvalidite);
    donneesEntrees.getDonneesCalculMontant().setListePensionInvalidite(attributionAssuranceCourante.getListePensionInvalidite());
    if ((competence.getCompetenceFinanciere() == 2) && (competence.getCompetenceAdministrative() == 2) && (competence.isEstPCRCForce())) {
      donneesEntrees.getDonneesCalculMontant().setAvecPrecompteCRC(Boolean.TRUE);
    } else {
      donneesEntrees.getDonneesCalculMontant().setAvecPrecompteCRC(null);
    }
    FormuleMontantSpec formule = attribution.getFormuleMontant("1");
    
    Damj dateCalcul = determinerDateCalcul(dossierExamen);
    
    return obtenirMontant(produitCourant, produit, demandeur, donneesEntrees, competence, formule, dateCalcul, estContexteFormation);
  }
  
  public Damj determinerDateCalcul(DossierExamen dossierExamen)
  {
    return dossierExamen.getDateAttribution();
  }
  
  public MontantAsuSpec obtenirMontant(ProduitSpec produitCourant, ProduitSpec produit, IndividuSpec demandeur, DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant, Competences competence, FormuleMontantSpec formule, Damj dateAttrib, boolean estContexteFormation)
    throws CoucheLogiqueException
  {
    donneesEntreesRecuperationMontant.setDateCalculMontant(dateAttrib);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setProduit(produit);
    donneesEntreesRecuperationMontant.setCompetences(competence);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setFormuleMontant(formule);
    donneesEntreesRecuperationMontant.setIndividu(demandeur);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setContexteFormation(estContexteFormation);
    if (estContexteFormation) {
      donneesEntreesRecuperationMontant.getDonneesCalculMontant().setFormuleMontant(null);
    }
    try
    {
      return (MontantAsuSpec)((ProduitAsuSpec)produitCourant).recupererMontant(donneesEntreesRecuperationMontant);
    }
    catch (ApplicativeException e)
    {
      throw new CoucheLogiqueException(e.getCode(), e);
    }
  }
  
  protected Competences getConteneurCompetence(AttributionAssuranceSpec attribution)
  {
    Competences conteneurCompetences = new Competences();
    
    conteneurCompetences.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(attribution.getConventionGestion());
    
    return conteneurCompetences;
  }
  
  protected Competences getConteneurCompetence(Competence competence)
  {
    Competences conteneurCompetences = new Competences();
    
    conteneurCompetences.setCompetenceAdministrative(competence.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(competence.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(competence.getConventionGestion());
    conteneurCompetences.setEstPCRCForce(competence.isEstPCRCForce());
    return conteneurCompetences;
  }
  
  private void reportElementsDroits(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    DossierExamenAssuranceSpec attributionSourceMontant = null;
    if (attributionCourante.getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
      attributionSourceMontant = attributionCourante;
    } else {
      attributionSourceMontant = attributionCourante.getAttributionPrecedente();
    }
    String contexteParticulierSjrProduitPrecedent = attributionSourceMontant.getAccesseurDroits().getContexteParticulierSjr();
    Sjr sjriProduitPrecedent = new Sjr(attributionSourceMontant.getAccesseurDroits().getSjrInitial().getValeur(), attributionSourceMontant.getAccesseurDroits().getDateEffetSjr(), contexteParticulierSjrProduitPrecedent);
    
    ProduitSpec produit = ((DossierAffectation)attributionCourante.getDemande().getDossierAffectation()).getProduit();
    
    Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
    {
      EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(attributionCourante.getDateAttribution());
      
      BigDecimal plafondParametre = "AREMAYOTTE".equals(contexteParticulierSjrProduitPrecedent) ? evtParam.getPlafondMayotte() : evtParam.getPlafond();
      
      BigDecimal plafond = plafondParametre.multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
      
      Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), contexteParticulierSjrProduitPrecedent);
      
      cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
    }
    else
    {
      cepa15.setSjrrpProduitPrecedent(OutilMappingSjmSjr.convertirSjr(((AttributionAssuranceSpec)attributionSourceMontant).getProduitMontantRetenu().getSalaireJournalier((AttributionAssuranceSpec)attributionSourceMontant, attributionCourante.getDateAttribution())));
    }
  }
  
  private void reportElementsDroitsSP(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    Demande demandeCourante = (Demande)attributionCourante.getDemande();
    
    QuantiteEuro sjrDroitPrecedentSP = new QuantiteEuro(demandeCourante.getDonneesTemporaires().getSjrSP().getValeur());
    Damj dateAttributionDroitAnterieur = demandeCourante.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    Damj dateTermePRC = demandeCourante.getDonneesTemporaires().getTermePrcSp();
    if (attributionCourante.getConstitutionProduitResultant().getTypeMontantRetenu() == 1)
    {
      reportElementsDroits(attributionCourante);
    }
    else
    {
      Sjr sjriProduitPrecedent = new Sjr(sjrDroitPrecedentSP.getValeur(), dateTermePRC, null);
      
      ProduitSpec produit = ((DossierAffectation)attributionCourante.getDemande().getDossierAffectation()).getProduit();
      
      Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
      if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
      {
        EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateAttributionDroitAnterieur);
        
        BigDecimal plafond = evtParam.getPlafond().multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
        
        Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), sjriProduitPrecedent.getContexteParticulier());
        
        cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
      }
      else
      {
        cepa15.setSjrrpProduitPrecedent(OutilMappingSjmSjr.convertirSjr(attributionCourante.getProduitMontantRetenu().getSalaireJournalier(attributionCourante, attributionCourante.getDateAttribution())));
      }
    }
  }
  
  public void reportElementsDroits(Readmission attributionCourante, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide()) {
      reportElementsDroitsSP(attributionCourante);
    } else {
      reportElementsDroits(attributionCourante);
    }
  }
  
  public int determinerTypeReadmission(ConstitutionProduitResultant cepa, MontantAsuSpec montantProduitResultant, Quantite capitalProduitResultant, MontantAsuSpec montantPrecedentAvecCompetenceDuDroitAServir, MontantAsuSpec montantCourantAvecCompetenceDuDroitAServir, Quantite capitalComparatifDroitPrecedent, Quantite capitalComparatifDroitCourant)
  {
    cepa.setCapitalMax(capitalProduitResultant);
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (capitalProduitResultant.equals(capitalComparatifDroitCourant)))
    {
      cepa.setTypeCapitalRetenu(1);
      cepa.setTypeMontantRetenu(1);
      return 12;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (montantProduitResultant.getSjrNonReduit().equals(montantPrecedentAvecCompetenceDuDroitAServir.getSjrNonReduit())) && (capitalProduitResultant.equals(capitalComparatifDroitCourant)))
    {
      cepa.setTypeCapitalRetenu(1);
      cepa.setTypeMontantRetenu(determinerMontantRetenu(montantPrecedentAvecCompetenceDuDroitAServir));
      return 26;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (montantProduitResultant.getSjrNonReduit().equals(montantCourantAvecCompetenceDuDroitAServir.getSjrNonReduit())) && (capitalProduitResultant.equals(capitalComparatifDroitPrecedent)))
    {
      cepa.setTypeCapitalRetenu(2);
      cepa.setTypeMontantRetenu(1);
      return 26;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (capitalProduitResultant.equals(capitalComparatifDroitPrecedent)))
    {
      cepa.setTypeCapitalRetenu(2);
      cepa.setTypeMontantRetenu(determinerMontantRetenu(montantPrecedentAvecCompetenceDuDroitAServir));
      return 11;
    }
    return -1;
  }
  
  private int determinerMontantRetenu(MontantAsuSpec mntPrecedent)
  {
    MontantAsuSpec montantPrecedent = mntPrecedent;
    if ((montantPrecedent.getCoefficientSaisonnier() != null) && (montantPrecedent.getCoefficientSaisonnier().compareTo(new BigDecimal("1")) == 0)) {
      return 3;
    }
    return 2;
  }
  
  public void affecterDureeDroitCourant(Demande demandeCourante, Quantite dureeDroitCourant)
    throws CoucheLogiqueException
  {
    ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionDurees().getDureeIndemnisation().setDureeEffective(dureeDroitCourant);
  }
  
  public Quantite obtenirCapitalPourComparaison(Quantite duree, MontantAsuSpec montant, DossierExamen dossierExamen, Demande demandeCourante, boolean capitalCourant)
    throws CoucheLogiqueException
  {
    Quantite capitalProduitEffectif = null;
    if ((!capitalCourant) && (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide()))
    {
      capitalProduitEffectif = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    }
    else
    {
      AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
      
      capitalProduitEffectif = AppelCalculParLiquidationAsu.calculerCapital(attributionCourante, montant, attributionCourante.getDateAttribution(), duree);
    }
    return new QuantiteEuro(capitalProduitEffectif.getValeur());
  }
  
  public Damj determinerPointDepart(AttributionAssuranceSpec attribution, Sjr sjr)
    throws CoucheLogiqueException, ApplicativeException
  {
    Demande demande = (Demande)attribution.getDemande();
    
    Contexte contexte = new Contexte();
    DomLiquidationAssurance dom = new DomLiquidationAssurance();
    Demande demandeCopiee = (Demande)demande.copie();
    
    demandeCopiee.setDemandeLiquidee(demande.estDemandeLiquidee());
    
    dom.setIndividu(demandeCopiee.getDemandeur());
    
    dom.setDemande(demandeCopiee);
    contexte.setDonnees(dom);
    Attribution attributionCopiee = (Attribution)demandeCopiee.getAttribution();
    
    attributionCopiee.getConstitutionSjr().setSjrrp(sjr);
    
    Parcours parcours = new ConstitutionDelaisReports();
    parcours.effectuerParcours(contexte);
    
    ConstitutionDelais cepaDelaisReports = ((Attribution)demandeCopiee.getAttribution()).getConstitutionDelais();
    return cepaDelaisReports.getPjiTheorique();
  }
  
  public void affecterDureeDroitPrecedent(DossierExamen readmission, Quantite duree)
  {
    readmission.getConstitutionProduitResultant().setDureeDroitPrecedent(duree);
  }
  
  public Quantite determinerDureeDroitPrecedentPourCalculCapital(Demande demandeCourante, Damj pointDepartUnique, MontantAsuSpec montantDroitPrecedent, boolean bornerRetraite)
    throws CoucheLogiqueException
  {
    Quantite quantiteReliquat = null;
    int nombreJours = 0;
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      quantiteReliquat = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
      BigDecimal montantPrecompte = montantDroitPrecedent.getMontantPrecompteEffectif().getValeur();
      if (montantPrecompte.compareTo(new BigDecimal("0")) > 0)
      {
        QuantiteJour duree = new QuantiteJour(Mathematiques.diviseASup(quantiteReliquat.getValeur(), montantPrecompte, 0));
        nombreJours = duree.getNombreJours();
      }
    }
    else
    {
      quantiteReliquat = demandeCourante.getReliquat().getQuantiteReliquat();
      nombreJours = quantiteReliquat.getValeurEntiere();
    }
    if (bornerRetraite) {
      return determinerDuree(nombreJours, pointDepartUnique, dossierExamen);
    }
    return new QuantiteJour(Integer.valueOf(nombreJours).toString());
  }
  
  public Quantite determinerDureeDroitPrecedentPourCalculCapitalPourFinAsr(Demande demandeCourante, Damj pointDepartUnique, MontantAsuSpec montantDroitPrecedent, boolean bornerRetraite)
    throws CoucheLogiqueException
  {
    Quantite quantiteReliquat = null;
    int nombreJours = 0;
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      quantiteReliquat = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
      BigDecimal montantPrecompte = montantDroitPrecedent.getMontantPrecompteEffectif().getValeur();
      if (montantPrecompte.compareTo(new BigDecimal("0")) > 0)
      {
        QuantiteJour duree = new QuantiteJour(Mathematiques.diviseASup(quantiteReliquat.getValeur(), montantPrecompte, 0));
        nombreJours = duree.getNombreJours();
      }
    }
    else
    {
      quantiteReliquat = ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().getDureeDroitPrecedent();
      nombreJours = quantiteReliquat.getValeurEntiere();
    }
    if (bornerRetraite == true) {
      return determinerDuree(nombreJours, pointDepartUnique, dossierExamen);
    }
    return new QuantiteJour(Integer.valueOf(nombreJours).toString());
  }
  
  public Quantite determinerDureeDroitPrecedentPourCalculCapitalPourFinAsrDCSuiteCSR(Demande demandeCourante, Damj pointDepartUnique, MontantAsuSpec montantDroitPrecedent, boolean bornerRetraite)
    throws CoucheLogiqueException
  {
    Quantite quantiteReliquat = null;
    int nombreJours = 0;
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      quantiteReliquat = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
      BigDecimal montantPrecompte = montantDroitPrecedent.getMontantPrecompteEffectif().getValeur();
      if (montantPrecompte.compareTo(new BigDecimal("0")) > 0)
      {
        QuantiteJour duree = new QuantiteJour(Mathematiques.diviseASup(quantiteReliquat.getValeur(), montantPrecompte, 0));
        nombreJours = duree.getNombreJours();
      }
    }
    else
    {
      Quantite Reliquat = demandeCourante.getReliquat().getQuantiteReliquat();
      DossierExamen dossierCourant = (DossierExamen)demandeCourante.getDossierExamen();
      Quantite dureeAsrServie = dossierCourant.getConstitutionDurees().getDureeIndemnisation().getDureeServieSurAsr();
      Quantite QteDroitPrecedent = Reliquat.soustraire(dureeAsrServie);
      nombreJours = QteDroitPrecedent.getValeurEntiere();
    }
    if (bornerRetraite) {
      return determinerDuree(nombreJours, pointDepartUnique, dossierExamen);
    }
    return new QuantiteJour(Integer.valueOf(nombreJours).toString());
  }
  
  private Quantite determinerDuree(int pnombreJours, Damj pointDepartUnique, DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = dossierExamen.getDemande().getDemandeur();
    Quantite nombreJours = new Quantite(pnombreJours, DureeReglementaire.UNITE_DEFAUT);
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = ((Demande)dossierExamen.getDemande()).getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int duree = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDepartUnique, nombreJours, bornerRetraite);
    return new Quantite(duree, DureeReglementaire.UNITE_DEFAUT);
  }
  
  public ReadmissionSpec miseAJourReadmissionEnFonctionType(int typeReadmission, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    ReadmissionSpec readmission = (Readmission)dossierExamenCourant.changerEtat(typeReadmission);
    readmission.setNatureDecision(typeReadmission);
    demandeCourante.getObjectifCourant().setSousType(typeReadmission);
    
    return readmission;
  }
  
  public void miseAJourCapitauxSurCepa15(DossierExamen readmission, Quantite capitalComparatifDroitPrecedent)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant constitutionProduitResultant = readmission.getConstitutionProduitResultant();
    
    constitutionProduitResultant.setCapitalDroitPrecedent(capitalComparatifDroitPrecedent);
  }
  
  public void miseAJourCapitauxSurCepaMontants(DossierExamen readmission, Quantite capitalComparatifDroitCourant)
    throws CoucheLogiqueException
  {
    readmission.getConstitutionMontantsBruts().setCapitalInitialBrut(capitalComparatifDroitCourant);
  }
  
  public void constitutionDureeDroitPrecedentCepa15(Demande demandeCourante)
  {
    ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().setDureeDroitPrecedent(demandeCourante.getReliquat().getQuantiteReliquat());
  }
  
  public void constitutionDureeDroitPrecedentCepa15PourFinAsr(Demande demandeCourante, AttributionAssuranceSpec attributionAsr)
    throws ApplicativeException
  {
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAsr, null, true, false);
    ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().setDureeDroitPrecedent(resultatCalcul.getReliquatAREAvecMaintien());
  }
  
  public void constitutionDureeDroitPrecedentCepa15FinAsrDcCsr(Demande demandeCourante)
  {
    Quantite Reliquat = demandeCourante.getReliquat().getQuantiteReliquat();
    DossierExamen dossierCourant = (DossierExamen)demandeCourante.getDossierExamen();
    Quantite dureeAsrServie = dossierCourant.getConstitutionDurees().getDureeIndemnisation().getDureeServieSurAsr();
    Quantite QteDroitPrecedent = Reliquat.soustraire(dureeAsrServie);
    
    ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().setDureeDroitPrecedent(QteDroitPrecedent);
  }
  
  public void affecterMontantPrecedentAvecCompetenceAServir(DossierExamen readmission, MontantAsuSpec montantPrecedent)
  {
    readmission.getConstitutionProduitResultant().setMontantDroitPrecedent(new QuantiteEuro(montantPrecedent.getMontantPrecompteEffectif().getValeur()));
  }
  
  public void affecterDureeDroitResultant(Quantite dureeDroitResultant, DossierExamen readmission)
  {
    ConstitutionProduitResultant constitutionProduitResultant = readmission.getConstitutionProduitResultant();
    
    constitutionProduitResultant.setDureeEffective(dureeDroitResultant);
    constitutionProduitResultant.setDureeTheorique(dureeDroitResultant);
  }
}

/* Location:
 * Qualified Name:     DeterminationProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */