package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjcSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionCumulActiviteConserveeApres;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieActiviteConservee;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieActiviteConserveeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.NonSalarieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneeEntreeParametre;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjcSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilDeterminationSjc
  implements OutilDeterminationSjcSpec
{
  protected static final BigDecimal ZERO = BigDecimal.ZERO;
  protected static final QuantiteEuro QUANTITE_EURO_ZERO = new QuantiteEuro("0");
  private static OutilDeterminationSjc instance = new OutilDeterminationSjc();
  
  public static OutilDeterminationSjc getInstance()
  {
    return instance;
  }
  
  public Prc determinerPrc(Demande demande)
    throws ApplicativeException
  {
    Periode periodeReferenceCalcul = null;
    JustificationPrc justificationPrcSjcip = null;
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    Prc prcSjrip = dossierExamenCourant.getConstitutionSjr().getSjrip().getPrc();
    if (prcSjrip != null)
    {
      periodeReferenceCalcul = new Periode(prcSjrip.getDateDebut(), prcSjrip.getDateFin());
      
      justificationPrcSjcip = (JustificationPrc)prcSjrip.getJustification().copie();
    }
    else
    {
      periodeReferenceCalcul = DelaiRecherche.getInstance().determinerPrcSjcipRaA2b(demande);
    }
    Prc prcSjcip = new PrcSjc(periodeReferenceCalcul);
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
    if (justificationPrcSjcip != null) {
      prcSjcip.setJustification(justificationPrcSjcip);
    }
    return prcSjcip;
  }
  
  public BigDecimal determinerPlafondSjcip(Demande demande)
  {
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    return dossierExamenCourant.getConstitutionSjr().getSjrip().getPlafondSjr().getValeurMontant();
  }
  
  public void completerSjcipAvecActivitesConserveesNonRetenues(DonneesEntreeDeterminationSjrSpec donneesEntree, Sjcip sjcip, Chronologie chronoGlobaleActivitesConservees, boolean modeInitialisationSjcip)
    throws CoucheLogiqueException
  {
    chronoGlobaleActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveNonRetenue = null;
    while (chronoGlobaleActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)chronoGlobaleActivitesConservees.elementSuivant();
      if (((modeInitialisationSjcip) || (!activiteConserveeDejaRetenueSjcip(sjcip, activiteConserveeCourante))) && (estAAjouter(donneesEntree, activiteConserveeCourante)))
      {
        sjrActiviteConserveNonRetenue = new SjrActiviteConservee(QUANTITE_EURO_ZERO);
        sjrActiviteConserveNonRetenue.setPeriodeActiviteConservee(activiteConserveeCourante);
        sjcip.ajouterSjrActiviteConservee(sjrActiviteConserveNonRetenue);
      }
    }
  }
  
  private boolean estAAjouter(DonneesEntreeDeterminationSjrSpec donneesEntree, TravailSpec activiteConserveeCourante)
    throws CoucheLogiqueException
  {
    boolean estAAjouter = false;
    if ((donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjc() == null) && (donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjcPerteActConservee() == null))
    {
      if ((activiteConserveeCourante instanceof NonSalarieSpec))
      {
        Chronologie chronoPansCourante = new ChronologiePeriodes();
        chronoPansCourante.ajouter(activiteConserveeCourante);
        
        StrategieConditionCumulActiviteConserveeApres strategieConditionCumulAC = new StrategieConditionCumulActiviteConserveeApres();
        BigDecimal remunerationPans = strategieConditionCumulAC.determinerMontantRemunerationBrutePansConserveeSurPRC(donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcInitiale().getFin(), chronoPansCourante);
        if (remunerationPans.compareTo(ZERO) > 0) {
          estAAjouter = true;
        }
      }
      else if (((activiteConserveeCourante instanceof ActiviteSalarie)) && (((ActiviteSalarie)activiteConserveeCourante).getContrat().estEnContexteDecoupage("MVS")))
      {
        estAAjouter = true;
      }
    }
    else {
      estAAjouter = true;
    }
    return estAAjouter;
  }
  
  protected boolean activiteConserveeDejaRetenueSjcip(Sjcip sjcip, TravailSpec activiteConservee)
  {
    boolean activiteConserveeDejaTraitee = false;
    
    SjrActiviteConservee sjrActiviteConserveCourant = null;
    Iterator<?> iterateur = sjcip.getCollectionSjrActiviteConservee().iterator();
    while ((iterateur.hasNext()) && (!activiteConserveeDejaTraitee))
    {
      sjrActiviteConserveCourant = (SjrActiviteConservee)iterateur.next();
      if (sjrActiviteConserveCourant.getIdentifiantPeriodeActiviteConservee().equalsIgnoreCase(activiteConservee.getIdentifiant())) {
        activiteConserveeDejaTraitee = true;
      }
    }
    return activiteConserveeDejaTraitee;
  }
  
  public void mettreAJourSjcipAvecTypeActiviteConservee(Sjcip sjcip)
  {
    Iterator<?> it = sjcip.getListSjrActiviteConservee().iterator();
    SjrActiviteConservee sjrActiviteConserveNonRetenue = null;
    while (it.hasNext())
    {
      sjrActiviteConserveNonRetenue = (SjrActiviteConservee)it.next();
      mettreAJourTypeActiviteConservee(sjrActiviteConserveNonRetenue);
    }
  }
  
  public static void mettreAJourTypeActiviteConservee(SjrActiviteConserveeSpec sjrActiviteConserve)
  {
    OutilGestionActivitesConservees.getInstance().mettreAJourTypeActiviteConservee(sjrActiviteConserve);
  }
  
  public Chronologie determinerChronoActivitesSalarieesConserveesPourSjcip(List<ContexteDemandeSpec> listeContexte, Damj termePrc, Chronologie chronoGlobaleActivitesConservees, Damj dateFaitGenerateur)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesSalarieesConserveesRetournee = null;
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFaitGenerateur);
    StrategieActiviteConserveeSpec strategie = (StrategieActiviteConserveeSpec)FabriqueStrategieActiviteConservee.getInstance().getStrategie(critere);
    
    filtres.ajouterFiltre(strategie.getFiltreDateDebut(listeContexte, termePrc));
    chronoActivitesSalarieesConserveesRetournee = chronoGlobaleActivitesConservees.copier(filtres);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des activités salariées conservées participant au SJCIP : " + chronoActivitesSalarieesConserveesRetournee.toString() });
    
    return chronoActivitesSalarieesConserveesRetournee;
  }
  
  public DonneesResultatDeterminationSjcSpec determinerSjcip(DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws CoucheLogiqueException
  {
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SJCI." });
    
    resultatDeterminationSjc = determinerListeSjrActiviteConservee(donneesEntree);
    
    return resultatDeterminationSjc;
  }
  
  protected Chronologie determinerChronoActivitesSalarieesConserveesAvecSuspensionOuAbsence(DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    Chronologie chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence = new ChronologiePeriodes();
    
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = donneesEntree.getDonneesEntreeComplementaires();
    Periode periodePrc = donneesEntreeComplementaires.getPeriodePrcBornee() != null ? donneesEntreeComplementaires.getPeriodePrcBornee() : donneesEntreeComplementaires.getPeriodePrcInitiale();
    
    Chronologie chronoActivitesSalarieesConserveesPrc = donneesEntreeComplementaires.getChronologieActiviteSalariePrc();
    
    chronoActivitesSalarieesConserveesPrc.iterer();
    ActiviteSalarie activiteSalarieeConserveeCourante = null;
    Chronologie chronoPeriodeSuspensionCourante = null;
    IncidentSpec periodeSuspensionCourante = null;
    Chronologie chronoSalaireCourante = null;
    Salaire salaireCourant = null;
    Quantite qteAbsenceCourante = null;
    boolean activiteConserveeARetourner = false;
    boolean continuerTraitement = true;
    while (chronoActivitesSalarieesConserveesPrc.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)chronoActivitesSalarieesConserveesPrc.elementSuivant();
      
      chronoPeriodeSuspensionCourante = activiteSalarieeConserveeCourante.getListePeriodesIncident().copier(new FiltreIncident());
      if ((chronoPeriodeSuspensionCourante != null) && (!chronoPeriodeSuspensionCourante.estVide()))
      {
        continuerTraitement = true;
        chronoPeriodeSuspensionCourante.iterer();
        while ((chronoPeriodeSuspensionCourante.encoreSuivant()) && (continuerTraitement))
        {
          periodeSuspensionCourante = (IncidentSpec)chronoPeriodeSuspensionCourante.elementSuivant();
          if (periodeSuspensionCourante.inter(periodePrc) > 0) {
            if (periodeSuspensionCourante.estTempsPlein())
            {
              activiteConserveeARetourner = true;
            }
            else
            {
              activiteConserveeARetourner = false;
              continuerTraitement = false;
            }
          }
        }
        if (activiteConserveeARetourner) {
          chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence.ajouter(activiteSalarieeConserveeCourante);
        }
      }
      if (!activiteConserveeARetourner)
      {
        chronoSalaireCourante = activiteSalarieeConserveeCourante.getListeSalaires();
        chronoSalaireCourante.iterer();
        continuerTraitement = true;
        while ((chronoSalaireCourante.encoreSuivant()) && (continuerTraitement))
        {
          salaireCourant = (Salaire)chronoSalaireCourante.elementSuivant();
          if (salaireCourant.getPeriode().estContenueDans(periodePrc))
          {
            qteAbsenceCourante = salaireCourant.getQuantiteAbsence();
            if (qteAbsenceCourante != null)
            {
              activiteConserveeARetourner = true;
            }
            else
            {
              activiteConserveeARetourner = false;
              continuerTraitement = false;
            }
          }
        }
        if (activiteConserveeARetourner) {
          chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence.ajouter(activiteSalarieeConserveeCourante);
        }
      }
    }
    return chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence;
  }
  
  private DonneesResultatDeterminationSjcSpec determinerListeSjrActiviteConservee(DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws CoucheLogiqueException
  {
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesResultatSjc();
    
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = donneesEntree.getDonneesEntreeComplementaires();
    Chronologie chronoActivitesSalarieesConserveesPrc = donneesEntreeComplementaires.getChronologieActiviteSalariePrc();
    
    chronoActivitesSalarieesConserveesPrc.iterer();
    ActiviteSalarie activiteSalarieeConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveeCourante = null;
    ArrayList<SjrActiviteConservee> resultatListeSjrActiviteConservee = new ArrayList();
    BigDecimal resultatSjci = ZERO;
    while (chronoActivitesSalarieesConserveesPrc.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)chronoActivitesSalarieesConserveesPrc.elementSuivant();
      if (!estActiviteEnContexteDecoupagePmvsAExclureDuCalculSjr(activiteSalarieeConserveeCourante, donneesEntree))
      {
        if (activiteSalarieeConserveeCourante.estEnConflit()) {
          leverAlerteNonBloquante(resultatDeterminationSjc.getListeAlertesNonBloquantes(), "A11MNB6", activiteSalarieeConserveeCourante);
        }
        if (activiteSalarieeConserveeCourante.getEntreprise().getIdentifiantBNE() == null)
        {
          Damj dateFCTDamj = activiteSalarieeConserveeCourante.getDateDebut();
          String dateFCTString = dateFCTDamj.formater();
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB10", new String[] { dateFCTString });
        }
        sjrActiviteConserveeCourante = determinerSjrActiviteConservee(activiteSalarieeConserveeCourante, donneesEntree, resultatDeterminationSjc.getListeDonneesResultatDeterminationSjr());
        if ((!sjrActiviteConserveeCourante.getSjrInitial().equals(new QuantiteEuro(ZERO))) || (donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjc() != null)) {
          resultatListeSjrActiviteConservee.add(sjrActiviteConserveeCourante);
        }
        resultatSjci = resultatSjci.add(sjrActiviteConserveeCourante.getSjrInitial().getValeurMontant());
      }
    }
    OutilDonneesDeterminationSjr.getInstance().completerDonneesResultatSjc(resultatDeterminationSjc, resultatSjci, resultatListeSjrActiviteConservee);
    
    return resultatDeterminationSjc;
  }
  
  private boolean estActiviteEnContexteDecoupagePmvsAExclureDuCalculSjr(ActiviteSalarie activiteSalarieeConserveeCourante, DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    return (activiteSalarieeConserveeCourante.getContrat().estEnContexteDecoupage("MVS")) && ((activiteSalarieeConserveeCourante.getContrat().estSuspensionDecoupee()) || (!activiteSalarieeConserveeCourante.chevauche(donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcInitiale())));
  }
  
  protected void leverAlerteNonBloquante(Map<String, Collection> resultatListeAlertesNonBloquantes, String codeAlerteNonBloquante, ActiviteSalarie periodeActiviteSalarie)
  {
    Collection<ObjetAlertesNonBloquantes> listeActivitesSalariees = null;
    if (resultatListeAlertesNonBloquantes.containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)resultatListeAlertesNonBloquantes.get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarie);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarie));
      resultatListeAlertesNonBloquantes.put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
  
  protected SjrActiviteConservee determinerSjrActiviteConservee(ActiviteSalarie activiteSalarieeConservee, DonneesEntreeDeterminationSjrSpec donneesEntree, Map<String, DonneesResultatDeterminationSjr> listeDonneesResultatDeterminationSjr)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SjrActiviteConservee." });
    
    SjrActiviteConservee resultatSjrActiviteConserveeRetourne = null;
    DonneesResultatDeterminationSjr resultatDeterminationSjrActiviteConservee = null;
    BigDecimal resultatSjriActiviteConservee = null;
    PrcSjc resultatPrcSjcActiviteConservee = null;
    
    DonneesEntreeDeterminationSjrSpec donneesEntreeSjrActiviteConservee = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntreeDeterminationSjrActiviteConservee(donneesEntree, activiteSalarieeConservee);
    
    Reglement reglementApplicableCourant = donneesEntreeSjrActiviteConservee.getDonneesEntreeDemande().getReglementApplicable();
    if (reglementApplicableCourant.estNomReglementIdentique("A2b"))
    {
      resultatSjrActiviteConserveeRetourne = determinerSjrActiviteConserveeA2B(activiteSalarieeConservee, donneesEntreeSjrActiviteConservee);
      
      resultatSjriActiviteConservee = resultatSjrActiviteConserveeRetourne.getSjrInitial().getValeurMontant();
      
      resultatDeterminationSjrActiviteConservee = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesResultatSjr(resultatSjriActiviteConservee, resultatSjriActiviteConservee);
      
      listeDonneesResultatDeterminationSjr.put(activiteSalarieeConservee.getIdentifiant(), resultatDeterminationSjrActiviteConservee);
      
      resultatPrcSjcActiviteConservee = determinerPrcSjcResultat(donneesEntreeSjrActiviteConservee);
    }
    else
    {
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntreeSjrActiviteConservee.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      resultatDeterminationSjrActiviteConservee = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerSjrip(donneesEntreeSjrActiviteConservee);
      
      listeDonneesResultatDeterminationSjr.put(activiteSalarieeConservee.getIdentifiant(), resultatDeterminationSjrActiviteConservee);
      
      resultatSjriActiviteConservee = resultatDeterminationSjrActiviteConservee.getSjri();
      resultatPrcSjcActiviteConservee = (PrcSjc)resultatDeterminationSjrActiviteConservee.getPrc();
      
      resultatSjrActiviteConserveeRetourne = new SjrActiviteConservee(new QuantiteEuro(resultatSjriActiviteConservee));
    }
    resultatSjrActiviteConserveeRetourne.setPrc(resultatPrcSjcActiviteConservee);
    
    resultatSjrActiviteConserveeRetourne.setPeriodeActiviteConservee(activiteSalarieeConservee);
    
    return resultatSjrActiviteConserveeRetourne;
  }
  
  private SjrActiviteConservee determinerSjrActiviteConserveeA2B(ActiviteSalarie activiteSalarieeConservee, DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    SjrActiviteConservee sjrActiviteConserveeRetourne = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SFJ pour activité conservée A2B." });
    
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = donneesEntree.getDonneesEntreeDemande();
    
    int numeroCategorieA2b = determinerNumeroCategorieA2b(activiteSalarieeConservee.getMetier().getCodeEmploi());
    String nomParametreCourant = "SFJ A2B CATEGORIE " + numeroCategorieA2b;
    DonneeEntreeParametre parametreActif = donneesEntree.getDonneesEntreeProduit().getParametreActif(nomParametreCourant, donneesEntreeDemande.getDateAttribution());
    
    BigDecimal salaireForfaitaireJournalier = parametreActif.getValeurParametre();
    
    sjrActiviteConserveeRetourne = new SjrActiviteConservee(new QuantiteEuro(salaireForfaitaireJournalier));
    return sjrActiviteConserveeRetourne;
  }
  
  private int determinerNumeroCategorieA2b(int codeCategorieA2b)
  {
    int numeroCategorieA2bRetourne = 0;
    switch (codeCategorieA2b)
    {
    case 90: 
      numeroCategorieA2bRetourne = 1;
      break;
    case 91: 
      numeroCategorieA2bRetourne = 2;
      break;
    case 92: 
      numeroCategorieA2bRetourne = 3;
      break;
    case 93: 
      numeroCategorieA2bRetourne = 4;
      break;
    case 94: 
      numeroCategorieA2bRetourne = 5;
      break;
    case 95: 
      numeroCategorieA2bRetourne = 6;
      break;
    case 96: 
      numeroCategorieA2bRetourne = 7;
      break;
    case 97: 
      numeroCategorieA2bRetourne = 8;
      break;
    case 98: 
      numeroCategorieA2bRetourne = 9;
      break;
    case 99: 
      numeroCategorieA2bRetourne = 10;
      break;
    case 100: 
      numeroCategorieA2bRetourne = 11;
      break;
    case 101: 
      numeroCategorieA2bRetourne = 12;
      break;
    case 102: 
      numeroCategorieA2bRetourne = 13;
      break;
    case 103: 
      numeroCategorieA2bRetourne = 14;
      break;
    case 104: 
      numeroCategorieA2bRetourne = 15;
      break;
    case 105: 
      numeroCategorieA2bRetourne = 16;
      break;
    case 106: 
      numeroCategorieA2bRetourne = 17;
      break;
    case 107: 
      numeroCategorieA2bRetourne = 18;
      break;
    case 108: 
      numeroCategorieA2bRetourne = 19;
      break;
    case 109: 
      numeroCategorieA2bRetourne = 20;
      break;
    }
    return numeroCategorieA2bRetourne;
  }
  
  private PrcSjc determinerPrcSjcResultat(DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    PrcSjc prcRetournee = null;
    
    Periode periodePrcInitiale = donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcInitiale();
    JustificationPrc justificationPrcRetournee = new JustificationPrc(periodePrcInitiale);
    Periode periodePrcBornee = donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcBornee();
    justificationPrcRetournee.setPeriodePrcBornee(periodePrcBornee);
    int typeBornagePrc = donneesEntree.getDonneesEntreeComplementaires().getTypeBornagePrc();
    justificationPrcRetournee.setTypeBornagePrc(typeBornagePrc);
    
    Periode periodePrcEffective = justificationPrcRetournee.getPeriodePrcEffective();
    prcRetournee = new PrcSjc(periodePrcEffective);
    
    prcRetournee.setJustification(justificationPrcRetournee);
    
    return prcRetournee;
  }
  
  public Sjc revaloriserSjcip(ConstitutionSjc cepConstitutionSjc, Damj dateRevalorisation)
  {
    Sjc sjcrpRetourne = null;
    if (cepConstitutionSjc != null)
    {
      Sjc sjcCourant = cepConstitutionSjc.getSjci();
      sjcrpRetourne = RevalorisationSalaire.revaloriserSjc(sjcCourant, dateRevalorisation);
    }
    else
    {
      sjcrpRetourne = new Sjc(ZERO);
    }
    return sjcrpRetourne;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSjc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */