package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSrPraeSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSrPrceSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafonds;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafondsParEmployeur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafondsParExerciceEtEmployeur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prae;
import fr.unedic.cali.asu.produits.liquidation.dom.Prce;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.conteneurs.DonneeEntreeParametre;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;

public class OutilDeterminationSrPrce
  implements OutilDeterminationSrPrceSpec
{
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static OutilDeterminationSrPrce s_instance = new OutilDeterminationSrPrce();
  
  public static OutilDeterminationSrPrce getInstance()
  {
    return s_instance;
  }
  
  public OutilJustificationSjrSpec recupererOutilJustificationSjr(DonneesEntreeComportementSpec p_donneesEntreeComportement)
  {
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntreeComportement.getFabriqueOutilFonctionnel();
    
    return fabriqueOutilFonctionnel.getOutilJustificationSjr(p_donneesEntreeComportement);
  }
  
  public BigDecimal determinerSrpe(Prce p_resultatPrce, DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
    throws CoucheLogiqueException
  {
    BigDecimal valeurSrpe = ZERO;
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(p_donneesEntree.getDonneesEntreeComportement());
    JustificationPlafonds resultatJustificationPlafonds = p_donneesResultat.getJustificationSjr().getJustificationPlafonds();
    
    JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExerciceCourant = null;
    if (outilJustificationSjr != null) {
      justificationPlafondsParExerciceCourant = outilJustificationSjr.initialiserJustificationPlafondsParExerciceEtEmployeur(resultatJustificationPlafonds);
    }
    String exerciceCourant = null;
    if (appliquerPlafondParExercice()) {
      exerciceCourant = Integer.toString(p_resultatPrce.getDateDebut().getAnnee());
    }
    Chronologie chronoActiviteSalarie = p_donneesEntree.getDonneesEntreeComplementaires().getChronologieActiviteSalariePrc();
    determinerChronoPraeParEmployeur(p_resultatPrce, chronoActiviteSalarie);
    
    BigDecimal sreCourant = determinerSre(p_resultatPrce, p_donneesEntree, p_donneesResultat, outilJustificationSjr, justificationPlafondsParExerciceCourant);
    
    BigDecimal ppeCourant = null;
    ChronologiePeriodes chronoPraeCourante = determinerChronoPraeTousEmployeur(p_resultatPrce);
    if ((chronoPraeCourante.contientChevauchementElements()) && (appliquerPlafondParExercice()))
    {
      ppeCourant = determinerPpe(p_donneesEntree, chronoPraeCourante);
      if (ppeCourant.compareTo(ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_INCOHERENCE_PPE", 2);
      }
      valeurSrpe = sreCourant.min(ppeCourant);
    }
    else
    {
      valeurSrpe = sreCourant;
    }
    if (outilJustificationSjr != null) {
      outilJustificationSjr.justifierPlafondsParExerciceEtEmployeur(justificationPlafondsParExerciceCourant, exerciceCourant, sreCourant, ppeCourant, valeurSrpe);
    }
    return valeurSrpe;
  }
  
  protected boolean appliquerPlafondParExercice()
  {
    return false;
  }
  
  private void determinerChronoPraeParEmployeur(Prce p_resultatPrce, Chronologie p_chronoActiviteSalarie)
  {
    Chronologie chronologiePraeParEmployeur = new ChronologiePeriodes();
    ActiviteSalarie periodeActiviteCourante = null;
    String identifiantEmployeurCourant = null;
    Periode periodePraeCourante = null;
    Prae resultatPraeCourante = null;
    
    Hashtable tableChronoPraeParEmployeur = p_resultatPrce.getTableChronoPraeParEmployeur();
    
    Periode periodePrceCourante = new Periode(p_resultatPrce.getDateDebut(), p_resultatPrce.getDateFin());
    Chronologie chronoActivitesPrceCourante = p_chronoActiviteSalarie.copier(new FiltreChevauchePeriode(periodePrceCourante));
    
    chronoActivitesPrceCourante.iterer();
    while (chronoActivitesPrceCourante.encoreSuivant())
    {
      periodeActiviteCourante = (ActiviteSalarie)chronoActivitesPrceCourante.elementSuivant();
      
      identifiantEmployeurCourant = periodeActiviteCourante.getEntreprise().getIdentifiantBNE();
      
      periodePraeCourante = p_resultatPrce.periodeIntersection(new Periode(periodeActiviteCourante.getDateDebut(), periodeActiviteCourante.getDateFin()));
      if (periodePraeCourante != null)
      {
        resultatPraeCourante = new Prae(periodePraeCourante);
        
        resultatPraeCourante.setPrce(p_resultatPrce);
        
        resultatPraeCourante.setPeriodeActiviteSalarie(periodeActiviteCourante);
        if (tableChronoPraeParEmployeur.containsKey(identifiantEmployeurCourant))
        {
          chronologiePraeParEmployeur = (ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant);
          chronologiePraeParEmployeur.ajouter(resultatPraeCourante);
        }
        else
        {
          chronologiePraeParEmployeur = new ChronologiePeriodes();
          chronologiePraeParEmployeur.ajouter(resultatPraeCourante);
          tableChronoPraeParEmployeur.put(identifiantEmployeurCourant, chronologiePraeParEmployeur);
        }
      }
    }
  }
  
  private ChronologiePeriodes determinerChronoPraeTousEmployeur(Prce p_resultatPrce)
  {
    ChronologiePeriodes chronoPraeTousEmployeurs = new ChronologiePeriodes();
    
    Hashtable tableChronoPraeParEmployeur = p_resultatPrce.getTableChronoPraeParEmployeur();
    String identifiantEmployeurCourant = null;
    for (Enumeration enumTable = tableChronoPraeParEmployeur.keys(); enumTable.hasMoreElements();)
    {
      identifiantEmployeurCourant = (String)enumTable.nextElement();
      chronoPraeTousEmployeurs.ajouter((ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant));
    }
    return chronoPraeTousEmployeurs;
  }
  
  private BigDecimal determinerSre(Prce p_resultatPrce, DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat, OutilJustificationSjrSpec p_outilJustificationSjr, JustificationPlafondsParExerciceEtEmployeur p_justificationPlafondsParExercice)
    throws CoucheLogiqueException
  {
    BigDecimal cumulSre = ZERO;
    BigDecimal srpeeTheorique = null;
    BigDecimal cumulSraeParEmployeur = null;
    BigDecimal cumulPaeParEmployeur = null;
    
    String identifiantEmployeurCourant = null;
    ChronologiePeriodes chronoPraeParEmployeur = null;
    Prae resultatPraeCourante = null;
    
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    
    Hashtable tableChronoPraeParEmployeur = p_resultatPrce.getTableChronoPraeParEmployeur();
    for (Enumeration enumTable = tableChronoPraeParEmployeur.keys(); enumTable.hasMoreElements();)
    {
      identifiantEmployeurCourant = (String)enumTable.nextElement();
      chronoPraeParEmployeur = (ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant);
      
      JustificationPlafondsParEmployeur justificationPlafondsParEmployeurCourant = null;
      if (p_outilJustificationSjr != null) {
        justificationPlafondsParEmployeurCourant = p_outilJustificationSjr.initialiserJustificationPlafondsParEmployeur(p_justificationPlafondsParExercice);
      }
      cumulSraeParEmployeur = ZERO;
      cumulPaeParEmployeur = ZERO;
      chronoPraeParEmployeur.iterer();
      while (chronoPraeParEmployeur.encoreSuivant())
      {
        resultatPraeCourante = (Prae)chronoPraeParEmployeur.elementSuivant();
        cumulSraeParEmployeur = cumulSraeParEmployeur.add(fabriqueOutilFonctionnel.getOutilDeterminationSrPrae().determinerSrae(resultatPraeCourante, p_donneesEntree, p_donneesResultat));
        
        cumulPaeParEmployeur = cumulPaeParEmployeur.add(fabriqueOutilFonctionnel.getOutilDeterminationSrPrae().determinerPae(resultatPraeCourante, p_donneesEntree, p_donneesResultat, justificationPlafondsParEmployeurCourant));
      }
      if (cumulPaeParEmployeur.compareTo(ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_CUMUL_PAE_EMPLOYEUR", new Object[] { resultatPraeCourante.getPeriodeActiviteSalarie().getDateFin() }, 2);
      }
      srpeeTheorique = cumulSraeParEmployeur.min(cumulPaeParEmployeur);
      
      cumulSre = cumulSre.add(srpeeTheorique);
      if (p_outilJustificationSjr != null) {
        p_outilJustificationSjr.justifierPlafondsParEmployeur(justificationPlafondsParEmployeurCourant, resultatPraeCourante.getPeriodeActiviteSalarie().getEntreprise().getLibelleEntreprise(), cumulSraeParEmployeur, cumulPaeParEmployeur, srpeeTheorique);
      }
    }
    return cumulSre;
  }
  
  private BigDecimal determinerPpe(DonneesEntreeDeterminationSjrSpec p_donneesEntree, ChronologiePeriodes p_chronoPrae)
  {
    BigDecimal cumulPpe = ZERO;
    ObjetChronoPeriode objetChronoPeriodeCourant = null;
    ArrayList listePeriodesMoisCivils = null;
    Periode periodeMoisCivilCourant = null;
    Periode periodeMoisCivilEntier = null;
    DonneeEntreeParametre parametreActif = null;
    BigDecimal plafondMensuelApplicable = ZERO;
    
    Chronologie chronoPraeSansChevauchement = p_chronoPrae.fusionnerChevauchementPeriodes();
    
    chronoPraeSansChevauchement.iterer();
    while (chronoPraeSansChevauchement.encoreSuivant())
    {
      objetChronoPeriodeCourant = (ObjetChronoPeriode)chronoPraeSansChevauchement.elementSuivant();
      
      listePeriodesMoisCivils = objetChronoPeriodeCourant.decouperEnMoisCivils();
      for (int boucle = 0; boucle < listePeriodesMoisCivils.size(); boucle++)
      {
        periodeMoisCivilCourant = (Periode)listePeriodesMoisCivils.get(boucle);
        
        parametreActif = p_donneesEntree.getDonneesEntreeProduit().getParametreActif("PLAFOND MENSUEL SR SJR", periodeMoisCivilCourant.getDebut());
        
        plafondMensuelApplicable = parametreActif.getValeurParametre();
        if ((!periodeMoisCivilCourant.getDebut().estLeDebutDuMois()) || (!periodeMoisCivilCourant.getFin().estLaFinDuMois()))
        {
          BigDecimal nominateur1 = plafondMensuelApplicable;
          BigDecimal nominateur2 = new BigDecimal(String.valueOf(periodeMoisCivilCourant.getDuree()));
          periodeMoisCivilEntier = new Periode(periodeMoisCivilCourant.getDebut().getDebutMois(), periodeMoisCivilCourant.getDebut().getFinMois());
          
          BigDecimal denominateur = new BigDecimal(String.valueOf(periodeMoisCivilEntier.getDuree()));
          plafondMensuelApplicable = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
        }
        cumulPpe = cumulPpe.add(plafondMensuelApplicable);
      }
    }
    return Mathematiques.tronque(cumulPpe, 2);
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSrPrce
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */