package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieActiviteConserveeConvention2014;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjcSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilGestionActivitesConserveesSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionCumulActiviteConserveeApres;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteNonSalariePeriodique;
import fr.unedic.cali.autresdoms.ga.dom.PeriodePansAvecRevenu;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.NonSalarieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFct;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class OutilGestionActivitesConservees
  implements OutilGestionActivitesConserveesSpec
{
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static final QuantiteEuro QUANTITE_EURO_ZERO = new QuantiteEuro("0");
  private static OutilGestionActivitesConservees instance = new OutilGestionActivitesConservees();
  
  public static OutilGestionActivitesConservees getInstance()
  {
    return instance;
  }
  
  public StrategieActiviteConserveeConvention2014Spec recupererStrategieActiviteConserveeConvention2014(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateAttribution());
    return (StrategieActiviteConserveeConvention2014Spec)FabriqueStrategieActiviteConserveeConvention2014.getInstance().getStrategie(critere);
  }
  
  public StrategieActiviteConserveeConvention2014Spec recupererStrategieActiviteConserveeConvention2014Revision(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    StrategieActiviteConserveeConvention2014Spec retour = null;
    if (demande.getDateAttribution() != null)
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(demande.getDateAttribution().veille());
      retour = (StrategieActiviteConserveeConvention2014Spec)FabriqueStrategieActiviteConserveeConvention2014.getInstance().getStrategie(critere);
    }
    return retour;
  }
  
  public Chronologie determinerChronoActivitesConserveesNouvelleRegle(DemandeAssuranceSpec demande, Periode periodePrc)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = (Demande)demande;
    
    Chronologie chronoGlobaleActivitesConservees = determinerChronoGlobaleActivitesConservees(demandeCourante);
    
    Chronologie chronoActivitesConserveesRetournee = determinerChronoActivitesConserveesRemunerationPrc(chronoGlobaleActivitesConservees, periodePrc);
    
    chronoActivitesConserveesRetournee = determinerChronoActiviteConserveesHorsSuspensionEnCours(chronoActivitesConserveesRetournee, demandeCourante);
    
    return chronoActivitesConserveesRetournee;
  }
  
  private Chronologie determinerChronoActiviteConserveesHorsSuspensionEnCours(Chronologie chronoActivitesConserveesRetournee, Demande demandeCourante)
  {
    Chronologie retour = chronoActivitesConserveesRetournee;
    ContexteDemandeSpec contexte = OutilGestionContexteDemande.trouverContexteDemandeAssurance(demandeCourante, "COURSDISPO");
    if (contexte != null)
    {
      IncidentSpec periode = ((ContexteDemande)contexte).getPeriodeSuspensiveEnCours();
      FiltreNegation filtre = new FiltreNegation(new FiltreActiviteSalarieAvecIncident(periode));
      retour = chronoActivitesConserveesRetournee.copier(filtre);
    }
    return retour;
  }
  
  public Collection<SjrActiviteConservee> determinerListeActivitesConserveesNouvelleRegle(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Periode periodePrcCourante = recupererPeriodePrc(demande);
    
    Chronologie chronoActivitesConserveesNouvelleRegle = determinerChronoActivitesConserveesNouvelleRegle(demande, periodePrcCourante);
    
    Collection<SjrActiviteConservee> listeActivitesConserveesRetournee = mapperChronoEnListeActivitesConservees(chronoActivitesConserveesNouvelleRegle);
    
    return listeActivitesConserveesRetournee;
  }
  
  public Periode recupererPeriodePrc(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = (Demande)demande;
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    
    Damj dateFaitGenerateur = demandeCourante.getDateFaitGenerateurOuDernierSinistre();
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnelSjr = (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(dateFaitGenerateur);
    
    Prc prcCourante = null;
    try
    {
      prcCourante = fabriqueOutilFonctionnelSjr.getOutilDeterminationSjc().determinerPrc(demandeCourante);
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getMessage());
    }
    return prcCourante.getPeriode();
  }
  
  public Chronologie determinerChronoGlobaleActivitesConservees(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    DonneesEntreeConstructionChronologie donneesEntreeConstructionChronologie = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.mapperDemandeDonneesEntreeConstructionChronologie((Demande)demande);
    
    return ConstructionChronologie.determinerChronoActivitesConservees(donneesEntreeConstructionChronologie);
  }
  
  private Chronologie determinerChronoActivitesConserveesRemunerationPrc(Chronologie chronoGlobaleActivitesConservees, Periode periodePrc)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesConserveesRetournee = new ChronologiePeriodes();
    
    chronoGlobaleActivitesConservees.iterer();
    while (chronoGlobaleActivitesConservees.encoreSuivant())
    {
      TravailSpec activiteConserveeCourante = (TravailSpec)chronoGlobaleActivitesConservees.elementSuivant();
      if (estActiviteConserveeAvecRemunerationAfferentePrc(activiteConserveeCourante, periodePrc)) {
        chronoActivitesConserveesRetournee.ajouter(activiteConserveeCourante);
      }
    }
    return chronoActivitesConserveesRetournee;
  }
  
  protected boolean estActiviteConserveeAvecRemunerationAfferentePrc(TravailSpec activiteTravailCourante, Periode periodePrc)
    throws CoucheLogiqueException
  {
    boolean conditionRemunerationAfferentePrc = false;
    BigDecimal remunerationActiviteConserveePrc = ZERO;
    if (estPresencePansSupraMensuelleAPartirDe2018DansPrc(activiteTravailCourante, periodePrc))
    {
      conditionRemunerationAfferentePrc = true;
    }
    else if ((activiteTravailCourante instanceof NonSalarieSpec))
    {
      Chronologie chronoPansCourante = new ChronologiePeriodes();
      chronoPansCourante.ajouter(activiteTravailCourante);
      StrategieConditionCumulActiviteConserveeApres strategieConditionCumulAC = new StrategieConditionCumulActiviteConserveeApres();
      remunerationActiviteConserveePrc = strategieConditionCumulAC.determinerMontantRemunerationBrutePansConserveeSurPRC(periodePrc.getFin(), chronoPansCourante);
    }
    else if ((activiteTravailCourante instanceof ActiviteSalarie))
    {
      remunerationActiviteConserveePrc = DeterminationRemuneration.determinerRemunerationActiviteSalarie((ActiviteSalarie)activiteTravailCourante, periodePrc);
    }
    if (remunerationActiviteConserveePrc.compareTo(ZERO) > 0) {
      conditionRemunerationAfferentePrc = true;
    }
    return conditionRemunerationAfferentePrc;
  }
  
  protected boolean estPresencePansSupraMensuelleAPartirDe2018DansPrc(TravailSpec activiteTravailCourante, Periode periodePrc)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    if ((activiteTravailCourante instanceof PeriodeActiviteNonSalariePeriodique))
    {
      PeriodeActiviteNonSalariePeriodique pans = (PeriodeActiviteNonSalariePeriodique)activiteTravailCourante;
      
      Collection<PeriodePansAvecRevenu> collectionPeriodeAvecRevenu = pans.getCollectionPeriodePansAvecRevenu();
      for (PeriodePansAvecRevenu revenuPans : collectionPeriodeAvecRevenu) {
        if ((!revenuPans.estUnePeriodeEmploiJustifiableMensuellement()) && (revenuPans.chevauche(periodePrc)) && (revenuPans.getDateDebut().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Prise en compte des ANS mensuel et supra M")))) {
          return true;
        }
      }
    }
    return retour;
  }
  
  public void mettreAJourTypeActiviteConservee(SjrActiviteConserveeSpec sjrActiviteConserve)
  {
    TravailSpec periodeActiviteConservee = sjrActiviteConserve.getPeriodeActiviteConservee();
    Chronologie chronologie = new ChronologiePeriodes();
    chronologie.ajouter(periodeActiviteConservee);
    
    FiltresTemporel filtreNonFctEtNonPans = new FiltresTemporel();
    filtreNonFctEtNonPans.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieFct()));
    filtreNonFctEtNonPans.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteNonSalariee()));
    Chronologie chronologieNonFctEtNonPans = chronologie.copier(filtreNonFctEtNonPans);
    
    boolean estForcerConservee = (chronologieNonFctEtNonPans != null) && (!chronologieNonFctEtNonPans.estVide());
    if ((!estForcerConservee) && (!sjrActiviteConserve.getPeriodeActiviteConservee().getDateFin().equals(Damj.FIN_DES_TEMPS))) {
      sjrActiviteConserve.setTypeActiviteConservee("P");
    } else {
      sjrActiviteConserve.setTypeActiviteConservee("C");
    }
  }
  
  public void recalculerActivitesConserveesPourDemandeMigree(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DemandeAssuranceSpec demandeCourante = (DemandeAssuranceSpec)demande;
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
    ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
    if (!(dossierExamen instanceof AttributionSpec)) {
      return;
    }
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    boolean mettreAJourListeActivitesConservees = false;
    if (dossierExamen.getReglementApplicable() != null)
    {
      Reglement reglementApplicableCourant = dossierExamen.getReglementApplicable().getReglement();
      if (reglementApplicableCourant != null) {
        if ((!reglementApplicableCourant.equals(produit.getReglement("A4"))) || (strategieActiviteConservee.traiterActivitesConserveesA4())) {
          mettreAJourListeActivitesConservees = true;
        }
      }
    }
    if (mettreAJourListeActivitesConservees)
    {
      Sjcip sjcip = null;
      ConstitutionSjc constitutionSjc = dossierExamen.getConstitutionSjc();
      if ((constitutionSjc != null) && (constitutionSjc.getSjcip() != null)) {
        sjcip = constitutionSjc.getSjcip();
      }
      ConditionActiviteConservee conditionActiviteConservee = dossierExamen.getConditionActiviteConservee();
      
      Chronologie chronoGlobaleActivitesConservees = determinerChronoGlobaleActivitesConservees(demandeCourante);
      
      chronoGlobaleActivitesConservees = chronoGlobaleActivitesConservees.copier(new FiltreNegation(new FiltrePeriodesJustifiees(false)));
      
      FiltresTemporel filtrePansAttestee = new FiltresTemporel();
      filtrePansAttestee.ajouterFiltre(new FiltrePeriodeActiviteNonSalariee());
      filtrePansAttestee.ajouterFiltre(new FiltrePeriodesAttestees());
      
      FiltrePeriodesSurFiltresExclusifs listeFiltresPeriodeAc = new FiltrePeriodesSurFiltresExclusifs();
      listeFiltresPeriodeAc.ajouterFiltre(filtrePansAttestee);
      listeFiltresPeriodeAc.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteNonSalariee()));
      Chronologie chronoActivitesConserveesFiltrees = chronoGlobaleActivitesConservees.copier(listeFiltresPeriodeAc);
      if (strategieActiviteConservee.persisterListeActivitesConserveesCapa12()) {
        conditionActiviteConservee.viderCollectionSjrActiviteConservee();
      } else {
        sjcip.viderCollectionSjrActiviteConservee();
      }
      Iterator<TravailSpec> it = chronoActivitesConserveesFiltrees.iterer();
      SjrActiviteConservee sjrActiviteConservee = null;
      TravailSpec periodeActiviteConservee = null;
      while (it.hasNext())
      {
        periodeActiviteConservee = (TravailSpec)it.next();
        
        sjrActiviteConservee = new SjrActiviteConservee(new QuantiteEuro("0"));
        sjrActiviteConservee.setPeriodeActiviteConservee(periodeActiviteConservee);
        
        mettreAJourTypeActiviteConservee(sjrActiviteConservee);
        if (strategieActiviteConservee.persisterListeActivitesConserveesCapa12()) {
          conditionActiviteConservee.ajouterSjrActiviteConservee(sjrActiviteConservee);
        } else {
          sjcip.ajouterSjrActiviteConservee(sjrActiviteConservee);
        }
      }
    }
  }
  
  public Collection<SjrActiviteConservee> mapperChronoEnListeActivitesConservees(Chronologie chronoActivitesConservees)
  {
    Collection<SjrActiviteConservee> listeActivitesConserveesRetournee = new ArrayList();
    
    chronoActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveCourant = null;
    while (chronoActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)chronoActivitesConservees.elementSuivant();
      
      sjrActiviteConserveCourant = new SjrActiviteConservee(QUANTITE_EURO_ZERO);
      sjrActiviteConserveCourant.setPeriodeActiviteConservee(activiteConserveeCourante);
      
      mettreAJourTypeActiviteConservee(sjrActiviteConserveCourant);
      listeActivitesConserveesRetournee.add(sjrActiviteConserveCourant);
    }
    return listeActivitesConserveesRetournee;
  }
}

/* Location:
 * Qualified Name:     OutilGestionActivitesConservees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */