package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.OutilMappingJustificationAffiliation;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.JustificationAffiliationJoursTravailles;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.affiliation.OutilVerificationReglementsMultiples;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalariePourCategorieParticuliere;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class RechercheQuantiteAppartenance
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  private static final int AFFI_MAX = 9999;
  private static RechercheQuantiteAppartenance rechercheQuantiteAppartenance = null;
  
  public static RechercheQuantiteAppartenance getInstance()
  {
    if (rechercheQuantiteAppartenance == null) {
      rechercheQuantiteAppartenance = new RechercheQuantiteAppartenance();
    }
    return rechercheQuantiteAppartenance;
  }
  
  public ConstitutionQuantiteAffiliation rechercher(Demande demande, boolean avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    if ((demande == null) || (demande.getDemandeur() == null)) {
      return null;
    }
    Collection<Pra> listePra = null;
    if ((demande.getDossierAffectation() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().isEstProduitValide()))
    {
      ActiviteSalarie periodeActiviteSalariee = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
      
      boolean contexteRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE");
      
      DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
      donneesEntreeDeterminationListePra.setDemande(demande);
      donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_QUANTITE_APPARTENANCE);
      donneesEntreeDeterminationListePra.setActiviteSalarie(periodeActiviteSalariee);
      donneesEntreeDeterminationListePra.setForcerReglementRecharge(contexteRechargement);
      
      donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(false);
      listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    }
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    Chronologie activitesAssistancesMaternelles = null;
    if (((ProduitAsuSpec)demande.getDossierAffectation().getProduit()).effectuerTraitementSpecifiqueAssistanceMaternellePourAffiliation()) {
      activitesAssistancesMaternelles = gestionAssistantesMaternellesAvantCalculAffiliation(demande);
    }
    ConstitutionQuantiteAffiliation qa = null;
    for (Iterator<Pra> iter = listePra.iterator(); (iter.hasNext()) && (qa == null);)
    {
      Pra pra = (Pra)iter.next();
      qa = determinerQuantiteAppartenancePRA(demande, pra, avecPeriodeNonAttestee);
    }
    if (((ProduitAsuSpec)demande.getDossierAffectation().getProduit()).effectuerTraitementSpecifiqueAssistanceMaternellePourAffiliation()) {
      gestionAssistantesMaternellesApresCalculAffiliation(activitesAssistancesMaternelles);
    }
    return qa;
  }
  
  public Reglement determinerReglement(Demande demande)
  {
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    
    Reglement reglementAppartenance = validationProduit.getReglementApplicable();
    if (reglementAppartenance == null) {
      reglementAppartenance = validationProduit.getPeriodeValidationProduit().getReglement();
    }
    return reglementAppartenance;
  }
  
  public ConstitutionQuantiteAffiliation determinerQuantiteAppartenancePRA(Demande demande, Pra pra, boolean avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    ConstitutionQuantiteAffiliation qteAppartenance = null;
    
    JustificationAffiliationSpec justificationAffiliation = null;
    
    Reglement reglementAppartenance = determinerReglement(demande);
    
    Chronologie chronoComplete = new ChronologiePeriodes();
    
    Chronologie chronoPeriodesParticipantes = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(demande.getListContexteDemande(), pra, passeProfessionnel, avecPeriodeNonAttestee);
    
    chronoComplete.ajouter(chronoPeriodesParticipantes);
    
    Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(demande, pra, passeProfessionnel);
    chronoComplete.ajouter(chronoActivitesAssimilables);
    
    ProduitAsuSpec produitValide = (ProduitAsuSpec)((DossierAffectation)demande.getDossierAffectation()).getProduit();
    
    CalculAppartenanceSpec outilCalculAppartenance = produitValide.getOutilCalculAppartenance(demande, false);
    
    ParametresCalculAppartenance parametres = new ParametresCalculAppartenance();
    parametres.setEffectuerImputationAffiliationPmvs(true);
    parametres.setPrendreEnCompteDernierJourFevrier(true);
    parametres.setPrendreEnCompteDonneesForcees(true);
    parametres.setActiverSpecificitesRechargement(false);
    parametres.setContexteAppel("cepAffi");
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE") ? "RECHARGE" : null;
    
    List<Unite> listeUnite = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteConstitutionQuantiteAffiliation(reglementAppartenance.getNomReglement(), produitValide);
    
    parametres.setListeUnitesReglement(listeUnite);
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoComplete, reglementAppartenance, parametres);
    
    Quantite qteAffiliation = null;
    
    Iterator<Unite> iter = listeUnite.iterator();
    boolean acquisSuperieurRequis = false;
    while ((iter.hasNext()) && (!acquisSuperieurRequis))
    {
      Unite unite = (Unite)iter.next();
      
      qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      BigDecimal valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      
      BigDecimal valRequise = pra.getQuantiteAffiliationRequise(unite).getValeur();
      boolean creerJustificationAffiliationForcee = ((((ProduitAsuSpec)demande.getDossierAffectation().getProduit()).effectuerTraitementSpecifiqueAssistanceMaternellePourAffiliation()) || ("RECHARGE".equals(contexteReglement))) && ((demande.getDonneesTemporaires().getQuantiteAffiliation() == null) || (demande.getDonneesTemporaires().getQuantiteAffiliation().getUnite().equals(unite)));
      if ((valAcquise.compareTo(valRequise) >= 0) || (demande.getContexteAffiliationValide() != null) || (demande.estContexteAsrPrecSuiteCsr()) || (creerJustificationAffiliationForcee))
      {
        if (quantitesAppartenance.estEnConflit()) {
          demande.setLiquideeAvecConflits(true);
        }
        qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
        
        qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
        
        qteAppartenance = ((DossierExamen)demande.getDossierExamen()).createConstitutionQuantiteAffiliation();
        qteAppartenance.setArticle3(pra.getArticle3());
        qteAppartenance.setDureeInitiale(pra.getDureeInitiale());
        
        qteAppartenance.setPeriodePRA(new Periode(pra.getDebut(), pra.getFin()));
        qteAppartenance.setQuantiteAffiliationAcquise(qteAffiliation);
        qteAppartenance.setQuantiteAssimilationAcquise(qteAssimilation);
        if (justificationAffiliation == null) {
          justificationAffiliation = quantitesAppartenance.getJustificationAffiliation(unite);
        }
        boolean estAffiliationPlafonnee = false;
        if ("justifCGENouveauModele".equals(justificationAffiliation.getTypeJustificationAffiliation()))
        {
          fr.unedic.cali.asu.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.dom.JustificationAffiliation)justificationAffiliation;
          
          estAffiliationPlafonnee = justif.isEstAffiliationPlafonnee();
          
          ((DossierAffecte)demande.getDossierAffectation()).getValidationProduit().setJustificationCalculAffiliation(justif);
        }
        else if ("justifJoursTravailles".equals(justificationAffiliation.getTypeJustificationAffiliation()))
        {
          JustificationAffiliationJoursTravailles justificationJTPersiste = new JustificationAffiliationJoursTravailles();
          OutilMappingJustificationAffiliation.getInstance().mapperJustificationJoursTravaillesNonPersistantVersPersistant(justificationAffiliation, justificationJTPersiste);
          
          ((DossierAffecte)demande.getDossierAffectation()).getValidationProduit().setJustificationAffiliationJoursTravailles(justificationJTPersiste);
        }
        else
        {
          fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justificationAffiliation;
          
          justif.setPeriodePraRetenue(pra);
          justif.setAppartenanceCalculee(qteAppartenance.getQuantiteAcquise());
          
          alimenterReglementApplicable(demande, justif);
          
          qteAppartenance.ajouterJustificationAffiliation(justif, qteAffiliation.getUnite());
          
          estAffiliationPlafonnee = justif.estAffiliationPlafonnee();
        }
        qteAppartenance.setEstAffiliationPlafonnee(estAffiliationPlafonnee);
        
        acquisSuperieurRequis = true;
      }
    }
    if (qteAppartenance != null)
    {
      iter = listeUnite.iterator();
      boolean ok = false;
      while ((iter.hasNext()) && (!ok))
      {
        Unite unite = (Unite)iter.next();
        if (!unite.equals(qteAffiliation.getUnite()))
        {
          qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
          qteAffiliation = retournerQuantite(qteAffiliation, unite);
          
          Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
          qteAssimilation = retournerQuantite(qteAssimilation, unite);
          
          qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
          
          qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
          
          qteAppartenance.setQuantiteAffiliationAcquiseSecondaire(qteAffiliation);
          qteAppartenance.setQuantiteAssimilationAcquiseSecondaire(qteAssimilation);
          ok = true;
        }
      }
      Enumeration listeUniteCalcul = quantitesAppartenance.getListUnitesCalculees();
      while (listeUniteCalcul.hasMoreElements())
      {
        Unite uniteCourante = (Unite)listeUniteCalcul.nextElement();
        qteAppartenance.ajouterJustificationAffiliation(quantitesAppartenance.getJustificationAffiliation(uniteCourante), uniteCourante);
      }
    }
    return qteAppartenance;
  }
  
  public Quantite retournerQuantite(Quantite qte, Unite unite)
  {
    if (qte == null) {
      return new Quantite("0", unite);
    }
    return qte;
  }
  
  public void alimenterReglementApplicable(Demande demande, fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation justif)
  {
    if (((DossierExamen)demande.getDossierExamen()).getConstitutionReglementApplicable() != null) {
      justif.setReglementApplicable(((DossierExamen)demande.getDossierExamen()).getConstitutionReglementApplicable().getReglement());
    }
  }
  
  public Quantite[] determinerAppartenanceInsuffisante(Demande demande, ActiviteSalarie pas, boolean avecPeriodeNonAttestee, ConditionQuantiteAffiliation capa07, DossierExamen dossierExamen)
    throws ApplicativeException
  {
    QuantitesAppartenance qteAppartenanceDeuxiemeExamen = null;
    if ((demande == null) || (demande.getDemandeur() == null)) {
      return null;
    }
    boolean estPeriodeFctForcee = demande.getDonneesTemporaires().getPeriodeFctARetenir() != null;
    
    Reglement reglementPropose = pas.getReglement();
    boolean estEnContexteDeRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE");
    if (estEnContexteDeRechargement)
    {
      EreRechargement ereRechargement = (EreRechargement)demande.getEvenementReferenceExamen();
      reglementPropose = ereRechargement.getReglementForcePourRechargement();
    }
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setDemande(demande);
    donneesEntreeDeterminationListePra.setActiviteSalarie(pas);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_REGLEMENT_APPLICABLE);
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    
    Pra praQteRequiseLaPlusPetite = recherchePraDontQteRequiseLaPlusPetite(listePra);
    
    ProduitAsuSpec produit = (ProduitAsuSpec)((DossierAffecte)demande.getDossierAffectation()).getProduit();
    QuantitesAppartenance qteAppartenanceRetenue;
    if ((estPeriodeFctForcee) && (!demande.estUneDemandeFinancement()))
    {
      QuantitesAppartenance qteAppartenanceRetenue = premierExamen(demande, praQteRequiseLaPlusPetite, reglementPropose, avecPeriodeNonAttestee);
      if (RechercheReglementApplicable.getInstance().determineConditionPram(demande, pas, reglementPropose, avecPeriodeNonAttestee, produit)) {
        qteAppartenanceDeuxiemeExamen = deuxiemeExamen(demande, praQteRequiseLaPlusPetite, reglementPropose, avecPeriodeNonAttestee, false);
      }
      if (qteAppartenanceDeuxiemeExamen != null) {
        qteAppartenanceRetenue = qteAppartenanceDeuxiemeExamen;
      }
    }
    else
    {
      boolean estJustificationCsa = estJustificationClauseDeSauvegarde(demande, praQteRequiseLaPlusPetite, pas, reglementPropose, avecPeriodeNonAttestee, produit);
      qteAppartenanceRetenue = deuxiemeExamen(demande, praQteRequiseLaPlusPetite, reglementPropose, avecPeriodeNonAttestee, estJustificationCsa);
    }
    if (qteAppartenanceRetenue == null)
    {
      Quantite zero = new Quantite("0", UniteAffiliation.JOUR);
      return new Quantite[] { zero, zero };
    }
    justificationAffiliation(capa07, qteAppartenanceRetenue, dossierExamen, praQteRequiseLaPlusPetite, false);
    
    pas.initialiserReglementForce(null);
    return transformeQuantiteAppartenanceEnQuantite(qteAppartenanceRetenue);
  }
  
  public Pra recherchePraDontQteRequiseLaPlusPetite(Collection<Pra> listePra)
    throws CoucheLogiqueException
  {
    int qteRequiseMini = 9999;
    Pra praQteRequiseLaPlusPetite = null;
    Iterator<Pra> iter;
    if ((listePra != null) && (!listePra.isEmpty())) {
      for (iter = listePra.iterator(); iter.hasNext();)
      {
        Pra pra = (Pra)iter.next();
        Object cleUnite = pra.getListeQuantitesAffiliationRequises().keys().nextElement();
        Quantite qteRequise = (Quantite)pra.getListeQuantitesAffiliationRequises().get(cleUnite);
        if (qteRequise.getValeurEntiere() < qteRequiseMini)
        {
          qteRequiseMini = qteRequise.getValeurEntiere();
          praQteRequiseLaPlusPetite = pra;
        }
      }
    }
    return praQteRequiseLaPlusPetite;
  }
  
  public void justificationAffiliation(ConditionQuantiteAffiliation capa07, QuantitesAppartenance qteAppartenance, DossierExamen dossierExamen, Pra pra, boolean estSimulation)
  {
    Quantite qteAffiliation2 = null;
    Quantite qteAssimilation2 = null;
    Quantite qteAffiliation = qteAppartenance.getQuantiteAffiliation(qteAppartenance.getUniteAppartenancePrincipale());
    Quantite qteAssimilation = qteAppartenance.getQuantiteAssimilation(qteAppartenance.getUniteAppartenancePrincipale());
    
    Unite uniteJustification = null;
    if (qteAffiliation != null)
    {
      qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
      uniteJustification = qteAffiliation.getUnite();
    }
    else
    {
      qteAffiliation = new Quantite(BigDecimal.ZERO, qteAppartenance.getUniteAppartenancePrincipale());
    }
    if (qteAssimilation != null) {
      qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
    } else {
      qteAssimilation = new Quantite(BigDecimal.ZERO, qteAppartenance.getUniteAppartenancePrincipale());
    }
    if (qteAppartenance.getUniteAppartenanceSecondaire() != null)
    {
      qteAffiliation2 = qteAppartenance.getQuantiteAffiliation(qteAppartenance.getUniteAppartenanceSecondaire());
      qteAssimilation2 = qteAppartenance.getQuantiteAssimilation(qteAppartenance.getUniteAppartenanceSecondaire());
      if (qteAffiliation2 != null)
      {
        qteAffiliation2 = new Quantite(qteAffiliation2.getValeur().setScale(10, 1), qteAffiliation2.getUnite());
        if (uniteJustification == null) {
          uniteJustification = qteAffiliation2.getUnite();
        }
      }
      if (qteAssimilation2 != null) {
        qteAssimilation2 = new Quantite(qteAssimilation2.getValeur().setScale(10, 1), qteAssimilation2.getUnite());
      }
    }
    ConstitutionQuantiteAffiliation constitutionQuantiteAffiliation = null;
    if (estSimulation)
    {
      constitutionQuantiteAffiliation = dossierExamen.createConstitutionQuantiteAffiliation();
      constitutionQuantiteAffiliation.setDureeInitiale(pra.getDureeInitiale());
      
      constitutionQuantiteAffiliation.setPeriodePRA(new Periode(pra.getDebut(), pra.getFin()));
      constitutionQuantiteAffiliation.setQuantiteAffiliationAcquise(qteAffiliation);
      constitutionQuantiteAffiliation.setQuantiteAssimilationAcquise(qteAssimilation);
      constitutionQuantiteAffiliation.setQuantiteAffiliationAcquiseSecondaire(qteAffiliation2);
      constitutionQuantiteAffiliation.setQuantiteAssimilationAcquiseSecondaire(qteAssimilation2);
    }
    JustificationAffiliationSpec justificationAffiliation = qteAppartenance.getJustificationAffiliation(uniteJustification);
    boolean estAffiliationPlafonnee;
    if ("justifCGENouveauModele".equals(justificationAffiliation.getTypeJustificationAffiliation()))
    {
      fr.unedic.cali.asu.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.dom.JustificationAffiliation)justificationAffiliation;
      
      boolean estAffiliationPlafonnee = justif.isEstAffiliationPlafonnee();
      if (((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit() == null)
      {
        ValidationProduit validationProduit = new ValidationProduit();
        validationProduit.setEstProduitValide(false);
        ((DossierAffecte)dossierExamen.getDossierAffecte()).setValidationProduit(validationProduit);
      }
      ((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit().setJustificationCalculAffiliation(justif);
    }
    else if ("justifJoursTravailles".equals(justificationAffiliation.getTypeJustificationAffiliation()))
    {
      boolean estAffiliationPlafonnee = false;
      if (((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit() == null)
      {
        ValidationProduit validationProduit = new ValidationProduit();
        validationProduit.setEstProduitValide(false);
        ((DossierAffecte)dossierExamen.getDossierAffecte()).setValidationProduit(validationProduit);
      }
      JustificationAffiliationJoursTravailles justificationJTPersiste = new JustificationAffiliationJoursTravailles();
      OutilMappingJustificationAffiliation.getInstance().mapperJustificationJoursTravaillesNonPersistantVersPersistant(justificationAffiliation, justificationJTPersiste);
      
      ((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit().setJustificationAffiliationJoursTravailles(justificationJTPersiste);
    }
    else
    {
      fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justificationAffiliation;
      justif.setPeriodePraRetenue(pra);
      
      estAffiliationPlafonnee = justif.estAffiliationPlafonnee();
      if (constitutionQuantiteAffiliation != null)
      {
        if (qteAppartenance.getQuantiteAssimilation(qteAppartenance.getUniteAppartenancePrincipale()) != null) {
          justif.setAppartenanceCalculee(constitutionQuantiteAffiliation.getQuantiteAcquise());
        } else {
          justif.setAppartenanceCalculee(constitutionQuantiteAffiliation.getQuantiteAffiliationAcquise());
        }
        constitutionQuantiteAffiliation.ajouterJustificationAffiliation(justif, qteAffiliation.getUnite());
      }
      else if (qteAppartenance.getQuantiteAssimilation(qteAppartenance.getUniteAppartenancePrincipale()) != null)
      {
        justif.setAppartenanceCalculee(qteAffiliation.ajouter(qteAssimilation));
      }
      else
      {
        justif.setAppartenanceCalculee(qteAffiliation);
      }
    }
    capa07.setJustificationAffiliation(justificationAffiliation);
    if (constitutionQuantiteAffiliation != null) {
      constitutionQuantiteAffiliation.setEstAffiliationPlafonnee(estAffiliationPlafonnee);
    }
  }
  
  protected Quantite[] transformeQuantiteAppartenanceEnQuantite(QuantitesAppartenance quantitesAppartenance)
  {
    Quantite[] retourQte = new Quantite[2];
    
    retourQte[0] = new Quantite(Mathematiques.arrondiASup(quantitesAppartenance.getQuantiteAppartenance(quantitesAppartenance.getUniteAppartenancePrincipale()).getValeur(), 10), quantitesAppartenance.getUniteAppartenancePrincipale());
    if (quantitesAppartenance.getUniteAppartenanceSecondaire() != null) {
      retourQte[1] = new Quantite(Mathematiques.arrondiASup(quantitesAppartenance.getQuantiteAppartenance(quantitesAppartenance.getUniteAppartenanceSecondaire()).getValeur(), 10), quantitesAppartenance.getUniteAppartenanceSecondaire());
    }
    return retourQte;
  }
  
  public QuantitesAppartenance premierExamen(Demande demande, Pra pra, Reglement reglement, boolean avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie chronoPAS = RechercheReglementApplicable.getInstance().determinerActivitesParticipantes(demande, pra, reglement, avecPeriodeNonAttestee, true);
    
    return verifierConditionAffiliation(demande, pra, chronoPAS, reglement, false);
  }
  
  public QuantitesAppartenance deuxiemeExamen(Demande demande, Pra pra, Reglement reglement, boolean avecPeriodeNonAttestee, boolean estJustificationCsa)
    throws ApplicativeException
  {
    Chronologie chronoPAS = RechercheReglementApplicable.getInstance().determinerActivitesParticipantes(demande, pra, avecPeriodeNonAttestee);
    
    return verifierConditionAffiliation(demande, pra, chronoPAS, reglement, estJustificationCsa);
  }
  
  private QuantitesAppartenance verifierConditionAffiliation(Demande demande, Pra pra, Chronologie chronoPAS, Reglement reglementAppartenance, boolean estJustificationCsa)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)((DossierAffecte)demande.getDossierAffectation()).getProduit();
    
    CalculAppartenanceSpec outilCalculAppartenance = produit.getOutilCalculAppartenance(demande, false);
    
    ParametresCalculAppartenance parametres = new ParametresCalculAppartenance();
    parametres.setEffectuerImputationAffiliationPmvs(true);
    parametres.setPrendreEnCompteDernierJourFevrier(true);
    parametres.setPrendreEnCompteDonneesForcees(true);
    parametres.setActiverSpecificitesRechargement(true);
    parametres.setComptabiliserAssimilation(true);
    parametres.setContexteAppel("rechercheReglementApplicable");
    List<Unite> listeUnites = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteRechercheReglementApplicable(reglementAppartenance.getNomReglement(), demande.estEnContexteDemande("RECHARGE"), produit);
    
    parametres.setListeUnitesReglement(listeUnites);
    if (estJustificationCsa)
    {
      parametres.setPrendreEnCompteDernierJourFevrier(false);
      parametres.setComptabiliserAssimilation(false);
    }
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoPAS, reglementAppartenance, parametres);
    
    Unite unite1 = (Unite)listeUnites.get(0);
    quantitesAppartenance.setUniteAppartenancePrincipale(unite1);
    if (listeUnites.size() > 1)
    {
      Unite unite2 = (Unite)listeUnites.get(1);
      quantitesAppartenance.setUniteAppartenanceSecondaire(unite2);
    }
    return quantitesAppartenance;
  }
  
  private Chronologie gestionAssistantesMaternellesAvantCalculAffiliation(Demande demande)
  {
    Chronologie activitesAssistantesMaternelles = null;
    if (demande.getDonneesTemporaires().getQuantiteAffiliation() == null)
    {
      activitesAssistantesMaternelles = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreActiviteSalariePourCategorieParticuliere(23));
      
      Reglement annexe1 = Reglement.getInstance("A1", demande.getDossierAffectationAdmission().getProduit());
      activitesAssistantesMaternelles.iterer();
      while (activitesAssistantesMaternelles.encoreSuivant())
      {
        ActiviteSalarie activiteCourante = (ActiviteSalarie)activitesAssistantesMaternelles.elementSuivant();
        activiteCourante.initialiserReglementForce(annexe1);
        
        activiteCourante = remplirActivite(activiteCourante, demande);
        activiteCourante.setListePeriodeElementaire(null);
      }
    }
    return activitesAssistantesMaternelles;
  }
  
  public ActiviteSalarie remplirActivite(ActiviteSalarie activiteCourante, Demande demande)
  {
    ArrayList<Periode> moisCivil = activiteCourante.getPeriode().decouperEnMoisCivils();
    for (int i = 0; i < moisCivil.size(); i++)
    {
      Periode mois = (Periode)moisCivil.get(i);
      Damj debutMoisCivil = mois.getDebut();
      if (debutMoisCivil.estApres(demande.getDateExamen())) {
        break;
      }
      PeriodeMesureActivite pma = new PeriodeMesureActivite(debutMoisCivil, mois.getFin());
      pma.ajouterQuantiteAffiliation(new Quantite(mois.getDuree(), UniteAffiliation.JOUR));
      activiteCourante.ajouterPeriodeMesureActiviteForcee(pma);
    }
    return activiteCourante;
  }
  
  private void gestionAssistantesMaternellesApresCalculAffiliation(Chronologie activites)
  {
    if (activites != null)
    {
      activites.iterer();
      while (activites.encoreSuivant())
      {
        ActiviteSalarie activiteCourante = (ActiviteSalarie)activites.elementSuivant();
        activiteCourante.supprimerReglementForce();
        activiteCourante.supprimerPeriodesMesureActiviteForcees();
        activiteCourante.setListePeriodeElementaire(null);
      }
    }
  }
  
  protected boolean estJustificationClauseDeSauvegarde(Demande demande, Pra praQteRequiseLaPlusPetite, ActiviteSalarie pas, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    Damj dateApplication = GestionnaireDateApplication.getInstance().recupererDateApplication("Activation de la non prise en compte de l'assimilation pour la ligne CSA");
    return (demande.getDateExamen().estApresOuCoincideAvec(dateApplication)) && (!determineConditionPram(demande, pas, reglement, avecPeriodeNonAttestee, produit)) && (verifierReglementAppartenanceDifferent(demande, praQteRequiseLaPlusPetite));
  }
  
  protected boolean determineConditionPram(Demande demande, ActiviteSalarie pas, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    return RechercheReglementApplicable.getInstance().determineConditionPram(demande, pas, reglement, avecPeriodeNonAttestee, produit);
  }
  
  protected boolean verifierReglementAppartenanceDifferent(DemandeAssuranceSpec demande, Pra pra)
  {
    return OutilVerificationReglementsMultiples.getInstance().verifierReglementAppartenanceDifferent(demande, pra);
  }
}

/* Location:
 * Qualified Name:     RechercheQuantiteAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */