package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.comparateur.ComparateurEvenementPeriodeZME;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.EvenementPeriodeZME;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementJustificationAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementZoneMemeExerciceSpec;
import fr.unedic.cali.asu.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.ElementZoneMemeExercice;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.PeriodeAffiliationSpec;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.ZoneMemeExercice;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class OutilTraitementZonesMemeExercice
  implements TraitementZoneMemeExerciceSpec
{
  private static final BigDecimal ZERO = new BigDecimal(0);
  
  public void traiterZonesMemeExercice(Periode p_pra, List p_periodesElementaires, List p_periodesAffiliationSupplementaire, List p_periodesAffiliationAssimilee, JustificationAffiliation p_justificationAffiliation, ParametresAffiliation p_parametres, ComportementAffiliationSpec p_comportement)
  {
    List listeZoneMemeExercice = constituerZonesMemeExercice(p_pra, p_periodesElementaires, p_periodesAffiliationSupplementaire, p_periodesAffiliationAssimilee, p_justificationAffiliation, p_comportement);
    
    Iterator it = listeZoneMemeExercice.iterator();
    while (it.hasNext())
    {
      ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
      
      constituerElementsZoneMemeExercice(zoneMemeExercice, p_periodesElementaires, p_periodesAffiliationSupplementaire, p_periodesAffiliationAssimilee);
      if (zoneMemeExercice.getListElementZoneMemeExercice().size() > 0)
      {
        regrouperQuantiteAppartenancePourZoneMemeExercice(zoneMemeExercice);
        
        determinerQuantiteAffiliationPourZoneMemeExercice(zoneMemeExercice, p_parametres, p_comportement);
        
        determinerQuantiteAssimilationPourZoneMemeExercice(zoneMemeExercice, p_parametres, p_comportement);
      }
      else
      {
        p_justificationAffiliation.supprimerZoneMemeExercice(zoneMemeExercice);
      }
    }
  }
  
  public Quantite cumulerAffiliationZoneMemeExercice(List p_listeZME, ParametresAffiliation p_parametres)
  {
    Quantite resultat = new Quantite(new BigDecimal(0), p_parametres.getUniteCalcul());
    
    Iterator it = p_listeZME.iterator();
    while (it.hasNext())
    {
      ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
      resultat = resultat.ajouter(zoneMemeExercice.getQuantiteAffiliationRetenue());
    }
    return resultat;
  }
  
  public Quantite cumulerAssimilationZoneMemeExercice(List p_listeZME, ParametresAffiliation p_parametres)
  {
    Quantite resultat = new Quantite(new BigDecimal(0), p_parametres.getUniteCalcul());
    
    Iterator it = p_listeZME.iterator();
    while (it.hasNext())
    {
      ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
      resultat = resultat.ajouter(zoneMemeExercice.getQuantiteAssimilationRetenue());
    }
    return resultat;
  }
  
  public ZoneMemeExercice determinerZoneMemeExerciceActivteALaDate(List p_listeZoneMemeExercice, Damj p_dateRecherche)
  {
    Iterator it = p_listeZoneMemeExercice.iterator();
    while (it.hasNext())
    {
      ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
      if (zoneMemeExercice.getPeriodeZomeMemeExercice().contient(p_dateRecherche)) {
        return zoneMemeExercice;
      }
    }
    return null;
  }
  
  protected List constituerZonesMemeExercice(Periode p_pra, List p_periodesElementaires, List p_periodesAffiliationSupplementaire, List p_periodesAffiliationAssimilee, JustificationAffiliation p_justificationAffiliation, ComportementAffiliationSpec p_comportement)
  {
    List resultat = new ArrayList();
    
    Chronologie chronologieEvenementSegmentantZME = constituerChronologieEvenementSegmentant(p_pra, p_periodesElementaires, p_periodesAffiliationSupplementaire, p_periodesAffiliationAssimilee);
    
    Iterator it = chronologieEvenementSegmentantZME.iterer();
    EvenementPeriodeZME evenementPrecedent = (EvenementPeriodeZME)it.next();
    while (it.hasNext())
    {
      EvenementPeriodeZME evenementCourant = (EvenementPeriodeZME)it.next();
      Damj dateDebutZME;
      Damj dateDebutZME;
      if (evenementPrecedent.getTypeEvenement() == 1) {
        dateDebutZME = evenementPrecedent.getDateEvenement();
      } else {
        dateDebutZME = evenementPrecedent.getDateEvenement().lendemain();
      }
      Damj dateFinZME;
      Damj dateFinZME;
      if (evenementCourant.getTypeEvenement() == 1) {
        dateFinZME = evenementCourant.getDateEvenement().veille();
      } else {
        dateFinZME = evenementCourant.getDateEvenement();
      }
      if (dateFinZME.estApresOuCoincideAvec(dateDebutZME))
      {
        ZoneMemeExercice zoneMemeExercice = creerInstanceZoneMemeExercice();
        zoneMemeExercice.setPeriodeZomeMemeExercice(new Periode(dateDebutZME, dateFinZME));
        
        p_comportement.getOutilTraitementJustificationAffiliation().ajouterZoneMemeExercice(p_justificationAffiliation, zoneMemeExercice);
        resultat.add(zoneMemeExercice);
      }
      evenementPrecedent = evenementCourant;
    }
    return resultat;
  }
  
  protected Chronologie constituerChronologieEvenementSegmentant(Periode p_pra, List p_periodesElementaires, List p_periodesAffiliationSupplementaire, List p_periodesAffiliationAssimilee)
  {
    Chronologie chronologieEvenementSegmentantZME = new ChronologiePeriodes();
    
    chronologieEvenementSegmentantZME.setComparateur(new ComparateurEvenementPeriodeZME());
    
    Iterator it = p_periodesElementaires.iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      
      Damj dateDebut = periodeElementaire.getPeriodePE().getDebut();
      Damj dateFin = periodeElementaire.getPeriodePE().getFin();
      if (dateDebut.estContenueDans(p_pra))
      {
        EvenementPeriodeZME evenementDebut = new EvenementPeriodeZME(dateDebut, 1);
        
        ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementDebut);
      }
      if (dateFin.estContenueDans(p_pra))
      {
        EvenementPeriodeZME evenementFin = new EvenementPeriodeZME(dateFin, 2);
        
        ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementFin);
      }
    }
    it = p_periodesAffiliationSupplementaire.iterator();
    while (it.hasNext())
    {
      AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
      if (affiliationSupplementaire.estTauxPlein())
      {
        Damj dateDebut = affiliationSupplementaire.getPeriodeAffiliationSupplementaire().getDebut();
        Damj dateFin = affiliationSupplementaire.getPeriodeAffiliationSupplementaire().getFin();
        if (dateDebut.estContenueDans(p_pra))
        {
          EvenementPeriodeZME evenementDebut = new EvenementPeriodeZME(dateDebut, 1);
          
          ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementDebut);
        }
        if (dateFin.estContenueDans(p_pra))
        {
          EvenementPeriodeZME evenementFin = new EvenementPeriodeZME(dateFin, 2);
          
          ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementFin);
        }
      }
    }
    it = p_periodesAffiliationAssimilee.iterator();
    while (it.hasNext())
    {
      AffiliationAssimilee affiliationAssimilee = (AffiliationAssimilee)it.next();
      
      Damj dateDebut = affiliationAssimilee.getPeriodeAssimilation().getDebut();
      Damj dateFin = affiliationAssimilee.getPeriodeAssimilation().getFin();
      if (dateDebut.estContenueDans(p_pra))
      {
        EvenementPeriodeZME evenementDebut = new EvenementPeriodeZME(dateDebut, 1);
        
        ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementDebut);
      }
      if (dateFin.estContenueDans(p_pra))
      {
        EvenementPeriodeZME evenementFin = new EvenementPeriodeZME(dateFin, 2);
        
        ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementFin);
      }
    }
    EvenementPeriodeZME evenementDebut = new EvenementPeriodeZME(p_pra.getDebut(), 1);
    
    ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementDebut);
    
    EvenementPeriodeZME evenementFin = new EvenementPeriodeZME(p_pra.getFin(), 2);
    
    ajouterEvenementPeriodeZME(chronologieEvenementSegmentantZME, evenementFin);
    
    return chronologieEvenementSegmentantZME;
  }
  
  private void ajouterEvenementPeriodeZME(Chronologie p_chronologieEvenementSegmentantZME, EvenementPeriodeZME p_evenement)
  {
    if (!p_chronologieEvenementSegmentantZME.contientElement(p_evenement)) {
      p_chronologieEvenementSegmentantZME.ajouter(p_evenement);
    }
  }
  
  protected void constituerElementsZoneMemeExercice(ZoneMemeExercice p_zoneMemeExercice, List p_periodesElementaires, List p_periodesAffiliationSupplementaire, List p_periodesAffiliationAssimilee)
  {
    Iterator it = p_periodesElementaires.iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      if (periodeElementaire.getPeriodePE().chevauche(p_zoneMemeExercice.getPeriodeZomeMemeExercice()))
      {
        Periode periodeIntersection = periodeElementaire.getPeriodePE().periodeIntersection(p_zoneMemeExercice.getPeriodeZomeMemeExercice());
        
        Quantite quantiteSurElementZme = OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeElementaire.getQuantiteRetenue(), periodeElementaire.getPeriodePE().getDuree(), periodeIntersection.getDuree());
        
        ElementZoneMemeExercice elementZME = creerInstanceElementZoneMemeExercice();
        elementZME.setPeriodeAffiliation(periodeElementaire);
        elementZME.setQuantiteAffiliation(quantiteSurElementZme);
        
        p_zoneMemeExercice.ajouterElementZoneMemeExercice(elementZME);
      }
    }
    it = p_periodesAffiliationSupplementaire.iterator();
    while (it.hasNext())
    {
      AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
      if (affiliationSupplementaire.getPeriodeAffiliationSupplementaire().chevauche(p_zoneMemeExercice.getPeriodeZomeMemeExercice()))
      {
        Periode periodeIntersection = affiliationSupplementaire.getPeriodeAffiliationSupplementaire().periodeIntersection(p_zoneMemeExercice.getPeriodeZomeMemeExercice());
        
        Quantite quantiteSurElementZme = OutilQuantiteAffiliation.getInstance().proratiserQuantite(affiliationSupplementaire.getQuantiteRetenue(), affiliationSupplementaire.getPeriodeAffiliationSupplementaire().getDuree(), periodeIntersection.getDuree());
        
        ElementZoneMemeExercice elementZME = creerInstanceElementZoneMemeExercice();
        elementZME.setPeriodeAffiliation(affiliationSupplementaire);
        elementZME.setQuantiteAffiliation(quantiteSurElementZme);
        
        p_zoneMemeExercice.ajouterElementZoneMemeExercice(elementZME);
      }
    }
    it = p_periodesAffiliationAssimilee.iterator();
    while (it.hasNext())
    {
      AffiliationAssimilee affiliationAssimilee = (AffiliationAssimilee)it.next();
      if (affiliationAssimilee.getPeriodeAssimilation().chevauche(p_zoneMemeExercice.getPeriodeZomeMemeExercice()))
      {
        Periode periodeIntersection = affiliationAssimilee.getPeriodeAssimilation().periodeIntersection(p_zoneMemeExercice.getPeriodeZomeMemeExercice());
        
        Quantite quantiteSurElementZme = OutilQuantiteAffiliation.getInstance().proratiserQuantite(affiliationAssimilee.getQuantiteAssimilation(), affiliationAssimilee.getPeriodeAssimilation().getDuree(), periodeIntersection.getDuree());
        
        ElementZoneMemeExercice elementZME = creerInstanceElementZoneMemeExercice();
        elementZME.setPeriodeAffiliation(affiliationAssimilee);
        elementZME.setQuantiteAffiliation(quantiteSurElementZme);
        
        p_zoneMemeExercice.ajouterElementZoneMemeExercice(elementZME);
      }
    }
  }
  
  protected void regrouperQuantiteAppartenancePourZoneMemeExercice(ZoneMemeExercice p_zoneMemeExercice)
  {
    Iterator it = p_zoneMemeExercice.getListElementZoneMemeExercice().iterator();
    while (it.hasNext())
    {
      ElementZoneMemeExercice elementZoneMemeExercice = (ElementZoneMemeExercice)it.next();
      if ((elementZoneMemeExercice.getPeriodeAffiliation().getNature() == 1) || (elementZoneMemeExercice.getPeriodeAffiliation().getNature() == 2))
      {
        Quantite quantiteElement = elementZoneMemeExercice.getQuantiteAffiliation();
        Quantite quantiteZME = p_zoneMemeExercice.getQuantiteAffiliationRegroupee(quantiteElement.getUnite());
        Quantite quantiteARetenir;
        Quantite quantiteARetenir;
        if (quantiteZME == null) {
          quantiteARetenir = quantiteElement;
        } else {
          quantiteARetenir = OutilQuantiteAffiliation.getInstance().regrouperQuantitesAffiliation(quantiteZME, quantiteElement);
        }
        p_zoneMemeExercice.ajouterQuantiteAffiliationRegroupee(quantiteARetenir);
      }
    }
  }
  
  protected void determinerQuantiteAffiliationPourZoneMemeExercice(ZoneMemeExercice p_zoneMemeExercice, ParametresAffiliation p_parametres, ComportementAffiliationSpec p_comportement)
  {
    Collection listeQuantites = p_zoneMemeExercice.getListQuantiteAffiliationRegroupee();
    
    Quantite quantiteRegroupeTypeHeure = regrouperQuantiteDeMemeType(listeQuantites, p_comportement.getConvertisseurUnite(), 2, p_parametres.getUniteCalcul());
    
    Quantite quantiteRegroupeTypeJour = regrouperQuantiteDeMemeType(listeQuantites, p_comportement.getConvertisseurUnite(), 1, p_parametres.getUniteCalcul());
    
    p_zoneMemeExercice.setQuantiteTotalUniteTypeHeure(quantiteRegroupeTypeHeure);
    p_zoneMemeExercice.setQuantiteTotalUniteTypeJour(quantiteRegroupeTypeJour);
    Quantite quantiteARetenir = quantiteRegroupeTypeHeure.max(quantiteRegroupeTypeJour);
    p_zoneMemeExercice.setQuantiteAffiliationRetenue(quantiteARetenir);
  }
  
  protected Quantite regrouperQuantiteDeMemeType(Collection p_listeQuantites, Convertisseur p_convertisseur, int p_typeUniteRegroupement, Unite p_uniteResultat)
  {
    Quantite resultat = new Quantite(new BigDecimal(0), p_uniteResultat);
    Iterator it = p_listeQuantites.iterator();
    while (it.hasNext())
    {
      Quantite quantite = (Quantite)it.next();
      if (OutilQuantiteAffiliation.getInstance().determinerTypeUniteAffiliation(quantite.getUnite()) == p_typeUniteRegroupement)
      {
        Quantite quantiteConvertie = p_convertisseur.convertir(quantite, p_uniteResultat);
        
        resultat = OutilQuantiteAffiliation.getInstance().appliquerRegroupementPourTypeUnite(resultat, quantiteConvertie, p_typeUniteRegroupement);
      }
    }
    return resultat;
  }
  
  protected void determinerQuantiteAssimilationPourZoneMemeExercice(ZoneMemeExercice p_zoneMemeExercice, ParametresAffiliation p_parametres, ComportementAffiliationSpec p_comportement)
  {
    BigDecimal cumulQuantiteAssimilation = cumulerQuantiteAssimilationPourZoneMemeExercice(p_zoneMemeExercice, p_parametres, p_comportement).getValeur();
    
    BigDecimal quantiteAffiliationUniteTypeHeure = p_comportement.getConvertisseurUnite().convertir(p_zoneMemeExercice.getQuantiteTotalUniteTypeHeure(), p_parametres.getUniteCalcul()).getValeur();
    
    BigDecimal quantiteAffiliationRetenue = p_comportement.getConvertisseurUnite().convertir(p_zoneMemeExercice.getQuantiteAffiliationRetenue(), p_parametres.getUniteCalcul()).getValeur();
    
    BigDecimal quantiteAssimilation = ZERO.max(cumulQuantiteAssimilation.min(cumulQuantiteAssimilation.add(quantiteAffiliationUniteTypeHeure).subtract(quantiteAffiliationRetenue)));
    
    p_zoneMemeExercice.setQuantiteAssimilationRetenue(new Quantite(quantiteAssimilation, p_parametres.getUniteCalcul()));
  }
  
  protected Quantite cumulerQuantiteAssimilationPourZoneMemeExercice(ZoneMemeExercice p_zoneMemeExercice, ParametresAffiliation p_parametres, ComportementAffiliationSpec p_comportement)
  {
    Iterator it = p_zoneMemeExercice.getListElementZoneMemeExercice().iterator();
    Unite uniteRecherche = p_parametres.getUniteCalcul();
    Quantite cumulAssimilation = new Quantite(new BigDecimal(0), uniteRecherche);
    while (it.hasNext())
    {
      ElementZoneMemeExercice elementZoneMemeExercice = (ElementZoneMemeExercice)it.next();
      if (elementZoneMemeExercice.getPeriodeAffiliation().getNature() == 3)
      {
        Quantite quantiteElement = elementZoneMemeExercice.getQuantiteAffiliation();
        Quantite quantiteConvertie = p_comportement.getConvertisseurUnite().convertir(quantiteElement, uniteRecherche);
        cumulAssimilation = cumulAssimilation.ajouter(quantiteConvertie);
      }
    }
    return cumulAssimilation;
  }
  
  protected ZoneMemeExercice creerInstanceZoneMemeExercice()
  {
    return new ZoneMemeExercice();
  }
  
  protected ElementZoneMemeExercice creerInstanceElementZoneMemeExercice()
  {
    return new ElementZoneMemeExercice();
  }
}

/* Location:
 * Qualified Name:     OutilTraitementZonesMemeExercice
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */