package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieContexteRepriseSystematiqueSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.List;

public class StrategieContexteRepriseSystematiqueAvantARE14
  implements StrategieContexteRepriseSystematiqueSpec
{
  public boolean determinerContexteRepriseSystematique(Demande demande)
  {
    Damj dateRIDE = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec()).getDateDebut();
    ObjetChronoPeriodePriseEnCharge pecPrecedente = OutillagePEC.getPecIndemnisablePrecedente(demande.getDemandeur(), demande.getFormulaire().getIdPec());
    if (pecPrecedente != null)
    {
      if (dateRIDE.equals(pecPrecedente.getDateFin())) {
        return true;
      }
      Periode periodeRecherche = new Periode(pecPrecedente.getDateFin(), dateRIDE.veille());
      
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreFinDansBornes(periodeRecherche));
      if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
        filtres.ajouterFiltre(new FiltreActiviteSalarie());
      } else {
        filtres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      }
      Chronologie activitesSalaries = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      if (activitesSalaries.estVide()) {
        return true;
      }
    }
    return false;
  }
  
  public List<Integer> determinerObjectifsExamenDv122Jour(Demande demande, int resultatContexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    switch (resultatContexteExamen)
    {
    case 1: 
      listeTypesObjectifs.add(Integer.valueOf(10));
      break;
    case 2: 
    case 3: 
    case 4: 
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    return listeTypesObjectifs;
  }
  
  public List<Integer> determinerObjectifsExamenDemandeExpresseAvecReliquatValide(Demande demande)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    listeTypesObjectifs.add(Integer.valueOf(12));
    return listeTypesObjectifs;
  }
  
  public List<Integer> determinerObjectifsFinAsp(Demande demande, int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "FINASPVOL")) {
      listeTypesObjectifs.add(Integer.valueOf(15));
    } else if (contexteExamen == 1) {
      listeTypesObjectifs.add(Integer.valueOf(10));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    return listeTypesObjectifs;
  }
  
  public List<Integer> determinerObjectifsExamenPourRepriseSystematique(Demande demande)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    ajouterObjectifReprise(demande, listeTypesObjectifs, 15);
    listeTypesObjectifs.add(Integer.valueOf(12));
    return listeTypesObjectifs;
  }
  
  protected void ajouterObjectifReprise(Demande demande, List<Integer> listeTypesObjectifs, int typeReprise)
  {
    if ("S".equalsIgnoreCase(demande.getModeLiquidation())) {
      listeTypesObjectifs.add(Integer.valueOf(34));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(typeReprise));
    }
  }
  
  public List<Integer> determinerObjectifsAntecedentSecteurPublic(Demande demande)
    throws CoucheLogiqueException
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    listeTypesObjectifs.add(Integer.valueOf(12));
    return listeTypesObjectifs;
  }
}

/* Location:
 * Qualified Name:     StrategieContexteRepriseSystematiqueAvantARE14
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */