package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDelaiAttenteSpec;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ResultatDeterminationDelaisReports;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreRenoncementPourAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionAssuranceAvecDiffere;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public class StrategieDelaiAttenteAvantARE14
  implements StrategieDelaiAttenteSpec
{
  private static final int DOUZE_MOIS = 12;
  
  public boolean determinerApplicabiliteDelaiAttente(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    boolean creationDelaiAttente = false;
    
    Od odCourante = (Od)demande.getOdAcquise();
    if (odCourante != null)
    {
      Damj termePeriode = odCourante.getDateDebut();
      DureeCalendaire duree12Mois = new DureeCalendaire(0, 12, 0);
      Periode periode12MoisSurOdCourante = CalculDelais.determinerDelai(termePeriode, duree12Mois);
      periode12MoisSurOdCourante.setDebut(periode12MoisSurOdCourante.getDebut().lendemain());
      
      FiltreET filtreNonRenoncementAvecDiffere = new FiltreET();
      filtreNonRenoncementAvecDiffere.ajouterFiltre(new FiltreNegation(new FiltreRenoncementPourAttributionAssurance(false, true, false, false, null)));
      
      filtreNonRenoncementAvecDiffere.ajouterFiltre(new FiltreAttributionAssuranceAvecDiffere());
      
      FiltreET filtreOdPourDelaisReport = new FiltreET();
      filtreOdPourDelaisReport.ajouterFiltre(filtreNonRenoncementAvecDiffere);
      filtreOdPourDelaisReport.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(false, true, false, false, null));
      
      AttributionAssuranceSpec odPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreOdPourDelaisReport);
      
      FiltreET filtreAttributionPourDelaisReport = new FiltreET();
      filtreAttributionPourDelaisReport.ajouterFiltre(filtreNonRenoncementAvecDiffere);
      filtreAttributionPourDelaisReport.ajouterFiltre(new FiltreAttributionStandardAssurance(false, true, false, false, null));
      
      AttributionSpec attribPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreAttributionPourDelaisReport);
      
      Damj dateAttributionDroitAnterieurSp = demande.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
      if (dateAttributionDroitAnterieurSp != null)
      {
        if (periode12MoisSurOdCourante.estApres(dateAttributionDroitAnterieurSp)) {
          creationDelaiAttente = true;
        }
      }
      else if (odPrecedente != null)
      {
        if (attribPrecedente == null) {
          attribPrecedente = odPrecedente;
        }
        if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension((DemandeAssuranceSpec)odPrecedente.getDemande())) {
          creationDelaiAttente = true;
        } else if (estDemandeFinDroitAsrOuAsp(odPrecedente)) {
          creationDelaiAttente = true;
        } else if ((periode12MoisSurOdCourante.estApres(odPrecedente.getDateEffet())) || (!estEntameDelaiAttenteOdPrecedente((DemandeAssuranceSpec)attribPrecedente.getDemande()))) {
          creationDelaiAttente = true;
        }
      }
      else
      {
        creationDelaiAttente = true;
      }
    }
    return creationDelaiAttente;
  }
  
  private boolean estDemandeFinDroitAsrOuAsp(AttributionAssuranceSpec odPrecedente)
  {
    return (OutilDemande.estUneDemandeFinDroitAsr(odPrecedente.getDemande())) || (OutilDemande.estUneDemandeFinDroitAsp(odPrecedente.getDemande()));
  }
  
  private static boolean estEntameDelaiAttenteOdPrecedente(DemandeAssuranceSpec demandeAttributionPrecedente)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)demandeAttributionPrecedente.getDossierAffectation().getProduit();
    return produit.estEntameDiffereStandard(demandeAttributionPrecedente);
  }
  
  public void alimenterListeCarencesForcees(DemandeAssuranceSpec demande, Collection<CarencePrefixeAFixer> collectionCarences) {}
  
  public void supprimerListeCarencesForcees(DemandeAssuranceSpec demande) {}
  
  public Quantite calculerReliquatDiffere(Damj dateAttribution, Damj pjiAttributionPrecedente, Damj dernierJourApplicationDiffere, Quantite reliquatInitial, CarencePrefixeAFixer delaiReportAttributionPrecedente)
  {
    Quantite reliquatCalcule = reliquatInitial;
    Damj dateDebutIndemnisation = pjiAttributionPrecedente;
    if (!dateAttribution.estAvant(pjiAttributionPrecedente))
    {
      Damj dateDebutApplicationCarence = delaiReportAttributionPrecedente.getPeriodeApplicationCarence().getDebut();
      int quantiteInitiale = delaiReportAttributionPrecedente.getQuantiteInitial().getValeurEntiere();
      dateDebutIndemnisation = dateDebutApplicationCarence.deplacerVersAvant(new DureeCalendaire(0, 0, quantiteInitiale));
    }
    if (dateAttribution.estAvant(dateDebutIndemnisation))
    {
      int reliquatARetenirALaDateAttribution = dateAttribution.joursEntre(dateDebutIndemnisation);
      reliquatARetenirALaDateAttribution = Math.min(reliquatARetenirALaDateAttribution, reliquatInitial.getValeurEntiere());
      if (reliquatARetenirALaDateAttribution > 0) {
        reliquatCalcule = new QuantiteJour(new BigDecimal(reliquatARetenirALaDateAttribution));
      }
    }
    else
    {
      reliquatCalcule = null;
    }
    return reliquatCalcule;
  }
}

/* Location:
 * Qualified Name:     StrategieDelaiAttenteAvantARE14
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */