package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationDiviseurSjrSpec;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.OutilSjrPnds;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeSalaireAvecAbsence;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeSalaireSansAbsence;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieSuspensionDecoupee;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public abstract class StrategieDeterminationDiviseurSjrAbstrait
  implements StrategieDeterminationDiviseurSjrSpec
{
  public OutilJustificationSjrSpec recupererOutilJustificationSjr(DonneesEntreeComportementSpec donneesEntreeComportement)
  {
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntreeComportement.getFabriqueOutilFonctionnel();
    
    return fabriqueOutilFonctionnel.getOutilJustificationSjr(donneesEntreeComportement);
  }
  
  public void determinerDureePrc(Prc prc, DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit)
  {
    int dureePrcCourante = 0;
    
    dureePrcCourante = donneesEntreeProduit.getParametrePlafondDiviseurPrc().intValue();
    int dureeReellePrc = prc.getDuree();
    if (dureeReellePrc < dureePrcCourante) {
      dureePrcCourante = dureeReellePrc;
    }
    prc.setDureePrc(Integer.valueOf(dureePrcCourante));
  }
  
  protected BigDecimal plafonnerDiviseurPrc(Prc prc, DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit)
  {
    BigDecimal dureePrc = new BigDecimal(String.valueOf(prc.getDureePrc()));
    BigDecimal parametrePlafondDiviseurPrc = donneesEntreeProduit.getParametrePlafondDiviseurPrc();
    return dureePrc.min(parametrePlafondDiviseurPrc);
  }
  
  public BigDecimal calculerNombreJourAbsence(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
    throws CoucheLogiqueException
  {
    BigDecimal cumulJoursAbsenceRetourne = BigDecimal.ZERO;
    BigDecimal nbJoursAbsencePeriodeSalaireCourante = BigDecimal.ZERO;
    Periode periodeCourante = null;
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Salaire periodeSalaireCourante = null;
    Chronologie chronoPeriodesSalaireAvecAbsence = null;
    Periode periodeIntersectionPrcCourante = null;
    int nbJoursDeductiblesSurSalaireCourant = 0;
    int nbJoursAbsenceArrondi = 0;
    int nbJoursAbsenceDeductible = 0;
    ChronologiePeriodes chronoPeriodesComplementaires = null;
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = donneesEntree.getDonneesEntreeComplementaires();
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = donneesEntree.getDonneesEntreeDemande();
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    Prc resultatPrc = donneesResultat.getPrc();
    Periode periodeReference = new Periode(resultatPrc.getDateDebut(), resultatPrc.getDateFin());
    
    boolean absenceDeductible = estAbsenceDeductible();
    
    Chronologie chronoActivites = determinerChronoActivitePourAbsence(donneesEntreeComplementaires);
    
    ChronologiePeriodes chronoPeriodeSalaireSansAbsenceChevauchantPrc = new ChronologiePeriodes();
    ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsence = null;
    if (chronoActivites.contientChevauchementElements())
    {
      chronoPeriodeSalaireSansAbsenceChevauchantPrc = determinerChronoPeriodesSalaireSansAbsenceChevauchantPrc(donneesEntree, donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), chronoActivites);
      
      chronoChevauchementsPeriodeSalaireAvecAbsence = determinerChronoChevauchementsPeriodeSalaireAvecAbsence(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), chronoActivites);
    }
    boolean presenceChevauchementPeriodeSalaireAvecAbsence = (chronoChevauchementsPeriodeSalaireAvecAbsence != null) && (chronoChevauchementsPeriodeSalaireAvecAbsence.getTaille() > 1);
    if (presenceChevauchementPeriodeSalaireAvecAbsence) {
      cumulJoursAbsenceRetourne = traiterChevauchementsPeriodeSalaireAvecAbsence(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), absenceDeductible, chronoChevauchementsPeriodeSalaireAvecAbsence, chronoPeriodeSalaireSansAbsenceChevauchantPrc, donneesEntreeComplementaires.getChronologieActiviteSalariePrc(), donneesEntreeComplementaires.getChronologiePeriodeDeductiblePrc(), outilJustificationSjr, resultatJustificationDiviseur);
    }
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(donnerFiltrePeriodeSalaireAvecAbsence());
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      if (periodeActiviteSalarieCourante.getContrat().estSuspensionDecoupee())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), periodeActiviteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide())) {
          chronoPeriodesSalaireAvecAbsence = (Chronologie)chronoPeriodesSuspension.copie();
        }
      }
      else
      {
        chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(donneesEntreeDemande.getIndividu(), periodeActiviteSalarieCourante, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen());
        
        chronoPeriodesSalaireAvecAbsence = chronoPeriodesSalairePnds.copier(listeFiltres);
        
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), periodeActiviteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide())) {
          chronoPeriodesSalaireAvecAbsence.ajouter(chronoPeriodesNonRemunereesApresDjtp);
        }
      }
      if ((chronoPeriodesSalaireAvecAbsence != null) && (chronoPeriodesSalaireAvecAbsence.getTaille() > 0))
      {
        chronoPeriodesSalaireAvecAbsence.iterer();
        while (chronoPeriodesSalaireAvecAbsence.encoreSuivant())
        {
          periodeSalaireCourante = (Salaire)chronoPeriodesSalaireAvecAbsence.elementSuivant();
          periodeCourante = new Periode(periodeSalaireCourante.getDateDebut(), periodeSalaireCourante.getDateFin());
          if ((!presenceChevauchementPeriodeSalaireAvecAbsence) || (!contientPeriodeSalaire(chronoChevauchementsPeriodeSalaireAvecAbsence, periodeSalaireCourante)))
          {
            periodeIntersectionPrcCourante = periodeCourante.periodeIntersection(periodeReference);
            chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodeSalaireSansAbsenceChevauchantPrc, periodeIntersectionPrcCourante);
            if ((chronoPeriodesComplementaires != null) && (!chronoPeriodesComplementaires.estVide()))
            {
              nbJoursAbsencePeriodeSalaireCourante = determinerAbsenceCumuleeHorsSalaireSansAbsence(periodeSalaireCourante, chronoPeriodesComplementaires);
              if (absenceDeductible)
              {
                nbJoursDeductiblesSurSalaireCourant = periodeIntersectionPrcCourante.inter((ChronologiePeriodes)donneesEntreeComplementaires.getChronologiePeriodeDeductiblePrc());
                
                nbJoursAbsenceArrondi = Mathematiques.arrondiASup(nbJoursAbsencePeriodeSalaireCourante, 0).intValue();
                if (nbJoursAbsenceArrondi > nbJoursDeductiblesSurSalaireCourant)
                {
                  nbJoursAbsenceDeductible = nbJoursAbsenceArrondi - nbJoursDeductiblesSurSalaireCourant;
                  
                  cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(new BigDecimal(nbJoursAbsenceDeductible));
                  if (outilJustificationSjr != null) {
                    outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursDeductibles(resultatJustificationDiviseur, periodeCourante, periodeActiviteSalarieCourante, nbJoursAbsenceDeductible);
                  }
                }
              }
              else
              {
                cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(nbJoursAbsencePeriodeSalaireCourante);
                if (outilJustificationSjr != null) {
                  outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursAbsence(resultatJustificationDiviseur, periodeCourante, periodeActiviteSalarieCourante, nbJoursAbsencePeriodeSalaireCourante);
                }
              }
            }
          }
        }
      }
    }
    if (!absenceDeductible) {
      resultatPrc.setNombreJourAbsence(cumulJoursAbsenceRetourne);
    }
    return cumulJoursAbsenceRetourne;
  }
  
  protected abstract Chronologie determinerChronoActivitePourAbsence(DonneesEntreeComplementairesDeterminationSjrSpec paramDonneesEntreeComplementairesDeterminationSjrSpec);
  
  protected abstract boolean estAbsenceDeductible();
  
  protected ChronologiePeriodes determinerChronoPeriodesSalaireSansAbsenceChevauchantPrc(DonneesEntreeDeterminationSjrSpec donneesEntree, IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, Chronologie chronoActivites)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodeSalaireSansAbsenceChevauchantPrc = new ChronologiePeriodes();
    
    FiltresTemporel listeFiltresSalaireSansAbsenceChevauchantPrc = new FiltresTemporel();
    listeFiltresSalaireSansAbsenceChevauchantPrc.ajouterFiltre(donnerFiltrePeriodeSalaireSansAbsence());
    listeFiltresSalaireSansAbsenceChevauchantPrc.ajouterFiltre(ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(donneesEntree.getDonneesEntreeDemande().getListeContexteDemande(), periodePrc, true));
    
    listeFiltresSalaireSansAbsenceChevauchantPrc.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieSuspensionDecoupee()));
    
    chronoActivites.iterer();
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Chronologie chronoPeriodesSalairePnds = null;
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      
      chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(individu, periodeActiviteSalarieCourante, dateFaitGenerateur, dateExamen);
      
      chronoPeriodeSalaireSansAbsenceChevauchantPrc.ajouter(chronoPeriodesSalairePnds.copier(listeFiltresSalaireSansAbsenceChevauchantPrc));
    }
    return chronoPeriodeSalaireSansAbsenceChevauchantPrc;
  }
  
  protected Chronologie determinerChronoPeriodesSalairePnds(IndividuSpec individu, ActiviteSalarie pas, Damj dateFaitGenerateur, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesNonRemunereesRetournee = null;
    chronoPeriodesNonRemunereesRetournee = OutilSjrPnds.determinerChronoPeriodesSalaire(individu, pas, dateFaitGenerateur, dateExamen);
    
    return chronoPeriodesNonRemunereesRetournee;
  }
  
  protected ChronologiePeriodes determinerChronoChevauchementsPeriodeSalaireAvecAbsence(IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, Chronologie chronoActivites)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne = new ChronologiePeriodes();
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresExclusifs.ajouterFiltre(donnerFiltrePeriodeSalaireAvecAbsence());
    listeFiltresExclusifs.ajouterFiltre(new FiltreActiviteSalarieSuspensionDecoupee());
    
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(listeFiltresExclusifs);
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodePrc));
    ChronologiePeriodes chronoGlobalePeriodeSalaireAvecAbsence = new ChronologiePeriodes();
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      if (periodeActiviteSalarieCourante.getContrat().estSuspensionDecoupee())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(individu, periodePrc, dateFaitGenerateur, dateExamen, periodeActiviteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide())) {
          chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesSuspension);
        }
      }
      else
      {
        chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(individu, periodeActiviteSalarieCourante, dateFaitGenerateur, dateExamen);
        
        chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesSalairePnds.copier(listeFiltres));
        
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(individu, periodePrc, dateFaitGenerateur, dateExamen, periodeActiviteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide())) {
          chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesNonRemunereesApresDjtp);
        }
      }
    }
    if ((chronoGlobalePeriodeSalaireAvecAbsence != null) && (chronoGlobalePeriodeSalaireAvecAbsence.contientChevauchementElements()))
    {
      ObjetChronoPeriode objetChronoPeriodeFusionneeCourante = null;
      Periode periodeFusionneeCourante = null;
      Chronologie chronoPeriodesChevauchantPeriodeCourante = null;
      
      ChronologiePeriodes chronoPeriodesFusionnees = chronoGlobalePeriodeSalaireAvecAbsence.fusionnerChevauchementPeriodes();
      
      chronoPeriodesFusionnees.iterer();
      while (chronoPeriodesFusionnees.encoreSuivant())
      {
        objetChronoPeriodeFusionneeCourante = (ObjetChronoPeriode)chronoPeriodesFusionnees.elementSuivant();
        periodeFusionneeCourante = new Periode(objetChronoPeriodeFusionneeCourante.getDateDebut(), objetChronoPeriodeFusionneeCourante.getDateFin());
        
        chronoPeriodesChevauchantPeriodeCourante = chronoGlobalePeriodeSalaireAvecAbsence.copier(new FiltreChevauchePeriode(periodeFusionneeCourante));
        if ((chronoPeriodesChevauchantPeriodeCourante != null) && (chronoPeriodesChevauchantPeriodeCourante.getTaille() > 1)) {
          chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne.ajouter(chronoPeriodesChevauchantPeriodeCourante);
        }
      }
    }
    return chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne;
  }
  
  protected ChronologiePeriodes determinerChronoPeriodesSuspension(IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, ActiviteSalarie periodeActiviteSalarie)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodesNonRemunereesRetournee = new ChronologiePeriodes();
    if (periodeActiviteSalarie.getContrat().estSuspensionDecoupee())
    {
      Periode periodeSuspension = new Periode(periodeActiviteSalarie.getDateDebut(), periodeActiviteSalarie.getDateFin());
      if (periodeSuspension.chevauche(periodePrc))
      {
        Chronologie chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(individu, periodeActiviteSalarie, dateFaitGenerateur, dateExamen);
        
        ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoPeriodesSalairePnds, periodeSuspension.periodeIntersection(periodePrc));
        if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
        {
          chronoPeriodesComplementaires.iterer();
          ObjetChronoPeriode periodeComplementaireCourante = null;
          Salaire periodeSalaireExclueCourante = null;
          while (chronoPeriodesComplementaires.encoreSuivant())
          {
            periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
            
            periodeSalaireExclueCourante = new Salaire(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
            
            periodeSalaireExclueCourante.setMontantSoumisAContribution(new QuantiteEuro("0"));
            periodeSalaireExclueCourante.setExclus(true);
            
            chronoPeriodesNonRemunereesRetournee.ajouter(periodeSalaireExclueCourante);
          }
        }
      }
    }
    return chronoPeriodesNonRemunereesRetournee;
  }
  
  protected ChronologiePeriodes determinerChronoPeriodesNonRemunereesApresDjtp(IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, ActiviteSalarie periodeActiviteSalarie)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodesNonRemunereesRetournee = new ChronologiePeriodes();
    
    Damj dernierJourTravaillePaye = periodeActiviteSalarie.getDernierJourTravaillePaye();
    if (dernierJourTravaillePaye != null) {
      if (dernierJourTravaillePaye.estAvant(periodeActiviteSalarie.getDateFin()))
      {
        Damj dateDebutPeriodeApresDjtp = dernierJourTravaillePaye.lendemain();
        Damj dateDebutActiviteSalarie = periodeActiviteSalarie.getDateDebut();
        if (dernierJourTravaillePaye.estAvant(dateDebutActiviteSalarie)) {
          dateDebutPeriodeApresDjtp = dateDebutActiviteSalarie;
        }
        Periode periodeApresDjtp = new Periode(dateDebutPeriodeApresDjtp, periodeActiviteSalarie.getDateFin());
        if (periodeApresDjtp.chevauche(periodePrc))
        {
          Chronologie chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(individu, periodeActiviteSalarie, dateFaitGenerateur, dateExamen);
          
          ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoPeriodesSalairePnds, periodeApresDjtp.periodeIntersection(periodePrc));
          if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
          {
            chronoPeriodesComplementaires.iterer();
            ObjetChronoPeriode periodeComplementaireCourante = null;
            Salaire periodeSalaireExclueCourante = null;
            while (chronoPeriodesComplementaires.encoreSuivant())
            {
              periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
              
              periodeSalaireExclueCourante = new Salaire(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
              
              periodeSalaireExclueCourante.setMontantSoumisAContribution(new QuantiteEuro("0"));
              periodeSalaireExclueCourante.setExclus(true);
              
              chronoPeriodesNonRemunereesRetournee.ajouter(periodeSalaireExclueCourante);
            }
          }
        }
      }
    }
    return chronoPeriodesNonRemunereesRetournee;
  }
  
  protected BigDecimal traiterChevauchementsPeriodeSalaireAvecAbsence(IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, boolean absenceDeductible, ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsence, ChronologiePeriodes chronoPeriodeSalaireSansAbsence, Chronologie chronoActiviteSalariePrcGlobale, Chronologie chronoPeriodesDeductibles, OutilJustificationSjrSpec outilJustificationSjr, JustificationDiviseur resultatJustificationDiviseur)
    throws CoucheLogiqueException
  {
    BigDecimal cumulJoursAbsence = BigDecimal.ZERO;
    
    ObjetChronoPeriode objetChronoPeriodeFusionneeCourante = null;
    Periode periodeFusionneeCourante = null;
    ChronologiePeriodes chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante = null;
    ChronologiePeriodes chronoActiviteSalarieAbsenceMinimalePourJustification = null;
    List listePeriodesUnitaires = null;
    Periode periodeUnitaireCourante = null;
    BigDecimal nbreJoursAbsencePlusPetit = BigDecimal.ZERO;
    Periode periodeIntersectionPrcCourante = null;
    int nbJoursDeductiblesSurSalaireCourant = 0;
    int nbJoursAbsenceArrondi = 0;
    int nbJoursAbsenceDeductible = 0;
    
    ChronologiePeriodes chronoPeriodesFusionnees = chronoChevauchementsPeriodeSalaireAvecAbsence.fusionnerChevauchementPeriodes();
    
    chronoPeriodesFusionnees.iterer();
    Iterator iter;
    while (chronoPeriodesFusionnees.encoreSuivant())
    {
      objetChronoPeriodeFusionneeCourante = (ObjetChronoPeriode)chronoPeriodesFusionnees.elementSuivant();
      periodeFusionneeCourante = new Periode(objetChronoPeriodeFusionneeCourante.getDateDebut(), objetChronoPeriodeFusionneeCourante.getDateFin());
      
      chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante = (ChronologiePeriodes)chronoChevauchementsPeriodeSalaireAvecAbsence.copier(new FiltreChevauchePeriode(periodeFusionneeCourante));
      
      listePeriodesUnitaires = OutillageChronologiePeriodes.decouper(periodeFusionneeCourante.periodeIntersection(periodePrc), chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante);
      for (iter = listePeriodesUnitaires.iterator(); iter.hasNext();)
      {
        periodeUnitaireCourante = (Periode)iter.next();
        
        nbreJoursAbsencePlusPetit = determinerAbsenceMinimale(periodeUnitaireCourante, chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante, chronoPeriodeSalaireSansAbsence);
        if (nbreJoursAbsencePlusPetit.compareTo(BigDecimal.ZERO) > 0)
        {
          chronoActiviteSalarieAbsenceMinimalePourJustification = reconstruireChronoActiviteSalarieAbsenceMinimale(individu, periodePrc, dateFaitGenerateur, dateExamen, periodeUnitaireCourante, chronoActiviteSalariePrcGlobale);
          if (absenceDeductible)
          {
            periodeIntersectionPrcCourante = periodeUnitaireCourante.periodeIntersection(periodePrc);
            nbJoursDeductiblesSurSalaireCourant = periodeIntersectionPrcCourante.inter((ChronologiePeriodes)chronoPeriodesDeductibles);
            
            nbJoursAbsenceArrondi = Mathematiques.arrondiASup(nbreJoursAbsencePlusPetit, 0).intValue();
            if (nbJoursAbsenceArrondi > nbJoursDeductiblesSurSalaireCourant)
            {
              nbJoursAbsenceDeductible = nbJoursAbsenceArrondi - nbJoursDeductiblesSurSalaireCourant;
              
              cumulJoursAbsence = cumulJoursAbsence.add(new BigDecimal(nbJoursAbsenceDeductible));
              if (outilJustificationSjr != null) {
                outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursDeductiblesNatureMultiple(resultatJustificationDiviseur, periodeUnitaireCourante, chronoActiviteSalarieAbsenceMinimalePourJustification, nbJoursAbsenceDeductible);
              }
            }
          }
          else
          {
            cumulJoursAbsence = cumulJoursAbsence.add(nbreJoursAbsencePlusPetit);
            if (outilJustificationSjr != null) {
              outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursAbsenceNatureMultiple(resultatJustificationDiviseur, periodeUnitaireCourante, chronoActiviteSalarieAbsenceMinimalePourJustification, nbreJoursAbsencePlusPetit);
            }
          }
        }
      }
    }
    return cumulJoursAbsence;
  }
  
  private BigDecimal determinerAbsenceMinimale(Periode periodeUnitaire, Chronologie chronoPeriodeSalaireAvecAbsence, ChronologiePeriodes chronoPeriodeSalaireSansAbsence)
  {
    BigDecimal nbreJoursAbsencePlusPetit = null;
    
    ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodeSalaireSansAbsence, periodeUnitaire);
    if ((chronoPeriodesComplementaires == null) || (chronoPeriodesComplementaires.estVide()))
    {
      nbreJoursAbsencePlusPetit = BigDecimal.ZERO;
    }
    else
    {
      Salaire periodeSalaireAvecAbsenceCourante = null;
      chronoPeriodeSalaireAvecAbsence.iterer();
      while (chronoPeriodeSalaireAvecAbsence.encoreSuivant())
      {
        periodeSalaireAvecAbsenceCourante = (Salaire)chronoPeriodeSalaireAvecAbsence.elementSuivant();
        if (periodeSalaireAvecAbsenceCourante.chevauche(periodeUnitaire))
        {
          BigDecimal cumulJoursAbsenceProratiseSurPeriodeUnitaire = determinerAbsenceCumuleeHorsSalaireSansAbsence(periodeSalaireAvecAbsenceCourante, chronoPeriodesComplementaires);
          if ((nbreJoursAbsencePlusPetit == null) || (cumulJoursAbsenceProratiseSurPeriodeUnitaire.compareTo(nbreJoursAbsencePlusPetit) < 0)) {
            nbreJoursAbsencePlusPetit = cumulJoursAbsenceProratiseSurPeriodeUnitaire;
          }
        }
      }
    }
    return nbreJoursAbsencePlusPetit;
  }
  
  protected BigDecimal determinerAbsenceCumuleeHorsSalaireSansAbsence(Salaire periodeSalaireAvecAbsence, ChronologiePeriodes chronoPeriodesHorsSalaireSansAbsence)
  {
    BigDecimal cumulJoursAbsenceRetourne = BigDecimal.ZERO;
    ObjetChronoPeriode periodeComplementaireCourante = null;
    Periode periodeCouranteHorsPeriodesSalairesSansAbsence = null;
    BigDecimal nbreJoursAbsenceProratisesCourant = BigDecimal.ZERO;
    
    chronoPeriodesHorsSalaireSansAbsence.iterer();
    while (chronoPeriodesHorsSalaireSansAbsence.encoreSuivant())
    {
      periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesHorsSalaireSansAbsence.elementSuivant();
      periodeCouranteHorsPeriodesSalairesSansAbsence = new Periode(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
      
      nbreJoursAbsenceProratisesCourant = Mathematiques.arrondiASup(periodeSalaireAvecAbsence.determinerNombreJoursAbsence(periodeCouranteHorsPeriodesSalairesSansAbsence), 2);
      
      cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(nbreJoursAbsenceProratisesCourant);
    }
    return cumulJoursAbsenceRetourne;
  }
  
  private ChronologiePeriodes reconstruireChronoActiviteSalarieAbsenceMinimale(IndividuSpec individu, Periode periodePrc, Damj dateFaitGenerateur, Damj dateExamen, Periode periodeRechercheAbsenceMinimale, Chronologie chronoActiviteSalariePrcGlobale)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoActiviteSalarieRetournee = new ChronologiePeriodes();
    
    FiltresTemporel listeFiltresSalaires = new FiltresTemporel();
    listeFiltresSalaires.ajouterFiltre(donnerFiltrePeriodeSalaireAvecAbsence());
    listeFiltresSalaires.ajouterFiltre(new FiltreChevauchePeriode(periodeRechercheAbsenceMinimale));
    
    ActiviteSalarie activiteSalarieCourante = null;
    Chronologie chronoSalairesRetenus = null;
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    chronoActiviteSalariePrcGlobale.iterer();
    while (chronoActiviteSalariePrcGlobale.encoreSuivant())
    {
      activiteSalarieCourante = (ActiviteSalarie)chronoActiviteSalariePrcGlobale.elementSuivant();
      
      chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(individu, activiteSalarieCourante, dateFaitGenerateur, dateExamen);
      
      chronoSalairesRetenus = chronoPeriodesSalairePnds.copier(listeFiltresSalaires);
      if (!chronoSalairesRetenus.estVide())
      {
        chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
      }
      else if (activiteSalarieCourante.getContrat().estSuspensionChomageSansRCT())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(individu, periodePrc, dateFaitGenerateur, dateExamen, activiteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide()) && (periodeRechercheAbsenceMinimale.inter(chronoPeriodesSuspension) > 0)) {
          chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
        }
      }
      else
      {
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(individu, periodePrc, dateFaitGenerateur, dateExamen, activiteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide()) && (periodeRechercheAbsenceMinimale.inter(chronoPeriodesNonRemunereesApresDjtp) > 0)) {
          chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
        }
      }
    }
    return chronoActiviteSalarieRetournee;
  }
  
  protected boolean contientPeriodeSalaire(Chronologie chrono, Salaire periodeSalaire)
  {
    Iterator iter = chrono.iterer();
    boolean trouve = false;
    while (iter.hasNext()) {
      if (((Salaire)iter.next()).estIdentiqueA(periodeSalaire)) {
        trouve = true;
      }
    }
    return trouve;
  }
  
  protected void genererAlerteBloquanteDiviseurNegatif(int casDiviseurNegatif, String formuleDiviseur, boolean estCalculSjr, Prc prc, BigDecimal dureePrcPlafonnee, String nomReglementApplicable, Damj dateFGD)
    throws CoucheLogiqueException
  {
    BigDecimal diviseurCasGeneral = prc.getNombreJourTravailEffectif();
    
    StringBuffer message = new StringBuffer();
    message.append("Diviseur pour ").append(estCalculSjr ? "SJR " : "SJC ");
    message.append(nomReglementApplicable);
    message.append(" sur PRC (").append(prc.getDateDebut()).append("-").append(prc.getDateFin()).append(") :");
    switch (casDiviseurNegatif)
    {
    case 1: 
      message.append(" ").append(formuleDiviseur).append(" -> ");
      message.append(dureePrcPlafonnee).append(" - ");
      message.append("(").append(prc.getNombreJourInappartenance()).append(" + ").append(prc.getNombreJourAbsence());
      message.append(") = ").append(prc.getDiviseur());
      break;
    case 2: 
      message.append(" ").append(formuleDiviseur).append(" -> Max [ ");
      message.append(dureePrcPlafonnee).append(" - ").append(prc.getNombreJourDeductible());
      message.append("; ").append(diviseurCasGeneral).append(" ] = ").append(prc.getDiviseur());
      break;
    case 3: 
      message.append(" ").append(formuleDiviseur).append(" -> Max [ ");
      message.append(dureePrcPlafonnee).append(" - ").append("(").append(prc.getNombreJourDeductible());
      message.append(" + ").append(prc.getDroitCongesA4ouA5()).append("); ").append(prc.getNombreHeuresTotal());
      message.append(" / 10; ").append(diviseurCasGeneral).append(" ] = ").append(prc.getDiviseur());
      break;
    case 4: 
      message.append(" ").append(formuleDiviseur).append(" -> Max [ ");
      message.append(dureePrcPlafonnee).append(" - ").append("(").append(prc.getNombreJourDeductible());
      message.append(" + ").append(prc.getDroitCongesA4ouA5()).append("); ");
      message.append(diviseurCasGeneral).append(" ] = ").append(prc.getDiviseur());
    }
    if (dateFGD != null) {
      message.append(", pour le FGD du " + dateFGD.toString());
    }
    throw new CoucheLogiqueException("ASU_PR_CALI_L_ERR_DIVISEUR_INF_OU_EGAL_A_ZERO", message.toString());
  }
  
  protected FiltreTemporel donnerFiltrePeriodeSalaireAvecAbsence()
  {
    return new FiltrePeriodeSalaireAvecAbsence();
  }
  
  protected FiltreTemporel donnerFiltrePeriodeSalaireSansAbsence()
  {
    return new FiltrePeriodeSalaireSansAbsence();
  }
}

/* Location:
 * Qualified Name:     StrategieDeterminationDiviseurSjrAbstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */