package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationDiviseurSjrCasGeneralSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class StrategieDeterminationDiviseurSjrCasGeneral
  extends StrategieDeterminationDiviseurSjrAbstrait
  implements StrategieDeterminationDiviseurSjrCasGeneralSpec
{
  private static final String FORMULE_CALCUL_DIVISEUR = "N - (ni + na)";
  
  public void determinerDiviseurCasGeneral(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
    throws CoucheLogiqueException
  {
    BigDecimal resultatDiviseurCasGeneral = null;
    
    Prc resultatPrc = p_donneesResultat.getPrc();
    BigDecimal resultatDureePrc = null;
    
    determinerDureePrc(resultatPrc, p_donneesEntree.getDonneesEntreeProduit());
    resultatDureePrc = new BigDecimal(resultatPrc.getDureePrc().intValue());
    
    calculerNombreJourInappartenance(p_donneesEntree, p_donneesResultat);
    Integer resultatNombreJourInappartenance = resultatPrc.getNombreJourInappartenance();
    
    calculerNombreJourAbsence(p_donneesEntree, p_donneesResultat);
    BigDecimal resultatNombreJourAbsence = resultatPrc.getNombreJourAbsence();
    
    BigDecimal jourInappartenancePlusJourAbsence = new BigDecimal(String.valueOf(resultatNombreJourInappartenance)).add(resultatNombreJourAbsence);
    
    resultatDiviseurCasGeneral = resultatDureePrc.subtract(jourInappartenancePlusJourAbsence);
    
    resultatPrc.setNombreJourTravailEffectif(resultatDiviseurCasGeneral);
  }
  
  private void calculerNombreJourInappartenance(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
  {
    Prc resultatPrc = p_donneesResultat.getPrc();
    Periode periodeReferenceCourante = new Periode(resultatPrc.getDateDebut(), resultatPrc.getDateFin());
    
    ChronologiePeriodes chronoPeriodesInappartenance = determinerChronoPeriodesInappartenance(p_donneesEntree.getDonneesEntreeComplementaires(), periodeReferenceCourante);
    if ((chronoPeriodesInappartenance != null) && (chronoPeriodesInappartenance.getTaille() > 0))
    {
      resultatPrc.setNombreJourInappartenance(Integer.valueOf(resultatPrc.inter(chronoPeriodesInappartenance)));
      
      OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(p_donneesEntree.getDonneesEntreeComportement());
      if (outilJustificationSjr != null)
      {
        JustificationDiviseur resultatJustificationDiviseur = p_donneesResultat.getJustificationSjr().getJustificationDiviseur();
        
        ObjetChronoPeriode objetChronoPeriodeInappartenanceCourant = null;
        Periode periodeInappartenanceCourante = null;
        ChronologiePeriodes chronoPeriodesChevauchantInappartenance = null;
        chronoPeriodesInappartenance.iterer();
        while (chronoPeriodesInappartenance.encoreSuivant())
        {
          objetChronoPeriodeInappartenanceCourant = (ObjetChronoPeriode)chronoPeriodesInappartenance.elementSuivant();
          periodeInappartenanceCourante = new Periode(objetChronoPeriodeInappartenanceCourant.getDateDebut(), objetChronoPeriodeInappartenanceCourant.getDateFin());
          
          chronoPeriodesChevauchantInappartenance = (ChronologiePeriodes)p_donneesEntree.getDonneesEntreeDemande().getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreChevauchePeriode(periodeInappartenanceCourante));
          
          outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursInappartenance(resultatJustificationDiviseur, periodeInappartenanceCourante, chronoPeriodesChevauchantInappartenance);
        }
      }
    }
  }
  
  private ChronologiePeriodes determinerChronoPeriodesInappartenance(DonneesEntreeComplementairesDeterminationSjrSpec p_donneesEntreeComplementaires, Periode p_periodePrc)
  {
    ChronologiePeriodes chronoPeriodeInappartenance = null;
    
    ChronologiePeriodes chronoPeriodesActivitesSpecifiqueInappartenance = (ChronologiePeriodes)p_donneesEntreeComplementaires.getChronologieActivitePourInappartenancePrc();
    
    ChronologiePeriodes chronoPeriodesActivitesFusionnees = null;
    if ((chronoPeriodesActivitesSpecifiqueInappartenance != null) && (chronoPeriodesActivitesSpecifiqueInappartenance.contientChevauchementElements())) {
      chronoPeriodesActivitesFusionnees = chronoPeriodesActivitesSpecifiqueInappartenance.fusionnerChevauchementPeriodes();
    } else {
      chronoPeriodesActivitesFusionnees = chronoPeriodesActivitesSpecifiqueInappartenance;
    }
    chronoPeriodeInappartenance = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodesActivitesFusionnees, p_periodePrc);
    return chronoPeriodeInappartenance;
  }
  
  protected boolean estAbsenceDeductible()
  {
    return false;
  }
  
  protected Chronologie determinerChronoActivitePourAbsence(DonneesEntreeComplementairesDeterminationSjrSpec p_donneesEntreeComplementaires)
  {
    return p_donneesEntreeComplementaires.getChronologieActiviteSalariePrc();
  }
  
  public void determinerDiviseur(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
    throws CoucheLogiqueException
  {
    BigDecimal resultatDiviseur = null;
    
    Prc resultatPrc = p_donneesResultat.getPrc();
    resultatDiviseur = resultatPrc.getNombreJourTravailEffectif();
    if (resultatDiviseur.signum() < 1)
    {
      boolean estTraitementDeterminationSjr = p_donneesEntree.getDonneesEntreeComportement().getTypeTraitementAppelant() == 1;
      
      BigDecimal resultatDureePrc = null;
      
      resultatDureePrc = new BigDecimal(resultatPrc.getDureePrc().intValue());
      
      String libelleReglementApplicable = p_donneesEntree.getDonneesEntreeDemande().getReglementApplicable().getLibelleCourt();
      
      Damj dateFGD = p_donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitCourant();
      
      genererAlerteBloquanteDiviseurNegatif(1, "N - (ni + na)", estTraitementDeterminationSjr, resultatPrc, resultatDureePrc, libelleReglementApplicable, dateFGD);
    }
    resultatPrc.setDiviseur(resultatDiviseur);
  }
}

/* Location:
 * Qualified Name:     StrategieDeterminationDiviseurSjrCasGeneral
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */