package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDelaiReport;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteSalarie;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public abstract class ConstitutionDelaisReportsAbstrait
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution des délais reports.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courant est null: constitution des délais reports impossible.");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDelais constitutionDelais = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDelais();
    
    ResultatDeterminationDelaisReports resultatCepa08 = determinerCollectionDelaisReports(contexte);
    if (resultatCepa08 != null) {
      mapperResultatDelaisReportVersCep(constitutionDelais, resultatCepa08);
    } else {
      resultatCepa08 = new ResultatDeterminationDelaisReports();
    }
    appelCalcul(demande, dossierExamenCourant, constitutionDelais);
    
    OutilTrace.tracerFinParcours();
    
    return resultatCepa08;
  }
  
  private void mapperResultatDelaisReportVersCep(ConstitutionDelais cep, ResultatDeterminationDelaisReports resultat)
  {
    Collection<?> collectionDelaisReports = resultat.getListeDelaisReports();
    cep.setDateDebutDernierDelaiAttente(resultat.getDateDebutDernierDelaiAttente());
    Iterator<?> i;
    if (collectionDelaisReports != null) {
      for (i = collectionDelaisReports.iterator(); i.hasNext();)
      {
        CarencePrefixeAFixer delaiReportCourant = (CarencePrefixeAFixer)i.next();
        alimenterCEPCollectionDelaisReports(cep, delaiReportCourant);
      }
    }
  }
  
  protected void appelCalcul(Demande demande, DossierExamen dossierExamenCourant, ConstitutionDelais constitutionDelais)
    throws ApplicativeException
  {
    alimenterTrancheExecutable(dossierExamenCourant);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Appel de l’avant calcul sans prise en compte des évènements GAEC." });
    ResultatExecutionCalculSpec resultatAvantCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamenCourant, null, false);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Alimentation de la CEP avec le résultat de l’avant calcul." });
    alimenterCEPResultatAvantCalcul(constitutionDelais, demande, resultatAvantCalcul);
  }
  
  protected abstract ResultatDeterminationDelaisReports determinerCollectionDelaisReports(Contexte paramContexte)
    throws ApplicativeException;
  
  private void alimenterCEPCollectionDelaisReports(ConstitutionDelais cepDelaisReports, CarencePrefixeAFixer delaiReport)
  {
    if (delaiReport != null)
    {
      cepDelaisReports.ajouterCarences(delaiReport);
      if (OutilDelaiReport.estDelaiReportDeType(delaiReport, "ISLR"))
      {
        boolean autresIndemnitesLegales = ((CarenceIslr)delaiReport).estAutresIndemnitesLegales();
        if (autresIndemnitesLegales) {
          cepDelaisReports.setAutresIndemnitesLegales(true);
        }
        boolean presenceTransaction = ((CarenceIslr)delaiReport).estPresenceTransaction();
        if (presenceTransaction)
        {
          cepDelaisReports.setPresenceTransaction(true);
          
          ActiviteSalarie activiteSalariePresenceTransaction = (ActiviteSalarie)((CarenceIslr)delaiReport).getOrigine();
          cepDelaisReports.setActivitePresenceAutreTransaction(activiteSalariePresenceTransaction);
        }
      }
    }
  }
  
  private void alimenterCEPResultatAvantCalcul(ConstitutionDelais constitutionDelais, Demande demande, ResultatExecutionCalculSpec resultatAvantCalcul)
  {
    boolean activiteAvecPresenceAutreTransactionRetenuDansAvant = alimenterCarencesSurCEP(constitutionDelais, demande, resultatAvantCalcul);
    if (resultatAvantCalcul != null) {
      constitutionDelais.setPjiTheorique(resultatAvantCalcul.getPji());
    }
    if (constitutionDelais.getDebutPMC() == null)
    {
      PreavisMesureConservatoireIndemnisable pmcI = rechercherPMCIndemnisableSeTerminantLePlusTard(constitutionDelais);
      if (pmcI != null)
      {
        constitutionDelais.setDebutPMC(pmcI.getPeriodeApplicationCarence().getDebut());
        constitutionDelais.setTermePMC(pmcI.getPeriodeApplicationCarence().getFin());
        constitutionDelais.setNbJoursPMC(pmcI.getQuantiteInitial().getValeurEntiere());
        constitutionDelais.setTypePmc(2);
      }
    }
    if ((constitutionDelais.isPresenceTransaction()) && (activiteAvecPresenceAutreTransactionRetenuDansAvant)) {
      leverAlerteA11MNB4SurDiffereIslr(demande, constitutionDelais.getActivitePresenceAutreTransaction());
    }
  }
  
  protected boolean alimenterCarencesSurCEP(ConstitutionDelais constitutionDelais, Demande demande, ResultatExecutionCalculSpec resultatAvantCalcul)
  {
    boolean activiteAvecPresenceAutreTransactionRetenuDansAvant = false;
    if ((resultatAvantCalcul != null) && (resultatAvantCalcul.getListeCarencesEffectives() != null))
    {
      List<CarencePrefixeAFixer> listeCarences = resultatAvantCalcul.getListeCarencesEffectives();
      for (CarencePrefixeAFixer delaiReportCourant : listeCarences)
      {
        traiterCarencePourAlimenterSurCEP(constitutionDelais, delaiReportCourant, demande);
        if ((delaiReportCourant.getOrigine() != null) && (constitutionDelais.getActivitePresenceAutreTransaction() != null) && (delaiReportCourant.getOrigine().equals(constitutionDelais.getActivitePresenceAutreTransaction()))) {
          activiteAvecPresenceAutreTransactionRetenuDansAvant = true;
        }
      }
    }
    return activiteAvecPresenceAutreTransactionRetenuDansAvant;
  }
  
  protected void traiterCarencePourAlimenterSurCEP(ConstitutionDelais constitutionDelais, CarencePrefixeAFixer delaiReport, Demande demande)
  {
    if (OutilDelaiReport.estDelaiReportDeType(delaiReport, "ICCP")) {
      alimenterICCPSurCEP(constitutionDelais, delaiReport, demande);
    } else if (OutilDelaiReport.estDelaiReportDeType(delaiReport, "ISLR")) {
      alimenterISLRSurCEP(constitutionDelais, delaiReport);
    } else if (OutilDelaiReport.estDelaiReportDeType(delaiReport, "PMC_NI")) {
      alimenterPMCNonIndemnisableSurCEP(constitutionDelais, delaiReport);
    } else if (OutilDelaiReport.estDelaiReportDeType(delaiReport, "Différé")) {
      alimenterDelaiAttenteSurCEP(constitutionDelais, delaiReport);
    }
  }
  
  protected void alimenterICCPSurCEP(ConstitutionDelais constitutionDelais, CarencePrefixeAFixer delaiReport, Demande demande)
  {
    constitutionDelais.setDebutCarenceICCP(delaiReport.getPeriodeApplicationCarence().getDebut());
    constitutionDelais.setTermeCarenceICCP(delaiReport.getPeriodeApplicationCarence().getFin());
    constitutionDelais.setNbJoursCarenceICCP(delaiReport.getQuantiteInitial().getValeurEntiere());
    ActiviteSalarie activiteOrigine = null;
    if ((delaiReport.getOrigine() != null) && ((delaiReport.getOrigine() instanceof ActiviteSalarie)))
    {
      activiteOrigine = (ActiviteSalarie)delaiReport.getOrigine();
      constitutionDelais.setIdentifiantFCTRetenueICCP(OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(activiteOrigine.getIdentifiant(), 17));
      leverAlertePopUpPourICCPConservatoireBatiment(demande, activiteOrigine);
    }
    if ((activiteOrigine == null) || (activiteOrigine.getQuantiteEuroIccp() == null)) {
      constitutionDelais.setMontantICCPOrigine(new QuantiteEuro("0"));
    } else {
      constitutionDelais.setMontantICCPOrigine(activiteOrigine.getQuantiteEuroIccp());
    }
  }
  
  protected void leverAlertePopUpPourICCPConservatoireBatiment(Demande demande, ActiviteSalarie activiteSalarie)
  {
    if ((OutilActiviteSalarie.getInstance().estAeAvecCaisseProfessionnelDuBatiment(activiteSalarie)) && (activiteSalarie.getPeriodeActiviteSalarieGaec().isIccpConservatoireCalculee()))
    {
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(activiteSalarie.getDateFin(), activiteSalarie.getDateFin(), 999);
      
      Collection listePeriodes = new ArrayList();
      listePeriodes.add(objetAlerteNonBloquante);
      demande.getAlertesNonBloquantes().put("ICCP_CONSERVATOIRE_BATIMENT", listePeriodes);
    }
  }
  
  protected void alimenterISLRSurCEP(ConstitutionDelais constitutionDelais, CarencePrefixeAFixer delaiReport)
  {
    constitutionDelais.setDebutCarenceISLR(delaiReport.getPeriodeApplicationCarence().getDebut());
    constitutionDelais.setTermeCarenceISLR(delaiReport.getPeriodeApplicationCarence().getFin());
    constitutionDelais.setNbJoursCarenceISLR(delaiReport.getQuantiteInitial().getValeurEntiere());
  }
  
  protected void alimenterPMCNonIndemnisableSurCEP(ConstitutionDelais constitutionDelais, CarencePrefixeAFixer delaiReport)
  {
    constitutionDelais.setDebutPMC(delaiReport.getPeriodeApplicationCarence().getDebut());
    constitutionDelais.setTermePMC(delaiReport.getPeriodeApplicationCarence().getFin());
    constitutionDelais.setNbJoursPMC(delaiReport.getQuantiteInitial().getValeurEntiere());
    constitutionDelais.setTypePmc(1);
  }
  
  protected void alimenterDelaiAttenteSurCEP(ConstitutionDelais constitutionDelais, CarencePrefixeAFixer delaiReport)
  {
    constitutionDelais.setDebutCarenceDiffere(delaiReport.getPeriodeApplicationCarence().getDebut());
    constitutionDelais.setTermeCarenceDiffere(delaiReport.getPeriodeApplicationCarence().getFin());
    constitutionDelais.setNbJoursCarenceDiffere(delaiReport.getQuantiteInitial().getValeurEntiere());
  }
  
  private static PreavisMesureConservatoireIndemnisable rechercherPMCIndemnisableSeTerminantLePlusTard(ConstitutionDelais cepDelaisReport)
  {
    List<?> listePMCIndemnisable = OutilDelaiReport.trouverDelaisReports(cepDelaisReport.getListCarences(), "PMC_I");
    
    PreavisMesureConservatoireIndemnisable pmcMax = null;
    if (listePMCIndemnisable != null)
    {
      Iterator<?> itPMCIndemnisable = listePMCIndemnisable.iterator();
      while (itPMCIndemnisable.hasNext())
      {
        PreavisMesureConservatoireIndemnisable pmc = (PreavisMesureConservatoireIndemnisable)itPMCIndemnisable.next();
        if ((pmcMax == null) || (pmcMax.getPeriodeApplicationCarence().getFin().estAvant(pmc.getPeriodeApplicationCarence().getFin()))) {
          pmcMax = pmc;
        }
      }
    }
    return pmcMax;
  }
  
  private static void leverAlerteA11MNB4SurDiffereIslr(Demande demande, ActiviteSalarie periodeActiviteSalarieCourante)
  {
    String codeAlerteNonBloquante = "A11MNB4";
    if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      Collection listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      Collection listeActivitesSalariees = new ArrayList();
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
      demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
  
  private void alimenterTrancheExecutable(DossierExamen dossierExamen)
    throws ApplicativeException
  {
    if (((Attribution)dossierExamen).getProduit() != null)
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)((Attribution)dossierExamen).getProduit();
      if (produit.estTrancheActivee(dossierExamen.getDemande()))
      {
        Contexte contexte = new Contexte();
        DomLiquidationAssurance dom = new DomLiquidationAssurance();
        contexte.setDonnees(dom);
        dom.setDemande(dossierExamen.getDemande());
        produit.constituerTranchesExecutables(contexte);
      }
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelaisReportsAbstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */