package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationProduitResultant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationProduitResultantFinAsr;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.Readmission;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import java.math.BigDecimal;

public class ConstitutionProduitResultantClassiqueFinDroit
  extends ConstitutionProduitResultantClassique
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    m_determinationProduitResultant = DeterminationProduitResultantFinAsr.getInstanceFinAsr();
  }
  
  protected int recuperationDuree(DossierExamen p_dossierExamenCourant, Demande p_demandeCourante, boolean p_bornerRetraite)
    throws CoucheLogiqueException
  {
    Demande demandeAssocie = trouverDemandeAssociee(p_demandeCourante);
    DossierExamen dossierExamenAsrAssociee = (DossierExamen)demandeAssocie.getDossierExamen();
    
    Quantite dureeImputationDroitAServir = p_dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getDureeServieSurAsr();
    
    BigDecimal nbjImputationDroitAServir = p_demandeCourante.getDonneesTemporaires().getNbjImputationDroitAServir();
    if (nbjImputationDroitAServir != null) {
      dureeImputationDroitAServir = dureeImputationDroitAServir.ajouter(new Quantite(nbjImputationDroitAServir.setScale(0), dureeImputationDroitAServir.getUnite()));
    }
    int typeReadmission = m_determinationProduitResultant.determinerTypeReadmission(p_dossierExamenCourant.getConstitutionProduitResultant(), m_montantProduitResultant, m_capitalProduitResultant, m_montantPrecedentAvecCompetenceDuDroitAServir, m_montantCourantAvecCompetenceDuDroitAServir, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    
    m_capitalComparatifDroitPrecedent = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, dossierExamenAsrAssociee, demandeAssocie, false);
    switch (typeReadmission)
    {
    case 11: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, p_demandeCourante));
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      
      imputerDureeSurDroitAServir(m_dureeIntermediaireDroitPrecedent, dureeImputationDroitAServir, p_dossierExamenCourant);
      
      m_readmissionCourante.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
      
      break;
    case 26: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, p_demandeCourante));
      
      m_dureeProduitResultant = m_determinationProduitResultant.determinationDureeProduitResultant(m_readmissionCourante, m_montantProduitResultant, m_pointDepartUnique, m_capitalProduitResultant, p_bornerRetraite);
      
      imputerDureeSurDroitAServir(m_dureeProduitResultant, dureeImputationDroitAServir, p_dossierExamenCourant);
      
      m_readmissionCourante.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
      
      break;
    default: 
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
      m_dureeProduitResultant = m_dureeIntermediaireDroitCourant;
      
      imputerDureeSurDroitAServir(m_dureeIntermediaireDroitCourant, dureeImputationDroitAServir, p_dossierExamenCourant);
      m_capitalComparatifDroitCourant = m_capitalProduitResultant;
      m_dureeIntermediaireDroitCourant = m_dureeProduitResultant;
      
      p_dossierExamenCourant.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
    }
    return typeReadmission;
  }
  
  protected void imputerDureeSurDroitAServir(Quantite p_dureeImputee, Quantite p_dureeAImputer, DossierExamen p_dossierExamenCourant)
    throws CoucheLogiqueException
  {
    m_dureeProduitResultant = p_dureeImputee.soustraire(p_dureeAImputer);
    if (m_dureeProduitResultant.getValeurEntiere() < 0) {
      m_dureeProduitResultant = new Quantite(0, p_dureeImputee.getUnite());
    }
    JustificationDroitResultant justif = ((Attribution)((Demande)p_dossierExamenCourant.getDemande()).getDossierExamen()).getConstitutionProduitResultant().getJustificationDroitResultant();
    justif.setImputationDroitRetenu(new QuantiteJour(p_dureeAImputer.getValeur()));
    
    Attribution attributionCourante = (Attribution)p_dossierExamenCourant;
    
    Quantite capitalProduitEffectif = AppelCalculParLiquidationAsu.calculerCapital(attributionCourante, m_montantProduitResultant, attributionCourante.getDateAttribution(), m_dureeProduitResultant);
    
    m_capitalProduitResultant = new QuantiteEuro(capitalProduitEffectif.getValeur());
  }
  
  protected Demande trouverDemandeAssociee(Demande p_demandeCourante)
  {
    return (Demande)OutilFinDroit.rechercherDemandeODPrecedenteCorrespondante(p_demandeCourante);
  }
  
  protected void verifierDuree(Quantite p_dureeProduitResultant)
    throws CoucheLogiqueException
  {}
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultantClassiqueFinDroit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */