package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationProduitResultant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.DeterminationCompetenceProduitResultant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.OutilDeterminationCompetence;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilPensionInvalidite;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.Readmission;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public abstract class ParcoursConstitutionProduitResultant
  extends ParcoursLiquidation
{
  protected MontantAsuSpec m_montantPrecedent = null;
  protected MontantAsuSpec m_montantCourant = null;
  protected MontantAsuSpec m_montantPrecedentAvecCompetenceDuDroitAServir = null;
  protected MontantAsuSpec m_montantCourantAvecCompetenceDuDroitAServir = null;
  protected MontantAsuSpec m_montantProduitResultant = null;
  protected Quantite m_dureeProduitResultant = null;
  protected Quantite m_capitalComparatifDroitCourant = null;
  protected Quantite m_capitalProduitResultant = null;
  protected Quantite m_capitalComparatifDroitPrecedent = null;
  protected Quantite m_dureeIntermediaireDroitCourant = null;
  protected Quantite m_dureeIntermediaireDroitPrecedent = null;
  protected Damj m_pointDepartUnique = null;
  protected Readmission m_readmissionCourante = null;
  protected DeterminationProduitResultant m_determinationProduitResultant = null;
  
  public Resultat constitutionProduitResultant(Contexte contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    boolean bornerRetraite = bornerRetraite();
    
    recuperationCapitaux(demandeCourante, dossierExamenCourant, bornerRetraite);
    
    recuperationMontants(demandeCourante, dossierExamenCourant);
    
    int typeReadmission = recuperationDuree(dossierExamenCourant, demandeCourante, bornerRetraite);
    
    miseAJourCepa15(demandeCourante, dom, typeReadmission);
    alimenterJustificationProduitResultant(demandeCourante, typeReadmission);
    return new Resultat(0);
  }
  
  protected void recuperationCapitaux(Demande demandeCourante, DossierExamen dossierExamenCourant, boolean bornerRetraite)
    throws CoucheLogiqueException, ApplicativeException
  {
    m_montantPrecedent = m_determinationProduitResultant.obtenirMontantDroitPrecedent(dossierExamenCourant, demandeCourante);
    
    m_montantCourant = m_determinationProduitResultant.obtenirMontantDroitCourant(dossierExamenCourant);
    
    m_pointDepartUnique = m_determinationProduitResultant.determinerPointDepartUnique(demandeCourante, m_montantCourant, m_montantPrecedent);
    
    m_dureeIntermediaireDroitCourant = DeterminationDureeEffective.getInstance().determinerDureeEffectivePourComparaisonCapitaux(demandeCourante, m_pointDepartUnique, bornerRetraite);
    
    m_capitalComparatifDroitCourant = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitCourant, m_montantCourant, dossierExamenCourant, demandeCourante, true);
    
    m_dureeIntermediaireDroitPrecedent = m_determinationProduitResultant.determinerDureeDroitPrecedentPourCalculCapital(demandeCourante, m_pointDepartUnique, m_montantPrecedent, bornerRetraite);
    
    m_capitalComparatifDroitPrecedent = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, dossierExamenCourant, demandeCourante, false);
    
    verifierCapitalPrecedentSP(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, m_capitalComparatifDroitPrecedent);
    if (m_capitalComparatifDroitPrecedent.compareTo(m_capitalComparatifDroitCourant) > 0) {
      m_capitalProduitResultant = m_capitalComparatifDroitPrecedent;
    } else {
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
    }
  }
  
  protected void recuperationMontants(Demande demandeCourante, DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    CompetenceSpec competence = dossierExamenCourant.getCompetence();
    ResultatDeterminationCompetence resultatDeterminationCompetence = new ResultatDeterminationCompetence();
    OutilDeterminationCompetence.mapperCompetenceSurResultat(dossierExamenCourant.getCompetence(), resultatDeterminationCompetence);
    DeterminationCompetenceProduitResultant.getInstance().determinerCompetencesProduitResultant(demandeCourante, m_capitalComparatifDroitCourant.getValeur(), m_capitalComparatifDroitPrecedent.getValeur(), resultatDeterminationCompetence);
    OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetence, competence);
    
    m_montantPrecedentAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitPrecedentAvecCompetenceAServir(dossierExamenCourant, demandeCourante);
    
    m_montantCourantAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitCourantAvecCompetenceAServir(dossierExamenCourant);
    if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) > 0) {
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
    } else if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) == 0)
    {
      if (m_montantPrecedentAvecCompetenceDuDroitAServir.getSjrNonReduit().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getSjrNonReduit()) > 0) {
        m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      } else {
        m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      }
    }
    else {
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
    }
  }
  
  protected int recuperationDuree(DossierExamen dossierExamenCourant, Demande demandeCourante, boolean bornerRetraite)
    throws CoucheLogiqueException
  {
    int typeReadmission = m_determinationProduitResultant.determinerTypeReadmission(dossierExamenCourant.getConstitutionProduitResultant(), m_montantProduitResultant, m_capitalProduitResultant, m_montantPrecedentAvecCompetenceDuDroitAServir, m_montantCourantAvecCompetenceDuDroitAServir, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    switch (typeReadmission)
    {
    case 11: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, demandeCourante));
      
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      m_capitalProduitResultant = m_capitalComparatifDroitPrecedent;
      m_dureeProduitResultant = m_dureeIntermediaireDroitPrecedent;
      imputerSurDroitAServir(m_dureeIntermediaireDroitPrecedent, demandeCourante, dossierExamenCourant);
      m_readmissionCourante.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
      break;
    case 26: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, demandeCourante));
      
      m_dureeProduitResultant = m_determinationProduitResultant.determinationDureeProduitResultant(m_readmissionCourante, m_montantProduitResultant, m_pointDepartUnique, m_capitalProduitResultant, bornerRetraite);
      
      imputerSurDroitAServir(m_dureeProduitResultant, demandeCourante, dossierExamenCourant);
      m_readmissionCourante.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
      
      break;
    default: 
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
      m_dureeProduitResultant = m_dureeIntermediaireDroitCourant;
      
      imputerSurDroitAServir(m_dureeIntermediaireDroitCourant, demandeCourante, dossierExamenCourant);
      dossierExamenCourant.getConstitutionProduitResultant().setCapitalMax(m_capitalProduitResultant);
    }
    verifierDuree(m_dureeProduitResultant);
    
    return typeReadmission;
  }
  
  protected void verifierDuree(Quantite dureeProduitResultant)
    throws CoucheLogiqueException
  {
    if (dureeProduitResultant.getValeurEntiere() <= 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB15");
    }
  }
  
  protected void imputerSurDroitAServir(Quantite dureeImputee, Demande demandeCourante, DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    BigDecimal montantImputationDroitAServir = demandeCourante.getDonneesTemporaires().getMontantImputationDroitAServir();
    int dureeImputationDroitAServir = 0;
    if (demandeCourante.getDonneesTemporaires().getNbjImputationDroitAServir() != null) {
      dureeImputationDroitAServir = demandeCourante.getDonneesTemporaires().getNbjImputationDroitAServir().intValue();
    }
    BigDecimal dureeImputationDroitAServirBigDecimal = new BigDecimal(dureeImputationDroitAServir);
    BigDecimal dureeAImputerBigDecimal = new BigDecimal(0);
    if ((montantImputationDroitAServir != null) || (dureeImputationDroitAServir != 0))
    {
      if (montantImputationDroitAServir != null) {
        dureeAImputerBigDecimal = new BigDecimal(montantImputationDroitAServir.divide(m_montantProduitResultant.getMontantBrut().getValeur(), 3).intValue());
      }
      if (dureeImputationDroitAServir != 0) {
        dureeAImputerBigDecimal = new BigDecimal(dureeAImputerBigDecimal.add(dureeImputationDroitAServirBigDecimal).intValue());
      }
      Quantite dureeAImputer = new QuantiteJour(dureeAImputerBigDecimal);
      m_dureeProduitResultant = dureeImputee.soustraire(dureeAImputer);
      if (m_dureeProduitResultant.getValeurEntiere() < 0) {
        m_dureeProduitResultant = new Quantite(0, dureeImputee.getUnite());
      }
      JustificationDroitResultant justif = ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionProduitResultant().getJustificationDroitResultant();
      justif.setImputationDroitRetenu(new QuantiteJour(dureeAImputer.getValeur()));
      
      Attribution attributionCourante = (Attribution)dossierExamenCourant;
      
      Quantite capitalProduitEffectif = AppelCalculParLiquidationAsu.calculerCapital(attributionCourante, m_montantProduitResultant, attributionCourante.getDateAttribution(), m_dureeProduitResultant);
      
      m_capitalProduitResultant = new QuantiteEuro(capitalProduitEffectif.getValeur());
    }
  }
  
  protected boolean bornerRetraite()
  {
    return false;
  }
  
  protected void miseAJourCepa15(Demande demandeCourante, DomLiquidationAssurance dom, int typeReadmission)
    throws CoucheLogiqueException
  {
    switch (typeReadmission)
    {
    case 11: 
      readmissionDroitPrecedent(demandeCourante, dom);
      break;
    case 26: 
      readmissionDroitResultant(demandeCourante, dom);
      break;
    default: 
      alimentationCepaDroitCourant(demandeCourante);
    }
  }
  
  protected void readmissionDroitPrecedent(Demande demandeCourante, DomLiquidationAssurance dom)
    throws CoucheLogiqueException
  {
    affectationDemandeOrigine(demandeCourante, dom);
    alimentationCepaDroitPrecedent(demandeCourante);
  }
  
  protected void readmissionDroitResultant(Demande demandeCourante, DomLiquidationAssurance dom)
    throws CoucheLogiqueException
  {
    affectationDemandeOrigine(demandeCourante, dom);
    alimentationCepaDroitResultant(demandeCourante);
  }
  
  protected void alimentationCepaDroitPrecedent(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demandeCourante.getAttribution();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
    Collection listePensionInvalidite = produit.determinerPensionInvaliditeDroitResultant(attribution);
    attribution.getConstitutionProduitResultant().setListePensionInvalidite(listePensionInvalidite);
    
    alimenterTrancheExecutable(attribution);
    
    MontantAsuSpec montantPrecedentAvecListePensionInvalidite = m_determinationProduitResultant.obtenirMontantDroitCourantAvecCompetenceAServir(attribution);
    if (montantPrecedentAvecListePensionInvalidite.getMontantBrut().getValeur().compareTo(m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantBrut().getValeur()) != 0)
    {
      m_capitalComparatifDroitPrecedent = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitPrecedent, m_montantPrecedentAvecCompetenceDuDroitAServir, attribution, demandeCourante, false);
      
      m_montantPrecedentAvecCompetenceDuDroitAServir = montantPrecedentAvecListePensionInvalidite;
    }
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(m_readmissionCourante, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(m_readmissionCourante, m_capitalComparatifDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(m_readmissionCourante, m_dureeIntermediaireDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitResultant(m_dureeProduitResultant, m_readmissionCourante);
    
    m_determinationProduitResultant.constitutionMontantCepa15(m_montantPrecedentAvecCompetenceDuDroitAServir, m_readmissionCourante);
    
    m_determinationProduitResultant.reportElementsDroits(m_readmissionCourante, demandeCourante);
  }
  
  protected void alimentationCepaDroitResultant(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(m_readmissionCourante, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(m_readmissionCourante, m_capitalComparatifDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(m_readmissionCourante, m_dureeIntermediaireDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitResultant(m_dureeProduitResultant, m_readmissionCourante);
    
    m_determinationProduitResultant.constitutionMontantCepa15(m_montantProduitResultant, m_readmissionCourante);
    
    alimenterTrancheExecutable((Attribution)demandeCourante.getAttribution());
    
    m_determinationProduitResultant.reportElementsDroits(m_readmissionCourante, demandeCourante);
  }
  
  protected void alimentationCepaDroitCourant(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(dossierExamenCourant, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(dossierExamenCourant, m_capitalComparatifDroitPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepaMontants(dossierExamenCourant, m_capitalComparatifDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(dossierExamenCourant, m_dureeIntermediaireDroitPrecedent);
  }
  
  protected abstract void affectationDemandeOrigine(Demande paramDemande, DomLiquidationAssurance paramDomLiquidationAssurance)
    throws CoucheLogiqueException;
  
  protected abstract void verifierCapitalPrecedentSP(Quantite paramQuantite1, MontantAsuSpec paramMontantAsuSpec, Quantite paramQuantite2)
    throws CoucheLogiqueException;
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    m_determinationProduitResultant = DeterminationProduitResultant.getInstance();
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 0;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
  
  protected void alimenterJustificationProduitResultant(Demande demandeCourante, int typeReadmission)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    JustificationDroitResultant justif = dossierExamenCourant.getConstitutionProduitResultant().getJustificationDroitResultant();
    
    boolean presencePI = false;
    Collection listePI = null;
    
    listePI = OutilPensionInvalidite.determinerStatutPensionInvaliditeDroitCourant((AttributionSpec)dossierExamenCourant);
    if (listePI != null)
    {
      Iterator i = listePI.iterator();
      while (i.hasNext())
      {
        PeriodePensionInvaliditeChaineeSpec piCourante = (PeriodePensionInvaliditeChaineeSpec)i.next();
        if (piCourante.getStatut() == 1) {
          presencePI = true;
        }
      }
    }
    BigDecimal montantCourantInitial = m_montantCourant.getMontantBrut().getValeur();
    BigDecimal montantCourantAV = null;
    if (m_montantCourant.getMontantJournalierAvantageVieillesseDeduit() != null)
    {
      montantCourantAV = m_montantCourant.getMontantJournalierAvantageVieillesseDeduit().getValeur();
      montantCourantInitial = montantCourantInitial.add(montantCourantAV);
    }
    BigDecimal montantCourantPI = null;
    if ((presencePI) && (m_montantCourant.getPensionInvaliditeADeduirePriseEnCompte() != null))
    {
      montantCourantPI = m_montantCourant.getPensionInvaliditeADeduirePriseEnCompte().getValeur();
      montantCourantInitial = montantCourantInitial.add(montantCourantPI);
    }
    BigDecimal montantCrcCourantCompCapitaux = null;
    if ("T".equals(m_montantCourant.getPositionExonerationCrc())) {
      montantCrcCourantCompCapitaux = new BigDecimal("0");
    } else if ((m_montantCourant.getAvecPrecompteCRC()) && (m_montantCourant.getCrc() != null)) {
      montantCrcCourantCompCapitaux = m_montantCourant.getCrc().getValeur();
    }
    BigDecimal montantCrcCourantCompMontants = null;
    if ("T".equals(m_montantCourantAvecCompetenceDuDroitAServir.getPositionExonerationCrc())) {
      montantCrcCourantCompMontants = new BigDecimal("0");
    } else if ((m_montantCourantAvecCompetenceDuDroitAServir.getAvecPrecompteCRC()) && (m_montantCourantAvecCompetenceDuDroitAServir.getCrc() != null)) {
      montantCrcCourantCompMontants = m_montantCourantAvecCompetenceDuDroitAServir.getCrc().getValeur();
    }
    BigDecimal imputationCourant = new BigDecimal("0");
    if ((dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation() != null) && (dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getQuantiteTotalJourImputation() != null)) {
      imputationCourant = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getQuantiteTotalJourImputation().getValeur();
    }
    BigDecimal montantBrutDroitCourantCompMontants = null;
    if (m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif() != null) {
      montantBrutDroitCourantCompMontants = m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().getValeur();
    }
    BigDecimal montantBrutDroitCourantCompCapitaux = null;
    if (m_montantCourant.getMontantPrecompteEffectif() != null) {
      montantBrutDroitCourantCompCapitaux = m_montantCourant.getMontantPrecompteEffectif().getValeur();
    }
    if (m_capitalComparatifDroitCourant != null) {
      justif.setCapitalDroitCourant(new QuantiteEuro(m_capitalComparatifDroitCourant.getValeur()));
    }
    if (m_dureeIntermediaireDroitCourant != null) {
      justif.setDureeDroitCourant(new QuantiteJour(m_dureeIntermediaireDroitCourant.getValeur()));
    }
    if (montantCourantInitial != null) {
      justif.setMontantInitialDroitCourant(new QuantiteEuro(montantCourantInitial));
    }
    if (imputationCourant != null) {
      justif.setImputationDroitCourant(new QuantiteJour(imputationCourant));
    }
    if (montantCourantAV != null) {
      justif.setAvantageVieillesseDroitCourant(new QuantiteEuro(montantCourantAV));
    }
    if (montantCourantPI != null) {
      justif.setPensionInvaliditeDroitCourant(new QuantiteEuro(montantCourantPI));
    }
    if (montantCrcCourantCompCapitaux != null) {
      justif.setCrcDroitCourantCompCapitaux(new QuantiteEuro(montantCrcCourantCompCapitaux));
    }
    if (montantCrcCourantCompMontants != null) {
      justif.setCrcDroitCourantCompMontants(new QuantiteEuro(montantCrcCourantCompMontants));
    }
    if (montantBrutDroitCourantCompMontants != null) {
      justif.setMontantBrutDroitCourantCompMontants(new QuantiteEuro(montantBrutDroitCourantCompMontants));
    }
    if (montantBrutDroitCourantCompCapitaux != null) {
      justif.setMontantBrutDroitCourantCompCapitaux(new QuantiteEuro(montantBrutDroitCourantCompCapitaux));
    }
    BigDecimal montantPrecedentInitial = m_montantPrecedent.getMontantBrut().getValeur();
    BigDecimal montantPrecedentAV = null;
    if (m_montantPrecedent.getMontantJournalierAvantageVieillesseDeduit() != null)
    {
      montantPrecedentAV = m_montantPrecedent.getMontantJournalierAvantageVieillesseDeduit().getValeur();
      montantPrecedentInitial = montantPrecedentInitial.add(montantPrecedentAV);
    }
    BigDecimal montantPrecedentPI = null;
    if ((presencePI) && (m_montantPrecedent.getPensionInvaliditeADeduirePriseEnCompte() != null))
    {
      montantPrecedentPI = m_montantPrecedent.getPensionInvaliditeADeduirePriseEnCompte().getValeur();
      montantPrecedentInitial = montantPrecedentInitial.add(montantPrecedentPI);
    }
    BigDecimal montantCrcPrecedentCompCapitaux = null;
    if ("T".equals(m_montantPrecedent.getPositionExonerationCrc())) {
      montantCrcPrecedentCompCapitaux = new BigDecimal("0");
    } else if ((m_montantPrecedent.getAvecPrecompteCRC()) && (m_montantPrecedent.getCrc() != null)) {
      montantCrcPrecedentCompCapitaux = m_montantPrecedent.getCrc().getValeur();
    }
    BigDecimal montantCrcPrecedentCompMontants = null;
    if ("T".equals(m_montantPrecedentAvecCompetenceDuDroitAServir.getPositionExonerationCrc())) {
      montantCrcPrecedentCompMontants = new BigDecimal("0");
    } else if ((m_montantPrecedentAvecCompetenceDuDroitAServir.getAvecPrecompteCRC()) && (m_montantPrecedentAvecCompetenceDuDroitAServir.getCrc() != null)) {
      montantCrcPrecedentCompMontants = m_montantPrecedentAvecCompetenceDuDroitAServir.getCrc().getValeur();
    }
    BigDecimal imputationPrecedent = new BigDecimal("0");
    Reliquat reliquat = ((Demande)dossierExamenCourant.getDemande()).getReliquat();
    if ((reliquat != null) && (reliquat.getQuantiteImputee() != null)) {
      imputationPrecedent = reliquat.getQuantiteImputee().getValeur();
    }
    BigDecimal montantBrutDroitPrecedentCompMontants = null;
    if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif() != null) {
      montantBrutDroitPrecedentCompMontants = m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().getValeur();
    }
    BigDecimal montantBrutDroitPrecedentCompCapitaux = null;
    if (m_montantPrecedent.getMontantBrut() != null) {
      montantBrutDroitPrecedentCompCapitaux = m_montantPrecedent.getMontantPrecompteEffectif().getValeur();
    }
    if (m_capitalComparatifDroitPrecedent != null) {
      justif.setCapitalDroitPrecedent(new QuantiteEuro(m_capitalComparatifDroitPrecedent.getValeur()));
    }
    if (m_dureeIntermediaireDroitPrecedent != null) {
      justif.setDureeDroitPrecedent(new QuantiteJour(m_dureeIntermediaireDroitPrecedent.getValeur()));
    }
    if (montantPrecedentInitial != null) {
      justif.setMontantInitialDroitPrecedent(new QuantiteEuro(montantPrecedentInitial));
    }
    if (imputationPrecedent != null) {
      justif.setImputationDroitPrecedent(new QuantiteJour(imputationPrecedent));
    }
    if (montantPrecedentAV != null) {
      justif.setAvantageVieillesseDroitPrecedent(new QuantiteEuro(montantPrecedentAV));
    }
    if (montantPrecedentPI != null) {
      justif.setPensionInvaliditeDroitPrecedent(new QuantiteEuro(montantPrecedentPI));
    }
    if (montantCrcPrecedentCompCapitaux != null) {
      justif.setCrcDroitPrecedentCompCapitaux(new QuantiteEuro(montantCrcPrecedentCompCapitaux));
    }
    if (montantCrcPrecedentCompMontants != null) {
      justif.setCrcDroitPrecedentCompMontants(new QuantiteEuro(montantCrcPrecedentCompMontants));
    }
    if (montantBrutDroitPrecedentCompMontants != null) {
      justif.setMontantBrutDroitPrecedentCompMontants(new QuantiteEuro(montantBrutDroitPrecedentCompMontants));
    }
    if (montantBrutDroitPrecedentCompCapitaux != null) {
      justif.setMontantBrutDroitPrecedentCompCapitaux(new QuantiteEuro(montantBrutDroitPrecedentCompCapitaux));
    }
    if (m_montantProduitResultant != null) {
      justif.setMontantDroitRetenu(new QuantiteEuro(m_montantProduitResultant.getMontantPrecompteEffectif().getValeur()));
    }
    if (m_capitalProduitResultant != null) {
      justif.setCapitalDroitRetenu(new QuantiteEuro(m_capitalProduitResultant.getValeur()));
    }
    if (m_dureeProduitResultant != null) {
      justif.setDureeDroitRetenu(new QuantiteJour(m_dureeProduitResultant.getValeur()));
    }
    if (justif.getImputationDroitRetenu() == null) {
      justif.setImputationDroitRetenu(new QuantiteJour("0"));
    }
    if (typeReadmission == 11) {
      justif.setEstCasParticulierPensionInvalidite(OutilPensionInvalidite.estCasParticulierPensionInvaliditeDroitResultant((AttributionSpec)dossierExamenCourant));
    } else {
      justif.setEstCasParticulierPensionInvalidite(false);
    }
    int statutPension = 0;
    listePI = ((AttributionAssuranceSpec)dossierExamenCourant).getListePensionInvalidite();
    if ((listePI != null) && (!listePI.isEmpty()))
    {
      statutPension = 2;
      Iterator it = listePI.iterator();
      PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
      while (it.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)it.next();
        if (pensionInvalidite.getStatut() == 1) {
          statutPension = 1;
        }
      }
    }
    justif.setStatutPensionInvaliditeDroitCourant(statutPension);
  }
  
  private void alimenterTrancheExecutable(Attribution attribution)
    throws CoucheLogiqueException
  {
    if (attribution.getProduit() != null)
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      if (produit.estTrancheActivee(attribution.getDemande()))
      {
        Contexte contexte = new Contexte();
        DomLiquidationAssurance dom = new DomLiquidationAssurance();
        contexte.setDonnees(dom);
        dom.setDemande(attribution.getDemande());
        try
        {
          produit.constituerTranchesExecutables(contexte);
        }
        catch (ApplicativeException ex)
        {
          throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle());
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */