package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDonneesDeterminationSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjcSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjcSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;

public abstract class ParcoursConstitutionSjcAbstrait
  extends ParcoursCali
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA10 = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    if ((!strategieActiviteConservee.constituerSalaireJournalierConserve(demandeCourante)) || (reglementApplicableCourant.estNomReglementIdentique("A4")))
    {
      resultatCEPA10.setEtat(1);
    }
    else
    {
      ConstitutionSjc constitutionSjc = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSjc();
      
      Sjcip sjcipCourant = determinerSjcip(demandeCourante);
      
      alimenterCEPSjcip(constitutionSjc, sjcipCourant);
      
      Sjc sjcrpCourant = determinerSjcrp(dossierExamenCourant);
      
      alimenterCEPSjcrp(constitutionSjc, sjcrpCourant);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA10;
  }
  
  private void alimenterCEPListeAlertesNonBloquantes(Demande p_demande, Hashtable p_listeAlertesNonBloquantesResultat)
  {
    String codeAlerteNonBloquanteResultat = null;
    Collection listePeriodeTravailResultat = null;
    Iterator itListePeriodeTravailResultat = null;
    ObjetAlertesNonBloquantes objetAlertesNonBloquantesResultat = null;
    Collection listePeriodeTravail = null;
    for (Enumeration enumeration = p_listeAlertesNonBloquantesResultat.keys(); enumeration.hasMoreElements();)
    {
      codeAlerteNonBloquanteResultat = (String)enumeration.nextElement();
      listePeriodeTravailResultat = (Collection)p_listeAlertesNonBloquantesResultat.get(codeAlerteNonBloquanteResultat);
      if (p_demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquanteResultat))
      {
        listePeriodeTravail = (Collection)p_demande.getAlertesNonBloquantes().get(codeAlerteNonBloquanteResultat);
        
        itListePeriodeTravailResultat = listePeriodeTravailResultat.iterator();
        while (itListePeriodeTravailResultat.hasNext())
        {
          objetAlertesNonBloquantesResultat = (ObjetAlertesNonBloquantes)itListePeriodeTravailResultat.next();
          if (!listePeriodeTravail.contains(objetAlertesNonBloquantesResultat)) {
            listePeriodeTravail.add(objetAlertesNonBloquantesResultat);
          }
        }
      }
      else
      {
        p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquanteResultat, listePeriodeTravailResultat);
      }
    }
  }
  
  private void alimenterCEPSjcip(ConstitutionSjc p_constitutionSjc, Sjcip p_sjcip)
  {
    Sjcip sjcipCourant = p_constitutionSjc.createSjcip(p_sjcip.getDateEffet(), p_sjcip.getPlafond(), p_sjcip.getSjcInitial());
    if (p_sjcip.getCollectionSjrActiviteConservee() != null)
    {
      Iterator iterateur = p_sjcip.getCollectionSjrActiviteConservee().iterator();
      SjrActiviteConservee sjrActiviteConserveCourant = null;
      while (iterateur.hasNext())
      {
        sjrActiviteConserveCourant = (SjrActiviteConservee)iterateur.next();
        sjcipCourant.ajouterSjrActiviteConservee(sjrActiviteConserveCourant);
      }
    }
  }
  
  private void alimenterCEPSjcrp(ConstitutionSjc p_constitutionSjc, Sjc p_sjcrp)
  {
    p_constitutionSjc.setSjcrp(p_sjcrp);
  }
  
  private Sjcip determinerSjcip(Demande p_demande)
    throws ApplicativeException
  {
    Sjcip sjcipRetourne = null;
    
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)p_demande.getDossierAffectation().getProduit();
    DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjc = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntree(p_demande, 2, (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(p_demande.getDateFaitGenerateurOuDernierSinistre()), false);
    
    Chronologie chronoGlobaleActivitesConservees = OutilGestionActivitesConservees.getInstance().determinerChronoGlobaleActivitesConservees(p_demande);
    
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntreeDeterminationSjc.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    Prc prcSjcipCourante = fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerPrc(p_demande);
    BigDecimal plafondSjcipCourant = fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerPlafondSjcip(p_demande);
    
    sjcipRetourne = verifierSjcipForce(prcSjcipCourante.getDateFin(), plafondSjcipCourant, chronoGlobaleActivitesConservees, donneesEntreeDeterminationSjc);
    if (sjcipRetourne == null) {
      sjcipRetourne = calculerSjcip(p_demande, prcSjcipCourante, plafondSjcipCourant, chronoGlobaleActivitesConservees, donneesEntreeDeterminationSjc);
    }
    fabriqueOutilFonctionnel.getOutilDeterminationSjc().mettreAJourSjcipAvecTypeActiviteConservee(sjcipRetourne);
    
    return sjcipRetourne;
  }
  
  protected abstract Sjcip verifierSjcipForce(Damj paramDamj, BigDecimal paramBigDecimal, Chronologie paramChronologie, DonneesEntreeDeterminationSjrSpec paramDonneesEntreeDeterminationSjrSpec)
    throws CoucheLogiqueException;
  
  private Sjcip calculerSjcip(Demande p_demande, Prc p_prcSjc, BigDecimal p_plafondSjc, Chronologie p_chronoGlobaleActivitesConservees, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    Sjcip sjcipRetourne = null;
    
    Damj termePrc = p_prcSjc.getDateFin();
    Chronologie chronoActivitesSalarieesConserveesPourSjcip = determinerChronoActivitesSalarieesConserveesPourSjcip(termePrc, p_chronoGlobaleActivitesConservees, p_donneesEntree);
    
    OutilDonneesDeterminationSjr.getInstance().alimenterDonneesEntreeComplementaires(p_donneesEntree, p_prcSjc.getJustification(), chronoActivitesSalarieesConserveesPourSjcip, null, null);
    
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerSjcip(p_donneesEntree);
    
    alimenterCEPListeAlertesNonBloquantes(p_demande, resultatDeterminationSjc.getListeAlertesNonBloquantes());
    
    sjcipRetourne = construireSjcip(termePrc, p_plafondSjc, resultatDeterminationSjc.getSjci(), resultatDeterminationSjc.getListeSjrActiviteConservee());
    
    fabriqueOutilFonctionnel.getOutilDeterminationSjc().completerSjcipAvecActivitesConserveesNonRetenues(p_donneesEntree, sjcipRetourne, p_chronoGlobaleActivitesConservees, false);
    
    return sjcipRetourne;
  }
  
  private Sjc determinerSjcrp(DossierExamen p_dossierExamen)
    throws CoucheLogiqueException
  {
    ConstitutionSjc cepConstitutionSjc = p_dossierExamen.getConstitutionSjc();
    Damj dateRevalorisation = p_dossierExamen.getDateAttribution();
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOfSjr = (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(p_dossierExamen.getFaitGenerateur().getDateFaitGenerateur());
    return fabriqueOfSjr.getOutilDeterminationSjc().revaloriserSjcip(cepConstitutionSjc, dateRevalorisation);
  }
  
  private Chronologie determinerChronoActivitesSalarieesConserveesPourSjcip(Damj p_termePrc, Chronologie p_chronoGlobaleActivitesConservees, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    return fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerChronoActivitesSalarieesConserveesPourSjcip(p_donneesEntree.getDonneesEntreeDemande().getListeContexteDemande(), p_termePrc, p_chronoGlobaleActivitesConservees, p_donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitCourant());
  }
  
  protected Sjcip construireSjcip(Damj p_dateEffetSjc, BigDecimal p_plafondSjc, BigDecimal p_sjc, ArrayList p_listeSjrActiviteConserve)
  {
    Sjcip sjcipRetourne = Sjcip.createNonPersistent();
    sjcipRetourne.setDateEvenement(p_dateEffetSjc);
    sjcipRetourne.setPlafond(new QuantiteEuro(p_plafondSjc));
    sjcipRetourne.setSjcInitial(new QuantiteEuro(p_sjc));
    if (p_listeSjrActiviteConserve != null) {
      for (int i = 0; i < p_listeSjrActiviteConserve.size(); i++) {
        sjcipRetourne.ajouterSjrActiviteConserve((SjrActiviteConservee)p_listeSjrActiviteConserve.get(i));
      }
    }
    return sjcipRetourne;
  }
  
  protected StrategieActiviteConserveeConvention2014Spec recupererStrategieActiviteConserveeConvention2014(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    return OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demandeCourante);
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionSjcAbstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */