package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationMontantICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDeterminationFormuleICCPMontant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationFormuleICCPMontantSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Temporel;
import java.util.List;

public class ParcoursDeterminationDelaisReportsA4
  extends ParcoursDeterminationDelaisReports
{
  protected Chronologie determinerChronologieActivitesPourICCPISLR(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Chronologie chronoRetourActivitesParticipantes = null;
    
    TravailSpec periodeFaitGenerateur = recupererPeriodeFaitGenerateur(demande);
    if (periodeFaitGenerateur != null)
    {
      boolean estDiffereICCPForce = ((demande.getDonneesTemporaires().getQuantiteJourICCP() != null) || (demande.getDonneesTemporaires().getQuantiteJourISLR() != null)) && (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null);
      if (estDiffereICCPForce)
      {
        String identifiantActiviteSalarieForcee = demande.getDonneesTemporaires().getIndentifiantFctPMC();
        if (!identifiantActiviteSalarieForcee.equalsIgnoreCase(periodeFaitGenerateur.getIdentifiant())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB30");
        }
      }
      Chronologie chronoActivitesParticipantes = new ChronologiePeriodes();
      chronoActivitesParticipantes.ajouter(periodeFaitGenerateur);
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarie());
      chronoRetourActivitesParticipantes = chronoActivitesParticipantes.copier(filtres);
    }
    return chronoRetourActivitesParticipantes;
  }
  
  protected BaseDelaiReport determinerBaseDelaiReportICCP(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation, boolean iccpConservatoireAutoriseBatiment)
    throws ApplicativeException
  {
    BaseDelaiReport baseDelaiReportActiviteCourante = OutilDeterminationMontantICCP.determinerBaseDelaiReportICCPA4(demande, activiteSalarie);
    
    alimenterCEPCumulMontantsICCPA4(demande, baseDelaiReportActiviteCourante.getQuantiteEuroIccp());
    
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = (QuantiteJourTravailDansSemaineSpec)activiteSalarie.getQuantiteJourIccp();
    baseDelaiReportActiviteCourante.setQuantiteJourIccp(quantiteJourIccp);
    
    Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
    boolean estEnContexteApprentissage = attributionCourante.isTopContratsRemuneresBaseSmic();
    baseDelaiReportActiviteCourante.setEstTopContratsRemuneresBaseSmic(estEnContexteApprentissage);
    
    Sjr sjrrp = recupererSjrrp(attributionCourante);
    baseDelaiReportActiviteCourante.setSjrrp(sjrrp);
    
    return baseDelaiReportActiviteCourante;
  }
  
  private void alimenterCEPCumulMontantsICCPA4(DemandeAssuranceSpec demande, QuantiteEuro cumulMontantICCPA4)
  {
    if (cumulMontantICCPA4 != null)
    {
      Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
      attributionCourante.getConstitutionDelais().setCumulMontantICCPA4Origine(cumulMontantICCPA4);
    }
  }
  
  protected FormuleDelaiReportSpec determinerFormuleICCP(BaseDelaiReport baseDelaiReport, DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    StrategieSpec strategie = FabriqueStrategieDeterminationFormuleICCPMontant.getInstance().getStrategie(critere);
    
    FormuleDelaiReportSpec formuleDelaiReportRetour = ((StrategieDeterminationFormuleICCPMontantSpec)strategie).recupererFormuleICCPMontant();
    
    return formuleDelaiReportRetour;
  }
  
  protected Damj recupererDatePivotPourFormuleISLR(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    return recupererPeriodeFaitGenerateur((DemandeAssuranceSpec)demandeCourante).getDateFin();
  }
  
  protected boolean determinerCalculICCPConservatoireBatimentAutorise(Demande demande, List<Temporel> listeActivitePourICCP, ActiviteSalarie activiteCourante)
    throws ApplicativeException
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationDelaisReportsA4
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */