package fr.unedic.cali.asu.cge01.liquidation.parcours.asp;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieAppelContrib;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieAppelContribSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ContributionsParticulieres;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ContributionParticuliere;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Indemnite;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteMonnaie;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class ParcoursDetecterContributionParticuliere
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)demandeCourante.getDossierExamen();
    ContributionParticuliereSpec contributionParticuliere = creerContributionParticuliere();
    if (ContributionsParticulieres.estDecisionPourAppelDetecContribPart(attributionCourante))
    {
      ActiviteSalarie activiteSalarieEtudiee = recupererActiviteSalarie(demandeCourante);
      boolean pap = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 10);
      if ((activiteSalarieEtudiee != null) && (OutilDemande.estUneDemandeAsp(demandeCourante)))
      {
        int motifFin = activiteSalarieEtudiee.getCodeMotifFin();
        if (!pap)
        {
          verifierDonneesForceesNonPap(demandeCourante);
          alimenterContrib(demandeCourante, contributionParticuliere, activiteSalarieEtudiee);
          contributionParticuliere.setTypeContributionParticuliere(getTypeContributionParticuliere(contributionParticuliere, motifFin));
        }
        else
        {
          alimenterContribPap(demandeCourante, contributionParticuliere, motifFin);
          contributionParticuliere.setTypeContributionParticuliere(getTypeContributionParticulierePap(contributionParticuliere, motifFin));
        }
        attributionCourante.setContributionParticuliere(contributionParticuliere);
      }
    }
    return new Resultat();
  }
  
  protected void verifierDonneesForceesNonPap(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    DonneesTemporaires df = demandeCourante.getDonneesTemporaires();
    if ((df.getMontantIndemnitePreavisContrib() != null) || (df.getContributionAdhesionVolontaire() != null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PAP_CONTRIB_PREAVIS_INTERDITE");
    }
  }
  
  private int getTypeContributionParticulierePap(ContributionParticuliereSpec contributionParticuliere, int motifFin)
  {
    int typeContribution = 0;
    if ((motifFin == 48) && (contributionParticuliere.isTopDetectionContributionPreavis())) {
      typeContribution = 14;
    } else if ((motifFin == 49) && (contributionParticuliere.isTopDetectionContributionPreavis())) {
      typeContribution = 15;
    }
    return typeContribution;
  }
  
  protected void alimenterContribPap(Demande demandeCourante, ContributionParticuliereSpec contributionParticuliere, int motifFin)
    throws CoucheLogiqueException
  {
    DonneesTemporaires df = demandeCourante.getDonneesTemporaires();
    BigDecimal montantPreavis = df.getMontantIndemnitePreavisContrib();
    BigDecimal montantAdhVol = df.getContributionAdhesionVolontaire();
    if (motifFin == 48)
    {
      if (montantAdhVol != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PAP_CONTRIB_PREAVIS_INTERDITE");
      }
      if (demandeCourante.estEnContexteDemande("PAPDC")) {
        if (montantPreavis == null)
        {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PAP_CONTRIB_PREAVIS_OBLIGATOIRE");
        }
        else if (montantPreavis.compareTo(BigDecimal.ZERO) > 0)
        {
          contributionParticuliere.setMontantPreavisCtp(montantPreavis);
          contributionParticuliere.setTopDetectionContributionPreavis(true);
        }
      }
    }
    else if (motifFin == 49)
    {
      if (montantPreavis != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PAP_CONTRIB_PREAVIS_INTERDITE");
      }
      if (montantAdhVol == null)
      {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PAP_CONTRIB_ADHVOL_OBLIGATOIRE");
      }
      else if (montantAdhVol.compareTo(BigDecimal.ZERO) > 0)
      {
        contributionParticuliere.setMontantPreavisCtp(montantAdhVol);
        contributionParticuliere.setTopDetectionContributionPreavis(true);
      }
    }
  }
  
  int getTypeContributionParticuliere(ContributionParticuliereSpec contributionParticuliere, int motifFin)
  {
    int typeContribution = 0;
    if (motifFin == 45)
    {
      if (contributionParticuliere.isTopDetectionContributionPreavis()) {
        typeContribution = 13;
      }
    }
    else if ((contributionParticuliere.isTopDetectionContributionPreavis()) && (contributionParticuliere.isTopDetectionContributionDif())) {
      typeContribution = 11;
    } else if ((contributionParticuliere.isTopDetectionContributionPreavis()) && (!contributionParticuliere.isTopDetectionContributionDif())) {
      typeContribution = 12;
    } else if ((contributionParticuliere.isTopDetectionContributionDif()) && (!contributionParticuliere.isTopDetectionContributionPreavis())) {
      typeContribution = 7;
    }
    return typeContribution;
  }
  
  protected void alimenterContrib(Demande demandeCourante, ContributionParticuliereSpec contributionParticuliere, ActiviteSalarie activiteSalarieEtudiee)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demandeCourante.getDateExamen());
    StrategieAppelContribSpec strategie = (StrategieAppelContribSpec)FabriqueStrategieAppelContrib.getInstance().getStrategie(critere);
    
    Collection<Indemnite> listeIndemnites = activiteSalarieEtudiee.getListeIndemnites();
    if (listeIndemnites != null)
    {
      Iterator<Indemnite> it = listeIndemnites.iterator();
      while (it.hasNext())
      {
        Indemnite indemnitePeriode = (Indemnite)it.next();
        int typeIndemnite = indemnitePeriode.getTypeIndemnite();
        if (typeIndemnite == 124) {
          alimenterContributionPreavis(indemnitePeriode, contributionParticuliere);
        } else if (typeIndemnite == 126) {
          alimenterContributionDif(indemnitePeriode, contributionParticuliere, strategie, activiteSalarieEtudiee);
        }
      }
    }
  }
  
  protected void alimenterContributionPreavis(Indemnite indemnitePeriode, ContributionParticuliereSpec contrib)
  {
    if ((indemnitePeriode.getMontant() != null) && (indemnitePeriode.getMontant().getValeurMontant().signum() > 0))
    {
      contrib.setMontantPreavisCtp(indemnitePeriode.getMontant().getValeurMontant());
      contrib.setTopDetectionContributionPreavis(true);
    }
  }
  
  protected void alimenterContributionDif(Indemnite indemnitePeriode, ContributionParticuliereSpec contrib, StrategieAppelContribSpec strategie, ActiviteSalarie activiteSalarieEtudiee)
  {
    if ((strategie.estPriseEnCompteAppelContribDiff()) && (indemnitePeriode.getMontant() != null) && (indemnitePeriode.getMontant().getValeurMontant().signum() > 0))
    {
      contrib.setTopDetectionContributionDif(true);
      BigDecimal salaireHoraireDif = indemnitePeriode.getMontant().getValeurMontant();
      contrib.setMontantFormationDifCtp(OutilAsr.calculerSommeAPayerDiff(activiteSalarieEtudiee.getPeriodeActiviteSalarieGaec().getNbHeuresDiff(), salaireHoraireDif));
    }
  }
  
  protected ContributionParticuliereSpec creerContributionParticuliere()
  {
    return new ContributionParticuliere();
  }
  
  protected ActiviteSalarie recupererActiviteSalarie(Demande demande)
  {
    ActiviteSalarie activiteSalarieRetournee = null;
    
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
      activiteSalarieRetournee = validationProduit.getPeriodeValidationProduit();
    }
    return activiteSalarieRetournee;
  }
}

/* Location:
 * Qualified Name:     ParcoursDetecterContributionParticuliere
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */