package fr.unedic.cali.asu.cge01.p02.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.PostTraitementsAsu;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.calcul.parcours.ResultatMigrationCalcul;
import fr.unedic.cali.asu.cge01.p02.calcul.dom.DureeRenouvellement;
import fr.unedic.cali.autresdoms.cohab.dom.DecisionSuivi;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDjiSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContientDate;
import fr.unedic.cali.parcours.ResultatDetailleNotificationProduit;
import fr.unedic.cali.parcours.ResultatDetailleProduit;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.cali.parcours.ResultatMigrationCalculProduit;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class PostTraitements
  extends PostTraitementsAsu
{
  public static ResultatDetailleProduit postTraitementResultatDetaille(AttributionSpec p_attribution, CalendrierExecutionCalcul p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    ResultatDetailleProduit resultat = new ResultatDetailleProduit();
    
    remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, resultat);
    
    return resultat;
  }
  
  public static ResultatDetailleNotificationProduit postTraitementResultatDetailleNotification(AttributionSpec p_attribution, CalendrierExecutionCalcul p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    ResultatDetailleNotificationProduit resultat = new ResultatDetailleNotificationProduit();
    
    remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, resultat);
    
    return resultat;
  }
  
  public static ResultatDeterminationEtatDroitProduit postTraitementResultatDeterminationEtatDroit(AttributionSpec p_attribution, CalendrierExecutionCalcul p_calendrierExecutionCalcul, Damj p_dateEtatDroit)
    throws CoucheLogiqueException
  {
    ResultatDeterminationEtatDroit resultat = new ResultatDeterminationEtatDroit();
    
    remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, p_dateEtatDroit, resultat);
    
    EtatAuDjiSpec etatAuDji = p_calendrierExecutionCalcul.getEtatAuDJI();
    if ((etatAuDji != null) && (p_dateEtatDroit == p_calendrierExecutionCalcul.getDernierJourIndemnisable()))
    {
      resultat.setReliquatDureeRenouvellement(etatAuDji.getReliquatDureeRenouvellement());
      
      resultat.setEstEnAttenteRenouvellement(etatAuDji.getEstEnAttenteRenouvellement());
    }
    else
    {
      resultat.setReliquatDureeRenouvellement(recupererReliquatDureeRenouvellement(p_calendrierExecutionCalcul));
      resultat.setEstEnAttenteRenouvellement(positionnerEstEnAttenteRenouvellement(p_calendrierExecutionCalcul, p_attribution));
    }
    return resultat;
  }
  
  private static boolean positionnerEstEnAttenteRenouvellement(CalendrierExecutionCalcul p_calendrierExecutionCalcul, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    boolean estEnAttente = false;
    Collection listeDecisionsSuivi = null;
    Iterator iterDecisionsSuivi = null;
    DecisionSuivi decisionSuivi = null;
    if ((p_calendrierExecutionCalcul instanceof CalendrierExecutionCalculPeriodique))
    {
      listeDecisionsSuivi = OutillagePeriodes.recupererDecisionsSuivi(p_attribution.getDemandeur());
      if (listeDecisionsSuivi != null)
      {
        iterDecisionsSuivi = listeDecisionsSuivi.iterator();
        while (iterDecisionsSuivi.hasNext())
        {
          decisionSuivi = (DecisionSuivi)iterDecisionsSuivi.next();
          if ((p_attribution.getRsod().equals(decisionSuivi.getRSOD())) && 
          
            (decisionSuivi.getNatureDecision().equals("RX"))) {
            estEnAttente = true;
          }
        }
      }
    }
    return estEnAttente;
  }
  
  private static Quantite recupererReliquatDureeRenouvellement(CalendrierExecutionCalculSpec p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    Quantite reliquatDureeRenouvellement = null;
    UniteTraitement ut = null;
    if ((p_calendrierExecutionCalcul instanceof CalendrierExecutionCalculPeriodique))
    {
      Chronologie chronoUT = ((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().copier(new FiltreContientDate(p_calendrierExecutionCalcul.getDernierJourIndemnisable()));
      if (!chronoUT.estVide()) {
        ut = (UniteTraitement)chronoUT.premierElement();
      } else {
        ut = (UniteTraitement)((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().dernierElement();
      }
      Collection collectionQuantiteDroit = ut.getConstituantsIndemnisationEnFinUT().getCollectionQuantiteDroit();
      DureeRenouvellement dureeRenouvellement = null;
      if (collectionQuantiteDroit != null)
      {
        Iterator iterator = collectionQuantiteDroit.iterator();
        while (iterator.hasNext())
        {
          QuantiteDroitSpec quantiteDroit = (QuantiteDroitSpec)iterator.next();
          if ((quantiteDroit instanceof DureeRenouvellement))
          {
            dureeRenouvellement = (DureeRenouvellement)quantiteDroit;
            if (quantiteDroit.getEtat() == 1) {
              break;
            }
          }
        }
      }
      if (dureeRenouvellement != null) {
        if (dureeRenouvellement.getEtat() == 1) {
          reliquatDureeRenouvellement = new QuantiteJour(dureeRenouvellement.getQuantiteCourante().getValeur().setScale(0));
        } else if (dureeRenouvellement.getEtat() == 2) {
          reliquatDureeRenouvellement = new QuantiteJour(new BigDecimal(0));
        }
      }
    }
    return reliquatDureeRenouvellement;
  }
  
  public static ResultatMigrationCalculProduit postTraitementResultatMigrationCalcul(AttributionSpec p_attribution, CalendrierExecutionCalcul p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    ResultatMigrationCalcul resultat = new ResultatMigrationCalcul();
    remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, resultat);
    
    return resultat;
  }
}

/* Location:
 * Qualified Name:     PostTraitements
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */