package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.DossierExamenGen;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionMontantNonNulSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.ConditionValiditeReliquatSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.List;

public abstract class DossierExamen
  extends DossierExamenGen
  implements DossierExamenAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  private transient AttributionAssuranceSpec attributionPrecedente;
  private transient AccesseurDroits accesseurDroits;
  
  protected DossierExamen() {}
  
  public DossierExamen(DomPCSpec pc)
  {
    super(pc);
  }
  
  protected DossierExamen(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  protected void copie(DossierExamen source)
  {
    if (source == null) {
      return;
    }
    setDossierAffecte(source.getDossierAffecte());
    setConditionsAttributionAdmission(source.getConditionsAttributionAdmission());
    setConstitutionElementsAdmission(source.getConstitutionElementsAdmission());
    setConditionsAttributionReprise(source.getConditionsAttributionReprise());
    setConstitutionElementsReprise(source.getConstitutionElementsReprise());
    setAttributionPrecedente(source.getAttributionPrecedente());
    setCompetence(source.getCompetence());
    setContexteDdeExpresse(getContexteDdeExpresse());
    setContributionParticuliere((ContributionParticuliere)source.getContributionParticuliere());
    setCompetenceSousJacente(source.getCompetenceSousJacente());
  }
  
  public void setDossierAffecte(DossierAffectationSpec dossierAffectation)
  {
    super.setDossierAffecte((DossierAffecte)dossierAffectation);
    if ((dossierAffectation != null) && (dossierAffectation.getDossierExamen() != this)) {
      dossierAffectation.setDossierExamen(this);
    }
  }
  
  public DemandeSpec getDemande()
  {
    if (getDossierAffecte() == null) {
      return null;
    }
    return getDossierAffecte().getDemande();
  }
  
  public void setAttributionPrecedente(AttributionAssuranceSpec decisionPrecedente)
  {
    attributionPrecedente = decisionPrecedente;
  }
  
  public AttributionAssuranceSpec getAttributionPrecedente()
  {
    if (((Demande)getDemande()).getDemandeOrigine() != null) {
      setAttributionPrecedente(((Demande)getDemande()).getDemandeOrigine().getAttribution());
    }
    return attributionPrecedente;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public abstract ConditionsAttributionSpec getConditionsAttributionActives();
  
  public abstract ConstitutionElementsSpec getConstitutionElementsActifs();
  
  public ConditionsAttributionAdmission getConditionsAttributionAdmission()
  {
    if (super.getConditionsAttributionAdmission() == null) {
      super.setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    return super.getConditionsAttributionAdmission();
  }
  
  public void setConditionsAttributionAdmission(ConditionsAttributionAdmission conditionsAttributionAdmission)
  {
    DomManager.supprimer(super.getConditionsAttributionAdmission(), conditionsAttributionAdmission);
    super.setConditionsAttributionAdmission(conditionsAttributionAdmission);
  }
  
  public ConditionsAttributionReprise getConditionsAttributionReprise()
  {
    if (super.getConditionsAttributionReprise() == null) {
      super.setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    return super.getConditionsAttributionReprise();
  }
  
  public void setConditionsAttributionReprise(ConditionsAttributionReprise conditionsAttributionReprise)
  {
    DomManager.supprimer(super.getConditionsAttributionReprise(), conditionsAttributionReprise);
    super.setConditionsAttributionReprise(conditionsAttributionReprise);
  }
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    return getConditionsAttributionAdmission().getConditionFaitGenerateur();
  }
  
  public void setConditionFaitGenerateur(FaitGenerateurSpec faitGenerateur)
  {
    getConditionsAttributionAdmission().setConditionFaitGenerateur((ConditionFaitGenerateur)faitGenerateur);
  }
  
  public ConditionAge getConditionAge()
  {
    return getConditionsAttributionActives().getConditionAge();
  }
  
  public void setConditionAge(ConditionAge conditionAge)
  {
    getConditionsAttributionActives().setConditionAge(conditionAge);
  }
  
  public ConditionCumulPrestationFamiliale getConditionCumulPrestationFamiliale()
  {
    return getConditionsAttributionActives().getConditionCumulPrestationFamiliale();
  }
  
  public void setConditionCumulPrestationFamiliale(ConditionCumulPrestationFamiliale conditionCumulPrestationFamiliale)
  {
    getConditionsAttributionActives().setConditionCumulPrestationFamiliale(conditionCumulPrestationFamiliale);
  }
  
  public ConditionQuantiteAffiliationSpec getConditionQuantiteAffiliation()
  {
    return getConditionsAttributionAdmission().getConditionQuantiteAffiliation();
  }
  
  public void setConditionQuantiteAffiliation(ConditionQuantiteAffiliation conditionQuantiteAffiliation)
  {
    getConditionsAttributionAdmission().setConditionQuantiteAffiliation(conditionQuantiteAffiliation);
  }
  
  public ConditionChomageInvolontaire getConditionChomageInvolontaire()
  {
    return getConditionsAttributionActives().getConditionChomageInvolontaire();
  }
  
  public void setConditionChomageInvolontaire(ConditionChomageInvolontaire chomageInvolontaire)
  {
    getConditionsAttributionActives().setConditionChomageInvolontaire(chomageInvolontaire);
  }
  
  public ConditionActiviteConservee getConditionActiviteConservee()
  {
    return getConditionsAttributionAdmission().getConditionActiviteConservee();
  }
  
  public void setConditionActiviteConservee(ConditionActiviteConservee activiteConservee)
  {
    getConditionsAttributionAdmission().setConditionActiviteConservee(activiteConservee);
  }
  
  public ConditionRechercheEmploi getConditionRechercheEmploi()
  {
    return getConditionsAttributionActives().getConditionRechercheEmploi();
  }
  
  public void setConditionRechercheEmploi(ConditionRechercheEmploi conditionRechercheEmploi)
  {
    getConditionsAttributionActives().setConditionRechercheEmploi(conditionRechercheEmploi);
  }
  
  public ConditionMontantNonNulSpec getConditionMontantNonNul()
  {
    return getConditionsAttributionActives().getConditionMontantNonNul();
  }
  
  public void setConditionMontantNonNul(ConditionMontantNonNul conditionMontantNonNul)
  {
    getConditionsAttributionActives().setConditionMontantNonNul(conditionMontantNonNul);
  }
  
  public ConditionChomageTotal getConditionChomageTotal()
  {
    return getConditionsAttributionAdmission().getConditionChomageTotal();
  }
  
  public void setConditionChomageTotal(ConditionChomageTotal conditionChomageTotal)
  {
    getConditionsAttributionAdmission().setConditionChomageTotal(conditionChomageTotal);
  }
  
  public ConditionValiditeReliquatSpec getConditionValiditeReliquat()
  {
    return getConditionsAttributionReprise().getConditionValiditeReliquat();
  }
  
  public void setConditionValiditeReliquat(ConditionValiditeReliquat conditionValiditeReliquat)
  {
    getConditionsAttributionActives().setConditionValiditeReliquat(conditionValiditeReliquat);
  }
  
  public ConstitutionElementsAdmission getConstitutionElementsAdmission()
  {
    if (super.getConstitutionElementsAdmission() == null) {
      super.setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    return super.getConstitutionElementsAdmission();
  }
  
  public void setConstitutionElementsAdmission(ConstitutionElementsAdmission constitutionElementsAdmission)
  {
    DomManager.supprimer(super.getConstitutionElementsAdmission(), constitutionElementsAdmission);
    super.setConstitutionElementsAdmission(constitutionElementsAdmission);
  }
  
  public ConstitutionElementsReprise getConstitutionElementsReprise()
  {
    if (super.getConstitutionElementsReprise() == null) {
      super.setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    return super.getConstitutionElementsReprise();
  }
  
  public void setConstitutionElementsReprise(ConstitutionElementsReprise constitutionElementsReprise)
  {
    DomManager.supprimer(super.getConstitutionElementsReprise(), constitutionElementsReprise);
    super.setConstitutionElementsReprise(constitutionElementsReprise);
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsActifs().getConstitutionDurees();
  }
  
  public Quantite getDureeRestanteAImputerFinCSP()
  {
    return getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation().getDureeRestantAImputer();
  }
  
  public void setConstitutionDurees(ConstitutionDurees constitutionDurees)
  {
    getConstitutionElementsActifs().setConstitutionDurees(constitutionDurees);
  }
  
  public ConstitutionDelais getConstitutionDelais()
  {
    return getConstitutionElementsActifs().getConstitutionDelais();
  }
  
  public void setConstitutionDelais(ConstitutionDelais constitutionDelais)
  {
    getConstitutionElementsActifs().setConstitutionDelais(constitutionDelais);
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsActifs().getConstitutionSjr();
  }
  
  public void setConstitutionSjr(ConstitutionSjr constitutionSjr)
  {
    getConstitutionElementsActifs().setConstitutionSjr(constitutionSjr);
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsActifs().getConstitutionSjc();
  }
  
  public void setConstitutionSjc(ConstitutionSjc constitutionSjc)
  {
    getConstitutionElementsActifs().setConstitutionSjc(constitutionSjc);
  }
  
  public ConstitutionQuantiteAffiliation getConstitutionQuantiteAffiliation()
  {
    return getConstitutionElementsAdmission().getConstitutionQuantiteAffiliation();
  }
  
  public void setConstitutionQuantiteAffiliation(ConstitutionQuantiteAffiliation constitutionQuantiteAffiliation)
  {
    getConstitutionElementsAdmission().setConstitutionQuantiteAffiliation(constitutionQuantiteAffiliation);
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsActifs().getConstitutionMontantsBruts();
  }
  
  public void setConstitutionMontantsBruts(ConstitutionMontantsBruts constitutionMontantsBruts)
  {
    getConstitutionElementsActifs().setConstitutionMontantsBruts(constitutionMontantsBruts);
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation();
  }
  
  public void setConstitutionPointDepartIndemnisation(ConstitutionPointDepartIndemnisation constitutionPointDepartIndemnisation)
  {
    getConstitutionElementsActifs().setConstitutionPointDepartIndemnisation(constitutionPointDepartIndemnisation);
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    return getConstitutionElementsActifs().getConstitutionReglementApplicable();
  }
  
  public void setConstitutionReglementApplicable(ConstitutionReglementApplicable reglementApplicable)
  {
    getConstitutionElementsActifs().setConstitutionReglementApplicable(reglementApplicable);
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsActifs().getConstitutionDateAttribution();
  }
  
  public void setConstitutionDateAttribution(ConstitutionDateAttribution constitutionDateAttribution)
  {
    getConstitutionElementsActifs().setConstitutionDateAttribution(constitutionDateAttribution);
  }
  
  public void setConstitutionProduitResultant(ConstitutionProduitResultant constitutionProduitResultant)
  {
    getConstitutionElementsAdmission().setConstitutionProduitResultant(constitutionProduitResultant);
  }
  
  public ConstitutionProduitResultant getConstitutionProduitResultant()
  {
    return getConstitutionElementsAdmission().getConstitutionProduitResultant();
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    return getConstitutionElementsAdmission().getConstitutionCoefficientSaisonnier();
  }
  
  public void setConstitutionCoefficientSaisonnier(ConstitutionCoefficientSaisonnier constitutionCoefficientSaisonnier)
  {
    getConstitutionElementsAdmission().setConstitutionCoefficientSaisonnier(constitutionCoefficientSaisonnier);
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    return getConstitutionElementsAdmission().getConstitutionCaractereSaisonnier();
  }
  
  public void setConstitutionCaractereSaisonnier(ConstitutionCaractereSaisonnier constitutionCaractereSaisonnier)
  {
    getConstitutionElementsAdmission().setConstitutionCaractereSaisonnier(constitutionCaractereSaisonnier);
  }
  
  public void setConstitutionCoefficientTempsPartiel(ConstitutionCoefficientTempsPartiel constitutionCoefficientTempsPartiel)
  {
    getConstitutionElementsAdmission().setConstitutionCoefficientTempsPartiel(constitutionCoefficientTempsPartiel);
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsAdmission().getConstitutionCoefficientTempsPartiel();
  }
  
  public DossierExamenSpec changerEtat(int typeDossierExamen)
    throws CoucheLogiqueException
  {
    DossierExamen nouveauDossier = null;
    switch (typeDossierExamen)
    {
    case 0: 
      nouveauDossier = new Examen();
      break;
    case 10: 
      nouveauDossier = new Od();
      break;
    case 11: 
      nouveauDossier = new Readmission();
      break;
    case 16: 
    case 28: 
    case 33: 
    case 36: 
      nouveauDossier = new Rejet();
      break;
    case 3: 
      nouveauDossier = new Reprise();
      break;
    case 47: 
    case 48: 
      nouveauDossier = new Novation();
      break;
    case 46: 
      nouveauDossier = new RepriseAssociee();
      break;
    case 49: 
      nouveauDossier = new PoursuiteIndemnisation();
      break;
    case 1: 
    case 2: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 12: 
    case 13: 
    case 14: 
    case 15: 
    case 17: 
    case 18: 
    case 19: 
    case 20: 
    case 21: 
    case 22: 
    case 23: 
    case 24: 
    case 25: 
    case 26: 
    case 27: 
    case 29: 
    case 30: 
    case 31: 
    case 32: 
    case 34: 
    case 35: 
    case 37: 
    case 38: 
    case 39: 
    case 40: 
    case 41: 
    case 42: 
    case 43: 
    case 44: 
    case 45: 
    default: 
      throw new UnsupportedOperationException("Impossible de changer l'etat du dossier d'examen vers le nouvel etat : " + typeDossierExamen);
    }
    if (nouveauDossier != null) {
      nouveauDossier.copie(this);
    }
    return nouveauDossier;
  }
  
  public String toString()
  {
    StringBuffer sb = new StringBuffer();
    sb.append("DossierExamen:");
    return sb.toString();
  }
  
  public boolean estDroitSaisonnier()
  {
    if (getConstitutionElementsAdmission().getConstitutionCaractereSaisonnier() != null)
    {
      int caractereSaisonnier = getConstitutionElementsAdmission().getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
      switch (caractereSaisonnier)
      {
      case 1: 
      case 2: 
        return true;
      }
      return false;
    }
    return false;
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getConditionsAttributionAdmission());
    DomManager.supprimer(super.getConditionsAttributionReprise());
    DomManager.supprimer(super.getConstitutionElementsAdmission());
    DomManager.supprimer(super.getConstitutionElementsReprise());
    DomManager.supprimer(super.getCompetence());
    DomManager.supprimer(super.getContributionParticuliere());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionsAttributionAdmission());
    DomManager.persisterEnProfondeur(super.getConditionsAttributionReprise());
    DomManager.persisterEnProfondeur(super.getConstitutionElementsAdmission());
    DomManager.persisterEnProfondeur(super.getConstitutionElementsReprise());
    DomManager.persisterEnProfondeur(super.getCompetence());
    DomManager.persisterEnProfondeur(super.getContributionParticuliere());
    DomManager.persisterEnProfondeur(super.getCompetenceSousJacente());
  }
  
  public Damj getDateAttribution()
  {
    if (getConstitutionDateAttribution() != null) {
      return getConstitutionDateAttribution().getDateAttribution();
    }
    return null;
  }
  
  public Damj getDateEvenement()
  {
    return getDateAttribution();
  }
  
  public void setDateEvenement(Damj dateEvenement)
  {
    m_dateEvenement = dateEvenement;
  }
  
  public AccesseurDroitsSpec getAccesseurDroits()
  {
    return accesseurDroits != null ? accesseurDroits : new AccesseurDroits(this);
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreStore() {}
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    DossierExamen copie = (DossierExamen)pCopie;
    if (getConditionsAttributionAdmission() != null) {
      copie.setConditionsAttributionAdmission((ConditionsAttributionAdmission)getConditionsAttributionAdmission().copie());
    }
    if (getConstitutionElementsAdmission() != null) {
      copie.setConstitutionElementsAdmission((ConstitutionElementsAdmission)getConstitutionElementsAdmission().copie());
    }
    if (getConditionsAttributionReprise() != null) {
      copie.setConditionsAttributionReprise((ConditionsAttributionReprise)getConditionsAttributionReprise().copie());
    }
    if (getConstitutionElementsReprise() != null) {
      copie.setConstitutionElementsReprise((ConstitutionElementsReprise)getConstitutionElementsReprise().copie());
    }
    if (getCompetence() != null) {
      copie.setCompetence((Competence)getCompetence().copie());
    }
    if (getCompetenceSousJacente() != null) {
      copie.setCompetenceSousJacente((Competence)getCompetenceSousJacente().copie());
    }
    copie.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copie.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copie.setDateEvenement(getDateEvenement());
    copie.setAttributionPrecedente(getAttributionPrecedente());
  }
  
  public FaitGenerateurSpec getFaitGenerateur()
  {
    return getConditionFaitGenerateur();
  }
  
  public ReglementApplicableSpec getReglementApplicable()
  {
    return getConstitutionReglementApplicable();
  }
  
  public CompetenceSpec getCompetence()
  {
    if (super.getCompetence() != null) {
      return super.getCompetence();
    }
    CompetenceSpec competenceAdministrativeParDefaut = new Competence();
    competenceAdministrativeParDefaut.setCompetenceFinanciere(1);
    competenceAdministrativeParDefaut.setCompetenceAdministrative(1);
    return competenceAdministrativeParDefaut;
  }
  
  public void setCompetence(CompetenceSpec competence)
  {
    DomManager.supprimer(super.getCompetence(), competence);
    super.setCompetence((Competence)competence);
  }
  
  public void setCompetenceSousJacente(CompetenceSpec competenceSousJacente)
  {
    DomManager.supprimer(super.getCompetenceSousJacente(), competenceSousJacente);
    super.setCompetenceSousJacente((Competence)competenceSousJacente);
  }
  
  public abstract JustificationAffiliationSpec getJustificationAffiliation();
  
  public void setContributionParticuliere(ContributionParticuliereSpec contributionParticuliere)
  {
    DomManager.supprimer(super.getContributionParticuliere(), contributionParticuliere);
    super.setContributionParticuliere((ContributionParticuliere)contributionParticuliere);
  }
  
  public boolean estRejetDV()
  {
    if ((getConditionChomageInvolontaire() != null) && (!getConditionChomageInvolontaire().estSatisfait())) {
      return true;
    }
    return false;
  }
  
  public List getListConditionsAttribution()
  {
    return getConditionsAttributionActives().getListeConditionsAttribution();
  }
  
  public void setDateFinPerteActiviteConservee(Damj dateFinPerteActiviteConservee)
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public void setMotifFinPerteActiviteConservee(String motifFinPerteActiviteConservee)
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public Damj getDateFinPerteActiviteConservee()
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public String getMotifFinPerteActiviteConservee()
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public boolean isEstSinistreOuCalamiteNaturelle()
  {
    return false;
  }
  
  public DemandeAssuranceSpec getDemandeAssurance()
  {
    return (DemandeAssuranceSpec)getDemande();
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
  }
  
  public OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
  }
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifAdmission()
  {
    return getConditionsAttributionAdmission();
  }
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifReprise()
  {
    return getConditionsAttributionReprise();
  }
}

/* Location:
 * Qualified Name:     DossierExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */