package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.SjcipGen;
import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjcipSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class Sjcip
  extends SjcipGen
  implements ObjetPersistantSpec, SjcipSpec
{
  private static final long serialVersionUID = 3780773529710661873L;
  
  public Sjcip() {}
  
  public Sjcip(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public Sjcip(Damj p_dateEffet, QuantiteEuro p_plafond, QuantiteEuro p_sjcInitial)
  {
    super(p_dateEffet);
    super.setPlafond(p_plafond);
    super.setSjcInitial(p_sjcInitial);
  }
  
  public Collection getListeSjrActiviteConserve()
  {
    return super.getCollectionSjrActiviteConservee();
  }
  
  public BigDecimal getSjcip()
  {
    BigDecimal valeurSjcip = new BigDecimal("0");
    if ((getSjcInitial() != null) && (getPlafond() != null)) {
      valeurSjcip = getSjcInitial().getValeur().min(getPlafond().getValeur());
    } else if (getSjcInitial() != null) {
      valeurSjcip = getSjcInitial().getValeur();
    } else if (getPlafond() != null) {
      valeurSjcip = getPlafond().getValeur();
    }
    return valeurSjcip;
  }
  
  public void ajouterSjrActiviteConserve(SjrActiviteConservee p_sjrActiviteConservee)
  {
    if (p_sjrActiviteConservee != null) {
      super.ajouterSjrActiviteConservee(p_sjrActiviteConservee);
    }
  }
  
  public void supprimerSjrActiviteConserve(SjrActiviteConservee p_sjrActiviteConservee)
  {
    if (p_sjrActiviteConservee != null)
    {
      super.supprimerSjrActiviteConservee(p_sjrActiviteConservee);
      DomManager.supprimer(p_sjrActiviteConservee);
    }
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString() + "\n");
    chaineRetour.append("Plafond Sjc : " + super.getPlafond() + "\n");
    chaineRetour.append("Sjc Initial : " + super.getSjcInitial() + "\n");
    chaineRetour.append("Liste Sjr Activité Conservée : " + getCollectionSjrActiviteConservee() + "\n");
    return chaineRetour.toString();
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(getCollectionSjrActiviteConservee());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(getCollectionSjrActiviteConservee());
  }
  
  public void jdoPreStore() {}
  
  public ObjetMetierSpec copie()
  {
    Sjcip copie = new Sjcip();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Sjcip copie = (Sjcip)p_copie;
    copie.setDateEvenement(getDateEvenement());
    
    Iterator iter = getListeSjrActiviteConserve().iterator();
    while (iter.hasNext())
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      copie.ajouterSjrActiviteConserve((SjrActiviteConservee)element.copie());
    }
    copie.setPlafond(getPlafond());
    copie.setSjcInitial(getSjcInitial());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void ajouterSjrActiviteConservee(SjrActiviteConserveeSpec sjrActiviteConserveeConstitutionSjc)
  {
    ajouterSjrActiviteConservee((SjrActiviteConservee)sjrActiviteConserveeConstitutionSjc);
  }
  
  public void remplacerCollectionSjrActiviteConservee(Collection collectionACopier)
  {
    for (Iterator i = collectionACopier.iterator(); i.hasNext();)
    {
      SjrActiviteConservee objet = (SjrActiviteConservee)i.next();
      DomManager.supprimer(objet);
    }
    super.remplacerCollectionSjrActiviteConservee(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     Sjcip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */