package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.PrcSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.parametres.AccesSalaireForfaitaireJournalierCategorieA2B;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutAvantDate;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class DeterminationSjcip
  implements OutilFonctionnel
{
  private static final BigDecimal VALEUR_NULLE = new BigDecimal("0");
  
  public static Sjcip determinerSjcip(Demande p_demandeCourante, Sjrip p_sjripCourant)
    throws CoucheLogiqueException
  {
    Sjcip sjcipCourant = null;
    
    ChronologiePeriodes chronoActivitesSalarieesConservees = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesSalarieesConservees(p_demandeCourante);
    
    Periode periodePrcSjcCourante = determinerPeriodePrcSjcCourante(p_demandeCourante, p_sjripCourant);
    
    ChronologiePeriodes chronoActivitesSalarieesConserveesRetenuesPourSjcip = (ChronologiePeriodes)chronoActivitesSalarieesConservees.copier(new FiltreDebutAvantDate(periodePrcSjcCourante.getFin()));
    if (Log.isTraceActive(DeterminationSjcip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjcip.class, "determinerSjcip", "Chronologie des activités salariées conservées participant au SJCIP : " + chronoActivitesSalarieesConserveesRetenuesPourSjcip);
    }
    QuantiteEuro quantiteSjciCumule = calculerSjciCumule(p_demandeCourante, chronoActivitesSalarieesConserveesRetenuesPourSjcip, periodePrcSjcCourante);
    
    ArrayList listeSjrActiviteConservee = determinerListeSjrActiviteConservee(p_demandeCourante, chronoActivitesSalarieesConserveesRetenuesPourSjcip, periodePrcSjcCourante);
    
    Damj dateEffetSjcip = periodePrcSjcCourante.getFin();
    
    sjcipCourant = determinerSjcipCourant(dateEffetSjcip, quantiteSjciCumule, p_sjripCourant, listeSjrActiviteConservee);
    
    return sjcipCourant;
  }
  
  private static SjrActiviteConservee determinerSjrActiviteConservee(Demande p_demande, ActiviteSalarie p_activiteSalarieeConservee, Periode p_periodePrcSjcCourante)
    throws CoucheLogiqueException
  {
    SjrActiviteConservee sjrActiviteConserveeRetourne = null;
    QuantiteEuro sjri = null;
    if (Log.isTraceActive(DeterminationSjcip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjcip.class, "determinerSjrActiviteConservee", "Début de la détermination du SjrActiviteConservee.");
    }
    Chronologie chronoPeriodesDeductiblesPrcSjcCourante = ConstructionChronologie.determinerChronoPeriodesDeductiblesPrc(p_demande, p_periodePrcSjcCourante);
    if (Log.isTraceActive(DeterminationSjcip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjcip.class, "determinerSjcip", "Chronologie des Périodes Déductibles chevauchant la PrcSjc courante : " + chronoPeriodesDeductiblesPrcSjcCourante);
    }
    PrcSjc prcSjcCourante = new PrcSjc(p_periodePrcSjcCourante, p_activiteSalarieeConservee, chronoPeriodesDeductiblesPrcSjcCourante);
    
    Reglement reglementApplicable = p_activiteSalarieeConservee.getReglement();
    if (reglementApplicable.equals(ProduitAsuCge01P02.getInstance().getReglement("A2b")))
    {
      sjrActiviteConserveeRetourne = determinerSjrActiviteConserveeA2B(p_activiteSalarieeConservee, p_demande.getDossierExamen().getDateAttribution());
    }
    else
    {
      prcSjcCourante.determinerSrip(p_demande, reglementApplicable, false);
      
      sjri = prcSjcCourante.getSjri();
      
      sjrActiviteConserveeRetourne = new SjrActiviteConservee(sjri);
    }
    prcSjcCourante.viderChronologies();
    sjrActiviteConserveeRetourne.setPrc(prcSjcCourante);
    
    sjrActiviteConserveeRetourne.setPeriodeActiviteConservee(p_activiteSalarieeConservee);
    
    return sjrActiviteConserveeRetourne;
  }
  
  private static SjrActiviteConservee determinerSjrActiviteConserveeA2B(ActiviteSalarie p_activiteSalarieeConservee, Damj p_dateAttribution)
  {
    SjrActiviteConservee sjrActiviteConserveeRetourne = null;
    
    BigDecimal salaireForfaitaireJournalier = AccesSalaireForfaitaireJournalierCategorieA2B.getInstance().get(p_activiteSalarieeConservee.getMetier().getCodeEmploi(), p_dateAttribution);
    
    sjrActiviteConserveeRetourne = new SjrActiviteConservee(new QuantiteEuro(salaireForfaitaireJournalier));
    
    return sjrActiviteConserveeRetourne;
  }
  
  public static Sjc revaloriserSjcip(Damj p_dateRevalorisation, Sjcip p_sjcip)
  {
    Sjc sjcCourant = new Sjc(p_sjcip.getSjcInitial().getValeur(), p_sjcip.getDateEffet(), null);
    
    Sjc sjcrpCalcule = RevalorisationSalaire.revaloriserSjc(sjcCourant, p_dateRevalorisation);
    
    return sjcrpCalcule;
  }
  
  private static void leverAlerteA11MNB6SurActiviteConserveeEnConflit(Demande p_demande, ActiviteSalarie p_periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    
    String codeAlerteNonBloquante = "A11MNB6";
    if (p_demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)p_demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(p_periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(p_periodeActiviteSalarieCourante));
      p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
  
  public static Periode determinerPeriodePrcSjcCourante(Demande p_demandeCourante, Sjrip p_sjripCourant)
  {
    Periode periodePrcSjcCourante = null;
    Prc prcCourante = p_sjripCourant.getPrc();
    if (prcCourante != null) {
      periodePrcSjcCourante = new Periode(prcCourante.getDateDebut(), prcCourante.getDateFin());
    } else {
      periodePrcSjcCourante = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerPrcSjcipRaA2b(p_demandeCourante);
    }
    if (Log.isTraceActive(DeterminationSjcip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjcip.class, "determinerSjcip", "Période PrcSjc courante : " + periodePrcSjcCourante);
    }
    return periodePrcSjcCourante;
  }
  
  public static QuantiteEuro calculerSjciCumule(Demande p_demandeCourante, ChronologiePeriodes p_chronoActivitesSalarieesConserveesRetenuesPourSjcip, Periode p_periodePrcSjcCourante)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoActivitesSalarieesConserveesRetenuesPourSjcipSuspendu = new ChronologiePeriodes();
    p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.iterer();
    ActiviteSalarie activiteSalarieeConserveeCourante = null;
    boolean bLeveeAlerte = false;
    boolean bContinue = true;
    while (p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.elementSuivant();
      Chronologie periodesSuspension = activiteSalarieeConserveeCourante.getListePeriodesIncident().copier(new FiltreIncident());
      if ((periodesSuspension != null) && (!periodesSuspension.estVide()))
      {
        bContinue = true;
        for (Iterator iterperiodeSuspension = periodesSuspension.iterer(); (iterperiodeSuspension.hasNext()) && (bContinue);)
        {
          IncidentSpec suspension = (IncidentSpec)iterperiodeSuspension.next();
          if (suspension.getPeriode().chevauche(p_periodePrcSjcCourante)) {
            if (suspension.estTempsPlein())
            {
              bLeveeAlerte = true;
            }
            else
            {
              bContinue = false;
              bLeveeAlerte = false;
            }
          }
        }
        if (bLeveeAlerte) {
          chronoActivitesSalarieesConserveesRetenuesPourSjcipSuspendu.ajouter(activiteSalarieeConserveeCourante);
        }
      }
      if (!bLeveeAlerte)
      {
        Periode tmpPeriode = new Periode();
        if (activiteSalarieeConserveeCourante.getDateDebut().estAvantOuCoincideAvec(p_periodePrcSjcCourante.getDebut())) {
          tmpPeriode.setDebut(p_periodePrcSjcCourante.getDebut());
        } else {
          tmpPeriode.setDebut(activiteSalarieeConserveeCourante.getDateDebut());
        }
        if (activiteSalarieeConserveeCourante.getDateFin().estApresOuCoincideAvec(p_periodePrcSjcCourante.getFin())) {
          tmpPeriode.setFin(p_periodePrcSjcCourante.getFin());
        } else {
          tmpPeriode.setFin(activiteSalarieeConserveeCourante.getDateFin());
        }
        Chronologie chronoSalaires = activiteSalarieeConserveeCourante.getListeSalaires();
        Salaire periodeSalaireCourant = null;
        chronoSalaires.iterer();
        bContinue = true;
        while ((chronoSalaires.encoreSuivant()) && (bContinue))
        {
          periodeSalaireCourant = (Salaire)chronoSalaires.elementSuivant();
          if (periodeSalaireCourant.getPeriode().estContenueDans(p_periodePrcSjcCourante))
          {
            Quantite qteAbscence = periodeSalaireCourant.getQuantiteAbsence();
            if (qteAbscence != null)
            {
              bLeveeAlerte = true;
            }
            else
            {
              bLeveeAlerte = false;
              
              bContinue = false;
            }
          }
        }
        if (bLeveeAlerte) {
          chronoActivitesSalarieesConserveesRetenuesPourSjcipSuspendu.ajouter(activiteSalarieeConserveeCourante);
        }
      }
    }
    BigDecimal sjci = new BigDecimal("0");
    p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.iterer();
    activiteSalarieeConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveeCourante = null;
    while (p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.elementSuivant();
      if (activiteSalarieeConserveeCourante.estEnConflit()) {
        leverAlerteA11MNB6SurActiviteConserveeEnConflit(p_demandeCourante, activiteSalarieeConserveeCourante);
      }
      if (activiteSalarieeConserveeCourante.getEntreprise().getIdentifiantBNE() == null)
      {
        Damj dateFCTDamj = activiteSalarieeConserveeCourante.getDateDebut();
        String dateFCTString = dateFCTDamj.formater();
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB10", new String[] { dateFCTString });
      }
      sjrActiviteConserveeCourante = determinerSjrActiviteConservee(p_demandeCourante, activiteSalarieeConserveeCourante, p_periodePrcSjcCourante);
      
      sjci = sjci.add(sjrActiviteConserveeCourante.getSjrInitial().getValeurMontant());
    }
    boolean activitesTotalementSuspendu = false;
    if (chronoActivitesSalarieesConserveesRetenuesPourSjcipSuspendu.equals(p_chronoActivitesSalarieesConserveesRetenuesPourSjcip)) {
      activitesTotalementSuspendu = true;
    }
    if ((p_demandeCourante.getDonneesTemporaires().getSjc() == null) && 
      (!p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.estVide()) && (sjci.compareTo(VALEUR_NULLE) == 0) && (!activitesTotalementSuspendu))
    {
      Damj dateFCTDamj = p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB9", new String[] { dateFCTString });
    }
    QuantiteEuro quantiteSjciCumule = new QuantiteEuro(sjci);
    
    return quantiteSjciCumule;
  }
  
  public static ArrayList determinerListeSjrActiviteConservee(Demande p_demandeCourante, ChronologiePeriodes p_chronoActivitesSalarieesConserveesRetenuesPourSjcip, Periode p_periodePrcSjcCourante)
    throws CoucheLogiqueException
  {
    ArrayList listeSjrActiviteConservee = new ArrayList();
    p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.iterer();
    ActiviteSalarie activiteSalarieeConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveeCourante = null;
    while (p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConserveesRetenuesPourSjcip.elementSuivant();
      if (activiteSalarieeConserveeCourante.estEnConflit()) {
        leverAlerteA11MNB6SurActiviteConserveeEnConflit(p_demandeCourante, activiteSalarieeConserveeCourante);
      }
      if (activiteSalarieeConserveeCourante.getEntreprise().getIdentifiantBNE() == null)
      {
        Damj dateFCTDamj = activiteSalarieeConserveeCourante.getDateDebut();
        String dateFCTString = dateFCTDamj.formater();
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB10", new String[] { dateFCTString });
      }
      sjrActiviteConserveeCourante = determinerSjrActiviteConservee(p_demandeCourante, activiteSalarieeConserveeCourante, p_periodePrcSjcCourante);
      
      listeSjrActiviteConservee.add(sjrActiviteConserveeCourante);
    }
    return listeSjrActiviteConservee;
  }
  
  public static Sjcip determinerSjcipCourant(Damj p_dateEffetSjcip, QuantiteEuro p_sjcInitial, Sjrip p_sjripCourant, ArrayList p_listeSjrActiviteConservee)
  {
    Sjcip sjcipCourant = null;
    QuantiteEuro quantitePlafondSjcip = new QuantiteEuro(p_sjripCourant.getPlafondSjr().getValeurMontant());
    
    sjcipCourant = new Sjcip(p_dateEffetSjcip, quantitePlafondSjcip, p_sjcInitial);
    
    Iterator iterateur = p_listeSjrActiviteConservee.iterator();
    while (iterateur.hasNext()) {
      sjcipCourant.ajouterSjrActiviteConserve((SjrActiviteConservee)iterateur.next());
    }
    return sjcipCourant;
  }
}

/* Location:
 * Qualified Name:     DeterminationSjcip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */