package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.cge01.p02.liquidation.parcours.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Temporel;
import java.util.Iterator;
import java.util.List;

public class RechercheConditionChomageInvolontaire
  implements OutilFonctionnel
{
  public static ResultatRechercheConditionChomageInvolontaire rechercherConditionChomageInvolontaire(Demande p_demande, Damj p_fctDV, Reglement p_reglementApplicable)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultat.setResultatElementDroit(resultatElementDroit);
    
    Pra pra = ConstructionPra.determinerPraDv(p_demande, p_fctDV, p_reglementApplicable);
    
    Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(pra, p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipanteTousReglements = ConstructionChronologie.determinerChronoPraTousReglement(pra, p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipante = new ChronologiePeriodes();
    chronoActiviteParticipante.ajouter(chronoActivitesAssimilables);
    chronoActiviteParticipante.ajouter(chronoActiviteParticipanteTousReglements);
    
    chronoActiviteParticipante = chronoActiviteParticipante.copier(new FiltreFinDansBornes(pra.getDebut(), pra.getFin()));
    
    boolean quantiteAppartenance = verifierConditionAffiliation(p_demande, pra, chronoActiviteParticipante);
    if (quantiteAppartenance)
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
      resultat.setSituationConditionChomageInvolontaire(3);
    }
    else
    {
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.setSituationConditionChomageInvolontaire(4);
      resultat.getResultatElementDroit().setCodeMotifEchec(92);
    }
    return resultat;
  }
  
  private static boolean verifierConditionAffiliation(DemandeSpec p_demande, Pra p_pra, Chronologie p_chronoPAS)
    throws ApplicativeException
  {
    ValidationProduitSpec validationProduit = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit();
    ActiviteSalarie periodeActiviteSalariee = null;
    if ((validationProduit == null) || (!validationProduit.isEstProduitValide()))
    {
      AttributionSpec attributionOrigine = ((DemandeAssuranceSpec)p_demande).rechercherOuvertureDroitPrecedenteDuMemeType();
      if (attributionOrigine != null)
      {
        DossierAffectation dossierAffectationOrigine = (DossierAffectation)attributionOrigine.getDemande().getDossierAffectation();
        validationProduit = dossierAffectationOrigine.getValidationProduit();
      }
    }
    if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
      periodeActiviteSalariee = validationProduit.getPeriodeValidationProduit();
    } else {
      periodeActiviteSalariee = (ActiviteSalarie)((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
    }
    Reglement reglementAppartenance = periodeActiviteSalariee.getReglement();
    
    QuantitesAppartenance quantitesAppartenance = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_demande, null, p_pra, p_chronoPAS, reglementAppartenance);
    
    List listeUnites = AccesListeUnitesReglement.get(reglementAppartenance, null).getListeUnites();
    for (Iterator iter = listeUnites.iterator(); iter.hasNext();)
    {
      Unite unite = (Unite)iter.next();
      Quantite qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      
      Quantite qteAcquise = qteAffiliation.ajouter(qteAssimilation);
      Quantite qteRequise = p_pra.getQuantiteAffiliationRequise(unite);
      if ((qteRequise != null) && (qteAcquise.compareTo(qteRequise) >= 0)) {
        return true;
      }
    }
    return false;
  }
  
  public static Reglement verificationReglementNonNull(Reglement p_reglement, int p_justificationAffectation)
    throws CoucheLogiqueException
  {
    Reglement reglement = p_reglement;
    if (p_reglement == null)
    {
      if ((p_justificationAffectation == 5) || (p_justificationAffectation == 6)) {
        reglement = ProduitAsuCge01P02.getInstance().getReglement("RG");
      }
      if (reglement == null) {
        if (Log.isTraceActive(DeterminationConditionChomageInvolontaire.class, Niveau.DEBUG))
        {
          Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "Règlement porté par la période de validation du produit nul et affectation différente du produit de secours : règlement indéterminable");
          
          throw new CoucheLogiqueException("HG_PR_CALI_L_ERR_CONTEXTE", "Règlement porté par la période de validation du produit nul et affectation différente du produit de secours : règlement indéterminable");
        }
      }
    }
    return reglement;
  }
  
  public static void traiterSituation1(Demande p_demandeAssurance, Reglement p_reglementApplicable, ResultatRechercheConditionChomageInvolontaire p_resultat)
  {
    if ((p_reglementApplicable != null) && (p_reglementApplicable.equals(ProduitAsuCge01P02.getInstance().getReglement("A3"))))
    {
      p_resultat.getResultatElementDroit().setEtatSatisfait(false);
      p_resultat.setSituationConditionChomageInvolontaire(1);
      p_resultat.getResultatElementDroit().setCodeMotifEchec(91);
    }
    else
    {
      boolean conditionQuantiteAffiliationObjectifAdmissionSatisfaite = false;
      DossierExamenSpec dossierExamenObjectifAdmission = p_demandeAssurance.getDossierExamen(1);
      if ((dossierExamenObjectifAdmission != null) && (((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation() != null)) {
        conditionQuantiteAffiliationObjectifAdmissionSatisfaite = ((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation().estSatisfait();
      }
      if (dossierExamenObjectifAdmission != null)
      {
        if (!conditionQuantiteAffiliationObjectifAdmissionSatisfaite)
        {
          p_resultat.getResultatElementDroit().setEtatSatisfait(true);
          p_resultat.setSituationConditionChomageInvolontaire(2);
        }
        else
        {
          p_resultat.getResultatElementDroit().setEtatSatisfait(false);
          p_resultat.setSituationConditionChomageInvolontaire(1);
          p_resultat.getResultatElementDroit().setCodeMotifEchec(91);
        }
      }
      else
      {
        p_resultat.getResultatElementDroit().setEtatSatisfait(true);
        p_resultat.setSituationConditionChomageInvolontaire(2);
      }
    }
  }
  
  public static void traiterSituation2(Demande p_demandeAssurance, Reglement p_reglementApplicable, ResultatRechercheConditionChomageInvolontaire p_resultat)
    throws ApplicativeException
  {
    if (p_reglementApplicable.equals(ProduitAsuCge01P02.getInstance().getReglement("A3")))
    {
      p_resultat.getResultatElementDroit().setEtatSatisfait(true);
      p_resultat.setSituationConditionChomageInvolontaire(2);
    }
    else
    {
      Chronologie chronologieActivitesDV = ConstructionChronologie.determinerChronoActivitesDV(p_demandeAssurance);
      
      FiltresTemporel filtreJustifieeEnConflit = new FiltresTemporel();
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesAvecConflit());
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesJustifiees());
      if (!chronologieActivitesDV.copier(filtreJustifieeEnConflit).estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB3");
      }
      if (chronologieActivitesDV.estVide())
      {
        p_resultat.getResultatElementDroit().setEtatSatisfait(true);
        p_resultat.setSituationConditionChomageInvolontaire(2);
      }
      else
      {
        Temporel derniereActivite = chronologieActivitesDV.premierElement();
        Damj dateFCTDVLaPlusRecente = derniereActivite.getDateFin();
        
        ResultatRechercheConditionChomageInvolontaire resultat = rechercherConditionChomageInvolontaire(p_demandeAssurance, dateFCTDVLaPlusRecente, p_reglementApplicable);
        
        p_resultat.getResultatElementDroit().setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
        p_resultat.getResultatElementDroit().setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
        p_resultat.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
      }
    }
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierChomageInvolontaireExamen122Jour(Demande p_demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultat.setResultatElementDroit(resultatElementDroit);
    if (p_demandeAssurance.getDonneesTemporaires().estAvisFavorableCommissionParitaire())
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
    }
    else if (p_demandeAssurance.getDonneesTemporaires().estAvisDefavorableCommissionParitaire())
    {
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.getResultatElementDroit().setCodeMotifEchec(93);
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB5");
    }
    fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().leverAlerteA11MB26(p_demandeAssurance);
    return resultat;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */