package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.JustificationSjc;
import fr.unedic.cali.asu.cge01.p02.parametres.Parametres;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.Map;

public class RechercheConditionCumulActiviteConservee
  implements OutilFonctionnel
{
  private static final BigDecimal COEFFICIENT_MENSUEL = new BigDecimal("30");
  
  public static ConditionActiviteConservee rechercherConditionCumulActiviteConservee(Demande demande, Chronologie chronoActivitesSalarieesConservees)
    throws CoucheLogiqueException
  {
    ConditionActiviteConservee conditionActiviteConservee = new ConditionActiviteConservee();
    if (!demande.getDonneesTemporaires().isEstLeveeConditionACMemeEmployeur())
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarie());
      filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtres.ajouterFiltre(new FiltrePeriodesQualifiables());
      filtres.ajouterFiltre(new FiltreMemeDateFin(demande.getFaitGenerateur().getDateFaitGenerateur()));
      Chronologie chronoActivitesSalarieesPerduesAuFgd = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      
      ActiviteSalarie activiteSalariePerdueCourante = null;
      ActiviteSalarie activiteSalarieConserveeCourante = null;
      String employeurActivitePerdue = null;
      String employeurActiviteConservee = null;
      do
      {
        chronoActivitesSalarieesPerduesAuFgd.iterer();
        while (!chronoActivitesSalarieesConservees.encoreSuivant())
        {
          if (!chronoActivitesSalarieesPerduesAuFgd.encoreSuivant()) {
            break;
          }
          activiteSalariePerdueCourante = (ActiviteSalarie)chronoActivitesSalarieesPerduesAuFgd.elementSuivant();
          
          employeurActivitePerdue = activiteSalariePerdueCourante.getEntreprise().getIdentifiantBNE();
          
          chronoActivitesSalarieesConservees.iterer();
        }
        activiteSalarieConserveeCourante = (ActiviteSalarie)chronoActivitesSalarieesConservees.elementSuivant();
        
        employeurActiviteConservee = activiteSalarieConserveeCourante.getEntreprise().getIdentifiantBNE();
      } while (employeurActiviteConservee.compareTo(employeurActivitePerdue) != 0);
      conditionActiviteConservee.setEtatSatisfait(false);
      conditionActiviteConservee.setCodeMotifEchec(122);
      conditionActiviteConservee.setSituationConditionActiviteConservee(1);
      return conditionActiviteConservee;
    }
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demande);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    boolean estReglementApplicableA4 = reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A4"));
    if ((strategieActiviteConservee.verifierSeuilsConditionActiviteConservee(estReglementApplicableA4)) && (!demande.getDonneesTemporaires().isConditionCumulActiviteConserveeRemplie()))
    {
      Periode periodeMoisCivilPrecedantDateExamen = determinerMoisCivilPrecedantDateExamen(demande);
      BigDecimal heuresActiviteConserveeSurMoisCivil = determinerHeuresActiviteConserveeSurMoisCivil(periodeMoisCivilPrecedantDateExamen, chronoActivitesSalarieesConservees);
      
      conditionActiviteConservee.setNombreHeuresMensuelActiviteConservee(heuresActiviteConserveeSurMoisCivil);
      
      JustificationSjc justificationSjc = new JustificationSjc();
      justificationSjc.setSeuilHoraire(Parametres.PLAFOND_HORAIRE_ACTIVITES_CONSERVEES);
      ((DossierExamen)demande.getDossierExamen()).getConstitutionSjc().setJustificationSjc(justificationSjc);
      if (heuresActiviteConserveeSurMoisCivil.compareTo(Parametres.PLAFOND_HORAIRE_ACTIVITES_CONSERVEES) > 0)
      {
        conditionActiviteConservee.setEtatSatisfait(false);
        conditionActiviteConservee.setSituationConditionActiviteConservee(2);
        conditionActiviteConservee.setCodeMotifEchec(121);
        return conditionActiviteConservee;
      }
      BigDecimal remunerationBruteConserveeSurMoisCivil = determinerRemunerationBruteConserveeSurMoisCivil(periodeMoisCivilPrecedantDateExamen, chronoActivitesSalarieesConservees);
      
      BigDecimal remunerationMensuelleBruteAvantPerteActivite = determinerRemunerationMensuelleBruteAvantPerteActivite(demande);
      BigDecimal plafondMensuelRemuneration = Parametres.POURCENTAGE_PLAFOND_REMUNERATION_ACTIVITES_CONSERVEES.multiply(remunerationMensuelleBruteAvantPerteActivite);
      conditionActiviteConservee.setMontantMensuelActiviteConservee(remunerationBruteConserveeSurMoisCivil);
      conditionActiviteConservee.setSeuilMontantMensuelActiviteConservee(plafondMensuelRemuneration);
      if (remunerationBruteConserveeSurMoisCivil.compareTo(plafondMensuelRemuneration) > 0)
      {
        conditionActiviteConservee.setEtatSatisfait(false);
        conditionActiviteConservee.setSituationConditionActiviteConservee(3);
        conditionActiviteConservee.setCodeMotifEchec(121);
        return conditionActiviteConservee;
      }
    }
    conditionActiviteConservee.setEtatSatisfait(true);
    conditionActiviteConservee.setSituationConditionActiviteConservee(4);
    
    return conditionActiviteConservee;
  }
  
  private static Periode determinerMoisCivilPrecedantDateExamen(Demande p_demande)
  {
    Damj dateDebutMoisCivil = null;
    Damj dateFinMoisCivil = null;
    
    Damj dateExamen = p_demande.getDateExamen();
    if (dateExamen.estLaFinDuMois())
    {
      dateFinMoisCivil = dateExamen;
      dateDebutMoisCivil = dateExamen.getDebutMois();
    }
    else
    {
      dateFinMoisCivil = dateExamen.getFinMoisPrecedent();
      dateDebutMoisCivil = dateFinMoisCivil.getDebutMois();
    }
    return new Periode(dateDebutMoisCivil, dateFinMoisCivil);
  }
  
  private static BigDecimal determinerHeuresActiviteConserveeSurMoisCivil(Periode p_moisCivil, Chronologie p_chronoActivitesSalarieesConservees)
  {
    BigDecimal cumulHeures = new BigDecimal("0");
    Unite uniteHeure = Unite.get("heure de travail");
    
    ActiviteSalarie activiteSalarieConserveeCourante = null;
    Map<Unite, Quantite> tableQuantitesAffiliationProratiseesSurMois = null;
    p_chronoActivitesSalarieesConservees.iterer();
    while (p_chronoActivitesSalarieesConservees.encoreSuivant())
    {
      activiteSalarieConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConservees.elementSuivant();
      if ((!activiteSalarieConserveeCourante.getReglement().equals(ProduitAsuCge01P02.getInstance().getReglement("A1"))) && (activiteSalarieConserveeCourante.getCategorieEmploiParticulier() != 22) && (activiteSalarieConserveeCourante.getCategorieEmploiParticulier() != 23))
      {
        tableQuantitesAffiliationProratiseesSurMois = activiteSalarieConserveeCourante.determinerQuantitesAffiliationArrondie(p_moisCivil);
        cumulHeures = cumulHeures.add(((Quantite)tableQuantitesAffiliationProratiseesSurMois.get(uniteHeure)).getValeur());
      }
    }
    return cumulHeures;
  }
  
  private static BigDecimal determinerRemunerationBruteConserveeSurMoisCivil(Periode p_moisCivil, Chronologie p_chronoActivitesSalarieesConservees)
    throws CoucheLogiqueException
  {
    BigDecimal cumulRemuneration = new BigDecimal("0");
    BigDecimal remunerationCouranteMoisCivil = new BigDecimal("0");
    
    ActiviteSalarie activiteSalarieConserveeCourante = null;
    p_chronoActivitesSalarieesConservees.iterer();
    while (p_chronoActivitesSalarieesConservees.encoreSuivant())
    {
      activiteSalarieConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConservees.elementSuivant();
      if (activiteSalarieConserveeCourante.getPeriode().chevauche(p_moisCivil))
      {
        boolean isTotalementSuspendu = false;
        FiltresTemporel filtres = new FiltresTemporel();
        filtres.ajouterFiltre(new FiltreIncident());
        Chronologie periodesSuspension = activiteSalarieConserveeCourante.getListePeriodesIncident().copier(filtres);
        int nbJourPeriode = 0;
        
        remunerationCouranteMoisCivil = DeterminationRemuneration.determinerRemunerationActiviteSalarieConserveeSurMoisCivil(activiteSalarieConserveeCourante, p_moisCivil);
        if (remunerationCouranteMoisCivil.compareTo(new BigDecimal("0")) == 0)
        {
          if ((periodesSuspension != null) && (!periodesSuspension.estVide()))
          {
            for (Iterator iterperiodeSuspension = periodesSuspension.iterer(); iterperiodeSuspension.hasNext();)
            {
              IncidentSpec suspension = (IncidentSpec)iterperiodeSuspension.next();
              Periode periodeSuspension = suspension.getPeriode();
              if ((periodeSuspension.chevauche(p_moisCivil)) && (suspension.estTempsPlein())) {
                if (p_moisCivil.estContenueDans(periodeSuspension)) {
                  isTotalementSuspendu = true;
                }
              }
            }
            if (!isTotalementSuspendu)
            {
              Periode tmpPeriode = new Periode();
              if (activiteSalarieConserveeCourante.getDateDebut().estAvantOuCoincideAvec(p_moisCivil.getDebut())) {
                tmpPeriode.setDebut(p_moisCivil.getDebut());
              } else {
                tmpPeriode.setDebut(activiteSalarieConserveeCourante.getDateDebut());
              }
              if (activiteSalarieConserveeCourante.getDateFin().estApresOuCoincideAvec(p_moisCivil.getFin())) {
                tmpPeriode.setFin(p_moisCivil.getFin());
              } else {
                tmpPeriode.setFin(activiteSalarieConserveeCourante.getDateFin());
              }
              if (tmpPeriode.getDuree() == nbJourPeriode) {
                isTotalementSuspendu = true;
              }
            }
          }
          if (!isTotalementSuspendu)
          {
            Periode tmpPeriode = new Periode();
            if (activiteSalarieConserveeCourante.getDateDebut().estAvantOuCoincideAvec(p_moisCivil.getDebut())) {
              tmpPeriode.setDebut(p_moisCivil.getDebut());
            } else {
              tmpPeriode.setDebut(activiteSalarieConserveeCourante.getDateDebut());
            }
            if (activiteSalarieConserveeCourante.getDateFin().estApresOuCoincideAvec(p_moisCivil.getFin())) {
              tmpPeriode.setFin(p_moisCivil.getFin());
            } else {
              tmpPeriode.setFin(activiteSalarieConserveeCourante.getDateFin());
            }
            Chronologie chronoSalaires = activiteSalarieConserveeCourante.getListeSalaires();
            Salaire periodeSalaireCourant = null;
            chronoSalaires.iterer();
            boolean bContinue = true;
            while ((chronoSalaires.encoreSuivant()) && (bContinue))
            {
              periodeSalaireCourant = (Salaire)chronoSalaires.elementSuivant();
              if (periodeSalaireCourant.getPeriode().estContenueDans(p_moisCivil))
              {
                Quantite qteAbscence = periodeSalaireCourant.getQuantiteAbsence();
                if (qteAbscence != null)
                {
                  isTotalementSuspendu = true;
                }
                else
                {
                  isTotalementSuspendu = false;
                  
                  bContinue = false;
                }
              }
            }
          }
          if ((remunerationCouranteMoisCivil.compareTo(BigDecimal.ZERO) == 0) && (!isTotalementSuspendu))
          {
            String[] params = new String[4];
            String moisCivil = "";
            moisCivil = p_moisCivil.getFin().getMois() < 10 ? "0" + String.valueOf(p_moisCivil.getFin().getMois()) : String.valueOf(p_moisCivil.getFin().getMois());
            params[0] = moisCivil;
            params[1] = String.valueOf(p_moisCivil.getFin().getAnnee()).substring(2);
            params[2] = activiteSalarieConserveeCourante.getDateDebut().toString().substring(0, 6).concat(activiteSalarieConserveeCourante.getDateDebut().toString().substring(8));
            params[3] = activiteSalarieConserveeCourante.getDateFin().toString().substring(0, 6).concat(activiteSalarieConserveeCourante.getDateFin().toString().substring(8));
            
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB8", params);
          }
        }
        cumulRemuneration = cumulRemuneration.add(remunerationCouranteMoisCivil);
      }
    }
    return cumulRemuneration;
  }
  
  private static BigDecimal determinerRemunerationMensuelleBruteAvantPerteActivite(Demande p_demande)
    throws CoucheLogiqueException
  {
    BigDecimal remunerationMensuelle = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    Sjr sjrrp = recupererSjr(p_demande);
    
    Sjc sjcrp = DeterminationSjcip.revaloriserSjcip(p_demande.getDateExamen(), dossierExamenCourant.getConstitutionSjc().getSjcip());
    
    remunerationMensuelle = COEFFICIENT_MENSUEL.multiply(sjrrp.getSalaire().add(sjcrp.getSalaire()));
    
    return remunerationMensuelle;
  }
  
  private static Sjr recupererSjr(Demande p_demande)
  {
    Attribution attribution = (Attribution)p_demande.getAttribution();
    if (attribution.getNatureDecision() == 11) {
      return attribution.getConstitutionProduitResultant().getSjrrpProduitPrecedent();
    }
    return attribution.getConstitutionSjr().getSjrrp();
  }
}

/* Location:
 * Qualified Name:     RechercheConditionCumulActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */