package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre14Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionChomageInvolontairePourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance est null pour une détermination condition chômage involontaire.");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(DeterminationConditionChomageInvolontairePourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontairePourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontairePourReprise.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionChomageInvolontairePourReprise ********\n");
    }
    Resultat resultatCapr09 = new Resultat(1);
    
    ConditionChomageInvolontaire conditionChomageInvolontaire = new ConditionChomageInvolontaire();
    
    Demande demandeAssurance = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamen = (DossierExamen)demandeAssurance.getDossierExamen();
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDemande(demandeAssurance);
    critereStrategie.setDatePivot(demandeAssurance.getDateExamen());
    StrategieConditionChomageInvolontaireAre14Spec strategie = (StrategieConditionChomageInvolontaireAre14Spec)FabriqueStrategieConditionChomageInvolontaire.getInstance().getStrategie(critereStrategie);
    
    ResultatRechercheConditionChomageInvolontaire resultat = strategie.rechercheConditionChomageInvolontairePourReprise(demandeAssurance);
    alimenterCap(conditionChomageInvolontaire, resultat);
    
    dossierExamen.setConditionChomageInvolontaire(conditionChomageInvolontaire);
    if (conditionChomageInvolontaire.estSatisfait())
    {
      resultatCapr09.setEtat(0);
    }
    else
    {
      resultatCapr09.setEtat(1);
      resultatCapr09.setMessageErreur(Integer.toString(conditionChomageInvolontaire.getCodeMotifEchec()));
    }
    if (Log.isTraceActive(DeterminationConditionChomageInvolontairePourReprise.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontairePourReprise.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionChomageInvolontairePourReprise ********\n");
    }
    return resultatCapr09;
  }
  
  private static void alimenterCap(ConditionChomageInvolontaire conditionChomageInvolontaire, ResultatRechercheConditionChomageInvolontaire resultat)
  {
    conditionChomageInvolontaire.setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
    conditionChomageInvolontaire.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
    conditionChomageInvolontaire.setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
    conditionChomageInvolontaire.setIdentifiantActivitePortantDV(resultat.getIdentifiantActivitePortantDV());
    conditionChomageInvolontaire.setDureeAeDv(resultat.getDureeAeDV());
    conditionChomageInvolontaire.setIntensiteHoraireSalarieAeDv(resultat.getIntensiteHoraireAeDV());
    conditionChomageInvolontaire.setQuantiteAffiliationPrincipaleInopposabilite(resultat.getQuantiteAffiliationPrincipaleInopposabilite());
    conditionChomageInvolontaire.setQuantiteAffiliationSecondaireInopposabilite(resultat.getQuantiteAffiliationSecondaireInopposabilite());
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionChomageInvolontairePourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */