package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationOrdreObjectifs;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieContexteRepriseSystematiqueSpec;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieContexteRepriseSystematique;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationObjectifReprise;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.List;

public class ParcoursDeterminationOrdreObjectifs
  extends ParcoursCali
{
  public static final int AGE_57_ANS = 57;
  private int numeroOrdre = 1;
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = getDemande(p_contexte);
    int contexteExamen = getDom(p_contexte).getContexteExamen();
    
    List listeTypesObjectifs = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ASPSJACENT")) {
      listeTypesObjectifs = determinerObjectifsSansAntecedent();
    } else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "RECHARGE")) {
      listeTypesObjectifs = determinerObjectifsRechargement();
    } else if (OutilDemande.estUneDemandeFinDroitCasGeneral(demandeCourante)) {
      listeTypesObjectifs = determinerObjectifsDemandeRechargement();
    } else if (demandeCourante.estLiquideeAvecDroitOptionReprise()) {
      listeTypesObjectifs = determinerObjectifsDroitOptionReprise();
    } else if (demandeCourante.getDecisionAutomatique() == 2) {
      listeTypesObjectifs = determinerObjectifsRepriseAutomatique();
    } else if (demandeCourante.getDecisionAutomatique() == 1) {
      listeTypesObjectifs = determinerObjectifsRejetAutomatique(contexteExamen);
    } else if ((demandeCourante.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) {
      listeTypesObjectifs = OutilDeterminationOrdreObjectifs.getInstance().determinerObjectifsExamenDv122Jour(demandeCourante, contexteExamen);
    } else {
      switch (getDom(p_contexte).getContexteExamen())
      {
      case 1: 
        listeTypesObjectifs = determinerObjectifsSansAntecedent();
        break;
      case 2: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentNonValide(demandeCourante);
        break;
      case 3: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentValide(p_contexte);
        break;
      case 4: 
        listeTypesObjectifs = determinerObjectifsAntecedentSecteurPublic(demandeCourante);
      }
    }
    demandeCourante.viderListeObjectifsExamen();
    for (int i = 0; i < listeTypesObjectifs.size(); i++)
    {
      int sousTypeObjectif = ((Integer)listeTypesObjectifs.get(i)).intValue();
      ObjectifExamen objectif = demandeCourante.creerObjectifExamen(sousTypeObjectif, getProduit(sousTypeObjectif, p_contexte));
      ajouteObjectifSurDemande(objectif, demandeCourante);
    }
    if ((demandeCourante.getDecisionAutomatique() == 2) && (demandeCourante.getListObjectifExamen() != null) && (demandeCourante.getListObjectifExamen().size() < 1)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_PAS_OBJECTIF_POUR_REPRISE_AUTO");
    }
    return new Resultat();
  }
  
  protected List determinerObjectifsRechargement()
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(44));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDemandeRechargement()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    
    return listeTypesObjectifs;
  }
  
  private void ajouteObjectifSurDemande(ObjectifExamen objectif, Demande demandeCourante)
  {
    objectif.setNumeroOrdre(numeroOrdre);
    demandeCourante.ajouterObjectifExamen(objectif);
    numeroOrdre += 1;
  }
  
  private boolean isSousTypeObjectifRerpise(int sousTypeObjectif)
  {
    boolean isReprise = (sousTypeObjectif == 14) || (sousTypeObjectif == 15) || (sousTypeObjectif == 13);
    
    return (isReprise) || (sousTypeObjectif == 27) || (sousTypeObjectif == 34);
  }
  
  private boolean isSousTypeObjectifAdmission(int sousTypeObjectif)
  {
    return (sousTypeObjectif == 12) || (sousTypeObjectif == 11) || (sousTypeObjectif == 10) || (sousTypeObjectif == 44);
  }
  
  private ProduitAsuSpec getProduit(int sousTypeObjectif, Contexte contexte)
  {
    ProduitAsuSpec produit = null;
    if (isSousTypeObjectifRerpise(sousTypeObjectif)) {
      produit = getDom(contexte).getProduitPrecedent();
    } else if (isSousTypeObjectifAdmission(sousTypeObjectif)) {
      produit = (ProduitAsuSpec)getDom(contexte).getDemande().getDossierAffectationAdmission().getProduit();
    } else if (sousTypeObjectif == 50) {
      produit = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(getDom(contexte).getDemande().getDateExamen());
    }
    return produit;
  }
  
  protected List determinerObjectifsDroitOptionReprise()
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(13));
    
    return listeTypesObjectifs;
  }
  
  protected List determinerObjectifsRepriseAutomatique()
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(27));
    
    return listeTypesObjectifs;
  }
  
  protected List determinerObjectifsRejetAutomatique(int p_contexteExamen)
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    if (p_contexteExamen == 3) {
      listeTypesObjectifs.add(Integer.valueOf(27));
    }
    return listeTypesObjectifs;
  }
  
  protected List determinerObjectifsSansAntecedent()
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    
    return listeTypesObjectifs;
  }
  
  protected List determinerObjectifsAvecAntecedentNonValide(Demande p_demande)
  {
    List listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    if (!p_demande.estEnContexteDroitAnterieurSecteurPublic()) {
      listeTypesObjectifs.add(Integer.valueOf(13));
    }
    return listeTypesObjectifs;
  }
  
  protected List determinerObjectifsAvecAntecedentValide(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    List listeTypesObjectifs = new ArrayList();
    Demande demande = getDemande(p_contexte);
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (demande.estDroitOptionReadmission())
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    else if (OutilDeterminationObjectifReprise.getInstance().determineDateExtinctionReliquatSurObjectifReprise(demande) != null)
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
      ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
    }
    else
    {
      Damj dateFgPrecedent = demande.getDateFaitGenerateurOdPrecedente();
      if (getIndividu(p_contexte).getAgeALaDate(dateFgPrecedent).getAnnees() >= 57)
      {
        if ((ere instanceof EreDemandeExpresse))
        {
          listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
        }
        else
        {
          StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
          listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
        }
      }
      else if ((ere instanceof EreDemandeExpresse))
      {
        listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
      }
      else
      {
        StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
        if (strategie.determinerContexteRepriseSystematique(demande))
        {
          demande.setContexteDeRepriseSansFCT(true);
          
          listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
        }
        else
        {
          listeTypesObjectifs.add(Integer.valueOf(12));
          ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
          if (getDom(p_contexte).estEnRepriseContextuelle())
          {
            listeTypesObjectifs = new ArrayList();
            ajouterObjectifReprise(demande, listeTypesObjectifs, 14);
            listeTypesObjectifs.add(Integer.valueOf(12));
          }
        }
      }
    }
    return listeTypesObjectifs;
  }
  
  private StrategieContexteRepriseSystematiqueSpec recupererStrategieRepriseSystematique(Demande p_demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(p_demande.getDateExamen());
    return (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
  }
  
  protected List<Integer> determinerObjectifDemandeExpresseAvecReliquatValide(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    
    StrategieContexteRepriseSystematiqueSpec strategie = (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
    
    return strategie.determinerObjectifsExamenDemandeExpresseAvecReliquatValide(demande);
  }
  
  private void ajouterObjectifReprise(Demande demande, List listeTypesObjectifs, int typeReprise)
  {
    boolean ajouterReprise = true;
    if ((OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) && ((!demande.getDonneesTemporaires().isDecisionCPRenseigneeChomageTotalSansRupture()) || (!demande.getDonneesTemporaires().isAvisFavorableCPChomageTotalSansRupture()))) {
      ajouterReprise = false;
    }
    if (ajouterReprise) {
      listeTypesObjectifs.add(Integer.valueOf(typeReprise));
    }
  }
  
  protected List determinerObjectifsAntecedentSecteurPublic(Demande p_demande)
    throws CoucheLogiqueException
  {
    return recupererStrategieRepriseSystematique(p_demande).determinerObjectifsAntecedentSecteurPublic(p_demande);
  }
  
  protected Demande getDemande(Contexte p_contexte)
  {
    Demande demande = (Demande)((DomLiquidationAssurance)p_contexte.getDonnees()).getDemandeSpec();
    demande.setLiquideeAvecDroitOptionReprise(((DomLiquidationAssurance)p_contexte.getDonnees()).isLiquidationAvecDroitOptionReprise());
    
    return demande;
  }
  
  protected DomLiquidationAssurance getDom(Contexte p_contexte)
  {
    return (DomLiquidationAssurance)p_contexte.getDonnees();
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationOrdreObjectifs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */