package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuIdSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class BaseCarence
  extends BaseDelaiReportAbstrait
{
  public BaseCarence() {}
  
  public BaseCarence(QuantiteJourTravailDansSemaineSpec pQuantiteJourIccp, QuantiteEuro pQuantiteEuroIccp, QuantiteEuro pQuantiteEuroIslr)
  {
    setQuantiteJourIccp(pQuantiteJourIccp);
    setQuantiteEuroIccp(pQuantiteEuroIccp);
    setQuantiteEuroIslr(pQuantiteEuroIslr);
  }
  
  public BigDecimal calculerIndemniteLicenciementLegale()
  {
    BigDecimal valeurIndemniteLegaleCalculee = BigDecimal.ZERO;
    
    Attribution odCourante = (Attribution)((Demande)periodeActiviteSalarieOrigine.getIdentifiantIndividu().getIndividu().getChronoDemandeAssurance().dernierElement()).getOdAcquise();
    if ((odCourante != null) && (odCourante.getConstitutionSjr() != null) && (odCourante.getConstitutionSjr().getSjrip() != null))
    {
      Sjrip sjripCourant = odCourante.getConstitutionSjr().getSjrip();
      BigDecimal nominateur1 = new BigDecimal("365.0");
      BigDecimal nominateur2 = sjripCourant.getSjrip();
      BigDecimal denominateur = new BigDecimal("12.0");
      BigDecimal valeurSalaireMensuel = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      
      Periode periodeActiviteSalarieeCourante = new Periode(periodeActiviteSalarieOrigine.getDateDebut(), periodeActiviteSalarieOrigine.getDateFin());
      
      BigDecimal nombreAnneesAnciennete = new BigDecimal(String.valueOf(periodeActiviteSalarieeCourante.getDureeCalendaire().getAnnees()));
      BigDecimal periodeActiviteSalarieeBigDecimal = new BigDecimal(String.valueOf(periodeActiviteSalarieeCourante.getDureeCalendaire().getMois()));
      
      nombreAnneesAnciennete = nombreAnneesAnciennete.add(Mathematiques.diviseParDefaut(periodeActiviteSalarieeBigDecimal, new BigDecimal("12")));
      if (nombreAnneesAnciennete.compareTo(new BigDecimal("2")) >= 0)
      {
        nominateur1 = valeurSalaireMensuel;
        nominateur2 = nombreAnneesAnciennete;
        denominateur = new BigDecimal("10.0");
        valeurIndemniteLegaleCalculee = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
        if (nombreAnneesAnciennete.compareTo(new BigDecimal("11")) >= 0)
        {
          nominateur1 = valeurSalaireMensuel;
          nominateur2 = nombreAnneesAnciennete.subtract(new BigDecimal("10.0"));
          denominateur = new BigDecimal("15.0");
          
          valeurIndemniteLegaleCalculee = valeurIndemniteLegaleCalculee.add(Mathematiques.proratiser(nominateur1, nominateur2, denominateur));
        }
        if (isLicenciementEconomique()) {
          valeurIndemniteLegaleCalculee = new BigDecimal(String.valueOf(2)).multiply(valeurIndemniteLegaleCalculee);
        }
        valeurIndemniteLegaleCalculee = Mathematiques.arrondiASup(valeurIndemniteLegaleCalculee, 2);
      }
    }
    return valeurIndemniteLegaleCalculee;
  }
  
  public QuantiteEuro getQuantiteEuroIslr()
  {
    QuantiteEuro quantiteIslr = null;
    if ((quantiteEuroIndemniteLicenciementTotale != null) && (!quantiteEuroIndemniteLicenciementTotale.getValeurMontant().equals(new BigDecimal("0"))))
    {
      BigDecimal valeurIndemniteLicenciementTotale = quantiteEuroIndemniteLicenciementTotale.getValeurMontant();
      BigDecimal valeurIndemniteLicenciementLegaleCalculee = calculerIndemniteLicenciementLegale();
      BigDecimal valeurIslr = valeurIndemniteLicenciementTotale.subtract(valeurIndemniteLicenciementLegaleCalculee);
      
      valeurIslr = valeurIslr.max(new BigDecimal(String.valueOf(0)));
      
      valeurIslr = Mathematiques.arrondiASup(valeurIslr, 2);
      quantiteIslr = new QuantiteEuro(valeurIslr);
    }
    else
    {
      quantiteIslr = quantiteEuroIslr;
    }
    return quantiteIslr;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    
    chaineRetour.append("\n\t Nombre de jours ICCP :" + quantiteJourIccp);
    chaineRetour.append("\n\t Montant ICCP : " + quantiteEuroIccp);
    chaineRetour.append("\n\t Licenciement économique : " + licenciementEconomique);
    chaineRetour.append("\n\t Montant Indemnité licenciement totale : " + quantiteEuroIndemniteLicenciementTotale);
    chaineRetour.append("\n\t Montant ISLR : " + quantiteEuroIslr);
    
    return chaineRetour.toString();
  }
  
  public QuantiteEuro getQuantiteEuroCarence()
  {
    return getQuantiteEuroIccp();
  }
  
  public QuantiteJourTravailDansSemaineSpec getQuantiteJourCarence()
  {
    return getQuantiteJourIccp();
  }
  
  public void setQuantiteEuroCarence(QuantiteEuro p_quantiteEuroCarence)
  {
    setQuantiteEuroIccp(p_quantiteEuroCarence);
  }
  
  public void setQuantiteJourCarence(QuantiteJourTravailDansSemaineSpec p_quantiteJourCarence)
  {
    setQuantiteJourIccp(p_quantiteJourCarence);
  }
  
  public ObjetMetierSpec copie()
  {
    BaseCarence copie = new BaseCarence();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    BaseCarence copie = (BaseCarence)p_copie;
    
    copie.setLicenciementEconomique(isLicenciementEconomique());
    copie.setPeriodeActiviteSalarieOrigine(getPeriodeActiviteSalarieOrigine());
    copie.setQuantiteEuroIccp(getQuantiteEuroIccp());
    copie.setQuantiteEuroIndemniteLicenciementTotale(getQuantiteEuroIndemniteLicenciementTotale());
    copie.setQuantiteEuroIslr(getQuantiteEuroIslr());
    copie.setQuantiteJourIccp(getQuantiteJourIccp());
  }
}

/* Location:
 * Qualified Name:     BaseCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */