package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategieSjrPnds;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategieSjrPndsSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIntensite;
import fr.unedic.cali.autresdoms.ga.dom.Prime;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.RemunerationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;

public class Prae
  extends ObjetChronoPeriode
  implements ObjetMetierSpec
{
  private static final long serialVersionUID = 1L;
  private static final int PRECISION_DEUX_CHIFFRES = 2;
  protected Prce prce = null;
  protected ActiviteSalarie periodeActiviteSalarie = null;
  
  public Prae() {}
  
  public Prae(Damj dateDebut, Damj dateFin)
  {
    super(dateDebut, dateFin);
  }
  
  public Prae(Periode periode)
  {
    super(periode);
  }
  
  private boolean prendreEnCompteSourceRemuneration(RemunerationSpec sourceRemuneration, Reglement reglementAppartenance)
    throws CoucheLogiqueException
  {
    boolean priseEnCompteRemuneration = false;
    
    boolean estSourceRemunerationTypeSalaire = sourceRemuneration.estType(Salaire.class);
    boolean estSourceRemunerationTypePrime = sourceRemuneration.estType(Prime.class);
    
    Periode periodePraeCourante = new Periode(getDateDebut(), getDateFin());
    if ((reglementAppartenance.estNomReglementIdentique("RG")) || (reglementAppartenance.estNomReglementIdentique("OP")) || (reglementAppartenance.estNomReglementIdentique("A2a")) || (reglementAppartenance.estNomReglementIdentique("A4")) || (reglementAppartenance.estNomReglementIdentique("A5")) || (reglementAppartenance.estNomReglementIdentique("A6")) || (reglementAppartenance.estNomReglementIdentique("A9B")) || (reglementAppartenance.estNomReglementIdentique("A8")) || (reglementAppartenance.estNomReglementIdentique("A10")))
    {
      if ((estSourceRemunerationTypeSalaire) || ((estSourceRemunerationTypePrime) && (((Prime)sourceRemuneration).getTypePrime() == 1)))
      {
        ObjetChronoPeriode periodeSourceRemuneration = (ObjetChronoPeriode)sourceRemuneration;
        if (periodeSourceRemuneration.inter(periodePraeCourante) > 0) {
          priseEnCompteRemuneration = true;
        }
      }
      else if ((estSourceRemunerationTypePrime) && (((Prime)sourceRemuneration).getTypePrime() == 2))
      {
        if (getPrce().getPrc().getPrip().contient(sourceRemuneration.getDatePaie())) {
          priseEnCompteRemuneration = true;
        }
      }
    }
    else if ((reglementAppartenance.estNomReglementIdentique("A1")) || (reglementAppartenance.estNomReglementIdentique("A3")) || (reglementAppartenance.estNomReglementIdentique("A9A")))
    {
      if (sourceRemuneration.getDatePaie() == null)
      {
        OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "PRAE, méthode prendreEnCompteSourceRemuneration, erreur : date de paie d'un salaire ou d'une prime non renseignée" });
        
        String typeRemuneration = "";
        Damj dateFinRemuneration = sourceRemuneration.getDateFin();
        if (estSourceRemunerationTypeSalaire) {
          typeRemuneration = "le salaire";
        } else if (estSourceRemunerationTypePrime) {
          typeRemuneration = "la prime";
        }
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ABSENCE_DATE_PAIE", new Object[] { typeRemuneration, dateFinRemuneration });
      }
      Periode periodeRecherche = null;
      if ((estSourceRemunerationTypeSalaire) || ((estSourceRemunerationTypePrime) && (((Prime)sourceRemuneration).getTypePrime() == 1)))
      {
        periodeRecherche = new Periode(getPrce().getDateDebut(), getPrce().getDateFin());
        if (sourceRemuneration.getDatePaie().estContenueDans(periodeRecherche)) {
          priseEnCompteRemuneration = true;
        }
        if ((!priseEnCompteRemuneration) && (getPeriodeActiviteSalarie().getDateFin().estAvantOuCoincideAvec(periodeRecherche.getFin())) && (sourceRemuneration.getDatePaie().estApres(periodeRecherche.getFin())) && (sourceRemuneration.getDatePaie().estContenueDans(new Periode(getPrce().getPrc().getDateDebut(), getPrce().getPrc().getDateFin())))) {
          priseEnCompteRemuneration = true;
        }
      }
      else if ((estSourceRemunerationTypePrime) && (((Prime)sourceRemuneration).getTypePrime() == 2))
      {
        periodeRecherche = new Periode(getPrce().getPrc().getDateDebut(), getPrce().getPrc().getDateFin());
        if (sourceRemuneration.getDatePaie().estContenueDans(periodeRecherche)) {
          priseEnCompteRemuneration = true;
        }
      }
    }
    return priseEnCompteRemuneration;
  }
  
  private boolean proratiserSourceRemuneration(Reglement reglementAppartenance)
  {
    boolean proratiserSurPeriodeReference = true;
    if ((reglementAppartenance.estNomReglementIdentique("A1")) || (reglementAppartenance.estNomReglementIdentique("A3")) || (reglementAppartenance.estNomReglementIdentique("A9A"))) {
      proratiserSurPeriodeReference = false;
    }
    return proratiserSurPeriodeReference;
  }
  
  private BigDecimal determinerRemunerationPrimesExceptionnelles(Reglement reglementApplicable, Reglement reglementAppartenance, JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteRetenue)
    throws CoucheLogiqueException
  {
    BigDecimal cumulPrimeExceptionnelle = BigDecimal.ZERO;
    
    Prime primeExceptionnelleCourante = null;
    Periode periodeActiviteSalariee = null;
    int nombreJoursCommuns = 0;
    BigDecimal montantPrimeExceptionnelle = BigDecimal.ZERO;
    
    Chronologie chronoPrimesExceptionnelles = periodeActiviteSalarie.getListePrimesExceptionnelles();
    chronoPrimesExceptionnelles.iterer();
    while (chronoPrimesExceptionnelles.encoreSuivant())
    {
      primeExceptionnelleCourante = (Prime)chronoPrimesExceptionnelles.elementSuivant();
      if (prendreEnCompteSourceRemuneration(primeExceptionnelleCourante, reglementAppartenance))
      {
        periodeActiviteSalariee = new Periode(getPeriodeActiviteSalarie().getDateDebut(), getPeriodeActiviteSalarie().getDateFin());
        nombreJoursCommuns = getPrce().getPrc().inter(periodeActiviteSalariee);
        if (nombreJoursCommuns > 0)
        {
          montantPrimeExceptionnelle = DeterminationRemuneration.determinerRemuneration(primeExceptionnelleCourante);
          
          BigDecimal nominateur1 = new BigDecimal(String.valueOf(getDuree()));
          BigDecimal nominateur2 = montantPrimeExceptionnelle;
          BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursCommuns));
          montantPrimeExceptionnelle = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
          
          montantPrimeExceptionnelle = montantPrimeExceptionnelle.multiply(getPrce().getPrc().determinerCoeffDureePrcPourPrimeExceptionnelle());
          
          montantPrimeExceptionnelle = montantPrimeExceptionnelle.multiply(getPrce().getPrc().determinerCoeffPrimeExceptionnelle(reglementApplicable, reglementAppartenance));
          
          cumulPrimeExceptionnelle = cumulPrimeExceptionnelle.add(montantPrimeExceptionnelle);
          
          JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(primeExceptionnelleCourante.getDatePaie(), primeExceptionnelleCourante.getDatePaie());
          
          justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(primeExceptionnelleCourante);
          justificationSrPeriodeRemunerationCourante.setMontantRetenu(montantPrimeExceptionnelle);
          justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
        }
      }
    }
    return cumulPrimeExceptionnelle;
  }
  
  private BigDecimal determinerRemunerationSalaires(Demande demande, Reglement reglementApplicable, Reglement reglementAppartenance, JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteRetenue)
    throws CoucheLogiqueException
  {
    BigDecimal cumulSalaires = BigDecimal.ZERO;
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demande.getFaitGenerateur().getDateFaitGenerateur());
    StrategieSjrPndsSpec strategieSjrPndsCourante = (StrategieSjrPndsSpec)FabriqueStrategieSjrPnds.getInstance().getStrategie(critereStrategie);
    
    Chronologie chronoSalaires = strategieSjrPndsCourante.determinerChronoPeriodesSalaire(demande, periodeActiviteSalarie);
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    Salaire periodeSalaireCourant = null;
    BigDecimal montantSalaire = BigDecimal.ZERO;
    Periode periodeMoisCivilCourant = null;
    Damj dateDebutAnneeSalaireCourant = null;
    BigDecimal valeurSmicMensuelCourant = null;
    chronoSalaires.iterer();
    while (chronoSalaires.encoreSuivant())
    {
      periodeSalaireCourant = (Salaire)chronoSalaires.elementSuivant();
      if (prendreEnCompteSourceRemuneration(periodeSalaireCourant, reglementAppartenance)) {
        if (!periodeSalaireCourant.estExclus())
        {
          if (periodeActiviteSalarie.estContratApprenti())
          {
            periodeMoisCivilCourant = new Periode(periodeSalaireCourant.getDateDebut().getDebutMois(), periodeSalaireCourant.getDateDebut().getFinMois());
            if (!periodeMoisCivilCourant.contient(new Periode(periodeSalaireCourant.getDateDebut(), periodeSalaireCourant.getDateFin())))
            {
              if (Log.isTraceActive(Prae.class, Niveau.DEBUG)) {
                Log.ecritTrace(Niveau.DEBUG, Prae.class, "determinerRemunerationSalaires", "PRAE, méthode determinerRemunerationSalaires, erreur : periode salaire Apprenti retenue non inclue dans mois civil");
              }
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CEPA06_SJR_SALAIRE_NON_MENSUEL");
            }
            dateDebutAnneeSalaireCourant = new Damj(periodeSalaireCourant.getDateFin().getAnnee(), 1, 1);
            valeurSmicMensuelCourant = fr.unedic.cali.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateDebutAnneeSalaireCourant).getSmicMensuelBase35h();
            if (valeurSmicMensuelCourant == null) {
              leverAlerteA11MNB7SurSalaireApprenti(demande, periodeActiviteSalarie);
            }
          }
          ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
          if (reglementApplicable.equals(produit.getReglement("A3"))) {
            periodeSalaireCourant.calculerMontantSoumisContributionRaA3();
          }
          if (proratiserSourceRemuneration(reglementAppartenance)) {
            montantSalaire = DeterminationRemuneration.determinerRemunerationProratiseeDansPeriodeRef(periodeSalaireCourant, periodeReference);
          } else {
            montantSalaire = DeterminationRemuneration.determinerRemuneration(periodeSalaireCourant);
          }
          cumulSalaires = cumulSalaires.add(montantSalaire);
          
          JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(periodeSalaireCourant.getDateDebut(), periodeSalaireCourant.getDateFin());
          
          justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(periodeSalaireCourant);
          justificationSrPeriodeRemunerationCourante.setMontantRetenu(montantSalaire);
          justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
        }
        else
        {
          leverAlerteNonBloquanteSurAbsenceSalaire(demande, periodeActiviteSalarie);
          
          JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(periodeSalaireCourant.getDateDebut(), periodeSalaireCourant.getDateFin());
          
          justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(periodeSalaireCourant);
          justificationSrPeriodeRemunerationCourante.setMontantRetenu(BigDecimal.ZERO);
          justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
        }
      }
    }
    ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoSalaires, periodeReference);
    if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
    {
      leverAlerteNonBloquanteSurAbsenceSalaire(demande, periodeActiviteSalarie);
      
      ObjetChronoPeriode periodeComplementaireCourante = null;
      chronoPeriodesComplementaires.iterer();
      while (chronoPeriodesComplementaires.encoreSuivant())
      {
        periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
        
        JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
        
        justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(null);
        justificationSrPeriodeRemunerationCourante.setMontantRetenu(BigDecimal.ZERO);
        justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
      }
    }
    return cumulSalaires;
  }
  
  private BigDecimal determinerRemunerationPrimesNormales(Reglement reglementApplicable, Reglement reglementAppartenance, JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteRetenue)
    throws CoucheLogiqueException
  {
    BigDecimal cumulPrimeNormale = BigDecimal.ZERO;
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    Chronologie chronoPrimesNormales = periodeActiviteSalarie.getListePrimesNormales();
    Prime periodePrimeNormaleCourante = null;
    BigDecimal montantPrimeNormale = BigDecimal.ZERO;
    chronoPrimesNormales.iterer();
    while (chronoPrimesNormales.encoreSuivant())
    {
      periodePrimeNormaleCourante = (Prime)chronoPrimesNormales.elementSuivant();
      if (prendreEnCompteSourceRemuneration(periodePrimeNormaleCourante, reglementAppartenance))
      {
        if (proratiserSourceRemuneration(reglementAppartenance)) {
          montantPrimeNormale = DeterminationRemuneration.determinerRemunerationProratiseeDansPeriodeRef(periodePrimeNormaleCourante, periodeReference);
        } else {
          montantPrimeNormale = DeterminationRemuneration.determinerRemuneration(periodePrimeNormaleCourante);
        }
        montantPrimeNormale = montantPrimeNormale.multiply(getPrce().getPrc().determinerCoeffPrimeNormale(reglementApplicable, reglementAppartenance));
        
        cumulPrimeNormale = cumulPrimeNormale.add(montantPrimeNormale);
        
        JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(periodePrimeNormaleCourante.getDateDebut(), periodePrimeNormaleCourante.getDateFin());
        
        justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(periodePrimeNormaleCourante);
        justificationSrPeriodeRemunerationCourante.setMontantRetenu(montantPrimeNormale);
        justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
      }
    }
    return cumulPrimeNormale;
  }
  
  public BigDecimal getPae(JustificationPlafondsParEmployeur justificationPlafondsParEmployeur)
  {
    BigDecimal cumulPae = BigDecimal.ZERO;
    BigDecimal plafondMensuelApplicable = BigDecimal.ZERO;
    
    Periode periodeMoisCivilCourant = null;
    Chronologie chronoPeriodesIntensite = null;
    JustificationPlafondsDetailParExerciceEtEmployeur justificationPlafondsDetailParExerciceEtEmployeurCourant = null;
    
    fr.unedic.cali.asu.parametres.ParametresIndemnisation parametresIndemnisation = fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation();
    
    chronoPeriodesIntensite = periodeActiviteSalarie.getListePeriodeIntensite();
    
    ArrayList listePeriodesMoisCivils = decouperEnMoisCivils();
    for (int boucle = 0; boucle < listePeriodesMoisCivils.size(); boucle++)
    {
      periodeMoisCivilCourant = (Periode)listePeriodesMoisCivils.get(boucle);
      
      plafondMensuelApplicable = parametresIndemnisation.getElementActif(periodeMoisCivilCourant.getDebut()).getPlafond();
      
      BigDecimal cptpApplicable = determinerCptpApplicable(chronoPeriodesIntensite, periodeMoisCivilCourant);
      
      plafondMensuelApplicable = plafondMensuelApplicable.multiply(cptpApplicable);
      if ((!periodeMoisCivilCourant.getDebut().estLeDebutDuMois()) || (!periodeMoisCivilCourant.getFin().estLaFinDuMois()))
      {
        BigDecimal nominateur1 = plafondMensuelApplicable;
        BigDecimal nominateur2 = new BigDecimal(String.valueOf(periodeMoisCivilCourant.getDuree()));
        BigDecimal denominateur = new BigDecimal("30");
        plafondMensuelApplicable = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      }
      cumulPae = cumulPae.add(plafondMensuelApplicable);
      
      justificationPlafondsDetailParExerciceEtEmployeurCourant = new JustificationPlafondsDetailParExerciceEtEmployeur(periodeMoisCivilCourant);
      justificationPlafondsDetailParExerciceEtEmployeurCourant.setCptp(cptpApplicable);
      justificationPlafondsDetailParExerciceEtEmployeurCourant.setPlafond(plafondMensuelApplicable);
      justificationPlafondsParEmployeur.getListeDetailsPlafondsParExerciceEtEmployeur().add(justificationPlafondsDetailParExerciceEtEmployeurCourant);
    }
    return Mathematiques.tronque(cumulPae, 2);
  }
  
  public ActiviteSalarie getPeriodeActiviteSalarie()
  {
    return periodeActiviteSalarie;
  }
  
  public Prce getPrce()
  {
    return prce;
  }
  
  public BigDecimal getSrae(Demande demande, Reglement reglementApplicable)
    throws CoucheLogiqueException
  {
    BigDecimal cumulSrae = BigDecimal.ZERO;
    
    BigDecimal montantRemunerationsRetenues = BigDecimal.ZERO;
    
    Reglement reglementAppartenanceCourant = periodeActiviteSalarie.getReglement();
    
    JustificationSr justificationSr = getPrce().getPrc().recupererJustificationSjr(demande).getJustificationSr();
    
    JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteRetenue = new JustificationSrPeriodeActiviteRetenue(getPeriodeActiviteSalarie().getPeriode());
    
    justificationSrPeriodeActiviteRetenue.setRaisonSociale(getPeriodeActiviteSalarie().getEntreprise().getLibelleEntreprise());
    justificationSrPeriodeActiviteRetenue.setReglement(reglementAppartenanceCourant.getNomReglement());
    justificationSr.getListeActivitesSalarieesRetenues().ajouter(justificationSrPeriodeActiviteRetenue);
    
    montantRemunerationsRetenues = determinerRemunerationSalaires(demande, reglementApplicable, reglementAppartenanceCourant, justificationSrPeriodeActiviteRetenue);
    
    cumulSrae = cumulSrae.add(montantRemunerationsRetenues);
    
    justificationSr.setTotalSalairesRetenus(justificationSr.getTotalSalairesRetenus().add(montantRemunerationsRetenues));
    
    montantRemunerationsRetenues = determinerRemunerationPrimesNormales(reglementApplicable, reglementAppartenanceCourant, justificationSrPeriodeActiviteRetenue);
    
    cumulSrae = cumulSrae.add(montantRemunerationsRetenues);
    
    justificationSr.setTotalPrimesNormalesRetenues(justificationSr.getTotalPrimesNormalesRetenues().add(montantRemunerationsRetenues));
    
    montantRemunerationsRetenues = determinerRemunerationPrimesExceptionnelles(reglementApplicable, reglementAppartenanceCourant, justificationSrPeriodeActiviteRetenue);
    
    cumulSrae = cumulSrae.add(montantRemunerationsRetenues);
    
    justificationSr.setTotalPrimesExceptionnellesRetenues(justificationSr.getTotalPrimesExceptionnellesRetenues().add(montantRemunerationsRetenues));
    
    justificationSr.setSalaireReferenceNonPlafonne(justificationSr.getSalaireReferenceNonPlafonne().add(cumulSrae));
    if (cumulSrae.compareTo(BigDecimal.ZERO) > 0)
    {
      Chronologie listePeriodeParticipantes = getPrce().getPrc().getChronoActiviteSalarieParticipantSr();
      if (!listePeriodeParticipantes.contientElement(getPeriodeActiviteSalarie())) {
        getPrce().getPrc().ajouterActiviteSalarieParticipantSr(getPeriodeActiviteSalarie());
      }
    }
    return cumulSrae;
  }
  
  public void setPeriodeActiviteSalarie(ActiviteSalarie periodeActiviteSalarie)
  {
    this.periodeActiviteSalarie = periodeActiviteSalarie;
  }
  
  public void setPrce(Prce prce)
  {
    this.prce = prce;
  }
  
  private BigDecimal determinerCptpApplicable(Chronologie chronoPeriodesIntensite, Periode periodeMoisCivilCourant)
  {
    BigDecimal cptpApplicable = BigDecimal.ONE;
    PeriodeIntensite periodeIntensiteCourante = null;
    
    chronoPeriodesIntensite.iterer();
    while (chronoPeriodesIntensite.encoreSuivant())
    {
      periodeIntensiteCourante = (PeriodeIntensite)chronoPeriodesIntensite.elementSuivant();
      if (periodeIntensiteCourante.chevauche(periodeMoisCivilCourant)) {
        if (periodeIntensiteCourante.getHorairesSalarie().compareTo(periodeIntensiteCourante.getHorairesEntreprise()) < 0)
        {
          cptpApplicable = Mathematiques.diviseParDefaut(periodeIntensiteCourante.getHorairesSalarie(), periodeIntensiteCourante.getHorairesEntreprise());
          
          cptpApplicable = Mathematiques.tronque(cptpApplicable, 2);
        }
      }
    }
    return cptpApplicable;
  }
  
  public ObjetMetierSpec copie()
  {
    Prae copie = new Prae();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieCourante)
  {
    Prae copie = (Prae)copieCourante;
    copie.setDateDebut(getDateDebut());
    copie.setDateFin(getDateFin());
    copie.setPeriodeActiviteSalarie((ActiviteSalarie)getPeriodeActiviteSalarie().copie());
    copie.setPrce((Prce)getPrce().copie());
  }
  
  private void leverAlerteNonBloquanteSurAbsenceSalaire(Demande demande, ActiviteSalarie periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    
    String codeAlerteNonBloquante = getPrce().getPrc().donnerCodeAlerteNonBloquanteSurAbsenceSalaire();
    if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
      demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
  
  private void leverAlerteA11MNB7SurSalaireApprenti(Demande demande, ActiviteSalarie periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    if (demande.getAlertesNonBloquantes().containsKey("A11MNB7"))
    {
      listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get("A11MNB7");
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
      demande.getAlertesNonBloquantes().put("A11MNB7", listeActivitesSalariees);
    }
  }
}

/* Location:
 * Qualified Name:     Prae
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */