package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.PrcGen;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategieSjrPnds;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.PriseEnComptePrimoDemandeur;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategieSjrPndsSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContratRemunereBaseSmic;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMemeRegime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeSalaireAvecAbsence;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeSalaireSansAbsence;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.NonConformiteException;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public abstract class Prc
  extends PrcGen
  implements ObjetPersistantSpec
{
  private static final int DUREE_PRC_365_JOURS = 365;
  private static final int DOUZE = 12;
  private static final int TRENTE_ET_UN = 31;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  public static final String FORMULE_CALCUL_DIVISEUR_RG_A1_A2 = "N - (ni + na)";
  public static final String FORMULE_CALCUL_DIVISEUR_A3 = "Max de (N - n; D0)";
  public static final String FORMULE_CALCUL_DIVISEUR_A4 = "Max de (N - (n + j); H / 10; D0)";
  public static final String FORMULE_CALCUL_DIVISEUR_A5 = "Max de (N - (n + j); D0)";
  protected transient Chronologie m_chronoActiviteSalarie = new ChronologiePeriodes();
  protected transient Chronologie m_chronoPeriodesDeductibles = new ChronologiePeriodes();
  protected transient Chronologie m_listeJustificationDiviseurPeriodesParticipantes = null;
  private transient Chronologie m_chronoActiviteSalarieParticipantSr = new ChronologiePeriodes();
  
  protected Prc() {}
  
  public Prc(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Prc(Damj dateDebut, Damj dateFin)
  {
    super(dateDebut, dateFin);
  }
  
  public Prc(Periode periode)
  {
    super(periode);
  }
  
  protected boolean ajouterActiviteSalarie(ActiviteSalarie activiteSalarie)
  {
    boolean ajoutOk = true;
    if (activiteSalarie == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      m_chronoActiviteSalarie.ajouter(activiteSalarie);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterActiviteSalarie", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  protected boolean ajouterPeriodeDeductible(ObjetChronoPeriode periodeDeductible)
  {
    boolean ajoutOk = true;
    if (periodeDeductible == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      m_chronoPeriodesDeductibles.ajouter(periodeDeductible);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterPeriodeDeductible", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  protected boolean ajouterActiviteSalarieParticipantSr(ActiviteSalarie activiteSalarie)
  {
    boolean ajoutOk = true;
    if (activiteSalarie == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      getChronoActiviteSalarieParticipantSr().ajouter(activiteSalarie);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterActiviteSalarieParticipantSr", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  private BigDecimal calculerNombreHeuresActiviteDansPrc(Chronologie chronoActivites, Reglement reglementApplicable, boolean premiereJustificationHeures)
  {
    BigDecimal cumulHeuresActiviteDansPrc = BigDecimal.ZERO;
    
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Chronologie chronoPeriodeMesureActiviteCourante = null;
    PeriodeMesureActivite periodeMesureActiviteCourante = null;
    Quantite quantiteAffiliationCourante = null;
    Periode periodeCourante = null;
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = null;
    Reglement reglementAppartenanceCourant = null;
    
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      BigDecimal nombreHeuresJustifieesParActivite = BigDecimal.ZERO;
      
      chronoPeriodeMesureActiviteCourante = periodeActiviteSalarieCourante.getListePeriodesMesureActivite();
      chronoPeriodeMesureActiviteCourante.iterer();
      while (chronoPeriodeMesureActiviteCourante.encoreSuivant())
      {
        periodeMesureActiviteCourante = (PeriodeMesureActivite)chronoPeriodeMesureActiviteCourante.elementSuivant();
        
        quantiteAffiliationCourante = periodeMesureActiviteCourante.getQuantiteAffiliation(Unite.get("heure de travail"));
        if (quantiteAffiliationCourante != null)
        {
          periodeCourante = new Periode(periodeMesureActiviteCourante.getDateDebut(), periodeMesureActiviteCourante.getDateFin());
          BigDecimal nominateur1 = new BigDecimal(String.valueOf(inter(periodeCourante)));
          BigDecimal nominateur2 = quantiteAffiliationCourante.getValeur();
          BigDecimal denominateur = new BigDecimal(String.valueOf(periodeCourante.getDuree()));
          BigDecimal nombreHeuresProratiseSurPrc = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
          
          cumulHeuresActiviteDansPrc = cumulHeuresActiviteDansPrc.add(nombreHeuresProratiseSurPrc);
          
          nombreHeuresJustifieesParActivite = nombreHeuresJustifieesParActivite.add(nombreHeuresProratiseSurPrc);
        }
      }
      if ((premiereJustificationHeures) && (nombreHeuresJustifieesParActivite.compareTo(BigDecimal.ZERO) > 0) && (m_listeJustificationDiviseurPeriodesParticipantes != null))
      {
        justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeActiviteSalarieCourante.getPeriode());
        justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(periodeActiviteSalarieCourante);
        justifDiviseurPeriodeParticipanteCourante.setNombreHeuresTotal(nombreHeuresJustifieesParActivite.intValue());
        
        reglementAppartenanceCourant = periodeActiviteSalarieCourante.getReglement();
        if (((reglementApplicable.equals(ProduitAsuCge01P03.getInstance().getReglement("A4"))) && (reglementAppartenanceCourant.equals(ProduitAsuCge01P03.getInstance().getReglement("A4")))) || ((reglementApplicable.equals(ProduitAsuCge01P03.getInstance().getReglement("A5"))) && (reglementAppartenanceCourant.equals(ProduitAsuCge01P03.getInstance().getReglement("A5"))))) {
          justifDiviseurPeriodeParticipanteCourante.setNombreHeuresDroitAConges(nombreHeuresJustifieesParActivite.intValue());
        }
        m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
      }
    }
    return Mathematiques.tronque(cumulHeuresActiviteDansPrc, 0);
  }
  
  private void calculerNombreHeuresTotal(Reglement reglementApplicable)
  {
    setNombreHeuresTotal(calculerNombreHeuresActiviteDansPrc(getChronoActiviteSalarie(), reglementApplicable, true));
  }
  
  private BigDecimal calculerNombreJourAbsence(Demande demande, Chronologie chronoActivites, boolean absenceDeductible)
    throws CoucheLogiqueException
  {
    BigDecimal cumulJoursAbsenceRetourne = BigDecimal.ZERO;
    Periode periodeCourante = null;
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Salaire periodeSalaireCourante = null;
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = null;
    Chronologie chronoPeriodesSalaireAvecAbsence = null;
    Periode periodeIntersectionPrcCourante = null;
    int nbJoursDeductiblesSurSalaireCourant = 0;
    int nbJoursAbsenceArrondi = 0;
    int nbJoursAbsenceDeductible = 0;
    ChronologiePeriodes chronoPeriodesComplementaires = null;
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    
    ChronologiePeriodes chronoPeriodeSalaireSansAbsenceChevauchantPrc = new ChronologiePeriodes();
    ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsence = null;
    if (chronoActivites.contientChevauchementElements())
    {
      chronoPeriodeSalaireSansAbsenceChevauchantPrc = determinerChronoPeriodesSalaireSansAbsenceChevauchantPrc(demande, chronoActivites);
      
      chronoChevauchementsPeriodeSalaireAvecAbsence = determinerChronoChevauchementsPeriodeSalaireAvecAbsence(demande, chronoActivites);
    }
    boolean presenceChevauchementPeriodeSalaireAvecAbsence = (chronoChevauchementsPeriodeSalaireAvecAbsence != null) && (chronoChevauchementsPeriodeSalaireAvecAbsence.getTaille() > 1);
    if (presenceChevauchementPeriodeSalaireAvecAbsence) {
      cumulJoursAbsenceRetourne = traiterChevauchementsPeriodeSalaireAvecAbsence(demande, chronoChevauchementsPeriodeSalaireAvecAbsence, absenceDeductible, chronoPeriodeSalaireSansAbsenceChevauchantPrc);
    }
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltrePeriodeSalaireAvecAbsence());
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      if (periodeActiviteSalarieCourante.getContrat().estSuspensionChomageSansRCT())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(demande, periodeActiviteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide())) {
          chronoPeriodesSalaireAvecAbsence = (Chronologie)chronoPeriodesSuspension.copie();
        }
      }
      else
      {
        chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, periodeActiviteSalarieCourante);
        
        chronoPeriodesSalaireAvecAbsence = chronoPeriodesSalairePnds.copier(listeFiltres);
        
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(demande, periodeActiviteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide())) {
          chronoPeriodesSalaireAvecAbsence.ajouter(chronoPeriodesNonRemunereesApresDjtp);
        }
      }
      if ((chronoPeriodesSalaireAvecAbsence != null) && (chronoPeriodesSalaireAvecAbsence.getTaille() > 0))
      {
        chronoPeriodesSalaireAvecAbsence.iterer();
        while (chronoPeriodesSalaireAvecAbsence.encoreSuivant())
        {
          periodeSalaireCourante = (Salaire)chronoPeriodesSalaireAvecAbsence.elementSuivant();
          periodeCourante = new Periode(periodeSalaireCourante.getDateDebut(), periodeSalaireCourante.getDateFin());
          if ((!presenceChevauchementPeriodeSalaireAvecAbsence) || (!contientPeriodeSalaire(chronoChevauchementsPeriodeSalaireAvecAbsence, periodeSalaireCourante)))
          {
            periodeIntersectionPrcCourante = periodeCourante.periodeIntersection(periodeReference);
            chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodeSalaireSansAbsenceChevauchantPrc, periodeIntersectionPrcCourante);
            if ((chronoPeriodesComplementaires != null) && (!chronoPeriodesComplementaires.estVide()))
            {
              BigDecimal nbJoursAbsensePeriodeSalaireCourante = determinerAbsenceCumuleeHorsSalaireSansAbsence(periodeSalaireCourante, chronoPeriodesComplementaires);
              if (absenceDeductible)
              {
                nbJoursDeductiblesSurSalaireCourant = periodeIntersectionPrcCourante.inter((ChronologiePeriodes)m_chronoPeriodesDeductibles);
                
                nbJoursAbsenceArrondi = Mathematiques.arrondiASup(nbJoursAbsensePeriodeSalaireCourante, 0).intValue();
                if (nbJoursAbsenceArrondi > nbJoursDeductiblesSurSalaireCourant)
                {
                  nbJoursAbsenceDeductible = nbJoursAbsenceArrondi - nbJoursDeductiblesSurSalaireCourant;
                  
                  cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(new BigDecimal(nbJoursAbsenceDeductible));
                  if (m_listeJustificationDiviseurPeriodesParticipantes != null)
                  {
                    justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeCourante);
                    justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(periodeActiviteSalarieCourante);
                    
                    justifDiviseurPeriodeParticipanteCourante.setNombreJoursDeductibles(nbJoursAbsenceDeductible);
                    m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
                  }
                }
              }
              else
              {
                cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(nbJoursAbsensePeriodeSalaireCourante);
                if (m_listeJustificationDiviseurPeriodesParticipantes != null)
                {
                  justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeCourante);
                  justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(periodeActiviteSalarieCourante);
                  
                  justifDiviseurPeriodeParticipanteCourante.setNombreJourAbsence(nbJoursAbsensePeriodeSalaireCourante);
                  m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
                }
              }
            }
          }
        }
      }
    }
    return cumulJoursAbsenceRetourne;
  }
  
  private boolean contientPeriodeSalaire(Chronologie chrono, Salaire periodeSalaire)
  {
    Iterator iter = chrono.iterer();
    boolean trouve = false;
    while (iter.hasNext()) {
      if (((Salaire)iter.next()).estIdentiqueA(periodeSalaire)) {
        trouve = true;
      }
    }
    return trouve;
  }
  
  private void calculerNombreJourDeductible(Demande demande)
    throws CoucheLogiqueException
  {
    int cumulJoursDeductibles = 0;
    if (m_chronoPeriodesDeductibles.getTaille() > 0)
    {
      ChronologiePeriodes chronoPeriodesDeductiblesSansChevauchement = null;
      if (m_chronoPeriodesDeductibles.contientChevauchementElements()) {
        chronoPeriodesDeductiblesSansChevauchement = ((ChronologiePeriodes)m_chronoPeriodesDeductibles).fusionnerChevauchementPeriodes();
      } else {
        chronoPeriodesDeductiblesSansChevauchement = (ChronologiePeriodes)m_chronoPeriodesDeductibles;
      }
      cumulJoursDeductibles = inter(chronoPeriodesDeductiblesSansChevauchement);
      if (m_listeJustificationDiviseurPeriodesParticipantes != null)
      {
        JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = null;
        ObjetChronoPeriode periodeDeductibleCourante = null;
        Periode periodeCourante = null;
        
        m_chronoPeriodesDeductibles.iterer();
        while (m_chronoPeriodesDeductibles.encoreSuivant())
        {
          periodeDeductibleCourante = (ObjetChronoPeriode)m_chronoPeriodesDeductibles.elementSuivant();
          periodeCourante = new Periode(periodeDeductibleCourante.getDateDebut(), periodeDeductibleCourante.getDateFin());
          
          justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeCourante);
          justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(periodeDeductibleCourante);
          
          justifDiviseurPeriodeParticipanteCourante.setNombreJoursDeductibles(inter(periodeCourante));
          m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
        }
      }
    }
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    DecorReglementaire decor = ((DossierAffectation)demande.getDossierAffectation()).getDecorReglementaire();
    listeFiltresExclusifs.ajouterFiltre(new FiltreMemeRegime("RG", decor));
    listeFiltresExclusifs.ajouterFiltre(new FiltreMemeRegime("A1", decor));
    listeFiltresExclusifs.ajouterFiltre(new FiltreMemeRegime("A2a", decor));
    Chronologie chronoPeriodesRgA1A2a = getChronoActiviteSalarie().copier(listeFiltresExclusifs);
    if (!chronoPeriodesRgA1A2a.estVide())
    {
      BigDecimal cumulJoursAbsenceDeductibles = calculerNombreJourAbsence(demande, chronoPeriodesRgA1A2a, true);
      if ((cumulJoursAbsenceDeductibles != null) && (cumulJoursAbsenceDeductibles.compareTo(BigDecimal.ZERO) > 0)) {
        cumulJoursDeductibles += cumulJoursAbsenceDeductibles.intValue();
      }
    }
    setNombreJourDeductible(cumulJoursDeductibles);
  }
  
  public BigDecimal determinerCoeffDureePrcPourPrimeExceptionnelle()
  {
    BigDecimal coeffDureePrcPourPrimeExceptionnelle = new BigDecimal("1");
    return coeffDureePrcPourPrimeExceptionnelle;
  }
  
  public BigDecimal determinerCoeffPrimeExceptionnelle(Reglement reglementApplicable, Reglement reglementAppartenance)
  {
    BigDecimal coefficientPrimeExceptionnelleCourant = new BigDecimal("1");
    if ((reglementAppartenance.estNomReglementIdentique("RG")) || (reglementAppartenance.estNomReglementIdentique("OP")) || (reglementAppartenance.estNomReglementIdentique("A2a")) || (reglementAppartenance.estNomReglementIdentique("A6"))) {
      if ((reglementApplicable.estNomReglementIdentique("RG")) || (reglementAppartenance.estNomReglementIdentique("OP")) || (reglementApplicable.estNomReglementIdentique("A1")) || (reglementApplicable.estNomReglementIdentique("A2a")) || (reglementApplicable.estNomReglementIdentique("A6"))) {
        coefficientPrimeExceptionnelleCourant = Mathematiques.diviseParDefaut(getDiviseur(), new BigDecimal(String.valueOf(getDureePrc())));
      }
    }
    return coefficientPrimeExceptionnelleCourant;
  }
  
  public BigDecimal determinerCoeffPrimeNormale(Reglement reglementApplicable, Reglement reglementAppartenance)
  {
    BigDecimal coefficientPrimeNormaleCourant = new BigDecimal("1");
    if ((reglementAppartenance.estNomReglementIdentique("RG")) || (reglementAppartenance.estNomReglementIdentique("OP")) || (reglementAppartenance.estNomReglementIdentique("A2a")) || (reglementAppartenance.estNomReglementIdentique("A6"))) {
      if ((reglementApplicable.estNomReglementIdentique("RG")) || (reglementAppartenance.estNomReglementIdentique("OP")) || (reglementApplicable.estNomReglementIdentique("A1")) || (reglementApplicable.estNomReglementIdentique("A2a")) || (reglementApplicable.estNomReglementIdentique("A6")))
      {
        BigDecimal nominateur = getDiviseur();
        BigDecimal denominateur = new BigDecimal(String.valueOf(getDureePrc())).subtract(new BigDecimal(String.valueOf(getNombreJourInappartenance())));
        
        coefficientPrimeNormaleCourant = Mathematiques.diviseParDefaut(nominateur, denominateur);
      }
    }
    return coefficientPrimeNormaleCourant;
  }
  
  private BigDecimal determinerDiviseurCasGeneral(Demande demande)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
    
    determinerDureePrc(produit.getReglement("RG"));
    
    BigDecimal dureePrcBigDecimal = new BigDecimal(String.valueOf(getDureePrc()));
    
    calculerNombreJourInappartenance(demande);
    
    setNombreJourAbsence(calculerNombreJourAbsence(demande, getChronoActiviteSalarie(), false));
    
    BigDecimal jourInappartenancePlusJourAbsence = new BigDecimal(String.valueOf(getNombreJourInappartenance())).add(getNombreJourAbsence());
    BigDecimal diviseurCasGeneral = dureePrcBigDecimal.subtract(jourInappartenancePlusJourAbsence);
    
    setNombreJourTravailEffectif(diviseurCasGeneral);
    
    return diviseurCasGeneral;
  }
  
  private void determinerDiviseur(Demande demande, Reglement reglementApplicable, boolean estCalculSJR)
    throws CoucheLogiqueException
  {
    BigDecimal diviseurPrcCourante = BigDecimal.ZERO;
    
    JustificationDiviseur justificationDiviseur = recupererJustificationSjr(demande).getJustificationDiviseur();
    m_listeJustificationDiviseurPeriodesParticipantes = justificationDiviseur.getListePeriodesParticipantes();
    
    BigDecimal diviseurCasGeneral = determinerDiviseurCasGeneral(demande);
    
    ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
    
    boolean estPrimoDemandeurA3A4A5 = PriseEnComptePrimoDemandeur.estPrimoDemandeurA3A4A5((Attribution)demande.getAttribution(), reglementApplicable);
    
    justificationDiviseur.setPrimoDemandeurA3A4A5(estPrimoDemandeurA3A4A5);
    
    boolean estReglementA8A10 = (reglementApplicable.estNomReglementIdentique("A8")) || (reglementApplicable.estNomReglementIdentique("A10"));
    if ((reglementApplicable.estNomReglementIdentique("RG")) || (reglementApplicable.estNomReglementIdentique("OP")) || (reglementApplicable.estNomReglementIdentique("A1")) || (reglementApplicable.estNomReglementIdentique("A2a")) || (reglementApplicable.estNomReglementIdentique("A6")) || (reglementApplicable.estNomReglementIdentique("A9A")) || (reglementApplicable.estNomReglementIdentique("A9B")) || (estPrimoDemandeurA3A4A5) || (estReglementA8A10))
    {
      diviseurPrcCourante = diviseurCasGeneral;
      if (diviseurPrcCourante.signum() < 1) {
        gestionAlerteBloquanteDiviseurNegatif(1, diviseurPrcCourante, null, null, null, null, estCalculSJR, reglementApplicable.getLibelleCourt());
      }
    }
    else
    {
      determinerDureePrc(reglementApplicable);
      
      BigDecimal dureePrcBigDecimal = new BigDecimal(String.valueOf(getDureePrc()));
      
      calculerNombreJourDeductible(demande);
      BigDecimal nombreJourDeductibleBigDecimal = new BigDecimal(String.valueOf(getNombreJourDeductible()));
      
      BigDecimal valeur1 = BigDecimal.ZERO;
      if (reglementApplicable.equals(produit.getReglement("A3")))
      {
        valeur1 = dureePrcBigDecimal.subtract(nombreJourDeductibleBigDecimal);
        diviseurPrcCourante = valeur1.max(diviseurCasGeneral);
        
        justificationDiviseur.setPremiereValeurFormule(valeur1.intValue());
        if (diviseurPrcCourante.signum() < 1) {
          gestionAlerteBloquanteDiviseurNegatif(2, diviseurPrcCourante, dureePrcBigDecimal, nombreJourDeductibleBigDecimal, diviseurCasGeneral, null, estCalculSJR, reglementApplicable.getLibelleCourt());
        }
      }
      else if (reglementApplicable.equals(produit.getReglement("A4")))
      {
        calculerNombreHeuresTotal(reglementApplicable);
        
        calculerDroitCongesA4ouA5(demande, reglementApplicable);
        BigDecimal droitCongesBigDecimal = new BigDecimal(String.valueOf(getDroitCongesA4ouA5()));
        
        valeur1 = dureePrcBigDecimal.subtract(nombreJourDeductibleBigDecimal.add(droitCongesBigDecimal));
        
        BigDecimal valeur2 = Mathematiques.diviseEntier(getNombreHeuresTotal(), new BigDecimal("10"));
        
        BigDecimal valeurMaximaleIntermediaire = valeur1.max(valeur2);
        diviseurPrcCourante = valeurMaximaleIntermediaire.max(diviseurCasGeneral);
        
        justificationDiviseur.setDiviseurMinimal(valeur2.intValue());
        
        justificationDiviseur.setPremiereValeurFormule(valeur1.intValue());
        if (diviseurPrcCourante.signum() < 1) {
          gestionAlerteBloquanteDiviseurNegatif(3, diviseurPrcCourante, dureePrcBigDecimal, nombreJourDeductibleBigDecimal, diviseurCasGeneral, droitCongesBigDecimal, estCalculSJR, reglementApplicable.getLibelleCourt());
        }
      }
      else if (reglementApplicable.equals(produit.getReglement("A5")))
      {
        calculerDroitCongesA4ouA5(demande, reglementApplicable);
        BigDecimal droitCongesBigDecimal = new BigDecimal(String.valueOf(getDroitCongesA4ouA5()));
        
        valeur1 = dureePrcBigDecimal.subtract(nombreJourDeductibleBigDecimal.add(droitCongesBigDecimal));
        diviseurPrcCourante = valeur1.max(diviseurCasGeneral);
        
        justificationDiviseur.setPremiereValeurFormule(valeur1.intValue());
        if (diviseurPrcCourante.signum() < 1) {
          gestionAlerteBloquanteDiviseurNegatif(4, diviseurPrcCourante, dureePrcBigDecimal, nombreJourDeductibleBigDecimal, diviseurCasGeneral, droitCongesBigDecimal, estCalculSJR, reglementApplicable.getLibelleCourt());
        }
      }
    }
    setDiviseur(diviseurPrcCourante);
  }
  
  private void determinerDureePrc(Reglement reglementApplicable)
  {
    int dureePrcCourante = 0;
    
    dureePrcCourante = getDuree();
    if ((reglementApplicable.estNomReglementIdentique("A3")) || (reglementApplicable.estNomReglementIdentique("A4")) || (reglementApplicable.estNomReglementIdentique("A5")))
    {
      dureePrcCourante = 365;
      int dureeReellePrc = getDuree();
      if (dureeReellePrc < dureePrcCourante) {
        dureePrcCourante = dureeReellePrc;
      }
    }
    setDureePrc(dureePrcCourante);
  }
  
  private ArrayList determinerListePrce()
  {
    ArrayList listePrce = new ArrayList();
    Periode periodePrceCourante = null;
    Prce prceCourante = null;
    
    ArrayList listeExercicesPrc = getListeExercices();
    for (int boucle = 0; boucle < listeExercicesPrc.size(); boucle++)
    {
      periodePrceCourante = periodeIntersection((Periode)listeExercicesPrc.get(boucle));
      if (periodePrceCourante != null)
      {
        prceCourante = new Prce(periodePrceCourante);
        
        prceCourante.setPrc(this);
        
        listePrce.add(prceCourante);
      }
    }
    return listePrce;
  }
  
  private void determinerPrip(Demande demande)
  {
    Damj termePrip = demande.getFaitGenerateur().getDateFaitGenerateur();
    
    DureeCalendaire dureeMaximale = new DureeCalendaire(0, 12, 0);
    Periode periodeReference = CalculDelais.determinerDelai(getDateFin(), dureeMaximale);
    periodeReference.setDebut(periodeReference.getDebut().lendemain());
    
    Damj borneDebutPrip = demande.getDateFaitGenerateurOdPrecedente();
    if (borneDebutPrip != null) {
      periodeReference = ((DelaiRecherche)DelaiRecherche.getInstance()).deplacerDepartDelai(borneDebutPrip, periodeReference);
    }
    Damj debutPrip = periodeReference.getDebut();
    
    setPrip(new Periode(debutPrip, termePrip));
  }
  
  public void determinerSrip(Demande demande, Reglement reglementApplicable, boolean estCalculSJR)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(Prc.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, Prc.class, "determinerSrip", "Début de la détermination du SRIP.");
    }
    determinerDiviseur(demande, reglementApplicable, estCalculSJR);
    
    determinerPrip(demande);
    
    ArrayList listePrce = determinerListePrce();
    
    BigDecimal cumulSrpe = BigDecimal.ZERO;
    for (int boucle = 0; boucle < listePrce.size(); boucle++) {
      cumulSrpe = cumulSrpe.add(((Prce)listePrce.get(boucle)).getSrpe(demande, reglementApplicable));
    }
    setSrip(Mathematiques.arrondiASup(cumulSrpe, 2));
    
    JustificationSr justificationSR = recupererJustificationSjr(demande).getJustificationSr();
    justificationSR.setSalaireReferencePlafonnne(getSrip());
    
    BigDecimal srJustifie = justificationSR.getSalaireReferenceNonPlafonne();
    justificationSR.setSalaireReferenceNonPlafonne(Mathematiques.arrondiASup(srJustifie, 2));
    
    BigDecimal primesExceptionnellesJustifiees = justificationSR.getTotalPrimesExceptionnellesRetenues();
    justificationSR.setTotalPrimesExceptionnellesRetenues(Mathematiques.arrondiASup(primesExceptionnellesJustifiees, 2));
    
    BigDecimal primesNormalesJustifiees = justificationSR.getTotalPrimesNormalesRetenues();
    justificationSR.setTotalPrimesNormalesRetenues(Mathematiques.arrondiASup(primesNormalesJustifiees, 2));
    
    BigDecimal salairesJustifies = justificationSR.getTotalSalairesRetenus();
    justificationSR.setTotalSalairesRetenus(Mathematiques.arrondiASup(salairesJustifies, 2));
    
    setTopContratsDeTypeParticulier(mettreAJourTopContratsRemuneresBaseSmic());
  }
  
  private boolean mettreAJourTopContratsRemuneresBaseSmic()
  {
    if (getChronoActiviteSalarieParticipantSr() != null)
    {
      Chronologie chronoFiltree = getChronoActiviteSalarieParticipantSr().copier(new FiltreContratRemunereBaseSmic());
      
      return getChronoActiviteSalarieParticipantSr().getTaille() == chronoFiltree.getTaille();
    }
    return false;
  }
  
  private ArrayList getListeExercices()
  {
    ArrayList listeExercices = new ArrayList();
    int anneeExercice = 0;
    Damj dateDebutExercice = null;
    Damj dateFinExercice = null;
    
    int nombreExercices = 1;
    if (getDateFin().getAnnee() != getDateDebut().getAnnee()) {
      nombreExercices = 2;
    }
    for (int boucle = 0; boucle < nombreExercices; boucle++)
    {
      anneeExercice = getDateDebut().getAnnee() + boucle;
      dateDebutExercice = new Damj(anneeExercice, 1, 1);
      dateFinExercice = new Damj(anneeExercice, 12, 31);
      listeExercices.add(new Periode(dateDebutExercice, dateFinExercice));
    }
    return listeExercices;
  }
  
  public QuantiteEuro getSjri()
    throws CoucheLogiqueException
  {
    if (getDiviseur().compareTo(BigDecimal.ZERO) == 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_INCOHERENCE_DIVISEUR", 2);
    }
    BigDecimal sjriCourant = Mathematiques.diviseParDefaut(getSrip(), getDiviseur());
    BigDecimal valeurSjri = Mathematiques.tronque(sjriCourant, 2);
    
    return new QuantiteEuro(valeurSjri);
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString() + "\n");
    chaineRetour.append("Prip : " + getPrip() + "\n");
    chaineRetour.append("Srip : " + getSrip() + "\n");
    chaineRetour.append("Diviseur (D) : " + getDiviseur() + "\n");
    chaineRetour.append("Durée Prc (N) : " + getDureePrc() + "\n");
    chaineRetour.append("n : " + getNombreJourDeductible() + "\n");
    chaineRetour.append("na : " + getNombreJourAbsence() + "\n");
    chaineRetour.append("ni : " + getNombreJourInappartenance() + "\n");
    chaineRetour.append("H : " + getNombreHeuresTotal() + "\n");
    chaineRetour.append("h : " + getNombreHeuresA4ouA5() + "\n");
    if (!getChronoActiviteSalarie().estVide()) {
      chaineRetour.append("Chrono périodes activités salariées : " + getChronoActiviteSalarie() + "\n");
    }
    if (!getChronoPeriodesDeductibles().estVide()) {
      chaineRetour.append("Chrono périodes déductibles : " + getChronoPeriodesDeductibles() + "\n");
    }
    chaineRetour.append("Top contrats type particulier : " + isTopContratsDeTypeParticulier() + "\n");
    
    return chaineRetour.toString();
  }
  
  public void setDateDebut(Damj dateDebut)
  {
    setPeriode(new Periode(dateDebut, getDateFin()));
  }
  
  public void setDateFin(Damj dateFin)
  {
    setPeriode(new Periode(getDateDebut(), dateFin));
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant() {}
  
  public void jdoPreStore() {}
  
  public void copieElements(ObjetMetierSpec pcopie)
  {
    Prc copie = (Prc)pcopie;
    if (getPeriode() != null) {
      copie.setPeriode(new Periode(getPeriode().getDebut(), getPeriode().getFin()));
    }
    if (getChronoActiviteSalarie() != null)
    {
      Iterator iter = getChronoActiviteSalarie().iterer();
      while (iter.hasNext())
      {
        ActiviteSalarie element = (ActiviteSalarie)iter.next();
        copie.ajouterActiviteSalarie(element);
      }
    }
    if (getChronoPeriodesDeductibles() != null)
    {
      Iterator iter = getChronoPeriodesDeductibles().iterer();
      while (iter.hasNext())
      {
        ObjetChronoPeriode element = (ObjetChronoPeriode)iter.next();
        copie.ajouterPeriodeDeductible(element);
      }
    }
    if (getPrip() != null) {
      copie.setPrip(new Periode(getPrip().getDebut(), getPrip().getFin()));
    }
    copie.setDiviseur(getDiviseur());
    copie.setDureePrc(getDureePrc());
    copie.setNombreHeuresTotal(getNombreHeuresTotal());
    copie.setNombreJourAbsence(getNombreJourAbsence());
    copie.setNombreJourDeductible(getNombreJourDeductible());
    copie.setSrip(getSrip());
    copie.setDroitCongesA4ouA5(getDroitCongesA4ouA5());
    copie.setNombreHeuresA4ouA5(getNombreHeuresA4ouA5());
    copie.setNombreJourInappartenance(getNombreJourInappartenance());
    copie.setNombreJourTravailEffectif(getNombreJourTravailEffectif());
    copie.setTopContratsDeTypeParticulier(isTopContratsDeTypeParticulier());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  private BigDecimal determinerAbsenceMinimale(Periode periodeUnitaire, Chronologie chronoPeriodeSalaireAvecAbsence, ChronologiePeriodes chronoPeriodeSalaireSansAbsence)
  {
    BigDecimal nbreJoursAbsencePlusPetit = null;
    
    ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodeSalaireSansAbsence, periodeUnitaire);
    if ((chronoPeriodesComplementaires == null) || (chronoPeriodesComplementaires.estVide()))
    {
      nbreJoursAbsencePlusPetit = BigDecimal.ZERO;
    }
    else
    {
      Salaire periodeSalaireAvecAbsenceCourante = null;
      chronoPeriodeSalaireAvecAbsence.iterer();
      while (chronoPeriodeSalaireAvecAbsence.encoreSuivant())
      {
        periodeSalaireAvecAbsenceCourante = (Salaire)chronoPeriodeSalaireAvecAbsence.elementSuivant();
        if (periodeSalaireAvecAbsenceCourante.chevauche(periodeUnitaire))
        {
          BigDecimal cumulJoursAbsenceProratiseSurPeriodeUnitaire = determinerAbsenceCumuleeHorsSalaireSansAbsence(periodeSalaireAvecAbsenceCourante, chronoPeriodesComplementaires);
          if ((nbreJoursAbsencePlusPetit == null) || (cumulJoursAbsenceProratiseSurPeriodeUnitaire.compareTo(nbreJoursAbsencePlusPetit) < 0)) {
            nbreJoursAbsencePlusPetit = cumulJoursAbsenceProratiseSurPeriodeUnitaire;
          }
        }
      }
    }
    return nbreJoursAbsencePlusPetit;
  }
  
  private BigDecimal determinerAbsenceCumuleeHorsSalaireSansAbsence(Salaire periodeSalaireAvecAbsence, ChronologiePeriodes chronoPeriodesHorsSalaireSansAbsence)
  {
    BigDecimal cumulJoursAbsenceRetourne = BigDecimal.ZERO;
    ObjetChronoPeriode periodeComplementaireCourante = null;
    Periode periodeCouranteHorsPeriodesSalairesSansAbsence = null;
    
    chronoPeriodesHorsSalaireSansAbsence.iterer();
    while (chronoPeriodesHorsSalaireSansAbsence.encoreSuivant())
    {
      periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesHorsSalaireSansAbsence.elementSuivant();
      periodeCouranteHorsPeriodesSalairesSansAbsence = new Periode(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
      
      BigDecimal nbreJoursAbsenceProratisesCourant = Mathematiques.arrondiASup(periodeSalaireAvecAbsence.determinerNombreJoursAbsence(periodeCouranteHorsPeriodesSalairesSansAbsence), 2);
      
      cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(nbreJoursAbsenceProratisesCourant);
    }
    return cumulJoursAbsenceRetourne;
  }
  
  private ChronologiePeriodes determinerChronoChevauchementsPeriodeSalaireAvecAbsence(Demande demande, Chronologie chronoPeriodeActivite)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne = new ChronologiePeriodes();
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeSalaireAvecAbsence());
    listeFiltresExclusifs.ajouterFiltre(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(listeFiltresExclusifs);
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    ChronologiePeriodes chronoGlobalePeriodeSalaireAvecAbsence = new ChronologiePeriodes();
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    chronoPeriodeActivite.iterer();
    while (chronoPeriodeActivite.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoPeriodeActivite.elementSuivant();
      if (periodeActiviteSalarieCourante.getContrat().estSuspensionChomageSansRCT())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(demande, periodeActiviteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide())) {
          chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesSuspension);
        }
      }
      else
      {
        chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, periodeActiviteSalarieCourante);
        
        chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesSalairePnds.copier(listeFiltres));
        
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(demande, periodeActiviteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide())) {
          chronoGlobalePeriodeSalaireAvecAbsence.ajouter(chronoPeriodesNonRemunereesApresDjtp);
        }
      }
    }
    if ((chronoGlobalePeriodeSalaireAvecAbsence != null) && (chronoGlobalePeriodeSalaireAvecAbsence.contientChevauchementElements()))
    {
      ObjetChronoPeriode objetChronoPeriodeFusionneeCourante = null;
      Periode periodeFusionneeCourante = null;
      Chronologie chronoPeriodesChevauchantPeriodeCourante = null;
      
      ChronologiePeriodes chronoPeriodesFusionnees = chronoGlobalePeriodeSalaireAvecAbsence.fusionnerChevauchementPeriodes();
      
      chronoPeriodesFusionnees.iterer();
      while (chronoPeriodesFusionnees.encoreSuivant())
      {
        objetChronoPeriodeFusionneeCourante = (ObjetChronoPeriode)chronoPeriodesFusionnees.elementSuivant();
        periodeFusionneeCourante = new Periode(objetChronoPeriodeFusionneeCourante.getDateDebut(), objetChronoPeriodeFusionneeCourante.getDateFin());
        
        chronoPeriodesChevauchantPeriodeCourante = chronoGlobalePeriodeSalaireAvecAbsence.copier(new FiltreChevauchePeriode(periodeFusionneeCourante));
        if ((chronoPeriodesChevauchantPeriodeCourante != null) && (chronoPeriodesChevauchantPeriodeCourante.getTaille() > 1)) {
          chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne.ajouter(chronoPeriodesChevauchantPeriodeCourante);
        }
      }
    }
    return chronoChevauchementsPeriodeSalaireAvecAbsenceRetourne;
  }
  
  private BigDecimal traiterChevauchementsPeriodeSalaireAvecAbsence(Demande demande, ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsence, boolean absenceDeductible, ChronologiePeriodes chronoPeriodeSalaireSansAbsence)
    throws CoucheLogiqueException
  {
    BigDecimal cumulJoursAbsence = BigDecimal.ZERO;
    
    ObjetChronoPeriode objetChronoPeriodeFusionneeCourante = null;
    Periode periodeFusionneeCourante = null;
    ChronologiePeriodes chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante = null;
    ChronologiePeriodes chronoActiviteSalarieAbsenceMinimalePourJustification = null;
    List listePeriodesUnitaires = null;
    Periode periodeUnitaireCourante = null;
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = null;
    Periode periodeIntersectionPrcCourante = null;
    int nbJoursDeductiblesSurSalaireCourant = 0;
    int nbJoursAbsenceArrondi = 0;
    int nbJoursAbsenceDeductible = 0;
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    
    ChronologiePeriodes chronoPeriodesFusionnees = chronoChevauchementsPeriodeSalaireAvecAbsence.fusionnerChevauchementPeriodes();
    
    chronoPeriodesFusionnees.iterer();
    Iterator iter;
    while (chronoPeriodesFusionnees.encoreSuivant())
    {
      objetChronoPeriodeFusionneeCourante = (ObjetChronoPeriode)chronoPeriodesFusionnees.elementSuivant();
      periodeFusionneeCourante = new Periode(objetChronoPeriodeFusionneeCourante.getDateDebut(), objetChronoPeriodeFusionneeCourante.getDateFin());
      
      chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante = (ChronologiePeriodes)chronoChevauchementsPeriodeSalaireAvecAbsence.copier(new FiltreChevauchePeriode(periodeFusionneeCourante));
      
      listePeriodesUnitaires = OutillageChronologiePeriodes.decouper(periodeFusionneeCourante.periodeIntersection(periodeReference), chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante);
      for (iter = listePeriodesUnitaires.iterator(); iter.hasNext();)
      {
        periodeUnitaireCourante = (Periode)iter.next();
        
        BigDecimal nbreJoursAbsencePlusPetit = determinerAbsenceMinimale(periodeUnitaireCourante, chronoPeriodesSalaireAvecAbsenceChevauchantPeriodeCourante, chronoPeriodeSalaireSansAbsence);
        if (nbreJoursAbsencePlusPetit.compareTo(BigDecimal.ZERO) > 0)
        {
          chronoActiviteSalarieAbsenceMinimalePourJustification = reconstruireChronoActiviteSalarieAbsenceMinimale(demande, periodeUnitaireCourante);
          if (absenceDeductible)
          {
            periodeIntersectionPrcCourante = periodeUnitaireCourante.periodeIntersection(periodeReference);
            nbJoursDeductiblesSurSalaireCourant = periodeIntersectionPrcCourante.inter((ChronologiePeriodes)m_chronoPeriodesDeductibles);
            
            nbJoursAbsenceArrondi = Mathematiques.arrondiASup(nbreJoursAbsencePlusPetit, 0).intValue();
            if (nbJoursAbsenceArrondi > nbJoursDeductiblesSurSalaireCourant)
            {
              nbJoursAbsenceDeductible = nbJoursAbsenceArrondi - nbJoursDeductiblesSurSalaireCourant;
              
              cumulJoursAbsence = cumulJoursAbsence.add(new BigDecimal(nbJoursAbsenceDeductible));
              if (m_listeJustificationDiviseurPeriodesParticipantes != null)
              {
                justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeUnitaireCourante);
                
                justifDiviseurPeriodeParticipanteCourante.renseignerNatureMultiplePeriode(chronoActiviteSalarieAbsenceMinimalePourJustification);
                justifDiviseurPeriodeParticipanteCourante.setNombreJoursDeductibles(nbJoursAbsenceDeductible);
                m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
              }
            }
          }
          else
          {
            cumulJoursAbsence = cumulJoursAbsence.add(nbreJoursAbsencePlusPetit);
            if (m_listeJustificationDiviseurPeriodesParticipantes != null)
            {
              justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeUnitaireCourante);
              
              justifDiviseurPeriodeParticipanteCourante.renseignerNatureMultiplePeriode(chronoActiviteSalarieAbsenceMinimalePourJustification);
              justifDiviseurPeriodeParticipanteCourante.setNombreJourAbsence(nbreJoursAbsencePlusPetit);
              m_listeJustificationDiviseurPeriodesParticipantes.ajouter(justifDiviseurPeriodeParticipanteCourante);
            }
          }
        }
      }
    }
    return cumulJoursAbsence;
  }
  
  private ChronologiePeriodes determinerChronoPeriodesSalaireSansAbsenceChevauchantPrc(Demande demande, Chronologie chronoActivites)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodeSalaireSansAbsenceChevauchantPrc = new ChronologiePeriodes();
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    
    FiltresTemporel listeFiltresSalaireSansAbsenceChevauchantPrc = new FiltresTemporel();
    listeFiltresSalaireSansAbsenceChevauchantPrc.ajouterFiltre(new FiltrePeriodeSalaireSansAbsence());
    listeFiltresSalaireSansAbsenceChevauchantPrc.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    chronoActivites.iterer();
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Chronologie chronoPeriodesSalairePnds = null;
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      
      chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, periodeActiviteSalarieCourante);
      
      chronoPeriodeSalaireSansAbsenceChevauchantPrc.ajouter(chronoPeriodesSalairePnds.copier(listeFiltresSalaireSansAbsenceChevauchantPrc));
    }
    return chronoPeriodeSalaireSansAbsenceChevauchantPrc;
  }
  
  private void calculerDroitCongesA4ouA5(Demande demande, Reglement reglementApplicable)
  {
    calculerNombreHeuresA4ouA5(demande, reglementApplicable);
    setDroitCongesA4ouA5(Mathematiques.tronque(Mathematiques.diviseParDefaut(new BigDecimal(getNombreHeuresA4ouA5()), new BigDecimal("52")), 0).intValue());
  }
  
  private void calculerNombreHeuresA4ouA5(Demande demande, Reglement reglementApplicable)
  {
    int nombreHeuresA4ouA5ActiviteDansPrc = 0;
    
    DecorReglementaire decor = ((DossierAffectation)demande.getDossierAffectation()).getDecorReglementaire();
    FiltrePeriodesSurFiltresExclusifs listeFiltresA4OuA5 = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresA4OuA5.ajouterFiltre(new FiltreMemeRegime("A4", decor));
    listeFiltresA4OuA5.ajouterFiltre(new FiltreMemeRegime("A5", decor));
    Chronologie chronoActivitesA4OuA5ChevauchantPrc = m_chronoActiviteSalarie.copier(listeFiltresA4OuA5);
    if (!chronoActivitesA4OuA5ChevauchantPrc.estVide()) {
      nombreHeuresA4ouA5ActiviteDansPrc = calculerNombreHeuresActiviteDansPrc(chronoActivitesA4OuA5ChevauchantPrc, reglementApplicable, false).intValue();
    }
    setNombreHeuresA4ouA5(nombreHeuresA4ouA5ActiviteDansPrc);
  }
  
  protected abstract void calculerNombreJourInappartenance(Demande paramDemande);
  
  public QuantiteEuro getPlafondSjr()
  {
    QuantiteEuro plafondSjr = null;
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    BigDecimal plafondMensuelApplicable = parametresIndemnisation.getElementActif(getDateFin()).getPlafond();
    
    BigDecimal nominateur1 = new BigDecimal("12");
    BigDecimal nominateur2 = plafondMensuelApplicable;
    BigDecimal denominateur = new BigDecimal("365");
    BigDecimal valeurPlafondSjr = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
    
    valeurPlafondSjr = Mathematiques.tronque(valeurPlafondSjr, 2);
    plafondSjr = new QuantiteEuro(valeurPlafondSjr);
    
    return plafondSjr;
  }
  
  public Chronologie getChronoActiviteSalarie()
  {
    return m_chronoActiviteSalarie;
  }
  
  public Chronologie getChronoPeriodesDeductibles()
  {
    return m_chronoPeriodesDeductibles;
  }
  
  public Chronologie getChronoActiviteSalarieParticipantSr()
  {
    return m_chronoActiviteSalarieParticipantSr;
  }
  
  public void viderChronologies()
  {
    m_chronoActiviteSalarie.vider();
    m_chronoPeriodesDeductibles.vider();
  }
  
  protected abstract JustificationSjr recupererJustificationSjr(Demande paramDemande);
  
  protected abstract String donnerCodeAlerteNonBloquanteSurAbsenceSalaire();
  
  private ChronologiePeriodes reconstruireChronoActiviteSalarieAbsenceMinimale(Demande demande, Periode periodeRechercheAbsenceMinimale)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoActiviteSalarieRetournee = new ChronologiePeriodes();
    
    FiltresTemporel listeFiltresSalaires = new FiltresTemporel();
    listeFiltresSalaires.ajouterFiltre(new FiltrePeriodeSalaireAvecAbsence());
    listeFiltresSalaires.ajouterFiltre(new FiltreChevauchePeriode(periodeRechercheAbsenceMinimale));
    
    ActiviteSalarie activiteSalarieCourante = null;
    Chronologie chronoSalairesRetenus = null;
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    Chronologie chronoActiviteSalariePrcGlobale = getChronoActiviteSalarie();
    chronoActiviteSalariePrcGlobale.iterer();
    while (chronoActiviteSalariePrcGlobale.encoreSuivant())
    {
      activiteSalarieCourante = (ActiviteSalarie)chronoActiviteSalariePrcGlobale.elementSuivant();
      
      chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, activiteSalarieCourante);
      
      chronoSalairesRetenus = chronoPeriodesSalairePnds.copier(listeFiltresSalaires);
      if (!chronoSalairesRetenus.estVide())
      {
        chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
      }
      else if (activiteSalarieCourante.getContrat().estSuspensionChomageSansRCT())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(demande, activiteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide()) && (periodeRechercheAbsenceMinimale.inter(chronoPeriodesSuspension) > 0)) {
          chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
        }
      }
      else
      {
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(demande, activiteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide()) && (periodeRechercheAbsenceMinimale.inter(chronoPeriodesNonRemunereesApresDjtp) > 0)) {
          chronoActiviteSalarieRetournee.ajouter(activiteSalarieCourante);
        }
      }
    }
    return chronoActiviteSalarieRetournee;
  }
  
  private ChronologiePeriodes determinerChronoPeriodesNonRemunereesApresDjtp(Demande demande, ActiviteSalarie periodeActiviteSalarie)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodesNonRemunereesRetournee = new ChronologiePeriodes();
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    
    Damj dernierJourTravaillePaye = periodeActiviteSalarie.getDernierJourTravaillePaye();
    if (dernierJourTravaillePaye != null) {
      if (dernierJourTravaillePaye.estAvant(periodeActiviteSalarie.getDateFin()))
      {
        Damj dateDebutPeriodeApresDjtp = dernierJourTravaillePaye.lendemain();
        Damj dateDebutActiviteSalarie = periodeActiviteSalarie.getDateDebut();
        if (dernierJourTravaillePaye.estAvant(dateDebutActiviteSalarie)) {
          dateDebutPeriodeApresDjtp = dateDebutActiviteSalarie;
        }
        Periode periodeApresDjtp = new Periode(dateDebutPeriodeApresDjtp, periodeActiviteSalarie.getDateFin());
        if (periodeApresDjtp.chevauche(periodeReference))
        {
          Chronologie chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, periodeActiviteSalarie);
          
          ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoPeriodesSalairePnds, periodeApresDjtp.periodeIntersection(periodeReference));
          if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
          {
            chronoPeriodesComplementaires.iterer();
            ObjetChronoPeriode periodeComplementaireCourante = null;
            Salaire periodeSalaireExclueCourante = null;
            while (chronoPeriodesComplementaires.encoreSuivant())
            {
              periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
              
              periodeSalaireExclueCourante = new Salaire(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
              
              periodeSalaireExclueCourante.setMontantSoumisAContribution(new QuantiteEuro("0"));
              periodeSalaireExclueCourante.setExclus(true);
              
              chronoPeriodesNonRemunereesRetournee.ajouter(periodeSalaireExclueCourante);
            }
          }
        }
      }
    }
    return chronoPeriodesNonRemunereesRetournee;
  }
  
  private Chronologie determinerChronoPeriodesSalairePnds(Demande demande, ActiviteSalarie pas)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesNonRemunereesRetournee = null;
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demande.getFaitGenerateur().getDateFaitGenerateur());
    StrategieSjrPndsSpec strategieSjrPndsCourante = (StrategieSjrPndsSpec)FabriqueStrategieSjrPnds.getInstance().getStrategie(critereStrategie);
    
    chronoPeriodesNonRemunereesRetournee = strategieSjrPndsCourante.determinerChronoPeriodesSalaire(demande, pas);
    
    return chronoPeriodesNonRemunereesRetournee;
  }
  
  private void gestionAlerteBloquanteDiviseurNegatif(int cas, BigDecimal diviseurPrcCourante, BigDecimal dureePrcBigDecimal, BigDecimal nombreJourDeductibleBigDecimal, BigDecimal diviseurCasGeneral, BigDecimal droitCongesBigDecimal, boolean estCalculSJR, String reglementApplicable)
    throws CoucheLogiqueException
  {
    StringBuffer message = new StringBuffer();
    message.append("Diviseur pour ").append(estCalculSJR ? "SJR " : "SJC ");
    message.append(reglementApplicable).append(" sur PRC (").append(getDateDebut()).append("-").append(getDateFin()).append(") :");
    switch (cas)
    {
    case 1: 
      message.append(" ").append("N - (ni + na)").append(" -> ");
      message.append(String.valueOf(getDureePrc())).append(" - ").append("(").append(getNombreJourInappartenance()).append(" + ");
      message.append(getNombreJourAbsence()).append(") = ").append(diviseurPrcCourante.toString());
      break;
    case 2: 
      message.append(" ").append("Max de (N - n; D0)").append(" -> Max [ ");
      message.append(dureePrcBigDecimal.toString()).append(" - ").append(nombreJourDeductibleBigDecimal.toString());
      message.append("; ").append(diviseurCasGeneral.toString()).append(" ] = ").append(diviseurPrcCourante.toString());
      break;
    case 3: 
      message.append(" ").append("Max de (N - (n + j); H / 10; D0)").append(" -> Max [ ");
      message.append(dureePrcBigDecimal.toString()).append(" - ").append("(").append(nombreJourDeductibleBigDecimal.toString());
      message.append(" + ").append(droitCongesBigDecimal.toString()).append("); ").append(getNombreHeuresTotal().toString());
      message.append(" / 10; ").append(diviseurCasGeneral.toString()).append(" ] = ").append(diviseurPrcCourante.toString());
      break;
    case 4: 
      message.append(" ").append("Max de (N - (n + j); D0)").append(" -> Max [ ");
      message.append(dureePrcBigDecimal.toString()).append(" - ").append("(").append(nombreJourDeductibleBigDecimal.toString());
      message.append(" + ").append(droitCongesBigDecimal.toString()).append("); ");
      message.append(diviseurCasGeneral.toString()).append(" ] = ").append(diviseurPrcCourante.toString());
    }
    throw new CoucheLogiqueException("ASU_PR_CALI_L_ERR_DIVISEUR_INF_OU_EGAL_A_ZERO", message.toString());
  }
  
  private ChronologiePeriodes determinerChronoPeriodesSuspension(Demande demande, ActiviteSalarie periodeActiviteSalarie)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodesNonRemunereesRetournee = new ChronologiePeriodes();
    
    Periode periodeReference = new Periode(getDateDebut(), getDateFin());
    if (periodeActiviteSalarie.getContrat().estSuspensionChomageSansRCT())
    {
      Periode periodeSuspension = new Periode(periodeActiviteSalarie.getDateDebut(), periodeActiviteSalarie.getDateFin());
      if (periodeSuspension.chevauche(periodeReference))
      {
        Chronologie chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(demande, periodeActiviteSalarie);
        
        ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoPeriodesSalairePnds, periodeSuspension.periodeIntersection(periodeReference));
        if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
        {
          chronoPeriodesComplementaires.iterer();
          ObjetChronoPeriode periodeComplementaireCourante = null;
          Salaire periodeSalaireExclueCourante = null;
          while (chronoPeriodesComplementaires.encoreSuivant())
          {
            periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
            
            periodeSalaireExclueCourante = new Salaire(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin());
            
            periodeSalaireExclueCourante.setMontantSoumisAContribution(new QuantiteEuro("0"));
            periodeSalaireExclueCourante.setExclus(true);
            
            chronoPeriodesNonRemunereesRetournee.ajouter(periodeSalaireExclueCourante);
          }
        }
      }
    }
    return chronoPeriodesNonRemunereesRetournee;
  }
}

/* Location:
 * Qualified Name:     Prc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */