package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.RevisionGen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ContributionParticuliere;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public class Revision
  extends RevisionGen
  implements RevisionSpec
{
  private static final long serialVersionUID = 4764233332022121407L;
  private static final String DEBUG_ATTRIBUTION_PRECEDENTE_NON_TROUVEE = "Impossible de trouver l'attribution précédente.";
  
  public Revision() {}
  
  public Revision(DomPCSpec revisionPC)
  {
    super(revisionPC);
  }
  
  public Revision(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Revision(Damj dateEvenement, DossierExamen dossierExamen)
  {
    this(dateEvenement);
    copie(dossierExamen);
  }
  
  public String getReferenceExterne()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getReferenceExterne();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getReferenceExterne", "Impossible de trouver l'attribution précédente.");
    }
    return null;
  }
  
  public String getRsod()
  {
    String rsod = "0";
    if (getAttributionPrecedente() != null) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String getSituationParticuliere()
  {
    return "";
  }
  
  public ObjetMetierSpec copie()
  {
    Revision copie = new Revision();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieSpec)
  {
    Revision copie = (Revision)copieSpec;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copie.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copie.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copie.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copie.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copie.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copie.getConstitutionElementsRevision());
    
    copie.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copie.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copie.setDateEvenement(getDateEvenement());
    copie.setNatureDecision(getNatureDecision());
    copie.setAttributionPrecedente(getAttributionPrecedente());
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return getConstitutionQuantiteAffiliation().getJustificationAffiliation();
  }
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
  
  private Attribution recupererAttributionPrecedente()
  {
    if ((getAttributionPrecedente() instanceof Attribution)) {
      return (Attribution)getAttributionPrecedente();
    }
    return null;
  }
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)getOuvertureDroit();
    if (attributionOrigine != null) {
      return attributionOrigine.getFaitGenerateur();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public CompetenceSpec getCompetence()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if ((attributionPrecedente != null) && (!attributionPrecedente.getDemande().estEnReExamen()) && (!attributionPrecedente.getDemande().estDemandeLiquidee()))
    {
      CompetenceSpec competence = (CompetenceSpec)attributionPrecedente.getCompetence().copie();
      setCompetence(competence);
      return competence;
    }
    setAttributionPrecedente(null);
    CompetenceSpec competenceAdministrativeParDefaut = new Competence();
    competenceAdministrativeParDefaut.setCompetenceFinanciere(1);
    competenceAdministrativeParDefaut.setCompetenceAdministrative(1);
    setCompetence(competenceAdministrativeParDefaut);
    return competenceAdministrativeParDefaut;
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsRevision().getConstitutionDurees();
  }
  
  public ConstitutionQuantiteAffiliation getConstitutionQuantiteAffiliation()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionQuantiteAffiliation();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getConstitutionQuantiteAffiliation", "Impossible de trouver l'attribution précédente.");
    }
    return null;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionReglementApplicable();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getConstitutionReglementApplicable", "Impossible de trouver l'attribution précédente.");
    }
    return null;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCaractereSaisonnier();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getConstitutionCaractereSaisonnier", "Impossible de trouver l'attribution précédente.");
    }
    return null;
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCoefficientSaisonnier();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getConstitutionCoefficientSaisonnier", "Impossible de trouver l'attribution précédente.");
    }
    return null;
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsRevision().getConstitutionSjr();
  }
  
  public ConstitutionDelais getConstitutionDelais()
  {
    return getConstitutionElementsRevision().getConstitutionDelais();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsRevision().getConstitutionSjc();
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsRevision().getConstitutionDateAttribution();
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsRevision().getConstitutionMontantsBruts();
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsRevision().getConstitutionPointDepartIndemnisation();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsRevision().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConstitutionProduitResultant getConstitutionProduitResultant()
  {
    return null;
  }
  
  public ConstitutionElementsSpec getConstitutionElementsActifs()
  {
    return getConstitutionElementsRevision();
  }
  
  public ConditionsAttributionSpec getConditionsAttributionActives()
  {
    return getConditionsAttributionRevision();
  }
  
  public ConditionMontantRevise getConditionMontantRevise()
  {
    return getConditionsAttributionRevision().getConditionMontantRevise();
  }
  
  public Sjc getSJC()
  {
    Sjc sjcTemporaire = null;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      sjcTemporaire = new Sjc(getConstitutionSjc().getSjcip().getSjcInitial().getValeur(), getConstitutionSjc().getSjcip().getDateEffet(), null);
    } else {
      sjcTemporaire = new Sjc(BigDecimal.ZERO, getConstitutionSjr().getSjrip().getDateEffet(), null);
    }
    return sjcTemporaire;
  }
  
  public Collection getListeDelaisReports()
  {
    return getConstitutionDelais().getListeDelaisReports();
  }
  
  public Collection getListeCarences()
  {
    return getConstitutionDelais().getListeCarences();
  }
  
  public Quantite getMontantAttributionPrecedente()
    throws CoucheLogiqueException
  {
    Attribution attribution = recupererAttributionPrecedente();
    if (attribution != null)
    {
      MontantAsuSpec montantPrecedent = attribution.getMontantRecalcule(getDemande().getDateDeclenchementExamen());
      if (montantPrecedent != null) {
        return montantPrecedent.getMontantPrecompteEffectif();
      }
    }
    return null;
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().isInvestigationFraude();
    }
    return false;
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((getMaintienEuropeenPrive() == null) && (recupererAttributionPrecedente() != null)) {
      if (recupererAttributionPrecedente().getMaintienEuropeen() == null) {
        setMaintienEuropeenPrive(MaintienEuropeen.getInstanceMaintienEuropeen(this));
      } else {
        setMaintienEuropeenPrive(recupererAttributionPrecedente().getMaintienEuropeen());
      }
    }
    return getMaintienEuropeenPrive();
  }
  
  public boolean estRejetDV()
  {
    return false;
  }
  
  protected void verifierCoherenceReferenceExterne() {}
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public Quantite getCapitalAServir()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getCapitalAServir();
    }
    return null;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public int getType()
  {
    return 1;
  }
  
  public boolean porteUnRejetDv()
  {
    return false;
  }
  
  public boolean estExecutable()
  {
    boolean resultat = false;
    if (super.estExecutable())
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePeriodes.recupererPeriodePECContenant(getDemandeur(), getDateAttribution());
      if ((periodePEC != null) && ((periodePEC.getTypePec() == null) || (periodePEC.getSousType() == null) || (nestPasDeTypeAdrOuArce(periodePEC)))) {
        resultat = true;
      }
    }
    return resultat;
  }
  
  private boolean nestPasDeTypeAdrOuArce(ObjetChronoPeriodePriseEnCharge periodePEC)
  {
    return (!periodePEC.estDeTypeAdr()) && (!periodePEC.estDeTypeArce());
  }
}

/* Location:
 * Qualified Name:     Revision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */