package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.SjcipGen;
import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjcipSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;

public class Sjcip
  extends SjcipGen
  implements ObjetPersistantSpec, SjcipSpec
{
  private static final long serialVersionUID = 1L;
  
  private Sjcip()
  {
    if (getDateEvenement() == null) {
      setDateEvenement(new Damj());
    }
  }
  
  public Sjcip(DomPCSpec cepAbstraitPC)
  {
    super(cepAbstraitPC);
  }
  
  private Sjcip(Damj dateEffet)
  {
    super(dateEffet);
    
    setDateEvenement(dateEffet);
  }
  
  public Sjcip(Damj dateEffet, QuantiteEuro plafondSjr, QuantiteEuro sjcInitial, DomPCSpec cepAbstraitPC)
  {
    super(cepAbstraitPC);
    setPlafond(plafondSjr);
    setSjcInitial(sjcInitial);
    setDateEvenement(dateEffet);
  }
  
  public BigDecimal getSjcip()
  {
    BigDecimal valeurSjcip = BigDecimal.ZERO;
    if ((getSjcInitial() != null) && (getPlafond() != null)) {
      valeurSjcip = getSjcInitial().getValeur().min(getPlafond().getValeur());
    } else if (getSjcInitial() != null) {
      valeurSjcip = getSjcInitial().getValeur();
    } else if (getPlafond() != null) {
      valeurSjcip = getPlafond().getValeur();
    }
    return valeurSjcip;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString());
    chaineRetour.append("\n");
    chaineRetour.append("Plafond Sjc : ");
    chaineRetour.append(getPlafond());
    chaineRetour.append("\n");
    chaineRetour.append("Sjc Initial : ");
    chaineRetour.append(getSjcInitial());
    chaineRetour.append("\n");
    chaineRetour.append("Liste Sjr Activité Conservée : ");
    chaineRetour.append(getCollectionSjrActiviteConservee());
    return chaineRetour.toString();
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionSjrActiviteConservee());
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    Sjcip copie = (Sjcip)pCopie;
    copie.setDateEvenement(getDateEvenement());
    
    Iterator iter = getCollectionSjrActiviteConservee().iterator();
    while (iter.hasNext())
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      copie.ajouterSjrActiviteConservee((SjrActiviteConservee)element.copie());
    }
    copie.setPlafond(getPlafond());
    
    copie.setSjcInitial(getSjcInitial());
  }
  
  public Collection getCollectionSjrActiviteConserveePerdue()
  {
    ArrayList listeActiviteConserveePerdue = new ArrayList();
    SjrActiviteConservee activite = null;
    Iterator iter = getCollectionSjrActiviteConservee().iterator();
    while (iter.hasNext())
    {
      activite = (SjrActiviteConservee)iter.next();
      if (("P".equals(activite.getTypeActiviteConservee())) || ("R".equals(activite.getTypeActiviteConservee()))) {
        listeActiviteConserveePerdue.add(activite);
      }
    }
    return Collections.unmodifiableCollection(listeActiviteConserveePerdue);
  }
  
  public void viderCollectionSjrActiviteConservee()
  {
    for (Iterator iter = getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      DomManager.supprimer(item);
    }
    super.clearCollectionSjrActiviteConservee();
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void ajouterSjrActiviteConservee(SjrActiviteConserveeSpec sjrActiviteConserveeConstitutionSjc)
  {
    ajouterSjrActiviteConservee((SjrActiviteConservee)sjrActiviteConserveeConstitutionSjc);
  }
  
  public void remplacerCollectionSjrActiviteConservee(Collection collectionACopier)
  {
    for (Iterator i = super.getCollectionSjrActiviteConservee().iterator(); i.hasNext();)
    {
      SjrActiviteConservee objet = (SjrActiviteConservee)i.next();
      DomManager.supprimer(objet);
    }
    super.remplacerCollectionSjrActiviteConservee(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     Sjcip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */