package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationCarenceIccpA4;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.BaseCarence;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategiePriseEnCompteIccp;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteIccpSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public class ConstructionBaseCarence
{
  private static final int MOIS_JUIN = 6;
  private static final int PREMIER_JOUR_MOIS = 1;
  private static ConstructionBaseCarence s_instance = new ConstructionBaseCarence();
  
  public static ConstructionBaseCarence getInstance()
  {
    return s_instance;
  }
  
  public BaseCarence determinerBaseCarence(ActiviteSalarie p_periodeActiviteSalarie, Damj p_dateFg)
  {
    BaseCarence baseCarence = null;
    
    QuantiteEuro quantiteEuroIccp = determinerMontantIccp(p_periodeActiviteSalarie, p_dateFg);
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = (QuantiteJourTravailDansSemaineSpec)p_periodeActiviteSalarie.getQuantiteJourIccp();
    QuantiteEuro quantiteEuroIslr = p_periodeActiviteSalarie.getQuantiteEuroIslr();
    baseCarence = new BaseCarence(quantiteJourIccp, quantiteEuroIccp, quantiteEuroIslr);
    
    baseCarence.setPeriodeActiviteSalarieOrigine(p_periodeActiviteSalarie);
    
    baseCarence.setLicenciementEconomique(p_periodeActiviteSalarie.isLicenciementEconomique());
    
    return baseCarence;
  }
  
  private QuantiteEuro determinerMontantIccp(ActiviteSalarie p_periodeActiviteSalarie, Damj p_dateFg)
  {
    QuantiteEuro quantiteEuroIccpRetournee = null;
    
    Reglement reglementAppartenance = p_periodeActiviteSalarie.getReglement();
    ProduitSpec produit = reglementAppartenance.getProduit();
    if (reglementAppartenance.equals(produit.getReglement("A5"))) {
      quantiteEuroIccpRetournee = determinerMontantIccpA5(p_periodeActiviteSalarie, p_dateFg);
    } else {
      quantiteEuroIccpRetournee = determinerMontantIccpALaFctOdRg(p_periodeActiviteSalarie);
    }
    return quantiteEuroIccpRetournee;
  }
  
  private QuantiteEuro determinerMontantIccpALaFctOdRg(ActiviteSalarie p_periodeActiviteSalarie)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    return strategiePriseEnCompteIccpCourante.determinerMontantIccpALaFctOdRg(p_periodeActiviteSalarie);
  }
  
  private QuantiteEuro determinerMontantIccpA5(ActiviteSalarie p_periodeActiviteSalarie, Damj p_dateFg)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    return strategiePriseEnCompteIccpCourante.determinerMontantIccpA5(p_periodeActiviteSalarie, p_dateFg);
  }
  
  protected QuantiteEuro determinerMontantIccpA5Salaires(ActiviteSalarie p_periodeActiviteSalarie, Damj p_dateFg)
  {
    QuantiteEuro quantiteEuroIccpRetournee = null;
    
    Periode periodeReference = determinerPeriodeReferenceA5(p_dateFg);
    
    Chronologie chronologieResultante = p_periodeActiviteSalarie.getListeSalaires().copier(new FiltreChevauchePeriode(periodeReference));
    Iterator iter = chronologieResultante.iterer();
    BigDecimal txICCP = null;
    BigDecimal txIPE = null;
    BigDecimal cumulMontantsIccp = null;
    while (iter.hasNext())
    {
      Salaire salaire = (Salaire)iter.next();
      
      QuantiteEuro montantICCPSalaire = (QuantiteEuro)salaire.getMontantIccp();
      if (montantICCPSalaire != null)
      {
        if (cumulMontantsIccp == null) {
          cumulMontantsIccp = new BigDecimal("0");
        }
        cumulMontantsIccp = cumulMontantsIccp.add(salaire.getMontantIccp().getValeur());
      }
      else
      {
        txICCP = salaire.getTauxIccp();
        txIPE = salaire.getTauxIndemnisationPrecarite();
      }
      if (txICCP != null)
      {
        if (cumulMontantsIccp == null) {
          cumulMontantsIccp = new BigDecimal("0");
        }
        cumulMontantsIccp = cumulMontantsIccp.add(salaire.getMontantBrutBase().getValeur());
      }
    }
    if (txICCP != null) {
      quantiteEuroIccpRetournee = new QuantiteEuro(determinerMontantIccpA5AvecMajorationRemuneration(cumulMontantsIccp, txICCP, txIPE));
    } else if (cumulMontantsIccp != null) {
      quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccp);
    }
    return quantiteEuroIccpRetournee;
  }
  
  private Periode determinerPeriodeReferenceA5(Damj p_dateFg)
  {
    Damj datePivot = new Damj(p_dateFg.getAnnee(), 6, 1);
    
    Damj dateDebutPeriode = null;
    if (p_dateFg.estApres(datePivot)) {
      dateDebutPeriode = new Damj(p_dateFg.getAnnee() - 1, 6, 1);
    } else {
      dateDebutPeriode = new Damj(p_dateFg.getAnnee() - 2, 6, 1);
    }
    return new Periode(dateDebutPeriode, p_dateFg);
  }
  
  private BigDecimal determinerMontantIccpA5AvecMajorationRemuneration(BigDecimal p_cumulSalaires, BigDecimal p_txIccp, BigDecimal p_txIpe)
  {
    BigDecimal montantIccpCalcule = null;
    BigDecimal denominateur;
    BigDecimal nominateur;
    BigDecimal denominateur;
    if (p_txIpe == null)
    {
      BigDecimal nominateur = p_txIccp;
      denominateur = p_txIccp.add(new BigDecimal("1"));
    }
    else
    {
      nominateur = p_txIccp;
      denominateur = p_txIccp.add(new BigDecimal("1")).multiply(p_txIpe.add(new BigDecimal("1")));
    }
    montantIccpCalcule = Mathematiques.proratiser(p_cumulSalaires, nominateur, denominateur);
    montantIccpCalcule = Mathematiques.arrondiASup(montantIccpCalcule, 2);
    
    return montantIccpCalcule;
  }
  
  public BaseCarence determinerBaseCarenceOdA4(ActiviteSalarie p_periodeFg, Chronologie p_chronologiePendantAttributionsAvecIccpRupture, Chronologie p_chronologieFctHorsAttributions, Periode p_periodeDelaiRechercheCarences, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente)
  {
    BaseCarence baseCarence = null;
    
    QuantiteEuro quantiteEuroIccp = determinerMontantIccpChronoFctOdA4(p_chronologiePendantAttributionsAvecIccpRupture, p_chronologieFctHorsAttributions, p_periodeDelaiRechercheCarences, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
    
    QuantiteEuro quantiteEuroIslr = p_periodeFg.getQuantiteEuroIslr();
    baseCarence = new BaseCarence(null, quantiteEuroIccp, quantiteEuroIslr);
    
    baseCarence.setPeriodeActiviteSalarieOrigine(p_periodeFg);
    
    baseCarence.setLicenciementEconomique(p_periodeFg.isLicenciementEconomique());
    
    return baseCarence;
  }
  
  private QuantiteEuro determinerMontantIccpChronoFctOdA4(Chronologie p_chronologiePendantAttributionsAvecIccpRupture, Chronologie p_chronologieFctHorsAttributions, Periode p_periodeDelaiRechercheCarences, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente)
  {
    QuantiteEuro quantiteEuroIccpRetournee = null;
    BigDecimal cumulMontantsIccpOdA4 = new BigDecimal("0");
    
    ActiviteSalarie periodeTraitee = null;
    QuantiteEuro quantiteEuroIccpCourante = null;
    p_chronologieFctHorsAttributions.iterer();
    while (p_chronologieFctHorsAttributions.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)p_chronologieFctHorsAttributions.elementSuivant();
      
      quantiteEuroIccpCourante = determinerMontantIccpOdA4(periodeTraitee, p_periodeDelaiRechercheCarences, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
      if ((quantiteEuroIccpCourante != null) && (quantiteEuroIccpCourante.getValeurMontant().compareTo(new BigDecimal("0")) > 0)) {
        cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(quantiteEuroIccpCourante.getValeurMontant());
      }
    }
    if (p_chronologiePendantAttributionsAvecIccpRupture != null)
    {
      p_chronologiePendantAttributionsAvecIccpRupture.iterer();
      while (p_chronologiePendantAttributionsAvecIccpRupture.encoreSuivant())
      {
        periodeTraitee = (ActiviteSalarie)p_chronologiePendantAttributionsAvecIccpRupture.elementSuivant();
        
        BigDecimal montantIccpProratise = determinerMontantIccpRuptureOdA4(periodeTraitee, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente, true);
        if (montantIccpProratise != null) {
          cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantIccpProratise);
        }
      }
    }
    quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccpOdA4);
    return quantiteEuroIccpRetournee;
  }
  
  private QuantiteEuro determinerMontantIccpOdA4(ActiviteSalarie p_periodeActiviteSalarie, Periode p_periodeDelaiRechercheCarences, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente)
  {
    QuantiteEuro quantiteEuroIccpRetournee = null;
    BigDecimal cumulMontantsIccpOdA4 = new BigDecimal("0");
    Chronologie chronoPeriodesSalaireCourante = p_periodeActiviteSalarie.getListeSalaires();
    
    BigDecimal montantICCPProratise = determinerMontantIccpRuptureOdA4(p_periodeActiviteSalarie, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente, false);
    if (montantICCPProratise != null) {
      cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantICCPProratise);
    }
    Salaire periodeSalaireCourante = null;
    Damj datePeriodeSalaireCourante = null;
    BigDecimal montantIccpSalaireCourant = null;
    
    chronoPeriodesSalaireCourante.iterer();
    while (chronoPeriodesSalaireCourante.encoreSuivant())
    {
      periodeSalaireCourante = (Salaire)chronoPeriodesSalaireCourante.elementSuivant();
      datePeriodeSalaireCourante = periodeSalaireCourante.getDatePaie() != null ? periodeSalaireCourante.getDatePaie() : periodeSalaireCourante.getDateFin();
      if (p_periodeDelaiRechercheCarences.contient(datePeriodeSalaireCourante))
      {
        montantIccpSalaireCourant = periodeSalaireCourante.determinerMontantIccp();
        if (montantIccpSalaireCourant != null)
        {
          montantIccpSalaireCourant = DeterminationCarenceIccpA4.getInstance().proratiserMontantICCP(montantIccpSalaireCourant, periodeSalaireCourante.getPeriode(), p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente);
          
          cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantIccpSalaireCourant);
        }
      }
    }
    quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccpOdA4);
    return quantiteEuroIccpRetournee;
  }
  
  private BigDecimal determinerMontantIccpRuptureOdA4(ActiviteSalarie p_periodeActiviteSalarie, Damj p_finPeriodeAttributionAsuPrecedente, Damj p_finPeriodeAttributionAssPrecedente, boolean p_estUneChronoPendantAttribution)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    BigDecimal montantICCPProratise = strategiePriseEnCompteIccpCourante.determinerMontantIccpOdA4(p_periodeActiviteSalarie, p_finPeriodeAttributionAsuPrecedente, p_finPeriodeAttributionAssPrecedente, p_estUneChronoPendantAttribution);
    
    return montantICCPProratise;
  }
}

/* Location:
 * Qualified Name:     ConstructionBaseCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */