package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.comparator.ComparatorPRAOrdreQuantiteAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.comparator.ComparatorPRAOrdreReglementApplicable;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.cge01.p03.parametres.ParametrageListePRA;
import fr.unedic.cali.asu.cge01.p03.parametres.ParametrageListePRARechargement;
import fr.unedic.cali.asu.cge01.p03.parametres.ParametragePRAPourDV;
import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.spec.ConstructionPRASpec;
import fr.unedic.cali.dom.spec.PraSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

public class OutilConstructionPRA
  extends fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilConstructionPRA
  implements ConstructionPRASpec
{
  private static final int PROC_ENGAGE_ARE2006 = 0;
  private static final int PROC_ENGAGE_AVANT_ARE2006 = 1;
  
  public Collection<Pra> determinerListePraQuantiteAppartenance(DonneesEntreeDeterminationListePra p_donneesEntreeDeterminationListePra)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_donneesEntreeDeterminationListePra.getDemande();
    if (deleguerTraitementSurProduitPrecedent(demande)) {
      return ProduitAsuCge01P02.getInstance().getOutilConstructionPRA().determinerListePraQuantiteAppartenance(p_donneesEntreeDeterminationListePra);
    }
    Comparator<Pra> comparateur = new ComparatorPRAOrdreReglementApplicable();
    if (ConstructionPra.ORDRE_QUANTITE_APPARTENANCE == p_donneesEntreeDeterminationListePra.getOrdreTriListe())
    {
      Damj dateFG = demande.getFaitGenerateur().getDateFaitGenerateur();
      DureeCalendaire ageFG = demande.getDemandeur().getAgeALaDate(dateFG);
      p_donneesEntreeDeterminationListePra.setAgeIndividu(ageFG);
      comparateur = new ComparatorPRAOrdreQuantiteAppartenance();
    }
    CleAccesPRA cle = construireCleAccesPRA(p_donneesEntreeDeterminationListePra);
    
    ParametrageListePRASpec parametre = null;
    if (p_donneesEntreeDeterminationListePra.isUtiliserParametreAffiRechargement()) {
      parametre = ParametrageListePRARechargement.getInstance();
    } else {
      parametre = ParametrageListePRA.getInstance();
    }
    List listePRA = parametre.getListePra(cle);
    
    Collections.sort(listePRA, comparateur);
    
    return listePRA;
  }
  
  private boolean deleguerTraitementSurProduitPrecedent(Demande p_demande)
  {
    return determinerProcedureEngagement(p_demande) == 1;
  }
  
  private static int determinerProcedureEngagement(Demande p_demande)
  {
    int codeEngagementProcedureLicenciement = 0;
    
    ActiviteSalarie periodeFaitGenerateurOuDernierSinistre = null;
    if ((p_demande.getFaitGenerateur() != null) && (p_demande.getFaitGenerateur().estSatisfait()))
    {
      periodeFaitGenerateurOuDernierSinistre = p_demande.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    else
    {
      TravailSpec dernierSinistre = ((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
      if ((dernierSinistre instanceof ActiviteSalarie)) {
        periodeFaitGenerateurOuDernierSinistre = (ActiviteSalarie)dernierSinistre;
      }
    }
    if (periodeFaitGenerateurOuDernierSinistre != null) {
      codeEngagementProcedureLicenciement = periodeFaitGenerateurOuDernierSinistre.isEngagementProcedureStrictementAvant(ProduitAsuCge01P03.getInstance().getPeriodeValidite().getDebut()) ? 1 : 0;
    }
    return codeEngagementProcedureLicenciement;
  }
  
  public PraSpec determinerPraPourDV(String p_reglement)
  {
    CleAccesPRA cle = new CleAccesPRA(p_reglement);
    
    return ParametragePRAPourDV.getInstanceProduit().getPram(cle);
  }
}

/* Location:
 * Qualified Name:     OutilConstructionPRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */