package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinApresOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Temporel;

public class OutilsChomageSansRCT
  extends fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT
{
  public static boolean estPremiereRepriseApresSuspension(DossierExamenAssuranceSpec p_dossierExamenCourant)
  {
    DemandeAssuranceSpec demande = p_dossierExamenCourant.getDemandeAssurance();
    if (demande.getObjectifCourant().getType() == 2)
    {
      if (estUnContexteRuptureDuContrat(demande))
      {
        FiltreTemporel filtrePeriodesSuspension = new FiltreActiviteSalarieSuspensionChomageSansRCT();
        Chronologie chronoPeriodes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePeriodesSuspension);
        
        OdSpec odPrec = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
        if ((odPrec != null) && (((OdAssuranceSpec)odPrec).getFaitGenerateur() != null))
        {
          Damj dateFgdPrec = ((OdAssuranceSpec)odPrec).getFaitGenerateur().getDateFaitGenerateur();
          if (dateFgdPrec != null) {
            chronoPeriodes = chronoPeriodes.copier(new FiltreFinApresOuCoincideAvecDate(dateFgdPrec.lendemain()));
          }
        }
        Temporel pas = chronoPeriodes.premierElement();
        if (pas != null)
        {
          if (demande.getDateDeclenchementExamen().estAvantOuCoincideAvec(pas.getDateFin())) {
            return false;
          }
          AttributionSpec attributionPrec = demande.rechercherAttributionPrecedenteDuMemeType();
          if (attributionPrec != null) {
            if (attributionPrec.getDateAttribution().coincideAvec(odPrec.getDateAttribution()))
            {
              if (demande.getDateDeclenchementExamen().estAvant(pas.getDateFin())) {
                return false;
              }
            }
            else if (attributionPrec.getDateAttribution().estApresOuCoincideAvec(pas.getDateFin())) {
              return false;
            }
          }
        }
        else
        {
          return false;
        }
        return true;
      }
      return false;
    }
    return false;
  }
  
  public static boolean estUnContexteRuptureDuContrat(DemandeAssuranceSpec p_demande)
  {
    return trouverActiviteSalarieRuptureSurContratGAEC(p_demande) != null;
  }
  
  public static ActiviteSalarie trouverActiviteSalarieRuptureSurContratGAEC(DemandeAssuranceSpec p_demande)
  {
    ActiviteSalarie periodeValidationProduit = trouverDernierSinistre(p_demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodes = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodes.estVide()) {
      return null;
    }
    return (ActiviteSalarie)chronoPeriodes.premierElement();
  }
  
  public static ActiviteSalarie trouverDernierSinistre(DemandeAssuranceSpec p_demande)
  {
    Damj dateRechercheDernierSinistre = p_demande.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRechercheDernierSinistre == null) {
      dateRechercheDernierSinistre = p_demande.getEvenementReferenceExamen().getDateExamen(p_demande);
    }
    return trouverDernierSinistre(p_demande, dateRechercheDernierSinistre);
  }
  
  public static boolean estDansUnePeriodeDeSuspension(DemandeAssuranceSpec p_demande)
  {
    boolean estDansUnePeriodeDeSuspension = false;
    Damj dateRecherche = p_demande.getDateRecherche();
    FiltreTemporel filtrePeriodesSuspension = new FiltreActiviteSalarieSuspensionChomageSansRCT();
    Chronologie chronoPeriodesSuspension = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePeriodesSuspension);
    chronoPeriodesSuspension.iterer();
    while (chronoPeriodesSuspension.encoreSuivant())
    {
      ActiviteSalarie suspension = (ActiviteSalarie)chronoPeriodesSuspension.elementSuivant();
      if (dateRecherche.estContenueDans(suspension.getPeriode())) {
        estDansUnePeriodeDeSuspension = true;
      }
    }
    return estDansUnePeriodeDeSuspension;
  }
}

/* Location:
 * Qualified Name:     OutilsChomageSansRCT
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */