package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.cge01.p03.liquidation.parcours.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutilChronologie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalarieePeriodique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class RechercheConditionChomageInvolontaire
  implements OutilFonctionnel
{
  private static ResultatRechercheConditionChomageInvolontaire rechercherConditionChomageInvolontaire(Demande p_demande, Damj p_fctDV, Reglement p_reglementApplicable)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatRechercheConditionChomageInvolontaire.setResultatElementDroit(resultatElementDroit);
    
    Pra pra = ConstructionPra.determinerPraDv(p_demande, p_fctDV, p_reglementApplicable);
    
    Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(pra, p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipanteTousReglements = ConstructionChronologie.determinerChronoPraTousReglement(pra, p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipante = new ChronologiePeriodes();
    chronoActiviteParticipante.ajouter(chronoActivitesAssimilables);
    chronoActiviteParticipante.ajouter(chronoActiviteParticipanteTousReglements);
    
    chronoActiviteParticipante = chronoActiviteParticipante.copier(new FiltreFinDansBornes(pra.getDebut(), pra.getFin()));
    
    boolean quantiteAppartenance = verifierConditionAffiliation(p_demande, pra, chronoActiviteParticipante);
    if (quantiteAppartenance)
    {
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
      resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(3);
    }
    else
    {
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
      resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(4);
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(92);
    }
    return resultatRechercheConditionChomageInvolontaire;
  }
  
  private static boolean verifierConditionAffiliation(DemandeSpec p_demande, Pra p_pra, Chronologie p_chronoPAS)
    throws ApplicativeException
  {
    ValidationProduitSpec validationProduit = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit();
    ActiviteSalarie periodeActiviteSalariee = null;
    if ((validationProduit == null) || (!validationProduit.isEstProduitValide()))
    {
      AttributionSpec attributionOrigine = ((DemandeAssuranceSpec)p_demande).rechercherOuvertureDroitPrecedenteDuMemeType();
      if (attributionOrigine != null)
      {
        DossierAffectation dossierAffectationOrigine = (DossierAffectation)attributionOrigine.getDemande().getDossierAffectation();
        validationProduit = dossierAffectationOrigine.getValidationProduit();
      }
    }
    if (validationProduit != null) {
      periodeActiviteSalariee = validationProduit.getPeriodeValidationProduit();
    } else {
      periodeActiviteSalariee = (ActiviteSalarie)((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
    }
    Reglement reglementAppartenance = periodeActiviteSalariee.getReglement();
    QuantitesAppartenance quantitesAppartenance = CalculAppartenance.getInstance().calculer(p_demande, null, p_pra, p_chronoPAS, reglementAppartenance);
    
    List listeUnites = AccesListeUnitesReglement.get(reglementAppartenance, null).getListeUnites();
    for (Iterator iter = listeUnites.iterator(); iter.hasNext();)
    {
      Unite unite = (Unite)iter.next();
      Quantite qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      
      Quantite qteAcquise = qteAffiliation.ajouter(qteAssimilation);
      Quantite qteRequise = p_pra.getQuantiteAffiliationRequise(unite);
      if ((qteRequise != null) && (qteAcquise.compareTo(qteRequise) >= 0)) {
        return true;
      }
    }
    return false;
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierChomageInvolontaireDemandeAssurance(Demande p_demandeAssurance, FaitGenerateurSpec p_faitGenerateur)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatRechercheConditionChomageInvolontaire.setResultatElementDroit(resultatElementDroit);
    
    int codeMotifFin = p_faitGenerateur.getPeriodeFaitGenerateur().getCodeMotifFin();
    int contexteDemisison = p_faitGenerateur.getPeriodeFaitGenerateur().getContrat().getContexteDemission();
    
    ProduitSpec produit = ((DossierAffectation)p_demandeAssurance.getDossierAffectation()).getProduit();
    if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison))
    {
      resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(1);
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(91);
    }
    else
    {
      Reglement reglementApplicableCourant = ((DossierAffectation)p_demandeAssurance.getDossierAffectation()).getReglementPeriodeValidationProduit();
      
      reglementApplicableCourant = verificationReglementNonNull(reglementApplicableCourant, p_demandeAssurance.getDossierAffectationAdmission().getJustificationAffectation());
      if (reglementApplicableCourant != null) {
        if (reglementApplicableCourant.equals(produit.getReglement("A3")))
        {
          resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
          resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
        }
        else
        {
          Damj dateDebutRechercheDV = Damj.NUIT_DES_TEMPS;
          Damj dateFinRechercheDV = p_faitGenerateur.getDateFaitGenerateur();
          
          Damj dateFGOdPrec = p_demandeAssurance.getDateFaitGenerateurOdPrecedente();
          if (dateFGOdPrec != null) {
            dateDebutRechercheDV = dateFGOdPrec.lendemain();
          }
          Chronologie chronoToutesPeriodes = p_demandeAssurance.getDemandeur().getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ();
          
          FiltresTemporel filtreChevauchePeriodeEtActiviteSalarie = new FiltresTemporel();
          filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreFinDansBornes(new Periode(dateDebutRechercheDV, dateFinRechercheDV)));
          
          filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreTravailSpec());
          Chronologie chronoDansDelaiRecherche = chronoToutesPeriodes.copier(filtreChevauchePeriodeEtActiviteSalarie);
          
          OutilChronologie.supprimerPeriodeParIdentifiant(chronoDansDelaiRecherche, p_faitGenerateur.getPeriodeFaitGenerateur());
          
          FiltrePeriodesSurFiltresExclusifs listeFiltres = new FiltrePeriodesSurFiltresExclusifs();
          
          FiltrePeriodesSurFiltresExclusifs filtreASupprimer = new FiltrePeriodesSurFiltresExclusifs();
          filtreASupprimer.ajouterFiltre(new FiltrePeriodeActiviteNonSalarieePeriodique());
          filtreASupprimer.ajouterFiltre(new FiltrePeriodesLiquidables(false));
          Chronologie chronoPans = chronoDansDelaiRecherche.copier(filtreASupprimer);
          if (!chronoPans.estVide())
          {
            ListIterator pans = chronoPans.iterer();
            while (pans.hasNext()) {
              chronoDansDelaiRecherche.supprimer((Temporel)pans.next());
            }
          }
          listeFiltres.ajouterFiltre(new FiltrePeriodesAttestees(false));
          
          listeFiltres.ajouterFiltre(new FiltrePeriodesJustifiees(false));
          
          listeFiltres.ajouterFiltre(new FiltrePeriodesAvecConflit());
          
          listeFiltres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
          
          Chronologie chronoFiltreeDansDelaiRecherche = chronoDansDelaiRecherche.copier(listeFiltres);
          if (chronoFiltreeDansDelaiRecherche.estVide())
          {
            resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
            resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
          }
          else
          {
            chronoFiltreeDansDelaiRecherche.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
            TravailSpec dernierePeriode = (TravailSpec)chronoFiltreeDansDelaiRecherche.premierElement();
            
            resultatRechercheConditionChomageInvolontaire = rechercherConditionChomageInvolontaire(p_demandeAssurance, dernierePeriode.getDateFin(), reglementApplicableCourant);
            
            boolean estContexteChomageNonLegitime = fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().determinerChomageNonLegitime(dernierePeriode);
            if (estContexteChomageNonLegitime) {
              return resultatRechercheConditionChomageInvolontaire;
            }
            if (!resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().estSatisfait()) {
              fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable(dernierePeriode);
            }
          }
        }
      }
    }
    return resultatRechercheConditionChomageInvolontaire;
  }
  
  private static Reglement verificationReglementNonNull(Reglement p_reglement, int p_justificationAffectation)
    throws CoucheLogiqueException
  {
    Reglement reglement = p_reglement;
    if (p_reglement == null)
    {
      if ((p_justificationAffectation == 5) || (p_justificationAffectation == 6)) {
        reglement = ProduitAsuCge01P03.getInstance().getReglement("RG");
      }
      if (reglement == null) {
        if (Log.isTraceActive(DeterminationConditionChomageInvolontaire.class, Niveau.DEBUG))
        {
          Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "Règlement porté par la période de validation du produit nul et affectation différente du produit de secours : règlement indéterminable");
          
          throw new CoucheLogiqueException("HG_PR_CALI_L_ERR_CONTEXTE", "Règlement porté par la période de validation du produit nul et affectation différente du produit de secours : règlement indéterminable");
        }
      }
    }
    return reglement;
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierChomageInvolontaireExamen122Jour(Demande p_demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatRechercheConditionChomageInvolontaire.setResultatElementDroit(resultatElementDroit);
    if (p_demandeAssurance.getDonneesTemporaires().estAvisFavorableCommissionParitaire())
    {
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
    }
    else if (p_demandeAssurance.getDonneesTemporaires().estAvisDefavorableCommissionParitaire())
    {
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
      resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(93);
      
      controleExpatrieRejetGARP(p_demandeAssurance);
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB5");
    }
    fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().leverAlerteA11MB26(p_demandeAssurance);
    return resultatRechercheConditionChomageInvolontaire;
  }
  
  private static void controleExpatrieRejetGARP(Demande p_demandeAssurance)
    throws CoucheLogiqueException
  {
    Reglement reglement = p_demandeAssurance.getDossierAffectationAdmission().getValidationProduit().getReglementApplicable();
    if (((reglement.equals("A9A")) || (reglement.equals("A9B"))) && (!p_demandeAssurance.getDonneesTemporaires().estAvisFavorableCommissionParitaire()) && (!p_demandeAssurance.getDonneesTemporaires().isRejetChomageVolontaireGARP())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EXPATRIE_DF_REJET_GARP_ABSENT");
    }
  }
  
  public static void traiterSituation1(Demande p_demandeAssurance, Reglement p_reglementApplicable, ResultatRechercheConditionChomageInvolontaire p_resultatRechercheConditionChomageInvolontaire)
  {
    ProduitSpec produit = ((DossierAffectation)p_demandeAssurance.getDossierAffectation()).getProduit();
    if ((p_reglementApplicable != null) && (p_reglementApplicable.equals(produit.getReglement("A3"))))
    {
      p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
      p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(1);
      p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(91);
    }
    else
    {
      boolean conditionQuantiteAffiliationObjectifAdmissionSatisfaite = false;
      DossierExamenSpec dossierExamenObjectifAdmission = p_demandeAssurance.getDossierExamen(1);
      if ((dossierExamenObjectifAdmission != null) && (((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation() != null)) {
        conditionQuantiteAffiliationObjectifAdmissionSatisfaite = ((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation().estSatisfait();
      }
      if (dossierExamenObjectifAdmission != null)
      {
        if (!conditionQuantiteAffiliationObjectifAdmissionSatisfaite)
        {
          p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
          p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
        }
        else
        {
          p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
          p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(1);
          p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(91);
        }
      }
      else
      {
        p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
        p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
      }
    }
  }
  
  public static void traiterSituation2(Demande p_demandeAssurance, Reglement p_reglementApplicable, ResultatRechercheConditionChomageInvolontaire p_resultatRechercheConditionChomageInvolontaire)
    throws ApplicativeException
  {
    ProduitSpec produit = ((DossierAffectation)p_demandeAssurance.getDossierAffectation()).getProduit();
    if (p_reglementApplicable.equals(produit.getReglement("A3")))
    {
      p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
      p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
    }
    else
    {
      Chronologie chronologieActivitesDV = ConstructionChronologie.determinerChronoActivitesDV(p_demandeAssurance);
      
      FiltresTemporel filtreJustifieeEnConflit = new FiltresTemporel();
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesAvecConflit());
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesJustifiees());
      if (!chronologieActivitesDV.copier(filtreJustifieeEnConflit).estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB3");
      }
      if (chronologieActivitesDV.estVide())
      {
        p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(true);
        p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(2);
      }
      else
      {
        Temporel derniereActivite = chronologieActivitesDV.premierElement();
        Damj dateFCTDVLaPlusRecente = derniereActivite.getDateFin();
        
        ResultatRechercheConditionChomageInvolontaire resultat = rechercherConditionChomageInvolontaire(p_demandeAssurance, dateFCTDVLaPlusRecente, p_reglementApplicable);
        
        p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
        p_resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
        p_resultatRechercheConditionChomageInvolontaire.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
      }
    }
  }
}

/* Location:
 * Qualified Name:     RechercheConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */