package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ConstitutionCaractereSaisonnierPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  private boolean m_caractereSaisonnierDetermine = false;
  private boolean m_caractereSaisonnier = false;
  private boolean m_caractereSaisonnierParNature = false;
  private boolean m_caractereSaisonnierParRythme = false;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Caractère saisonnier impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: constitution du Caractère saisonnier impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionCaractereSaisonnier.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionCaractereSaisonnierPourReprise ********");
    }
    Resultat resultatCEPR18 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    DonneesTemporaires donneestemporaires = demande.getDonneesTemporaires();
    if (donneestemporaires.isCaractereSaisonnierForce())
    {
      m_caractereSaisonnierDetermine = true;
      m_caractereSaisonnier = true;
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 2) {
        m_caractereSaisonnierParNature = true;
      }
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 1) {
        m_caractereSaisonnierParRythme = true;
      }
    }
    ConstitutionCaractereSaisonnier cepr18 = dossierExamen.getConstitutionElementsActifs().createConstitutionCaractereSaisonnier();
    
    ElementBaseIndemnisation elementBaseIndemnisation = dossierExamen.getAttributionPrecedente().getElementBaseIndemnisation();
    if (m_caractereSaisonnierDetermine)
    {
      cepr18.setCaractereSaisonnierRetenu(true);
      if (m_caractereSaisonnierParNature) {
        cepr18.setTypeCaractereSaisonnierRetenu(2);
      } else {
        cepr18.setTypeCaractereSaisonnierRetenu(1);
      }
    }
    else
    {
      if ((elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 1) || (elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 2)) {
        cepr18.setCaractereSaisonnierRetenu(true);
      } else {
        cepr18.setCaractereSaisonnierRetenu(false);
      }
      cepr18.setTypeCaractereSaisonnierRetenu(elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu());
    }
    cepr18.setActivite3Sur5(elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme());
    if (Log.isTraceActive(ConstitutionCaractereSaisonnierPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "\t\t******** Résultat Parcours ConstitutionCaractereSaisonnierPourReprise ********\n" + resultatCEPR18);
      
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCaractereSaisonnierPourReprise.class, "demarrer", "\t\t******** Fin Parcours ConstitutionCaractereSaisonnierPourReprise ********\n");
    }
    return resultatCEPR18;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCaractereSaisonnierPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */