package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import java.math.BigDecimal;

public class ConstitutionDureePourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if ((DomLiquidationAssurance.getDemande(p_contexte).getReliquat() == null) || (!DomLiquidationAssurance.getDemande(p_contexte).getReliquat().estReliquatValide()) || (((DomLiquidationAssurance)p_contexte.getDonnees()).getContexteExamen() != 3)) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Pas de reliquat pour cette demande d'assurance.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDurees constitutionDurees = dossierExamen.getConstitutionElementsActifs().createConstitutionDurees();
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    
    Quantite qteNbJourImputer = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    Reliquat reliquat = DomLiquidationAssurance.getDemande(p_contexte).getReliquat();
    Quantite quantiteReliquat = new Quantite(reliquat.getQuantiteReliquat().getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    if (demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteNbJourImputer = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      quantiteReliquat = quantiteReliquat.soustraire(qteNbJourImputer);
    }
    Quantite qteTotalJourImputation = reliquat.getQuantiteImputee().ajouter(qteNbJourImputer);
    dureeIndemnisation.setQuantiteJourImputationForce(qteNbJourImputer);
    dureeIndemnisation.setQuantiteTotalJourImputation(qteTotalJourImputation);
    dureeIndemnisation.setDureeTheorique(quantiteReliquat);
    dureeIndemnisation.setDureeImputation(qteTotalJourImputation);
    
    dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), dossierExamen.getDateAttribution(), quantiteReliquat, DureeReglementaire.UNITE_DEFAUT, ConstitutionDuree.bornageALaRetraiteApplicablePourReprise(demande)));
    
    OutilTrace.tracerFinParcours();
    
    return new Resultat();
  }
}

/* Location:
 * Qualified Name:     ConstitutionDureePourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */