package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.RechercheQuantiteAppartenance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionQuantiteAffiliation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance est null pour une détermination condition quantite affiliation.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(DeterminationConditionQuantiteAffiliation.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionQuantiteAffiliation.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionQuantiteAffiliation ********\n");
    }
    Resultat resultatCapa07 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierAffectation dossierAffectation = (DossierAffectation)demandeCourante.getDossierAffectation();
    DossierExamen dossierExamen = (DossierExamen)dossierAffectation.getDossierExamen();
    ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
    
    ConditionQuantiteAffiliation conditionQuantiteAffiliation = dossierExamen.createConditionQuantiteAffiliation();
    if (dossierExamen.getConditionFaitGenerateur().estSatisfait())
    {
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        conditionQuantiteAffiliation.setEtatSatisfait(true);
        resultatCapa07.setEtat(0);
      }
      else
      {
        conditionQuantiteAffiliation.setEtatSatisfait(false);
        conditionQuantiteAffiliation.setCodeMotifEchec(71);
        ActiviteSalarie dossierAffectationSinistre;
        ActiviteSalarie dossierAffectationSinistre;
        if (demandeCourante.getDonneesTemporaires().getIdentifiantPeriodeFctARetenir() != null) {
          dossierAffectationSinistre = (ActiviteSalarie)demandeCourante.getDonneesTemporaires().getPeriodeFctARetenir();
        } else {
          dossierAffectationSinistre = (ActiviteSalarie)dossierAffectation.getSinistre();
        }
        Quantite[] appartenance = RechercheQuantiteAppartenance.determinerAppartenanceInsuffisante(demandeCourante, dossierAffectationSinistre, false, conditionQuantiteAffiliation, dossierExamen);
        
        conditionQuantiteAffiliation.setQuantiteAppartenance(appartenance[0]);
        conditionQuantiteAffiliation.setQuantiteAppartenanceSecondaire(appartenance[1]);
        resultatCapa07.setEtat(1);
        resultatCapa07.setMessageErreur(Integer.toString(71));
      }
    }
    else
    {
      conditionQuantiteAffiliation.setEtatSatisfait(true);
      resultatCapa07.setEtat(2);
    }
    if (Log.isTraceActive(DeterminationConditionQuantiteAffiliation.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionQuantiteAffiliation.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionQuantiteAffiliation ********\n");
    }
    return resultatCapa07;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */