package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ContributionParticuliere;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.ContributionsParticulieres;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;

public class ParcoursDetecterContributionParticuliere
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ContributionParticuliere contributionParticuliere = new ContributionParticuliere();
    
    boolean boolContributionSpecifique = false;
    boolean boolContributionSuplementaire = false;
    if (ContributionsParticulieres.estDecisionPourAppelDetecContribPart((OdAssuranceSpec)dossierExamenCourant))
    {
      boolContributionSpecifique = estContributionSpecifique(dossierExamenCourant);
      boolContributionSuplementaire = estContributionSupplementaire(dossierExamenCourant);
    }
    if ((boolContributionSpecifique) && (boolContributionSuplementaire)) {
      contributionParticuliere.setTypeContributionParticuliere(3);
    } else if (boolContributionSpecifique) {
      contributionParticuliere.setTypeContributionParticuliere(2);
    } else if (boolContributionSuplementaire) {
      contributionParticuliere.setTypeContributionParticuliere(1);
    } else {
      contributionParticuliere.setTypeContributionParticuliere(0);
    }
    dossierExamenCourant.setContributionParticuliere(contributionParticuliere);
    
    return new Resultat();
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit. : DetectionContributionParticuliere impossible");
    }
    if (DomLiquidationAssurance.getDemande(contexte).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Absence individu demandeur sur la demande : DetectionContributionParticuliere impossible");
    }
    if (DomLiquidationAssurance.getDemande(contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: DetectionContributionParticuliere impossible");
    }
  }
  
  private boolean estContributionSupplementaire(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = (Demande)dossierExamenCourant.getDemande();
    
    ActiviteSalarie sinistre = dossierExamenCourant.getFaitGenerateur().getPeriodeFaitGenerateur();
    ContratTravail contrat = sinistre.getContrat();
    int codeMotifFinContrat = sinistre.getContrat().getCodeMotifFin();
    Damj dateRCT = contrat.getDateRuptureContratTravail();
    Damj debutPreavis = null;
    if (contrat.getPreavis() != null) {
      debutPreavis = contrat.getPreavis().getDebut();
    }
    boolean estAdmissibleContributionSupplementaire = true;
    if (!ContributionParticuliere.estMotifAppelContribSuppl(codeMotifFinContrat)) {
      estAdmissibleContributionSupplementaire = false;
    }
    if ((estAdmissibleContributionSupplementaire) && (contrat.getNature() != 1)) {
      estAdmissibleContributionSupplementaire = false;
    }
    switch (sinistre.getMetier().getChampApplication())
    {
    case 2: 
    case 8: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    if ((estAdmissibleContributionSupplementaire) && (dateRCT != null))
    {
      if (demandeCourante.getDemandeur().getAgeALaDate(dateRCT).getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    else if ((estAdmissibleContributionSupplementaire) && (debutPreavis != null))
    {
      if (demandeCourante.getDemandeur().getAgeALaDate(debutPreavis).getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    else if ((estAdmissibleContributionSupplementaire) && (sinistre.getDateFin() != null))
    {
      DureeCalendaire ageFinSinistre = demandeCourante.getDemandeur().getAgeALaDate(sinistre.getDateFin());
      if (ageFinSinistre.getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    if ("98000".equals(sinistre.getEntreprise().getCodePostalEntreprise())) {
      estAdmissibleContributionSupplementaire = false;
    }
    if (sinistre.getMetier().getChampApplication() == 4) {
      estAdmissibleContributionSupplementaire = false;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 23: 
    case 29: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    switch (contrat.getPohf())
    {
    case 3: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 10: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 22: 
    case 23: 
    case 37: 
    case 38: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    if (sinistre.getDateDebut().estApres(ContributionParticuliereSpec.DATE_CRTL_EXCLU_EMPL_PAS))
    {
      DureeCalendaire ageDebutSinistre = demandeCourante.getDemandeur().getAgeALaDate(sinistre.getDateDebut());
      if (ageDebutSinistre.getAnnees() > 45) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    if ((estAdmissibleContributionSupplementaire) && (demandeCourante.getFaitGenerateur() != null) && (demandeCourante.getFaitGenerateur().getDateFaitGenerateur().estApresOuCoincideAvec(ContributionParticuliereSpec.DATE_CTRL_FAIT_GENERATEUR_CONT_SUPPL))) {
      estAdmissibleContributionSupplementaire = false;
    }
    return estAdmissibleContributionSupplementaire;
  }
  
  private boolean estContributionSpecifique(DossierExamen dossierExamenCourant)
  {
    boolean estAdmissibleContributionSpecifique = true;
    
    Demande demandeCourante = (Demande)dossierExamenCourant.getDemande();
    
    ActiviteSalarie sinistre = dossierExamenCourant.getFaitGenerateur().getPeriodeFaitGenerateur();
    ContratTravail contrat = sinistre.getContrat();
    int codeMotifFinContrat = sinistre.getContrat().getCodeMotifFin();
    if ((estAdmissibleContributionSpecifique) && (contrat.getNature() != 1)) {
      estAdmissibleContributionSpecifique = false;
    }
    if (!ContributionParticuliere.estMotifAppelContribSpecifique(codeMotifFinContrat)) {
      estAdmissibleContributionSpecifique = false;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 23: 
    case 29: 
      estAdmissibleContributionSpecifique = false;
      break;
    }
    if ((sinistre.getMetier().getChampApplication() == 3) || (sinistre.getMetier().getChampApplication() == 4)) {
      estAdmissibleContributionSpecifique = false;
    }
    if ("98000".equals(sinistre.getEntreprise().getCodePostalEntreprise())) {
      estAdmissibleContributionSpecifique = false;
    }
    switch (contrat.getPohf())
    {
    case 3: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 10: 
      estAdmissibleContributionSpecifique = false;
      break;
    }
    String me2c = demandeCourante.getTopContribution();
    boolean propositionPapOk = (demandeCourante.estTopPropositionPAP() != null) && (demandeCourante.estTopPropositionPAP().booleanValue());
    if (("O".equals(me2c)) || ("C".equals(me2c)) || (propositionPapOk)) {
      estAdmissibleContributionSpecifique = false;
    }
    if (((FormulaireAsu)demandeCourante.getFormulaire()).isDroitAuCongeReclassement()) {
      estAdmissibleContributionSpecifique = false;
    }
    if (sinistre.getDateFin().estAvantOuCoincideAvec(ContributionParticuliereSpec.DATE_CTRL_FCT_CONT_SPE)) {
      estAdmissibleContributionSpecifique = false;
    }
    return estAdmissibleContributionSpecifique;
  }
}

/* Location:
 * Qualified Name:     ParcoursDetecterContributionParticuliere
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */