package fr.unedic.cali.asu.cge01.p03.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRA
  implements ParametrageListePRASpec
{
  public static final int PRA_72_MOIS = 72;
  public static final int PRA_48_MOIS = 48;
  public static final int PRA_36_MOIS = 36;
  public static final int PRA_26_MOIS = 26;
  public static final int PRA_24_MOIS = 24;
  public static final int PRA_22_MOIS = 22;
  public static final int PRA_20_MOIS = 20;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int DUREE_DROIT_1277 = 1277;
  public static final int DUREE_DROIT_1095 = 1095;
  public static final int DUREE_DROIT_700 = 700;
  public static final int DUREE_DROIT_213 = 213;
  public static final int DUREE_DROIT_365 = 365;
  public static final int DUREE_DROIT_912 = 912;
  public static final int DUREE_DROIT_546 = 546;
  public static final int JOUR_AFFILIATION_821 = 821;
  public static final int JOUR_AFFILIATION_540 = 540;
  public static final int JOUR_AFFILIATION_1095 = 1095;
  public static final int JOUR_AFFILIATION_487 = 487;
  public static final int JOUR_AFFILIATION_320 = 320;
  public static final int JOUR_AFFILIATION_1600 = 1600;
  public static final int JOUR_AFFILIATION_182 = 182;
  public static final int JOUR_AFFILIATION_120 = 120;
  public static final int JOUR_AFFILIATION_365 = 365;
  public static final int JOUR_AFFILIATION_240 = 240;
  public static final int JOUR_AFFILIATION_1642 = 1642;
  public static final int JOUR_AFFILIATION_1094 = 1094;
  public static final int JOUR_AFFILIATION_730 = 730;
  public static final int JOUR_AFFILIATION_546 = 546;
  public static final int JOUR_AFFILIATION_1170 = 1170;
  public static final int JOUR_AFFILIATION_780 = 780;
  public static final int JOUR_AFFILIATION_693 = 693;
  public static final int JOUR_AFFILIATION_460 = 460;
  public static final int JOUR_AFFILIATION_260 = 260;
  public static final int JOUR_AFFILIATION_170 = 170;
  public static final int JOUR_AFFILIATION_520 = 520;
  public static final int JOUR_AFFILIATION_345 = 345;
  public static final int HEURE_TRAVAIL_4095 = 4095;
  public static final int HEURE_TRAVAIL_2700 = 2700;
  public static final int HEURE_TRAVAIL_2426 = 2426;
  public static final int HEURE_TRAVAIL_910 = 910;
  public static final int HEURE_TRAVAIL_600 = 600;
  public static final int HEURE_TRAVAIL_1820 = 1820;
  public static final int HEURE_TRAVAIL_1200 = 1200;
  public static final int HEURE_TRAVAIL_3767 = 3767;
  public static final int HEURE_TRAVAIL_2232 = 2232;
  public static final int HEURE_TRAVAIL_837 = 837;
  public static final int HEURE_TRAVAIL_1674 = 1674;
  public static final int HEURE_TRAVAIL_5670 = 5670;
  public static final int HEURE_TRAVAIL_3780 = 3780;
  public static final int HEURE_TRAVAIL_2240 = 2240;
  public static final int HEURE_TRAVAIL_840 = 840;
  public static final int HEURE_TRAVAIL_2520 = 2520;
  public static final int HEURE_TRAVAIL_1680 = 1680;
  public static final int HEURE_TRAVAIL_1260 = 1260;
  public static final int HEURE_TRAVAIL_3360 = 3360;
  public static final int CENT_TRIMESTRES_ACQUIS = 1;
  private Collection<Pra> listePRA;
  private static ParametrageListePRA instance;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  private static final int CINQ = 5;
  private static final int SIX = 6;
  
  public static ParametrageListePRA getInstance()
  {
    if (instance == null) {
      instance = new ParametrageListePRA();
    }
    return instance;
  }
  
  public ParametrageListePRA()
  {
    initInstance();
  }
  
  private void initInstance()
  {
    listePRA = new ArrayList();
    
    initInstanceRG();
    
    initInstanceRGP();
    
    initInstanceRGOP();
    
    initInstanceA1();
    
    initInstanceA2A();
    
    initInstanceA2B();
    
    initInstanceA3();
    
    initInstanceA4();
    
    initInstanceA5();
    
    initInstanceA9A();
    
    initInstanceA9B();
  }
  
  public List<Pra> getListePra(CleAccesPRA cle)
  {
    List<Pra> resultatListePRA = new ArrayList();
    
    Iterator<Pra> it = listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(cle)) {
        resultatListePRA.add((Pra)pra.copie());
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceRG()
  {
    Pra pra = new Pra("RG", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2426, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 320, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 1820, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 240, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGP()
  {
    Pra pra = new Pra("RGP", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2426, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 320, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 1820, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 240, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGOP()
  {
    Pra pra = new Pra("OP", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 3767, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("OP", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2232, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 320, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("OP", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 837, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("OP", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 1674, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 240, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA1()
  {
    Pra pra = new Pra("A1", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 320, "jour d'affiliation");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 240, "jour d'affiliation");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2A()
  {
    Pra pra = new Pra("A2a", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 5670, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 3780, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 3360, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 320, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 2240, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 1260, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 840, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 2520, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 240, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 1680, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2B()
  {
    Pra pra = new Pra("A2b", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 540, "embarquement administratif");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 320, "embarquement administratif");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 120, "embarquement administratif");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 240, "embarquement administratif");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA3()
  {
    Pra pra = new Pra("A3", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 1170, "vacation");
    positionnerQuantiteAssimilationMax(pra, 780, "vacation");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 693, "vacation");
    positionnerQuantiteAssimilationMax(pra, 460, "vacation");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 260, "vacation");
    positionnerQuantiteAssimilationMax(pra, 170, "vacation");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 520, "vacation");
    positionnerQuantiteAssimilationMax(pra, 345, "vacation");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA4()
  {
    Pra pra = new Pra("A4", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 2426, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 1820, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA5()
  {
    Pra pra = new Pra("A5", new int[] { 2, 3 }, 36, 5, 2);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", 26, 4, 3);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 2426, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 3);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", 22, 2, 6);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", 20, 1, 5);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 1820, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 5);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA9A()
  {
    Pra pra = new Pra("A9A", new int[] { 2, 3 }, 36, 4, 1);
    pra.setArticle3("4");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1095, 1);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", 26, 3, 2);
    pra.setArticle3("3");
    positionnerQuantiteAffiliationRequise(pra, 487, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2426, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 320, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1600, "heure de travail");
    positionnerDureeDroit(pra, 700, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", 22, 2, 4);
    pra.setArticle3("1");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 4);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", 20, 1, 3);
    pra.setArticle3("2");
    positionnerQuantiteAffiliationRequise(pra, 365, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 1820, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 240, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1200, "heure de travail");
    positionnerDureeDroit(pra, 365, 3);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA9B()
  {
    Pra pra = new Pra("A9B", new int[] { 3 }, 72, 3, 1, 1);
    pra.setArticle3("7");
    positionnerQuantiteAffiliationRequise(pra, 1642, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1094, "jour d'affiliation");
    positionnerDureeDroit(pra, 1277, 1);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9B", new int[] { 2, 3 }, 48, 2, 2);
    pra.setArticle3("6");
    positionnerQuantiteAffiliationRequise(pra, 1095, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 730, "jour d'affiliation");
    positionnerDureeDroit(pra, 912, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9B", 24, 1, 3);
    pra.setArticle3("5");
    positionnerQuantiteAffiliationRequise(pra, 546, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 365, "jour d'affiliation");
    
    positionnerDureeDroit(pra, 546, 3);
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra pra)
  {
    listePRA.add(pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra pra, int quantite, String uniteAffiliation)
  {
    Unite unite = Unite.get(uniteAffiliation);
    Quantite quantitePra = new Quantite(quantite, unite);
    pra.getListeQuantitesAffiliationRequises().put(unite, quantitePra);
  }
  
  private void positionnerQuantiteAssimilationMax(Pra pra, int quantite, String uniteAffiliation)
  {
    Unite unite = Unite.get(uniteAffiliation);
    Quantite quantitePra = new Quantite(quantite, unite);
    pra.getListeQuantitesAssimilationMaximales().put(unite, quantitePra);
  }
  
  private void positionnerDureeDroit(Pra pra, int duree, int ordre)
  {
    positionnerDureeDroit(pra, duree, ordre, -1, -1);
  }
  
  private void positionnerDureeDroit(Pra pra, int duree, int ordre, int codeAge, int nombreTrimestre)
  {
    DureeDroitPourPRA dureePra = new DureeDroitPourPRA(duree, ordre);
    
    CleAccesDureeDroit cle = new CleAccesDureeDroit(codeAge, nombreTrimestre);
    
    dureePra.setCleAcces(cle);
    
    pra.ajouterDureeDroit(dureePra);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */