package fr.unedic.cali.asu.cge01.p04.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeDebutPec;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.cge01.calcul.FacadeCalculLigneSansTrancheImpl;
import fr.unedic.cali.asu.cge01.calcul.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantAREF;
import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.Maintien;
import fr.unedic.cali.asu.cge01.p04.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.fabriques.FabriqueConventionTransitoireCalcul2014;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeDetection100TMaintien;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeDetectionAgeMaintien;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieGenerationEnqueteCumulARSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieGestionDRVSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EvenementMaintien;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.FinActionFormation;
import fr.unedic.cali.calcul.dom.periode.FinPeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.FinPeriodeFormationNonIndemnisee;
import fr.unedic.cali.calcul.dom.periode.FinPeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.periode.FinPeriodeSanctionReductionMontant;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeInterStageFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.periode.PeriodeSanctionReductionMontant;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTEAvecImputation;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public class FacadeCalculProduitImpl
  extends FacadeCalculLigneSansTrancheImpl
{
  private static final int DIX = 10;
  
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes p_chronologiePeriodes, AttributionSpec p_attribution, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    return new Qualification().qualificationPeriodes(p_chronologiePeriodes, p_attribution);
  }
  
  public void traitementPeriodeSegmentante(AttributionSpec p_attribution, ObjetChronoPeriode p_periode, ConstituantsIndemnisation p_constituantsIndemnisation, UniteTraitement p_ut, PeriodeAnalyseSpec p_pa, ArretProduitAvecRaison p_arretProduitAvecRaison, ChronologiePeriodes p_periodesAnalyses)
    throws ApplicativeException
  {
    if (OutilsMaintienEuropeenEessiASU.controlerContexteMaintienEuropeen(p_attribution.getDemandeur(), p_periode.getDateDebut())) {
      if ((p_periode instanceof PeriodeFormation))
      {
        if (((PeriodeFormation)p_periode).estEffective()) {
          passerEnIndemnisationAvecFormation(p_periode, p_constituantsIndemnisation);
        } else {
          passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
        }
      }
      else if ((p_periode instanceof ObjetChronoPeriodeDetectionAgeMaintien))
      {
        if (!((AttributionAssuranceSpec)p_attribution).estMaintenue()) {
          if (Maintien.getInstance().controlerConditionsDetectionHorsAge((AttributionAssuranceSpec)p_attribution, p_constituantsIndemnisation, p_periode.getDateDebut(), p_ut)) {
            Maintien.getInstance().effectuerDetection((AttributionAssuranceSpec)p_attribution, p_periode.getDateDebut(), p_constituantsIndemnisation);
          }
        }
      }
      else if ((p_periode instanceof ObjetChronoPeriodeDetection100TMaintien))
      {
        if (!((AttributionAssuranceSpec)p_attribution).estMaintenue()) {
          if (Maintien.getInstance().controlerConditionsDetectionHors100T((AttributionAssuranceSpec)p_attribution, p_constituantsIndemnisation, p_periode.getDateDebut(), p_ut)) {
            Maintien.getInstance().effectuerDetection((AttributionAssuranceSpec)p_attribution, p_periode.getDateDebut(), p_constituantsIndemnisation);
          }
        }
      }
      else if ((p_periode instanceof ObjetChronoPeriodeMaintien))
      {
        if (((ObjetChronoPeriodeMaintien)p_periode).getDateMaintienHorsPEC() != null) {
          Maintien.getInstance().detecter((AttributionAssuranceSpec)p_attribution, ((ObjetChronoPeriodeMaintien)p_periode).getDateMaintienHorsPEC(), false, p_constituantsIndemnisation);
        } else {
          Maintien.getInstance().detecter((AttributionAssuranceSpec)p_attribution, p_periode.getDateDebut(), false, p_constituantsIndemnisation);
        }
        if (((AttributionAssuranceSpec)p_attribution).estMaintenue()) {
          if (((ObjetChronoPeriodeMaintien)p_periode).getDateMaintienHorsPEC() != null) {
            p_ut.ajouterEvenement(new EvenementMaintien(((ObjetChronoPeriodeMaintien)p_periode).getDateMaintienHorsPEC()));
          } else {
            p_ut.ajouterEvenement(new EvenementMaintien(p_periode.getDateDebut()));
          }
        }
      }
    }
    if (((p_periode instanceof PeriodeInterStageFormation)) || ((p_periode instanceof FinActionFormation)))
    {
      passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
    }
    else if ((p_periode instanceof PeriodeSanctionReductionMontant))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      if (((PeriodeSanctionReductionMontant)p_periode).getCodeSanction().equals("R1")) {
        elementBaseIndemnisation.setCoefficientSanctionReduction(new BigDecimal("0.80"));
      } else if (((PeriodeSanctionReductionMontant)p_periode).getCodeSanction().equals("R2")) {
        elementBaseIndemnisation.setCoefficientSanctionReduction(new BigDecimal("0.50"));
      }
    }
    else if (((p_periode instanceof FinPeriodeSanctionReductionMontant)) && (((p_pa != null) && (p_pa.getDateDebut().estContenueDans(((FinPeriodeSanctionReductionMontant)p_periode).getPeriode()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      elementBaseIndemnisation.setCoefficientSanctionReduction(new BigDecimal("1.00"));
    }
    else if (((p_periode instanceof PeriodePensionInvalidite)) && (p_periode.getDateDebut().estApresOuCoincideAvec(p_attribution.getPji())))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().add(((PeriodePensionInvalidite)p_periode).getQuantiteEuro().getValeur()));
    }
    else if (((p_periode instanceof PeriodeAvantageVieillesse)) && (p_periode.getDateDebut().estApresOuCoincideAvec(p_attribution.getPji())))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      BigDecimal montantAv = null;
      if ((elementBaseIndemnisation.getDateEffetAV() == null) || (elementBaseIndemnisation.getDateEffetAV().estAvant(p_periode.getDateDebut())))
      {
        montantAv = ((PeriodeAvantageVieillesse)p_periode).getQuantiteEuro().getValeur();
        elementBaseIndemnisation.setDateEffetAV(p_periode.getDateDebut());
      }
      else if (elementBaseIndemnisation.getDateEffetAV().coincideAvec(p_periode.getDateDebut()))
      {
        montantAv = elementBaseIndemnisation.getMontantAvantageVieillesse().add(((PeriodeAvantageVieillesse)p_periode).getQuantiteEuro().getValeur());
      }
      if (montantAv != null)
      {
        elementBaseIndemnisation.setMontantAvantageVieillesse(montantAv);
        if ((elementBaseIndemnisation.getSjr() != null) && (elementBaseIndemnisation.getSjr().getSalaire() != null) && (!elementBaseIndemnisation.getSjr().getSalaire().equals(new BigDecimal("0.00"))))
        {
          BigDecimal coeffAV = montantAv.divide(elementBaseIndemnisation.getSjr().getSalaire(), 10, 4);
          
          elementBaseIndemnisation.setCoefficientAvantageVieillesse(coeffAV);
        }
      }
    }
    else if (((p_periode instanceof FinPeriodeAvantageVieillesse)) && (((p_pa != null) && (p_pa.getDateDebut().equals(p_periode.getDateDebut()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      elementBaseIndemnisation.setCoefficientAvantageVieillesse(new BigDecimal("0"));
      elementBaseIndemnisation.setMontantAvantageVieillesse(new BigDecimal("0"));
    }
    else if (((p_periode instanceof FinPeriodePensionInvalidite)) && (((p_pa != null) && (p_pa.getDateDebut().equals(p_periode.getDateDebut()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().subtract(((FinPeriodePensionInvalidite)p_periode).getQuantiteEuro().getValeur()));
    }
    else if (((p_periode instanceof FinPeriodeFormationNonIndemnisee)) && (((p_pa != null) && (p_pa.getDateDebut().equals(p_periode.getDateDebut()))) || ((p_pa == null) && (p_periode.getDateDebut().estContenueDans(p_ut.getPeriode())))))
    {
      if (((Attribution)p_attribution).getDureeInitiale().getValeurEntiere() > ((ProduitAsuSpec)p_attribution.getProduit()).getDureeMinimumPourImputationFormation()) {
        imputerQuantiteIndemnisationADate(p_ut, p_periode, p_pa, p_constituantsIndemnisation, p_arretProduitAvecRaison, p_attribution);
      }
    }
    else if (((p_periode instanceof PeriodeSuspensionDDTEAvecImputation)) && (p_pa != null) && (((PeriodeSuspensionDDTEAvecImputation)p_periode).getPeriodeInitiale().getDebut().coincideAvec(p_pa.getDateDebut())))
    {
      PeriodeSuspensionDDTEAvecImputation periode = (PeriodeSuspensionDDTEAvecImputation)p_periode.copie();
      
      Damj finPeriodesAnalyse = null;
      ObjetChronoPeriode periodesAnalyse = (ObjetChronoPeriode)p_periodesAnalyses.dernierElement();
      finPeriodesAnalyse = periodesAnalyse.getDateFin();
      if ((finPeriodesAnalyse != null) && (((PeriodeSuspensionDDTEAvecImputation)p_periode).getPeriodeInitiale().getFin().estApres(finPeriodesAnalyse))) {
        periode.setDateFin(finPeriodesAnalyse);
      }
      imputerQuantiteIndemnisationDuAuxSanctions(p_attribution, p_ut, periode, p_constituantsIndemnisation, p_arretProduitAvecRaison);
    }
    else if ((p_periode instanceof ObjetChronoPeriodeDebutPec))
    {
      OutilsMaintienEuropeenEessiASU.controlerEtEmettreEnqueteMaintienEuropeen(p_attribution, p_constituantsIndemnisation, p_periode.getDateDebut(), this, null, p_ut);
      passerEnIndemnisationSansFormation(p_constituantsIndemnisation);
    }
  }
  
  private void passerEnIndemnisationSansFormation(ConstituantsIndemnisation p_constituantsIndemnisation)
  {
    DureeIndemnisation duree = (DureeIndemnisation)OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_constituantsIndemnisation.getCollectionQuantiteDroit());
    if (duree != null) {
      duree.setCodeFormuleMontant(FormuleMontantRegimeGeneral.getCode());
    } else {
      p_constituantsIndemnisation.setCodeFormuleMontant(FormuleMontantRegimeGeneral.getCode());
    }
    ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant().copie();
    p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisation);
  }
  
  private void passerEnIndemnisationAvecFormation(ObjetChronoPeriode p_periode, ConstituantsIndemnisation p_constituantsIndemnisation)
  {
    DureeIndemnisation duree = (DureeIndemnisation)OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_constituantsIndemnisation.getCollectionQuantiteDroit());
    if (duree != null) {
      duree.setCodeFormuleMontant(FormuleMontantAREF.getCode());
    } else {
      p_constituantsIndemnisation.setCodeFormuleMontant(FormuleMontantAREF.getCode());
    }
    ElementBaseIndemnisationAREF elementBaseIndemnisationAREF = new ElementBaseIndemnisationAREF((ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant());
    if ((p_periode instanceof PeriodeFormation)) {
      elementBaseIndemnisationAREF.setEffectif(((PeriodeFormation)p_periode).estEffective());
    }
    p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationAREF);
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAJourCumulAR(UniteTraitement p_ut, AttributionSpec p_attribution, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, ContexteUT p_contexteUT, ArretProduitAvecRaison p_arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    ConstituantsCalculActiviteReduiteAsu constituantsCalculActiviteReduite = (ConstituantsCalculActiviteReduiteAsu)p_constituantsCalculActiviteReduite;
    
    int cumulActiviteReduite = constituantsCalculActiviteReduite.getCumul();
    boolean existeAttributionPrecedenteAvecCumulAr = false;
    boolean individuPossedeCesSurUt = false;
    boolean individuPossedeCaeSurUt = false;
    boolean individuPossedeCaeCuiSurUt = false;
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(p_ut.getDateDebut());
    FabriqueConventionTransitoireCalcul2014 fabrique = FabriqueConventionTransitoireCalcul2014.getInstance();
    StrategieGenerationEnqueteCumulARSpec strategie = (StrategieGenerationEnqueteCumulARSpec)fabrique.getStrategie(critere);
    
    FabriqueConventionTransitoireCalcul2014 fabriqueDRV = FabriqueConventionTransitoireCalcul2014.getInstance();
    StrategieGestionDRVSpec strategieGestionDRVARE14Apres = fabriqueDRV.getStrategieGestionDRV(critere);
    if ((strategieGestionDRVARE14Apres.mettreAjourCumulMoisNonIndemnise()) && (constituantsCalculActiviteReduite != null) && (!((AttributionAssuranceSpec)p_attribution).estMaintenue()) && (p_ut.getDateDebut().estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Fin application de l'ancien dispositif DRV")))) {
      miseAjourNombreMoisNonIndemnise(p_attribution, p_ut, constituantsCalculActiviteReduite, p_contexteUT, p_arretProduitAvecRaison);
    }
    if ((((p_attribution instanceof RepriseSpec)) || ((p_attribution instanceof RevisionSpec))) && (p_attribution.getPji().estContenueDans(p_ut.getPeriode()))) {
      existeAttributionPrecedenteAvecCumulAr = super.existeAttributionPrecedenteAvecCumulAr(p_attribution, p_contexteUT);
    }
    if (existeAttributionPrecedenteAvecCumulAr) {
      constituantsCalculActiviteReduite.setCumul(cumulActiviteReduite + 1);
    }
    Reglement reglementOdCourante = ((Attribution)p_attribution).getReglementApplicable().getReglement();
    if ((!existeAttributionPrecedenteAvecCumulAr) && (!reglementOdCourante.equals(p_attribution.getProduit().getReglement("A4"))))
    {
      Iterator iterateurPeriode = p_ut.getQualificationPeriodes().getPeriodesDecalantes().iterer();
      while (iterateurPeriode.hasNext())
      {
        ObjetChronoPeriode periodeActivite = (ObjetChronoPeriode)iterateurPeriode.next();
        if ((periodeActivite instanceof PeriodeActiviteEmploiCalcul))
        {
          if (7 == ((PeriodeActiviteEmploiCalcul)periodeActivite).getTypeContratParticulier()) {
            individuPossedeCesSurUt = true;
          }
          if (14 == ((PeriodeActiviteEmploiCalcul)periodeActivite).getTypeContratParticulier()) {
            individuPossedeCaeSurUt = true;
          }
          if (23 == ((PeriodeActiviteEmploiCalcul)periodeActivite).getTypeContratParticulier()) {
            individuPossedeCaeCuiSurUt = true;
          }
        }
      }
      if ((!individuPossedeCesSurUt) && (!individuPossedeCaeSurUt) && (!individuPossedeCaeCuiSurUt) && (!p_ut.isNeutralisee()) && (p_ut.getCreditDecalage() != null) && (p_ut.getCreditDecalage().getValeur() != null) && (p_ut.getCreditDecalage().getValeur().intValue() >= 0) && (p_ut.getQuantiteIndemnisee() != null) && (p_ut.getQuantiteIndemnisee().getValeur() != null) && (p_ut.getQuantiteIndemnisee().getValeur().intValue() >= 1))
      {
        cumulActiviteReduite++;
        constituantsCalculActiviteReduite.setCumul(cumulActiviteReduite);
        if ((p_ut.getStatut() != 5) && (cumulActiviteReduite == 13) && (p_attribution.getDemandeur().getAgeALaDate(p_ut.getDateDebut()).getAnnees() < 50) && (strategie != null) && (strategie.genererEnqueteCumulAR())) {
          GestionSuivi.enregistrerEnquetePbjcNcp(p_attribution, p_ut.getDateFin(), 11, 0, true, null, this, p_ut.getConstituantsIndemnisationEnFinUT());
        }
        if ((p_ut.getStatut() != 5) && (cumulActiviteReduite == 1)) {
          GestionSuivi.enregistrerEnquetePbjcNcp(p_attribution, Damj.max(p_ut.getDateDebut(), p_attribution.getPji()), 4, 0, true, null, this, p_ut.getConstituantsIndemnisationEnFinUT());
        }
      }
    }
    return constituantsCalculActiviteReduite;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */