package fr.unedic.cali.asu.cge01.p04.liquidation.parcours;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConserveeAncienneRegle;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCva10P02;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;

public class DeterminationConditionCumulActiviteConservee
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final QuantiteEuro QUANTITE_EURO_ZERO = new QuantiteEuro("0");
  
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCAPA12 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    boolean estReglementApplicableA4 = reglementApplicableCourant.equals(produit.getReglement("A4"));
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    ConditionActiviteConservee conditionActiviteConservee = dossierExamenCourant.createConditionActiviteConservee();
    if ((estReglementApplicableA4) && (!strategieActiviteConservee.traiterActivitesConserveesA4()))
    {
      conditionActiviteConservee.setEtatSatisfait(true);
    }
    else
    {
      Periode periodePrc = OutilGestionActivitesConservees.getInstance().recupererPeriodePrc(demandeCourante);
      Chronologie chronoGlobaleActivitesConservees = strategieActiviteConservee.recupererChronoActivitesConservees(demandeCourante, periodePrc);
      if (strategieActiviteConservee.persisterListeActivitesConserveesCapa12()) {
        mettreAJourDomListeActivitesConservees(false, dossierExamenCourant, periodePrc.getFin(), chronoGlobaleActivitesConservees);
      } else if (estReglementApplicableA4) {
        mettreAJourDomListeActivitesConservees(true, dossierExamenCourant, periodePrc.getFin(), chronoGlobaleActivitesConservees);
      }
      if (ProduitAsuCva10P02.getInstance().getCode() == produit.getCode())
      {
        conditionActiviteConservee.setEtatSatisfait(true);
      }
      else
      {
        leverAlerteA11MB7SurOriginePasConservee(chronoGlobaleActivitesConservees);
        
        RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConserveeAncienneRegle.getInstance();
        
        ConteneurConditionActiviteConservee conteneurConditionActiviteConservee = rechercheConditionCumulActiviteConservee.rechercherConditionCumulActiviteConservee(demandeCourante, chronoGlobaleActivitesConservees);
        
        rechercheConditionCumulActiviteConservee.mapperConteneurVersConditionActiviteConservee(conteneurConditionActiviteConservee, conditionActiviteConservee);
        if (demandeCourante.getDonneesTemporaires().isConditionCumulActiviteConserveeRemplie()) {
          conditionActiviteConservee.setEtatSatisfait(true);
        }
      }
    }
    if (conditionActiviteConservee.estSatisfait())
    {
      resultatCAPA12.setEtat(0);
    }
    else
    {
      resultatCAPA12.setEtat(1);
      resultatCAPA12.setMessageErreur(Integer.toString(conditionActiviteConservee.getCodeMotifEchec()));
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Résultat", resultatCAPA12 });
    
    OutilTrace.tracerFinParcours();
    
    return resultatCAPA12;
  }
  
  public static void leverAlerteA11MB7SurOriginePasConservee(Chronologie chronoGlobaleActivitesConservees)
    throws CoucheLogiqueException
  {
    FiltrePeriodesSurFiltresExclusifs filtreExclusif = new FiltrePeriodesSurFiltresExclusifs();
    Chronologie chronoActivitesSalarieesConserveesFiltrees = null;
    Chronologie chronoActivitesNonSalarieesConserveesFiltrees = null;
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodesJustifiees(false));
    
    FiltresTemporel filtreCertifieeNonQualifiee = new FiltresTemporel();
    
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltreActiviteSalarie());
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltrePeriodesQualifiables(false));
    filtreExclusif.ajouterFiltre(filtreCertifieeNonQualifiee);
    
    chronoActivitesSalarieesConserveesFiltrees = chronoGlobaleActivitesConservees.copier(filtreExclusif);
    if (!chronoActivitesSalarieesConserveesFiltrees.estVide())
    {
      Damj dateFCTDamj = chronoActivitesSalarieesConserveesFiltrees.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB7_1", new String[] { dateFCTString });
    }
    FiltresTemporel filtreActiviteNonSalarieNonAtteste = new FiltresTemporel();
    filtreActiviteNonSalarieNonAtteste.ajouterFiltre(new FiltrePeriodeActiviteNonSalariee());
    filtreActiviteNonSalarieNonAtteste.ajouterFiltre(new FiltrePeriodesAttestees(false));
    
    chronoActivitesNonSalarieesConserveesFiltrees = chronoGlobaleActivitesConservees.copier(filtreActiviteNonSalarieNonAtteste);
    if (!chronoActivitesNonSalarieesConserveesFiltrees.estVide())
    {
      Damj dateFCTDamj = chronoActivitesNonSalarieesConserveesFiltrees.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB7_2", new String[] { dateFCTString });
    }
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition de cumul avec une activite conservee impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen courant est null: determination condition de cumul avec une activite conservee impossible.");
    }
    if ((dossierExamenCourant.getConstitutionSjr() == null) || (dossierExamenCourant.getConstitutionSjr().getSjrip() == null)) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le Sjrip est null: determination condition de cumul avec une activite conservee impossible.");
    }
  }
  
  private void mettreAJourDomListeActivitesConservees(boolean persisterCepa10, DossierExamen dossierExamen, Damj termePrc, Chronologie chronoActivitesConservees)
  {
    ConditionActiviteConservee conditionActiviteConservee = null;
    ConstitutionSjc constitutionSjc = null;
    if (persisterCepa10)
    {
      constitutionSjc = dossierExamen.createConstitutionSjc();
      constitutionSjc.createSjcip(termePrc, QUANTITE_EURO_ZERO, QUANTITE_EURO_ZERO);
    }
    else
    {
      conditionActiviteConservee = dossierExamen.getConditionActiviteConservee();
    }
    chronoActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveCourant = null;
    while (chronoActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)chronoActivitesConservees.elementSuivant();
      
      sjrActiviteConserveCourant = new SjrActiviteConservee(QUANTITE_EURO_ZERO);
      sjrActiviteConserveCourant.setPeriodeActiviteConservee(activiteConserveeCourante);
      
      OutilGestionActivitesConservees.getInstance().mettreAJourTypeActiviteConservee(sjrActiviteConserveCourant);
      if (persisterCepa10) {
        constitutionSjc.getSjcip().ajouterSjrActiviteConservee(sjrActiviteConserveCourant);
      } else {
        conditionActiviteConservee.ajouterSjrActiviteConservee(sjrActiviteConserveCourant);
      }
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionCumulActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */