package fr.unedic.cali.asu.cge01.p05.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeEffective;
import fr.unedic.cali.asu.cge01.liquidation.parcours.cep02dureeRegl.asp.ConstitutionDureePostPrime;
import fr.unedic.cali.asu.cge01.liquidation.parcours.novation.ParcoursConstitutionReglementApplicable;
import fr.unedic.cali.asu.cge01.p05.liquidation.dom.gen.ObjectifExamenRevisionAdmissionGen;
import fr.unedic.cali.asu.cge01.revision.ConstitutionCapitalDroitCourant;
import fr.unedic.cali.asu.cge01.revision.ConstitutionCapitalEffectif;
import fr.unedic.cali.asu.cge01.revision.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.cge01.revision.ConstitutionDelaisReports;
import fr.unedic.cali.asu.cge01.revision.ConstitutionDureeReglementaire;
import fr.unedic.cali.asu.cge01.revision.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.revision.ConstitutionMontantsEffectifs;
import fr.unedic.cali.asu.cge01.revision.DeterminationCompetencesAdministratives;
import fr.unedic.cali.asu.cge01.revision.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.revision.DeterminationConditionFaitGenerateur;
import fr.unedic.cali.asu.cge01.revision.DeterminationConditionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.revision.ParcoursConstitutionSjr;
import fr.unedic.cali.asu.cge01.revision.ParcoursLiquidationDemandesSousJacentesRevision;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionDateAttributionRevision;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenRevisionAdmission
  extends ObjectifExamenRevisionAdmissionGen
{
  private static List<ContexteDemandeSpec> s_contexteDemande = null;
  private static final long serialVersionUID = -6574141057884168780L;
  
  public ObjectifExamenRevisionAdmission(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ObjectifExamenRevisionAdmission() {}
  
  public ObjectifExamenRevisionAdmission(List<ContexteDemandeSpec> p_contexteDemande)
  {
    s_contexteDemande = p_contexteDemande;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    super.copieElements(p_copie);
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenRevisionAdmission copie = new ObjectifExamenRevisionAdmission();
    copieElements(copie);
    return copie;
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ParcoursConstitutionReglementApplicable();
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return new DeterminationConditionFaitGenerateur();
  }
  
  public Parcours creerParcoursCoefficientTempsPartiel()
  {
    return new ConstitutionCoefficientTempsPartiel();
  }
  
  public Parcours creerParcoursDeterminationCompetencesFinanceAdmDroitCourant()
  {
    return new DeterminationCompetencesAdministratives();
  }
  
  public Parcours creerParcoursDureesReglementaires()
  {
    return new ConstitutionDureeReglementaire();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    if (s_contexteDemande != null)
    {
      boolean estEnCoursPapDcParlementaire = (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "PAPDC")) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "PAPPARLEM"));
      if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "REVAUTO")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "ASPDC")) || (estEnCoursPapDcParlementaire)) {
        return null;
      }
    }
    return new ConstitutionDelaisReports();
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ConstitutionMontantsBruts();
  }
  
  public Parcours creerParcoursCapitalDroitCourant()
  {
    return new ConstitutionCapitalDroitCourant();
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttributionRevision();
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(s_contexteDemande, 9)) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionChomageInvolontaire();
  }
  
  public Parcours creerParcoursConditionQuantiteAffiliation()
  {
    return new DeterminationConditionQuantiteAffiliation();
  }
  
  public Parcours creerParcoursMontantsEffectifs()
  {
    return new ConstitutionMontantsEffectifs();
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    return new ConstitutionCapitalEffectif();
  }
  
  public Parcours creerParcoursSalaireJournalierDeReference()
  {
    return new ParcoursConstitutionSjr();
  }
  
  public Parcours creerParcoursLiquidationDemandeAssociee()
  {
    return new ParcoursLiquidationDemandesSousJacentesRevision();
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return new ConstitutionDureeEffective();
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return new ConstitutionDateLimiteIndemnisation();
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return new ConstitutionDureePostPrime();
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenRevisionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */