package fr.unedic.cali.asu.cge01.p07.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDateAttributionCsr;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDelaisReportsReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDelaisReportsRepriseCsr;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeEffectiveReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeEffectiveRepriseCsr;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeEffectiveReprisePmvs;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeReglementaireRepriseRevision;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationCompetencesReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationCondition28JoursSuspension;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationConditionAccordCP;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationConditionChomageInvolontaireReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationConditionCumulActiviteConserveeReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ParcoursDetecterContributionParticuliereContexteEntreeCsp;
import fr.unedic.cali.asu.cge01.liquidation.parcours.cep02dureeRegl.asp.ConstitutionDureePostPrime;
import fr.unedic.cali.asu.cge01.p07.liquidation.dom.gen.ObjectifExamenRepriseGen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ObjectifExamenSpec;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionDateAttributionReprise;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionMontantsBrutsReprise;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenReprise
  extends ObjectifExamenRepriseGen
{
  private static final long serialVersionUID = -2603744178994985619L;
  
  public ObjectifExamenReprise(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ObjectifExamenReprise() {}
  
  public ObjectifExamenReprise(List<ContexteDemandeSpec> contexteDemande)
  {
    setContexteDemande(contexteDemande);
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenReprise copie = new ObjectifExamenReprise();
    copieElements(copie);
    return copie;
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    Parcours parcours;
    Parcours parcours;
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estContextePresentDansRegroupement(getContexteDemande(), 9))) {
      parcours = new ParcoursTraitementSatisfait();
    } else {
      parcours = new DeterminationConditionChomageInvolontaireReprise();
    }
    return parcours;
  }
  
  public Parcours creerParcoursSalaireJournalierDeReference()
  {
    return null;
  }
  
  public Parcours creerParcoursSalaireJournalierConserve()
  {
    return null;
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    Parcours parcours;
    Parcours parcours;
    if (OutilsChomageSansRCT.estUnContexteDeChomageEnCoursDeSuspension(getContexteDemande()))
    {
      parcours = new ConstitutionDureeEffectiveRepriseCsr();
    }
    else
    {
      Parcours parcours;
      if (OutilGestionContexteDemande.trouverUnContextePresent(getContexteDemande(), 2) != null) {
        parcours = new ConstitutionDureeEffectiveReprisePmvs();
      } else {
        parcours = new ConstitutionDureeEffectiveReprise();
      }
    }
    return parcours;
  }
  
  public Parcours creerParcoursDeterminationCompetenceFinanceAdmDroitResultant()
  {
    return new DeterminationCompetencesReprise();
  }
  
  public Parcours creerParcoursDureesReglementaires()
  {
    return new ConstitutionDureeReglementaireRepriseRevision();
  }
  
  public Parcours creerParcoursProduitResultant()
  {
    return null;
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    Parcours parcours;
    Parcours parcours;
    if (OutilsChomageSansRCT.estUnContexteDeChomageEnCoursDeSuspension(getContexteDemande())) {
      parcours = new ConstitutionDateAttributionCsr();
    } else {
      parcours = new ConstitutionDateAttributionReprise();
    }
    return parcours;
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    boolean estEnCoursPapDcParlementaire = (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "PAPDC")) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "PAPPARLEM"));
    Parcours parcours;
    Parcours parcours;
    if (OutilsChomageSansRCT.estUnContexteDeChomageEnCoursDeSuspension(getContexteDemande()))
    {
      parcours = new ConstitutionDelaisReportsRepriseCsr();
    }
    else
    {
      Parcours parcours;
      if (((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "AREENTRCSP")) && (!OutilGestionContexteDemande.estContextePresentDansRegroupement(getContexteDemande(), 10))) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "ASPDC")) || (estEnCoursPapDcParlementaire)) {
        parcours = null;
      } else {
        parcours = new ConstitutionDelaisReportsReprise();
      }
    }
    return parcours;
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ConstitutionMontantsBrutsReprise();
  }
  
  public Parcours creerParcoursConditionCsrAccordCp()
  {
    Parcours parcours;
    Parcours parcours;
    if (OutilsChomageSansRCT.estUnContexteDeChomageEnCoursDeSuspension(getContexteDemande())) {
      parcours = new DeterminationConditionAccordCP();
    } else {
      parcours = new ParcoursTraitementSatisfait();
    }
    return parcours;
  }
  
  public Parcours creerParcoursCondition28JSuspension()
  {
    if (OutilsChomageSansRCT.estUnContexteDeChomageEnCoursDeSuspension(getContexteDemande())) {
      return new DeterminationCondition28JoursSuspension();
    }
    return new ParcoursTraitementSatisfait();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    Parcours parcours;
    Parcours parcours;
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(getContexteDemande(), "ARECOURCSP"))) {
      parcours = getObjectifProduitActif().creerParcoursConditionRechercheEmploi();
    } else {
      parcours = super.creerParcoursConditionRechercheEmploi();
    }
    return parcours;
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    Parcours parcours;
    Parcours parcours;
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(getContexteDemande(), 7)) {
      parcours = new ParcoursTraitementSatisfait();
    } else {
      parcours = super.creerParcoursConditionCumulPrestationFamiliale();
    }
    return parcours;
  }
  
  public Parcours creerParcoursConditionCumulActiviteConservee()
  {
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(getContexteDemande(), 7)) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionCumulActiviteConserveeReprise();
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return new ConstitutionDateLimiteIndemnisation();
  }
  
  public Parcours creerParcoursDetectionContributionParticuliere(Demande demande)
  {
    return new ParcoursDetecterContributionParticuliereContexteEntreeCsp();
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return new ConstitutionDureePostPrime();
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */