package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.cep.sjr;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationSrPrae;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.services.CoucheLogiqueException;
import java.math.BigDecimal;

public class OutilDeterminationSrPraeConvention2017
  extends OutilDeterminationSrPrae
{
  public BigDecimal determinerCoeffPrimeExceptionnelle(Prc resultatPrc, Reglement reglementApplicable, Reglement reglementAppartenance, DonneesResultatDeterminationSjr donneesResultatDeterminationSjr)
  {
    BigDecimal coefficientPrimeExceptionnelle = BigDecimal.ONE;
    
    boolean estReglementAppartenanceOk = (estReglementRG(reglementAppartenance)) || (estReglementAnnexe2Aet6(reglementAppartenance));
    
    boolean estReglementApplicableOk = (estReglementRG(reglementApplicable)) || (reglementApplicable.estNomReglementIdentique("A1"));
    if ((estReglementAppartenanceOk) && (estReglementApplicableOk))
    {
      if (donneesResultatDeterminationSjr.getJustificationSjr() != null)
      {
        BigDecimal dureePrc = BigDecimal.valueOf(donneesResultatDeterminationSjr.getPrc().getDuree());
        
        BigDecimal diviseurTravaille = donneesResultatDeterminationSjr.getJustificationSjr().getJustificationDiviseur().getDiviseur();
        coefficientPrimeExceptionnelle = diviseurTravaille.divide(dureePrc, 4, 1);
      }
    }
    else {
      coefficientPrimeExceptionnelle = super.determinerCoeffPrimeExceptionnelle(resultatPrc, reglementApplicable, reglementAppartenance, donneesResultatDeterminationSjr);
    }
    return coefficientPrimeExceptionnelle;
  }
  
  public BigDecimal determinerCoeffPrimeNormale(Prc resultatPrc, Reglement reglementApplicable, Reglement reglementAppartenance, DonneesResultatDeterminationSjr donneesResultatDeterminationSjr, boolean estDiviseurSjrForce)
    throws CoucheLogiqueException
  {
    BigDecimal coefficientPrimeNormale = BigDecimal.ONE;
    
    boolean estReglementAppartenanceOk = (estReglementRG(reglementAppartenance)) || (estReglementAnnexe2Aet6(reglementAppartenance));
    
    boolean estReglementApplicableOk = (estReglementRG(reglementApplicable)) || (reglementApplicable.estNomReglementIdentique("A1"));
    if ((estReglementAppartenanceOk) && (estReglementApplicableOk))
    {
      if (donneesResultatDeterminationSjr.getJustificationSjr() != null)
      {
        coefficientPrimeNormale = donneesResultatDeterminationSjr.getJustificationSjr().getJustificationDiviseur().getCoefficientAbsence();
        if ((coefficientPrimeNormale == null) && (estDiviseurSjrForce)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_ERR_DIVISEUR_SJR_FORCE_AVEC_PRIME");
        }
      }
    }
    else {
      coefficientPrimeNormale = super.determinerCoeffPrimeNormale(resultatPrc, reglementApplicable, reglementAppartenance, donneesResultatDeterminationSjr, estDiviseurSjrForce);
    }
    return coefficientPrimeNormale;
  }
  
  protected boolean estActiviteCandidatePlafonnementAffiliation(ActiviteSalarie activiteSalarie, ProduitSpec produit)
  {
    return (super.estActiviteCandidatePlafonnementAffiliation(activiteSalarie, produit)) && (!estAssMat(activiteSalarie));
  }
  
  private boolean estAssMat(ActiviteSalarie activiteSalarie)
  {
    int categorie = activiteSalarie.getCategorieEmploiParticulier();
    
    return (categorie == 22) || (categorie == 23);
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSrPraeConvention2017
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */