package fr.unedic.cali.asu.cge01.p07.liquidation.parcours;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cep.dureereglementaire.dom.CoupleDureeAllongementMontant;
import fr.pe.cali.reglementaire.regles.assurance.cep.dureereglementaire.dom.DonneesEntreesDureeReglementaireConvention2017;
import fr.pe.cali.reglementaire.regles.assurance.cep.dureereglementaire.dom.ResultatDureeReglementaireConvention2017;
import fr.pe.cali.reglementaire.regles.assurance.cep.dureereglementaire.fabrique.FabriqueCorpsRegleConstitutionDureeReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cep.dureereglementaire.outils.spec.IOutilConstitutionDureeReglementaireConvention2017;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilFonctionnelDureeReglementaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConstitutionDureeReglementaire
  extends ParcoursCali
  implements ParcoursAssurance
{
  private int valeurAucunAllongement = 0;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultatCEPA02 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    
    IOutilConstitutionDureeReglementaireConvention2017 outilR = recupererOutilReglementaire(attribution);
    DonneesEntreesDureeReglementaireConvention2017 donneesEntree = creerConteneurDonneesEntree(attribution);
    OutilFonctionnelDureeReglementaire of = recupererOutilFonctionnel(attribution);
    donneesEntree.setOutilFonctionnel(of);
    
    ResultatDureeReglementaireConvention2017 resultat = outilR.determinerDureeReglementaire(donneesEntree);
    mapperResultatSurDom(resultat, getConstitutionDurees(attribution));
    miseAjourQuantiteAffiliation(attribution, resultat);
    return resultatCEPA02;
  }
  
  private OutilFonctionnelDureeReglementaire recupererOutilFonctionnel(Attribution attribution)
  {
    return new OutilFonctionnelDureeReglementaire((Demande)attribution.getDemande());
  }
  
  protected DonneesEntreesDureeReglementaireConvention2017 creerConteneurDonneesEntree(Attribution attribution)
  {
    DonneesEntreesDureeReglementaireConvention2017 donnees = new DonneesEntreesDureeReglementaireConvention2017();
    if (OutilDemande.estUneDemandeRevisionAdmission(attribution.getDemande())) {
      alimenterConteneurPourRevision(donnees, attribution);
    } else {
      alimenterConteneurPourCasGeneral(donnees, attribution);
    }
    return donnees;
  }
  
  private void alimenterConteneurPourRevision(DonneesEntreesDureeReglementaireConvention2017 donnees, Attribution attribution)
  {
    Demande demande = (Demande)attribution.getDemande();
    DureeCalendaire ageFG = demande.getDemandeur().getAgeALaDate(demande.getFaitGenerateur().getDateFaitGenerateur());
    donnees.setAgeDemandeur(ageFG.getAnnees());
    
    Quantite montantJournalierBrutRevision = attribution.getMontantJournalierBrut();
    if (montantJournalierBrutRevision != null) {
      donnees.setMontantJournalierBrutRevision(montantJournalierBrutRevision.getValeur());
    }
    Quantite capitalRevision = attribution.getCapitalAServir();
    if (capitalRevision != null) {
      donnees.setCapitalRevision(capitalRevision.getValeur());
    }
    alimenterConteneurPourRevisionCoupleAttributionRevisee(attribution, donnees);
    alimenterConteneurPourRevisionListeCoupleDroitTheorique(attribution, donnees);
  }
  
  private void alimenterConteneurPourRevisionCoupleAttributionRevisee(AttributionAssuranceSpec attributionRevision, DonneesEntreesDureeReglementaireConvention2017 donnees)
  {
    CoupleDureeAllongementMontant coupleAttributionRevisee = new CoupleDureeAllongementMontant();
    
    Reliquat reliquat = ((Demande)attributionRevision.getDemandeAssurance()).getReliquat();
    if (reliquat != null)
    {
      coupleAttributionRevisee.setDureeAllongement(reliquat.getReliquatAllongementArefPossible());
      coupleAttributionRevisee.setMontant(reliquat.getMontantJournalierReliquat());
    }
    donnees.setCoupleReliquatDureeMontantAttributionRevisee(coupleAttributionRevisee);
  }
  
  private void alimenterConteneurPourRevisionListeCoupleDroitTheorique(AttributionAssuranceSpec attributionRevision, DonneesEntreesDureeReglementaireConvention2017 donnees)
  {
    ArrayList<CoupleDureeAllongementMontant> listeCoupleDroitTheorique = new ArrayList();
    
    List<DemandeAssuranceSpec> listeDemandeAssocieesAdmission = recupererListeDemandeSousJacentes(attributionRevision);
    Iterator<DemandeAssuranceSpec> iterateur = listeDemandeAssocieesAdmission.iterator();
    while (iterateur.hasNext())
    {
      DemandeAssuranceSpec demandeAssuranceSousJacente = (DemandeAssuranceSpec)iterateur.next();
      if (demandeAssuranceSousJacente.getAttribution() != null)
      {
        Attribution attributionSousJacente = (Attribution)demandeAssuranceSousJacente.getAttribution();
        DureeIndemnisation duree = attributionSousJacente.getConstitutionDurees().getDureeIndemnisation();
        if ((duree != null) && (duree.getDureeAllongementAREF() > valeurAucunAllongement))
        {
          CoupleDureeAllongementMontant couple = new CoupleDureeAllongementMontant();
          couple.setDureeAllongement(duree.getDureeAllongementAREF());
          couple.setMontant(attributionSousJacente.getMontantJournalierBrut().getValeur());
          listeCoupleDroitTheorique.add(couple);
        }
      }
    }
    donnees.setListeCoupleDureeMontantDroitTheorique(listeCoupleDroitTheorique);
  }
  
  protected List<DemandeAssuranceSpec> recupererListeDemandeSousJacentes(AttributionAssuranceSpec attribution)
  {
    return OutilsRevisions.getListeDemandesAssocieesAdmission((Demande)attribution.getDemandeAssurance());
  }
  
  private void alimenterConteneurPourCasGeneral(DonneesEntreesDureeReglementaireConvention2017 donnees, Attribution attribution)
  {
    Demande demande = (Demande)attribution.getDemandeAssurance();
    FaitGenerateurSpec faitGenerateur = demande.getFaitGenerateur();
    DureeCalendaire ageFG = demande.getDemandeur().getAgeALaDate(faitGenerateur.getDateFaitGenerateur());
    donnees.setAgeDemandeur(ageFG.getAnnees());
    
    ConstitutionQuantiteAffiliation cepQuantiteAffiliation = attribution.getConstitutionQuantiteAffiliation();
    donnees.setAffiliationPrincipale(cepQuantiteAffiliation.getQuantiteAcquise());
    donnees.setAffiliationSecondaire(cepQuantiteAffiliation.getQuantiteAcquiseSecondaire());
    
    boolean contexteRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE");
    
    donnees.setContexteRechargement(contexteRechargement);
    
    boolean demandeRechargement = "ASU_29".equals(demande.getEvenementReferenceExamen().getTypeExamen());
    donnees.setDemandeRechargement(demandeRechargement);
    
    DonneesTemporaires donneesTemporaires = demande.getDonneesTemporaires();
    donnees.setImputationDroitCourantForcee(donneesTemporaires.getNbJourImputer());
    
    donnees.setNomReglement(attribution.getReglementApplicable().getReglement().getNomReglement());
    if (donneesTemporaires.getDureeTheoriqueForcee() != null) {
      donnees.setDureeTheoriqueForcee(donneesTemporaires.getDureeTheoriqueForcee().getValeur());
    }
    if (donneesTemporaires.getDureeAllongementAREFForcee() != null) {
      donnees.setDureeAllongementArefForcee(donneesTemporaires.getDureeAllongementAREFForcee());
    }
  }
  
  protected IOutilConstitutionDureeReglementaireConvention2017 recupererOutilReglementaire(Attribution attribution)
  {
    CriteresFabriqueReglementaire criteres = recupererCriteresFabriqueReglementaire(attribution);
    return (IOutilConstitutionDureeReglementaireConvention2017)FabriqueCorpsRegleConstitutionDureeReglementaire.getInstance().recupererOutilCorpsRegle(criteres);
  }
  
  protected CriteresFabriqueReglementaire recupererCriteresFabriqueReglementaire(Attribution attribution)
  {
    CriteresFabriqueReglementaire criteres = new CriteresFabriqueReglementaire();
    criteres.setCodeProduit(attribution.getProduit().getNomUnique());
    criteres.setDate(attribution.getDateAttribution());
    List<String> contextesReglementaires = new ArrayList();
    if (OutilDemande.estUneDemandeRevisionAdmission(attribution.getDemande())) {
      contextesReglementaires.add("DureeReglementaireContexteRevision");
    } else {
      contextesReglementaires.add("DureeReglementaireContexteGeneral");
    }
    criteres.setListeContextesReglementaires(contextesReglementaires);
    return criteres;
  }
  
  private ConstitutionDurees getConstitutionDurees(DossierExamen dossierExamenCourant)
  {
    ConstitutionDurees constitutionDurees = dossierExamenCourant.getConstitutionDurees();
    if (constitutionDurees == null) {
      constitutionDurees = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDurees();
    }
    return constitutionDurees;
  }
  
  public void mapperResultatSurDom(ResultatDureeReglementaireConvention2017 resultat, ConstitutionDurees constitutionDurees)
  {
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    
    Quantite dureeTheorique = new Quantite(resultat.getDureeTheoriqueDroitCourant(), DureeReglementaire.UNITE_DEFAUT);
    Quantite imputationForcee = new Quantite(resultat.getDureeImputationForcee(), DureeReglementaire.UNITE_DEFAUT);
    Quantite imputationFormation = new Quantite(resultat.getDureeImputationFormation(), DureeReglementaire.UNITE_DEFAUT);
    Quantite imputationTotale = new Quantite(resultat.getDureeImputationForcee() + resultat.getDureeImputationFormation(), DureeReglementaire.UNITE_DEFAUT);
    
    dureeIndemnisation.setDureeTheorique(dureeTheorique);
    dureeIndemnisation.setDureeImputation(imputationFormation);
    
    dureeIndemnisation.setQuantiteTotalJourImputation(imputationTotale);
    dureeIndemnisation.setQuantiteJourImputationForce(imputationForcee);
    
    dureeIndemnisation.setEligibleAllongementAREF(resultat.isEligibleAllongement());
    dureeIndemnisation.setDureeAllongementAREF(resultat.getDureeAllongementPossible());
    
    dureeIndemnisation.setDureeAllongementAREFSousJacent(resultat.getDureeAllongementPossibleDroitSousJacent());
    
    dureeIndemnisation.setDureeCalculee(resultat.getDureeCalculeeAvantPlafondPlancher());
    dureeIndemnisation.setDureeMinimale(resultat.getDureeMinimale());
    dureeIndemnisation.setDureeMaximale(resultat.getDureeMaximale());
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution des durees impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courante est null: constitution des durees impossible.");
    }
  }
  
  private void miseAjourQuantiteAffiliation(DossierExamen dossierExamenCourant, ResultatDureeReglementaireConvention2017 resultat)
  {
    if (resultat.isPlusieursUnites())
    {
      ConstitutionQuantiteAffiliation cepAffi = dossierExamenCourant.getConstitutionQuantiteAffiliation();
      if (!cepAffi.getQuantiteAcquise().getUnite().getCode().equals(resultat.getUniteRetenu().getCode()))
      {
        JustificationAffiliationSpec justif = cepAffi.getJustificationAffiliation(resultat.getUniteRetenu());
        ((DossierAffecte)dossierExamenCourant.getDossierAffecte()).getValidationProduit().setJustificationCalculAffiliation((JustificationAffiliation)justif);
        
        Quantite qteTemp = cepAffi.getQuantiteAffiliationAcquise();
        Quantite qteTemp1 = cepAffi.getQuantiteAssimilationAcquise();
        Quantite qteTemp2 = cepAffi.getQuantiteAffiliationAcquiseSecondaire();
        Quantite qteTemp3 = cepAffi.getQuantiteAssimilationAcquiseSecondaire();
        
        cepAffi.setQuantiteAffiliationAcquise(qteTemp2);
        cepAffi.setQuantiteAssimilationAcquise(qteTemp3);
        cepAffi.setQuantiteAffiliationAcquiseSecondaire(qteTemp);
        cepAffi.setQuantiteAssimilationAcquiseSecondaire(qteTemp1);
      }
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */