package fr.unedic.cali.asu.cge01.p07.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRARechargement
  implements ParametrageListePRASpec
{
  public static final int PRA_36_MOIS = 36;
  public static final int PRA_28_MOIS = 28;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_53ANS = 4;
  public static final int SUP_EGAL_57ANS = 3;
  private Collection<Pra> listePRA;
  private static ParametrageListePRARechargement instance;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  public static final int DONNEE_SANS_OBJET = -1;
  
  public ParametrageListePRARechargement()
  {
    initInstance();
  }
  
  public static ParametrageListePRARechargement getInstance()
  {
    if (instance == null) {
      instance = new ParametrageListePRARechargement();
    }
    return instance;
  }
  
  private void initInstance()
  {
    listePRA = new ArrayList();
    
    initInstanceRG();
    
    initInstanceRGInterimaire();
    
    initInstanceRGParticulier();
    
    initInstanceA1();
    
    initInstanceA2A();
    
    initInstanceA2B();
    
    initInstanceA3();
    
    initInstanceA5();
    
    initInstanceA9A();
  }
  
  public List<Pra> getListePra(CleAccesPRA cle)
    throws CoucheLogiqueException
  {
    List<Pra> resultatListePRA = new ArrayList();
    if ("OP".equals(cle.getNomReglement())) {
      throw new CoucheLogiqueException("Le règlement RG_OP n'est pas géré pour le produit ARE09");
    }
    Iterator<Pra> it = listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(cle)) {
        resultatListePRA.add((Pra)pra.copie());
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceRG()
  {
    Pra pra = new Pra("RG", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGInterimaire()
  {
    Pra pra = new Pra("RG5", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG5", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGParticulier()
  {
    Pra pra = new Pra("RGP", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA1()
  {
    Pra pra = new Pra("A1", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 22, "jour travaillés");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 22, "jour travaillés");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2A()
  {
    Pra pra = new Pra("A2a", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2B()
  {
    Pra pra = new Pra("A2b", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "embarquement administratif");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "embarquement administratif");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA3()
  {
    Pra pra = new Pra("A3", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 43, "vacation");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 43, "vacation");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA5()
  {
    Pra pra = new Pra("A5", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA9A()
  {
    Pra pra = new Pra("A9A", new int[] { 4, 3 }, 36, 4, 1);
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", new int[] { 1, 2 }, 28, 2, 3);
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra pra)
  {
    listePRA.add(pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra pra, int quantite, String uniteAffiliation)
  {
    Unite unite = Unite.get(uniteAffiliation);
    Quantite quantiteAffi = new Quantite(quantite, unite);
    pra.getListeQuantitesAffiliationRequises().put(unite, quantiteAffi);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRARechargement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */