package fr.unedic.cali.asu.cge01.revision;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeAssociee;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.PensionInvaliditeChainee;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCreationDemande;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class ParcoursLiquidationDemandesSousJacentesRevision
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA = new Resultat();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    AttributionAssuranceSpec attributionPrecedente = recupererAttributionPrecedente(contexte);
    
    List<TravailSpec> listeFcts = recupererFctsAReviser(demande, attributionPrecedente.getListeActiviteConservee());
    
    lancerLiquidationDemandesSousJacentes(demande, listeFcts, contexte);
    
    alimenterResultat(resultatCEPA);
    
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA;
  }
  
  private AttributionAssuranceSpec recupererAttributionPrecedente(Contexte contexte)
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    
    return dom.getAttributionPrecedente();
  }
  
  private List<TravailSpec> recupererFctsAReviser(Demande demande, Chronologie listeActiviteConservee)
  {
    List<TravailSpec> listeFcts = new ArrayList();
    TravailSpec periodeForcee = demande.getDonneesTemporaires().getPeriodeRevision();
    
    Chronologie listeActiviteSalarieConservee = listeActiviteConservee.copier(new FiltreActiviteSalarie());
    listeFcts.add(periodeForcee);
    listeActiviteSalarieConservee.iterer();
    while (listeActiviteSalarieConservee.encoreSuivant())
    {
      TravailSpec periode = (TravailSpec)listeActiviteSalarieConservee.elementSuivant();
      if ((periodeForcee.getDateFin().coincideAvec(periode.getDateFin())) && (!listeFcts.contains(periode))) {
        listeFcts.add(periode);
      }
    }
    return listeFcts;
  }
  
  private List<Demande> lancerLiquidationDemandesSousJacentes(Demande demande, List<TravailSpec> listeFcts, Contexte contexte)
    throws ApplicativeException
  {
    List<Demande> listeDemandesAChainer = new ArrayList();
    boolean uneSeuleFct = listeFcts.size() == 1;
    
    Iterator<TravailSpec> it = listeFcts.iterator();
    while (it.hasNext())
    {
      TravailSpec periode = (TravailSpec)it.next();
      
      Demande demandeCourante = creerDemandeAssociee(demande, periode);
      if (uneSeuleFct) {
        forcerDonnesDemandeSousJacente(demande, demandeCourante);
      }
      listeDemandesAChainer.add(demandeCourante);
      
      lancerLiquidation(demandeCourante, contexte);
    }
    chainerDemandes(demande, listeDemandesAChainer);
    return listeDemandesAChainer;
  }
  
  private Demande creerDemandeAssociee(Demande demande, TravailSpec periodeRevision)
    throws ApplicativeException
  {
    String typeDemande = "ASU_21";
    Damj dateDepot = demande.getDateDepot();
    IndividuSpec individu = demande.getDemandeur();
    
    Demande demandeAssociee = (Demande)OutilCreationDemande.creerDemande(typeDemande, dateDepot, individu, demande.getFormulaire().getIdPec(), null);
    
    demandeAssociee.setDemandeur(demande.getDemandeur());
    
    ((FormulaireAsu)demandeAssociee.getFormulaire()).setReferenceExterne(demande.getFormulaire().getReferenceExterne());
    
    ((EreDemandeAssociee)demandeAssociee.getEvenementReferenceExamen()).setContexteDemande("ARESJREV");
    if ("REVAUTO".equals(((EreRevisionConvention2014)demande.getEvenementReferenceExamen()).getContexteDemande())) {
      ((EreDemandeAssociee)demandeAssociee.getEvenementReferenceExamen()).setDateExamenForcee(demande.getEvenementReferenceExamen().getDateExamen(demande));
    }
    demandeAssociee.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("ARESJREV");
    
    demande.createDonneesDemandeAssociee();
    
    demandeAssociee.getDonneesTemporaires().setPeriodeRevision(periodeRevision);
    demandeAssociee.getDonneesTemporaires().setIdentifiantPeriodeActiviteConserveePerdue(periodeRevision.getIdentifiant());
    
    return demandeAssociee;
  }
  
  private void lancerLiquidation(Demande demande, Contexte pContexte)
    throws ApplicativeException
  {
    IndividuSpec individu = demande.getDemandeur();
    
    individu.activerChronoPasseProPourLiquidationRevision();
    
    DomLiquidationAssurance dom = new DomLiquidationAssurance();
    Contexte contexte = new Contexte();
    contexte.setDonnees(dom);
    
    dom.setDemande(demande);
    dom.setIndividu(demande.getDemandeur());
    
    dom.setContexteService(((DomLiquidationAssurance)pContexte.getDonnees()).getContexteService());
    
    ParcoursLiquidationDemandeSousJacentePourFct parcours = new ParcoursLiquidationDemandeSousJacentePourFct();
    
    demande.setDemandeLiquidee(true);
    parcours.demarrerParcours(contexte);
    demande.setDemandeLiquidee(false);
    
    individu.desactiverChronoPasseProPourLiquidationRevision();
  }
  
  private void chainerDemandes(Demande demande, List<Demande> listeDemandesAChainer)
  {
    Demande demandePrecedente = demande;
    
    Iterator<Demande> it = listeDemandesAChainer.iterator();
    while (it.hasNext())
    {
      Demande demandeCourante = (Demande)it.next();
      if (demandePrecedente.getDonneesDemandeAssociee() == null) {
        demandePrecedente.createDonneesDemandeAssociee();
      }
      demandePrecedente.getDonneesDemandeAssociee().setDemandeAssociee(demandeCourante);
      demandePrecedente = demandeCourante;
    }
  }
  
  private void alimenterResultat(Resultat resultatCEPA)
  {
    resultatCEPA.setEtat(0);
  }
  
  private void forcerDonnesDemandeSousJacente(Demande demandeRevision, Demande demandeSousJacente)
  {
    DonneesTemporaires donneesForcees = demandeRevision.getDonneesTemporaires();
    DonneesTemporaires donneesForceesSJ = demandeSousJacente.getDonneesTemporaires();
    if (donneesForcees != null)
    {
      donneesForceesSJ.setIdentifiantPeriodeFctARetenir(donneesForcees.getIdentifiantPeriodeActiviteConserveePerdue());
      donneesForceesSJ.setQuantiteAffiliation(donneesForcees.getQuantiteAffiliation());
      donneesForceesSJ.setSjr(donneesForcees.getSjrPerteActConservee());
      donneesForceesSJ.setDureeTheoriqueForcee(donneesForcees.getDureeTheoriqueForcee());
      donneesForceesSJ.setCoefficientTempsPartiel(donneesForcees.getCoefficientTempsPartielActConservee());
      donneesForceesSJ.setTermePrc(donneesForcees.getTermePrc());
      donneesForceesSJ.setEstDesactivationPnds(donneesForcees.isEstDesactivationPnds());
      
      Collection<PensionInvaliditeChainee> listePi = donneesForcees.getListePensionInvalidite();
      if (listePi != null)
      {
        Iterator<PensionInvaliditeChainee> it = listePi.iterator();
        while (it.hasNext()) {
          donneesForceesSJ.addPensionInvalidite((PensionInvaliditeChainee)((PensionInvaliditeChainee)it.next()).copie());
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationDemandesSousJacentesRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */