package fr.unedic.cali.asu.cge01.revision.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConstitutionMontantsBrutsSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantAsp;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class DeterminationCapital
{
  public static final BigDecimal COEFFICIENT_SAISONNIER_1 = new BigDecimal("1");
  public static final BigDecimal CAPITAL_0 = new BigDecimal("0");
  
  public static MontantAsuSpec determinerMontantDroitAReviser(Demande pDemandeRevision)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionRevision = (AttributionAssuranceSpec)pDemandeRevision.getDossierExamen();
    AttributionAssuranceSpec odRevisee = attributionRevision.getAttributionPrecedente();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = recupererDonneesEntreesRecuperationMontantDroitAReviser(odRevisee, recupererDateCalculMontantCapital(pDemandeRevision));
    
    return DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
  }
  
  public static BigDecimal determinerCapitalDroitAReviser(Demande pDemandeRevision, MontantAsuSpec pMontantDroitAReviser, boolean pEstDroitAReviserDifferentMaintien)
    throws ApplicativeException
  {
    AttributionAssuranceSpec attributionRevision = (AttributionAssuranceSpec)pDemandeRevision.getDossierExamen();
    AttributionAssuranceSpec odRevisee = (AttributionAssuranceSpec)attributionRevision.getOuvertureDroit();
    Damj dateCalcul = pDemandeRevision.getDateFaitGenerateurOuDernierSinistre().lendemain();
    
    Reliquat reliquat = pDemandeRevision.getReliquat();
    
    BigDecimal capitalDroiAReviser = CAPITAL_0;
    if (pEstDroitAReviserDifferentMaintien)
    {
      Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(odRevisee, pMontantDroitAReviser, dateCalcul, reliquat.getQuantiteReliquat());
      
      capitalDroiAReviser = capitalProduitCourant.getValeur();
    }
    return capitalDroiAReviser;
  }
  
  public static boolean estDroitAReviserDifferentMaintien(Contexte contexte)
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    
    return (dom.getResultatExecutionCalculDroitPrecedent().getReliquatDureeIndemnisation() != null) && (dom.getResultatExecutionCalculDroitPrecedent().getReliquatDureeIndemnisation().getValeurEntiere() != 0);
  }
  
  public static BigDecimal determinerCapitalActivitesConservees(Demande p_demandeRevision)
    throws ApplicativeException
  {
    List<DemandeAssuranceSpec> listeDemandeAssocieesAdmission = OutilsRevisions.getListeDemandesAssocieesAdmission(p_demandeRevision);
    
    Iterator<DemandeAssuranceSpec> iterateur = listeDemandeAssocieesAdmission.iterator();
    BigDecimal capitalActiviteConservee = new BigDecimal("0");
    while (iterateur.hasNext())
    {
      DemandeAssuranceSpec demandeAssurance = (DemandeAssuranceSpec)iterateur.next();
      
      DossierExamenAssuranceSpec dossierExamenSousJacente = (DossierExamenAssuranceSpec)demandeAssurance.getDossierExamen();
      if (dossierExamenSousJacente.getConstitutionMontantsBruts() != null) {
        capitalActiviteConservee = capitalActiviteConservee.add(dossierExamenSousJacente.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
      }
    }
    return capitalActiviteConservee;
  }
  
  public static BigDecimal determinerCapitalRevise(Demande p_demandeRevision)
    throws ApplicativeException
  {
    BigDecimal capitalActiviteConservees = determinerCapitalActivitesConservees(p_demandeRevision);
    BigDecimal capitaDroitAReviser = p_demandeRevision.getReliquat().getCapitalReliquat();
    return capitalActiviteConservees.add(capitaDroitAReviser);
  }
  
  private static Damj recupererDateCalculMontantCapital(Demande pDemandeRevision)
    throws CoucheLogiqueException
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(pDemandeRevision, "REVAUTO")) {
      return pDemandeRevision.getDateExamen();
    }
    return pDemandeRevision.getDateFaitGenerateurOuDernierSinistre().lendemain();
  }
  
  private static DonneesEntreesRecuperationMontant recupererDonneesEntreesRecuperationMontantDroitAReviser(AttributionAssuranceSpec p_odRevisee, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = ((GammeAsuSpec)p_odRevisee.getGamme()).mapperDonneesEntreesRecuperationMontant(p_odRevisee);
    
    DonneesCalculMontant dcm = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    dcm.setCoefficientSaisonnier(COEFFICIENT_SAISONNIER_1);
    
    donneesEntreesRecuperationMontant.setDateCalculMontant(p_dateCalcul);
    if (donneesEntreesRecuperationMontant.getDonneesCalculMontant().getProduit().equals(ProduitAsuCaa14P02.getInstance())) {
      donneesEntreesRecuperationMontant.getDonneesCalculMontant().setProduit(donneesEntreesRecuperationMontant.getDonneesCalculMontantAsp().getProduitAreSousJacent());
    }
    ProduitAsuSpec produitAre = (ProduitAsuSpec)donneesEntreesRecuperationMontant.getDonneesCalculMontant().getProduit();
    FormuleMontantSpec formuleMontant = produitAre.getFormuleMontant("1");
    dcm.setFormuleMontant(formuleMontant);
    
    return donneesEntreesRecuperationMontant;
  }
}

/* Location:
 * Qualified Name:     DeterminationCapital
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */