package fr.unedic.cali.asu.csr04.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionCSR28Jours;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Rejet;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategieCondition28Jours;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategieCondition28JoursSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationCondition28JoursSuspension
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_context)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_context) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition des 28 jours de suspension impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_context).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Le demandeur est null: determination condition des 28 jours de suspension impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCondition28JoursSuspension = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DomLiquidationAssurance.getDemande(p_contexte).getDemandeur();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    DonneesTemporaires donneesTemporaires = demandeCourante.getDonneesTemporaires();
    
    boolean isLeveeCondition28JoursSuspension = donneesTemporaires.isLeveeCondition28JoursChomageTotalSansRupture();
    DossierExamenSpec dossierExamen = demandeCourante.getDossierAffectation().getDossierExamen();
    if (!dossierExamen.estType(Rejet.class)) {
      if (!isLeveeCondition28JoursSuspension)
      {
        CritereStrategie criteres = new CritereStrategie();
        if (demandeCourante.getDonneesTemporaires().getDateChomageTotalSansRupture() != null) {
          criteres.setDatePivot(demandeCourante.getDonneesTemporaires().getDateChomageTotalSansRupture().lendemain());
        } else {
          criteres.setDatePivot(demandeCourante.getDateExamen());
        }
        FabriqueStrategieCondition28Jours fabrique = new FabriqueStrategieCondition28Jours();
        StrategieCondition28JoursSpec strategie = (StrategieCondition28JoursSpec)fabrique.getStrategie(criteres);
        
        ConditionCSR28Jours conditionCSR28Jours = dossierExamenCourant.getConditionsAttributionAdmission().createConditionCSR28Jours();
        conditionCSR28Jours.setEtatSatisfait(true);
        
        Periode periodeSuspension = OutilsChomageSansRCT.getPeriodeSuspension(demandeCourante).getPeriode();
        if (periodeSuspension.getDuree() < strategie.getNombreJoursSuspension())
        {
          resultatCondition28JoursSuspension = new Resultat(1);
          conditionCSR28Jours.setCodeMotifEchec(202);
          resultatCondition28JoursSuspension.setMessageErreur(Integer.toString(conditionCSR28Jours.getCodeMotifEchec()));
          conditionCSR28Jours.setEtatSatisfait(false);
        }
        else
        {
          Damj dateIde = demandeCourante.getDateExamen();
          if (!dateIde.estContenueDans(periodeSuspension))
          {
            resultatCondition28JoursSuspension = new Resultat(1);
            conditionCSR28Jours.setCodeMotifEchec(202);
            resultatCondition28JoursSuspension.setMessageErreur(Integer.toString(conditionCSR28Jours.getCodeMotifEchec()));
            conditionCSR28Jours.setEtatSatisfait(false);
          }
          else
          {
            ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePECContenant(DomLiquidationAssurance.getDemande(p_contexte).getDemandeur(), dateIde);
            if (periodeSuspension.getDebut().joursEntre(periodePEC.getDateFin()) < strategie.getNombreJoursSuspension())
            {
              resultatCondition28JoursSuspension = new Resultat(1);
              conditionCSR28Jours.setCodeMotifEchec(202);
              resultatCondition28JoursSuspension.setMessageErreur(Integer.toString(conditionCSR28Jours.getCodeMotifEchec()));
              conditionCSR28Jours.setEtatSatisfait(false);
            }
          }
        }
      }
    }
    OutilTrace.tracerFinParcours();
    return resultatCondition28JoursSuspension;
  }
}

/* Location:
 * Qualified Name:     DeterminationCondition28JoursSuspension
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */