package fr.unedic.cali.asu.cva10.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.math.BigDecimal;
import java.util.Collection;

public class DeterminationMontantsBruts
  implements OutilFonctionnel
{
  public static final String MONTANT_RETENU_ASP = "1";
  public static final String MONTANT_RETENU_ARE_SOUS_JACENT = "2";
  
  public static DeterminationMontantsBruts getInstance()
  {
    return new DeterminationMontantsBruts();
  }
  
  public void determinerMontantsBrutsPourReprise(Demande p_demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)p_demande.getAttribution();
    
    Demande demandeOdOrigine = (Demande)attributionCourante.getOuvertureDroit().getDemande();
    
    attributionCourante.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    
    MontantAsuSpec montantAttributionASP = null;
    MontantAsuSpec montantAttributionARESJ = null;
    String typeMontantRetenu = "1";
    
    montantAttributionASP = determinerMontantASP(attributionCourante);
    
    Attribution attributionPrecedente = (Attribution)attributionCourante.getAttributionPrecedente();
    if ((attributionPrecedente != null) && (attributionPrecedente.getConstitutionMontantsBruts() != null) && 
      ("2".equals(attributionPrecedente.getConstitutionMontantsBruts().getTypeMontantRetenuDroitCourant()))) {
      typeMontantRetenu = "2";
    }
    if ((demandeOdOrigine != null) && (demandeOdOrigine.getDonneesDemandeAssociee() != null) && (demandeOdOrigine.getDonneesDemandeAssociee().getDemandeAssociee() != null)) {
      montantAttributionARESJ = determinerMontantARESousJacent(attributionCourante, demandeOdOrigine.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution());
    }
    alimenterResultatCep(typeMontantRetenu, montantAttributionASP, attributionCourante, montantAttributionARESJ);
  }
  
  public void determinerMontantsBruts(Demande p_demande)
    throws CoucheLogiqueException
  {
    Attribution attributionAsp = (Attribution)p_demande.getAttribution();
    
    attributionAsp.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)attributionAsp.getProduit();
    Collection listePensionInvalidite = produit.determinerPensionInvaliditeDroitCourant(attributionAsp);
    ConstitutionMontantsBruts resultatCep = attributionAsp.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    resultatCep.setListePensionInvalidite(listePensionInvalidite);
    
    MontantAsuSpec montantAttributionASP = null;
    MontantAsuSpec montantAttributionARESJ = null;
    String typeMontantRetenu = "1";
    
    montantAttributionASP = determinerMontantASP(attributionAsp);
    if ((p_demande.getDonneesDemandeAssociee() != null) && (p_demande.getDonneesDemandeAssociee().getDemandeAssociee() != null) && (p_demande.getDonneesDemandeAssociee().getDemandeAssociee().getDossierExamen() != null) && (!NaturesDecisions.estdeTypeRejet(((DecisionSpec)p_demande.getDonneesDemandeAssociee().getDemandeAssociee().getDossierExamen()).getNatureDecision())))
    {
      AttributionAssuranceSpec attributionARESJ = p_demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution();
      montantAttributionARESJ = determinerMontantARESousJacent(attributionAsp, attributionARESJ);
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_REJET_ARE_SOUS_JACENT_ASP_DC ");
    }
    if ((montantAttributionASP != null) && (montantAttributionARESJ != null) && (montantAttributionARESJ.getMontantPrecompte().compareTo(montantAttributionASP.getMontantPrecompte()) == 1)) {
      typeMontantRetenu = "2";
    } else {
      typeMontantRetenu = "1";
    }
    alimenterResultatCep(typeMontantRetenu, montantAttributionASP, attributionAsp, montantAttributionARESJ);
  }
  
  private MontantAsuSpec determinerMontantASP(Attribution p_attributionAsp)
    throws CoucheLogiqueException
  {
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)p_attributionAsp.getGamme()).mapperDonneesEntreesRecuperationMontant(p_attributionAsp);
    
    donneesEntrees.setDateCalculMontant(p_attributionAsp.getDateEffet());
    
    FormuleMontantSpec formuleMontant = p_attributionAsp.getFormuleMontant("1");
    formuleMontant.setFormuleMontantApplicable(1);
    donneesEntrees.getDonneesCalculMontant().setFormuleMontant(formuleMontant);
    
    MontantAsuSpec montantAttributionASP = DeterminationMontant.determinerMontant(donneesEntrees);
    
    return montantAttributionASP;
  }
  
  private MontantAsuSpec determinerMontantARESousJacent(Attribution p_attributionAsp, AttributionAssuranceSpec p_attributionARESJ)
    throws CoucheLogiqueException
  {
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)p_attributionAsp.getGamme()).mapperDonneesEntreesRecuperationMontant(p_attributionAsp);
    
    donneesEntrees.getDonneesCalculMontant().setPriseEnCompteAvantageVieillesse(false);
    donneesEntrees.setDateCalculMontant(p_attributionAsp.getDateAttribution());
    donneesEntrees.getDonneesCalculMontant().setProduit(p_attributionARESJ.getProduit());
    
    Competences conteneurCompetencesARESJ = new Competences();
    conteneurCompetencesARESJ.setCompetenceAdministrative(p_attributionARESJ.getCompetenceAdministrative());
    conteneurCompetencesARESJ.setCompetenceFinanciere(p_attributionARESJ.getCompetenceFinanciere());
    conteneurCompetencesARESJ.setConventionGestion(p_attributionARESJ.getConventionGestion());
    donneesEntrees.setCompetences(conteneurCompetencesARESJ);
    
    FormuleMontantSpec formuleMontantARESJ = p_attributionAsp.getFormuleMontant("1");
    formuleMontantARESJ.setFormuleMontantApplicable(2);
    formuleMontantARESJ.setFormuleMontantDroitAssocie(p_attributionARESJ.getFormuleMontant("2"));
    donneesEntrees.getDonneesCalculMontant().setFormuleMontant(formuleMontantARESJ);
    
    donneesEntrees.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontant().setAvecPrecompteCRC(Boolean.TRUE);
    
    MontantAsuSpec montantAAttributionARESJ = DeterminationMontant.determinerMontant(donneesEntrees);
    
    return montantAAttributionARESJ;
  }
  
  private void alimenterResultatCep(String p_typeMontantRetenu, MontantAsuSpec p_montantAsp, Attribution p_attributionAsp, MontantAsuSpec p_montantARESJ)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCep = p_attributionAsp.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    resultatCep.setTypeMontantRetenuDroitCourant(p_typeMontantRetenu);
    if (p_montantARESJ != null)
    {
      resultatCep.setMontantDroitAssocie(p_montantARESJ.getMontantBrut());
      resultatCep.setCrcAreSousJacent(p_montantARESJ.getCrc());
    }
    resultatCep.setMontantAAttribution(p_montantAsp);
    
    resultatCep.setMontantJournalierBrut(p_montantAsp.getMontantPrecompteEffectif());
    
    resultatCep.setMontantBrutSansDeduction(p_montantAsp.getMontantBrut());
    if (p_montantAsp != null)
    {
      resultatCep.setMontantBase(p_montantAsp.getBase());
      resultatCep.setMontantMini(p_montantAsp.getMini());
      resultatCep.setMontantPlafond(p_montantAsp.getPlafond());
      resultatCep.setMontantPlancher(p_montantAsp.getPlancher());
      resultatCep.setMontantBrutSansPensionInvaliditeADeduire(p_montantAsp.getMontantBrutSansPensionInvaliditeADeduire());
      resultatCep.setPensionInvaliditeADeduirePriseEnCompte(p_montantAsp.getPensionInvaliditeADeduirePriseEnCompte());
      resultatCep.setMontantJournalierAvantageVieillesse(p_montantAsp.getMontantJournalierAvantageVieillesse());
      resultatCep.setMontantJournalierAvantageVieillesseDeduit(p_montantAsp.getMontantJournalierAvantageVieillesseDeduit());
      resultatCep.setCrc(p_montantAsp.getCrc());
      resultatCep.setQuatreVingtSjr(p_montantAsp.getPlafond().getValeur());
      resultatCep.setMiniAREF(p_montantAsp.getMini().getValeur());
    }
    Quantite nbJourIndemnisesTheorique = p_attributionAsp.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    
    MontantAsuSpec montantPourCalculCapital = p_montantAsp;
    if ("2".equals(p_typeMontantRetenu)) {
      montantPourCalculCapital = p_montantARESJ;
    }
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(p_attributionAsp, montantPourCalculCapital, p_attributionAsp.getDateAttribution(), nbJourIndemnisesTheorique);
    
    resultatCep.setCapitalInitialBrut(capitalProduitCourant);
  }
}

/* Location:
 * Qualified Name:     DeterminationMontantsBruts
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */