package fr.unedic.cali.asu.cve13.p01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsAlimentationDonneesCalculMontant;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisationATPF;
import fr.unedic.cali.asu.cve13.p01.calcul.dom.FormuleMontantATP;
import fr.unedic.cali.asu.cve13.p01.calcul.dom.FormuleMontantATPF;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final int CINQUANTE_ANS = 50;
  private static final int PIVOT = 10;
  
  public Quantite calculerCapital(AttributionSpec p_attribution, MontantAsuSpec p_montant, Damj p_pointDeDepart, Quantite p_nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = p_attribution.getDemandeur();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = p_pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, p_pointDeDepart, p_nbJoursIndemnisables, false);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = p_montant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec p_attribution, Damj p_dateAttribution, Damj p_pointDeDepart, Quantite p_nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec p_attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite p_quantiteInitiale, Quantite p_nbHeuresFormation)
    throws IllegalArgumentException
  {
    return null;
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)p_attribution;
    
    return (attribution.getCompetenceFinanciere() == 2) && ((attribution.getCompetenceAdministrative() != 1) || ((attribution.getConventionGestion() != null) && (!attribution.getConventionGestion().estPrecompteCRC())));
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantATP();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantATPF();
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec p_attribution, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec p_attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant p_donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = p_donneesEntreesRecuperationMontant.getDateCalculMontant();
    IndividuSpec individu = p_donneesEntreesRecuperationMontant.getIndividu();
    
    DonneesCalculMontant donneesCalculMontant = p_donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    OutilsAlimentationDonneesCalculMontant.alimenterDonneesEbiCasGeneral(p_donneesEntreesRecuperationMontant, elementBaseIndemnisationCourant);
    
    OutilsAlimentationDonneesCalculMontant.alimenterDonneesEbiSpectacle(p_donneesEntreesRecuperationMontant.getDonneesCalculMontantSpectacle(), elementBaseIndemnisationCourant);
    
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    boolean isPlafonne = false;
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr((Sjr)donneesCalculMontant.getSalaireJournalier(), dateCalcul, isPlafonne);
    elementBaseIndemnisationCourant.setSjrATP(sjrRevalorise);
    
    Sjr sjrRevalorisePlafonne = RevalorisationSalaire.revaloriserSjr((Sjr)donneesCalculMontant.getSalaireJournalier(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorisePlafonne);
    if (donneesCalculMontant.getCoefficientSaisonnier() != null)
    {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
      if ((donneesCalculMontant.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
        if ((donneesCalculMontant.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontant.isConditionCaractereSaisonnierParRythme())) {
          elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1.00"));
        }
      }
    }
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null)
    {
      elementBaseIndemnisationCourant.setCoefficientTempsPartielATP(donneesCalculMontant.getCoefficientTempsPartiel());
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    }
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite()) {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
    } else {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0"));
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = new BigDecimal(0);
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
      elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
      
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal("0.00"));
    }
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else if ((p_donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((p_donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((p_donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!p_donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(new Boolean(false));
    }
    elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationATPF ebiAREF = new ElementBaseIndemnisationATPF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
  
  protected ResultatDeterminationEtatDroit reportAntecedentTheorique(AttributionAssuranceSpec p_attributionAEtudier)
    throws ApplicativeException
  {
    ResultatDeterminationEtatDroit resultatCalcul = new ResultatDeterminationEtatDroit();
    return resultatCalcul;
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant p_donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec fm = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(p_donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = p_donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      fm = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      fm = getFormuleMontantEnFormation();
    } else {
      fm = getFormuleMontant();
    }
    return fm.calculer(constituantsIndemnisation, p_donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */