package fr.unedic.cali.asu.cve13.p01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public class ActiviteReduite
{
  private static final BigDecimal ZERO = new BigDecimal(0);
  private static final BigDecimal CUMUL_JOURS_AR_NEUTRALISATION = new BigDecimal(277);
  
  public static ResultatActiviteReduite genererEvenementActiviteReduite(ChronologiePeriodes p_periodeEmploi, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite)
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    
    BigDecimal cumulJoursARSurUT = ZERO;
    evtRetour.setCumulNbHeuresJustifiees(ZERO);
    evtRetour.setCumulGainJustifie(ZERO);
    evtRetour.setNbHeuresPrisesEnCompte(ZERO);
    evtRetour.setGainPrisEnCompte(ZERO);
    
    evtRetour.setNeutralise(estUTANeutraliser(p_constituantsCalculActiviteReduite));
    if (evtRetour.isNeutralise()) {
      evtRetour.setTypeNeutralisation(3);
    }
    cumulJoursARSurUT = calculerNombreJoursActiviteSurUT(p_periodeEmploi);
    if (cumulJoursARSurUT != null) {
      evtRetour.setCumulJourDeTravail(cumulJoursARSurUT);
    }
    calculerGainHeureSurUT(p_periodeEmploi, evtRetour);
    
    return evtRetour;
  }
  
  protected static void calculerGainHeureSurUT(ChronologiePeriodes p_periodes, ResultatActiviteReduite p_evtRetour)
  {
    ObjetChronoPeriodeCalcul periodeTravailCalcul = null;
    
    Iterator iterateur = p_periodes.iterer();
    if ((p_periodes != null) && (iterateur != null))
    {
      p_periodes.iterer();
      while (p_periodes.encoreSuivant())
      {
        periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodes.elementSuivant();
        if ((periodeTravailCalcul instanceof PeriodeTravailJustifiee))
        {
          PeriodeTravailJustifiee periodeTravailJustifiee = (PeriodeTravailJustifiee)periodeTravailCalcul;
          if (periodeTravailJustifiee.getGain() != null)
          {
            p_evtRetour.setCumulGainJustifie(p_evtRetour.getCumulGainJustifie().add(periodeTravailJustifiee.getGain()));
            p_evtRetour.setCumulNbHeuresJustifiees(p_evtRetour.getCumulNbHeuresJustifiees().add(periodeTravailJustifiee.getNombreHeures()));
          }
        }
        else if ((periodeTravailCalcul instanceof PeriodePrime))
        {
          PeriodePrime periodePrime = (PeriodePrime)periodeTravailCalcul;
          if (periodePrime.getMontant() != null) {
            p_evtRetour.setCumulGainJustifie(p_evtRetour.getCumulGainJustifie().add(periodePrime.getMontant().getValeur()));
          }
        }
        else if ((periodeTravailCalcul instanceof DsmTravail))
        {
          DsmTravail periodeTravailDeclaree = (DsmTravail)periodeTravailCalcul;
          if (periodeTravailDeclaree.getGain() != null)
          {
            p_evtRetour.setGainPrisEnCompte(p_evtRetour.getGainPrisEnCompte().add(periodeTravailDeclaree.getGain()));
            p_evtRetour.setNbHeuresPrisesEnCompte(p_evtRetour.getNbHeuresPrisesEnCompte().add(periodeTravailDeclaree.getNombreHeures()));
          }
        }
      }
    }
  }
  
  protected static BigDecimal calculerNombreJoursActiviteSurUT(ChronologiePeriodes p_periodes)
  {
    int nombreJoursAR = 0;
    ObjetChronoPeriodeCalcul periodeTravailCalcul = null;
    periodeTravailCalcul = null;
    
    Iterator iterateur = p_periodes.iterer();
    if ((p_periodes != null) && (iterateur != null))
    {
      p_periodes.iterer();
      Periode periodeResultante = null;
      while (p_periodes.encoreSuivant())
      {
        periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodes.elementSuivant();
        if (periodeResultante == null)
        {
          periodeResultante = periodeTravailCalcul.getPeriode();
          nombreJoursAR = periodeResultante.getDuree();
        }
        else if (((periodeTravailCalcul instanceof PeriodeTravailJustifiee)) || ((periodeTravailCalcul instanceof PeriodePrime)))
        {
          if (periodeResultante.inter(periodeTravailCalcul.getPeriode()) == 0) {
            nombreJoursAR += periodeTravailCalcul.getDuree();
          } else {
            nombreJoursAR += periodeTravailCalcul.getDuree() - periodeResultante.inter(periodeTravailCalcul.getPeriode());
          }
          periodeResultante.setFin(periodeTravailCalcul.getDateFin());
        }
      }
    }
    return new BigDecimal(nombreJoursAR);
  }
  
  protected static boolean estUTANeutraliser(ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite)
  {
    boolean isNeutralise = false;
    
    ConstituantsCalculActiviteReduiteAsu constituantsCalculActiviteReduite = (ConstituantsCalculActiviteReduiteAsu)p_constituantsCalculActiviteReduite;
    
    BigDecimal cumulActiviteReduite = new BigDecimal(constituantsCalculActiviteReduite.getCumulJours());
    if (cumulActiviteReduite.compareTo(CUMUL_JOURS_AR_NEUTRALISATION) > 0) {
      isNeutralise = true;
    }
    return isNeutralise;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */