package fr.unedic.cali.asu.ddm16.p01.calcul.outilsfonctionnels;

import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclareeSanction;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePrimeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ListIterator;

public class ActiviteReduite
  extends fr.unedic.cali.asu.calcul.outilsfonctionnels.ActiviteReduite
{
  public static BigDecimal calculerGainRetenu(Chronologie periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    
    Chronologie chronoFiltree = periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (!(periodeCourante instanceof PansNonInstallee)) {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu;
  }
  
  public static BigDecimal calculerSeuilMensuel(Damj mois, BigDecimal sjr, BigDecimal sjc, boolean estApprenti, boolean avecSjc, BigDecimal cumulGainPansConservee, boolean presencePansConservee)
    throws CoucheLogiqueException
  {
    BigDecimal montantJournalierRetenu;
    BigDecimal montantJournalierRetenu;
    if (avecSjc) {
      montantJournalierRetenu = sjr.add(sjc);
    } else {
      montantJournalierRetenu = sjr;
    }
    BigDecimal sommeSjrSjc = sjr.add(sjc);
    BigDecimal montantMoyenMensuelRetenu = null;
    BigDecimal smicJournalier = getSmicJournalier(mois.getDebutMois());
    if ((estApprenti) && (!presencePansConservee)) {
      if (!avecSjc)
      {
        if (smicJournalier.compareTo(sjr) > 0) {
          montantJournalierRetenu = smicJournalier;
        }
      }
      else if (smicJournalier.compareTo(sommeSjrSjc) > 0) {
        montantJournalierRetenu = smicJournalier;
      }
    }
    montantMoyenMensuelRetenu = montantJournalierRetenu.multiply(new BigDecimal("30")).add(cumulGainPansConservee);
    
    return Mathematiques.tronque(montantMoyenMensuelRetenu.multiply(new BigDecimal("0.7")), 2);
  }
  
  public static ResultatActiviteReduite genererEvenementActiviteReduite(Damj dateDebutPeriodeActiviteReduite, Chronologie periodeEmploi, BigDecimal sjr)
    throws CoucheLogiqueException
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    BigDecimal cumulNbHeures = BigDecimal.ZERO;
    BigDecimal cumulGain = BigDecimal.ZERO;
    
    BigDecimal cumulGainPrimes = BigDecimal.ZERO;
    
    BigDecimal cumulGainActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    
    BigDecimal cumulGainPNDS = BigDecimal.ZERO;
    BigDecimal cumulNbJourTravail = BigDecimal.ZERO;
    
    BigDecimal cumulGainICCPConserve = BigDecimal.ZERO;
    
    BigDecimal cumulGainICCPRepris = BigDecimal.ZERO;
    
    Chronologie periodesEmploiCourantes = periodeEmploi.copier(new FiltrePeriodeTravailCalcul());
    Chronologie periodesPrime = periodeEmploi.copier(new FiltrePeriodePrimeCalcul());
    
    PeriodeTravail periodeCourante = null;
    boolean neutralisation = false;
    
    BigDecimal cumulGainConserve = BigDecimal.ZERO;
    
    BigDecimal cumulGainPrimesConservees = BigDecimal.ZERO;
    PeriodePrime prime = null;
    
    BigDecimal cumulGainPansConservee = BigDecimal.ZERO;
    
    periodesPrime.iterer();
    while (periodesPrime.encoreSuivant())
    {
      prime = (PeriodePrime)periodesPrime.elementSuivant();
      if (prime.getTypeActivite() == 1) {
        cumulGainPrimesConservees = cumulGainPrimesConservees.add(prime.getMontant().getValeur());
      }
      cumulGainPrimes = cumulGainPrimes.add(prime.getMontant().getValeur());
    }
    ListIterator iterateur = periodesEmploiCourantes.iterer();
    while (iterateur.hasNext())
    {
      periodeCourante = (PeriodeTravail)iterateur.next();
      if ((periodeCourante instanceof PeriodeNonDeclareeSanction)) {
        cumulGainPNDS = cumulGainPNDS.add(((PeriodeNonDeclareeSanction)periodeCourante).getGain());
      }
      if ((periodeCourante instanceof PeriodeTravailJustifiee))
      {
        cumulGainJustifie = cumulGainJustifie.add(periodeCourante.getGain());
        cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeCourante.getNombreHeures());
      }
      if ((periodeCourante instanceof PansNonInstallee))
      {
        cumulGainActiviteNonSalarieeNonInstallee = cumulGainActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain());
      }
      else
      {
        cumulNbJourTravail = cumulNbJourTravail.add(new BigDecimal(periodeCourante.getDuree()));
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          if (!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) {
            cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          }
          cumulGain = cumulGain.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGainHorsIccp());
          if (((PeriodeActiviteEmploiCalcul)periodeCourante).getTypeActivite() == 1)
          {
            cumulGainConserve = cumulGainConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGain());
            
            cumulGainICCPConserve = cumulGainICCPConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
          }
          else
          {
            cumulGainICCPRepris = cumulGainICCPRepris.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
          }
        }
        else
        {
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          
          cumulGain = cumulGain.add(periodeCourante.getGain());
          if (((periodeCourante instanceof Pans)) && 
            (((Pans)periodeCourante).getTypeActivite() == 1))
          {
            cumulGainConserve = cumulGainConserve.add(((Pans)periodeCourante).getGain());
            cumulGainPansConservee = cumulGainPansConservee.add(((Pans)periodeCourante).getGain());
          }
        }
      }
    }
    boolean presencePansConservee = !periodesEmploiCourantes.copier(new FiltrePeriodePANSConservee()).estVide();
    
    evtRetour.setSeuilRemuneration(calculerSeuilMensuel(dateDebutPeriodeActiviteReduite, sjr, BigDecimal.ZERO, false, false, BigDecimal.ZERO, presencePansConservee));
    
    cumulGain = calculerGainRetenu(periodesEmploiCourantes);
    cumulGain = cumulGain.add(cumulGainPrimes);
    
    evtRetour.setNeutralise(neutralisation);
    evtRetour.setNbHeuresPrisesEnCompte(cumulNbHeures);
    evtRetour.setGainPrisEnCompte(cumulGain.add(cumulGainActiviteNonSalarieeNonInstallee));
    
    evtRetour.setCumulGainJustifie(cumulGainJustifie);
    evtRetour.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    
    evtRetour.setCumulJourDeTravail(cumulNbJourTravail);
    
    evtRetour.setCumulGainICCPConserves(cumulGainICCPConserve);
    
    evtRetour.setCumulGainICCPRepris(cumulGainICCPRepris);
    
    return evtRetour;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */