package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.DonneesTemporairesGen;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.Collection;
import java.util.Iterator;

public class DonneesTemporaires
  extends DonneesTemporairesGen
  implements ObjetPersistantSpec
{
  private static final long serialVersionUID = -2368090646206285058L;
  public static final short SANS_ETAT = 0;
  public static final short AVIS_FAVORABLE_CP = 1;
  public static final short AVIS_DEFAVORABLE_CP = 2;
  public static final int ETAT_OK = 1;
  public static final int ETAT_KO = 2;
  public static final int PAS_OCCURENCE_ELEMENT = -1;
  private transient TravailSpec periodeFctARetenir;
  private transient TravailSpec periodeRevision;
  private transient TravailSpec periodeFctARetenirRuptureContratTravail;
  private transient TravailSpec periodeCarenceExpatrie;
  public static final int PAS_DE_COORDINATION_REGLEMENT_EUROPEENNE = 0;
  public static final int RESSORTISSANT_EUROPEEN = 1;
  public static final int NON_RESSORTISSANT_EUROPEEN = 2;
  
  public DonneesTemporaires(DomPCSpec pc)
  {
    super(pc);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionPensionInvalidite());
    DomManager.persisterEnProfondeur(super.getCollectionPeriodeRepriseActiviteMemeEmployeurPossible());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec objetMetier)
  {
    DonneesTemporaires copie = (DonneesTemporaires)objetMetier;
    
    copie.setAllongementDelaiDecheance(getAllongementDelaiDecheance());
    copie.setAllongementDelaiForclusion(getAllongementDelaiForclusion());
    copie.setCoefficientSaisonnier(getCoefficientSaisonnier());
    copie.setCanAvecCentVingtTrimestres(isCanAvecCentVingtTrimestres());
    copie.setCaractereSaisonnierForce(isCaractereSaisonnierForce());
    copie.setCoefficientTempsPartiel(getCoefficientTempsPartiel());
    copie.setFortuiteCaractereSaisonnierParRythme(isFortuiteCaractereSaisonnierParRythme());
    copie.setFortuiteCaractereSaisonnierParType(isFortuiteCaractereSaisonnierParType());
    copie.setInopposabiliteDelaiDecheance(isInopposabiliteDelaiDecheance());
    copie.setPensionRaccordement(isPensionRaccordement());
    copie.setSjc(getSjc());
    copie.setSjr(getSjr());
    copie.setTermePrc(getTermePrc());
    copie.setTypeCaractereSaisonnierForce(getTypeCaractereSaisonnierForce());
    copie.setListePeriodesRepriseActiviteMemeEmployeur(getListePeriodesRepriseActiviteMemeEmployeur());
    copie.setCapitalReliquatSecteurPublic(getCapitalReliquatSecteurPublic());
    copie.setDateAttributionDroitAnterieurSp(getDateAttributionDroitAnterieurSp());
    copie.setDateFgDroitAnterieurSp(getDateFgDroitAnterieurSp());
    copie.setDureeInitialeDroitAnterieurSp(getDureeInitialeDroitAnterieurSp());
    copie.setDateDebutPI(getDateDebutPI());
    copie.setDateFinPI(getDateFinPI());
    copie.setIdentifiantPeriodeFctARetenir(getIdentifiantPeriodeFctARetenir());
    copie.setQuantiteAffiliation(getQuantiteAffiliation());
    copie.setAvisCommissionParitaire(getAvisCommissionParitaire());
    copie.setQuantiteJoursDiffereIccpConservatoire(getQuantiteJoursDiffereIccpConservatoire());
    copie.setConditionCumulActiviteConserveeRemplie(isConditionCumulActiviteConserveeRemplie());
    copie.setPmcIndemnisable(isPmcIndemnisable());
    copie.setFinPmc(getFinPmc());
    copie.setIndentifiantFctPMC(getIndentifiantFctPMC());
    copie.setLeveePmc(isLeveePmc());
    copie.setReliquatSecteurPublicEteint(isReliquatSecteurPublicEteint());
    copie.setReliquatSecteurPublicPrescritRejete(isReliquatSecteurPublicPrescritRejete());
    
    copie.setLeverBornageDureeEffectiveRetraite(isLeverBornageDureeEffectiveRetraite());
    
    copie.setNbJourImputationDroitPrecedent(getNbJourImputationDroitPrecedent());
    copie.setNatureMontantAide(getNatureMontantAide());
    copie.setSjrSP(getSjrSP());
    copie.setTermePrcSp(getTermePrcSp());
    copie.setCoefficientTempsPartielSp(getCoefficientTempsPartielSp());
    copie.setCoefficientSaisonnierSp(getCoefficientSaisonnierSp());
    copie.setMontantAide(getMontantAide());
    
    copie.setDateAttributionAide(getDateAttributionAide());
    
    copie.setMotifExamen(getMotifExamen());
    copie.setDateFinEvenement(getDateFinEvenement());
    copie.setEstRetenirActSectPrive(isEstRetenirActSectPrive());
    copie.setDateEffetActConserveeDonneesTemporaire(getDateEffetActConserveeDonneesTemporaire());
    
    copie.setDateChomageTotalSansRupture(getDateChomageTotalSansRupture());
    copie.setEstDecisionCPRenseigneeChomageTotalSansRupture(isDecisionCPRenseigneeChomageTotalSansRupture());
    copie.setEstAvisFavorableCPChomageTotalSansRupture(isAvisFavorableCPChomageTotalSansRupture());
    copie.setEstSinistreOuCalamiteNaturelleChomageTotalSansRupture(isSinistreOuCalamiteNaturelleChomageTotalSansRupture());
    copie.setDateAttributionCPChomageTotalSansRupture(getDateAttributionCPChomageTotalSansRupture());
    copie.setAccordPoursuite182JoursChomageTotalSansRupture(isAccordPoursuite182JoursChomageTotalSansRupture());
    copie.setDateMaximumPoursuiteIndeminisationChomageTotalSansRupture(getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture());
    copie.setIdentifiantPeriodeFinContratDeTravailChomageTotalSansRupture(getIdentifiantPeriodeFinContratDeTravailChomageTotalSansRupture());
    copie.setNouvelleDateAttributionChomageTotalSansRupture(getNouvelleDateAttributionChomageTotalSansRupture());
    copie.setQuantiteJoursDiffereChomageTotalSansRupture(getQuantiteJoursDiffereChomageTotalSansRupture());
    copie.setLeveeCondition28JoursChomageTotalSansRupture(isLeveeCondition28JoursChomageTotalSansRupture());
    
    copie.setTypeCoordinationEuropeenne(getTypeCoordinationEuropeenne());
    copie.setNbJourImputer(getNbJourImputer());
    
    copie.setEstPrimoDemandeurA3A4A5(isEstPrimoDemandeurA3A4A5());
    copie.setPrimoDemandeurA3A4A5Renseignee(isPrimoDemandeurA3A4A5Renseignee());
    
    copie.setSjrPerteActConservee(getSjrPerteActConservee());
    copie.setSjcPerteActConservee(getSjcPerteActConservee());
    copie.setCoefficientTempsPartielActConservee(getCoefficientTempsPartielActConservee());
    copie.setIdentifiantPeriodeActiviteConserveePerdue(getIdentifiantPeriodeActiviteConserveePerdue());
    
    copie.setReglementApplicableSpectacle(getReglementApplicableSpectacle());
    copie.setRangAllongementPraSpectacle(getRangAllongementPraSpectacle());
    copie.setSripSpectacle(getSripSpectacle());
    copie.setTotalRemunerationDansPRC(getTotalRemunerationDansPRC());
    copie.setNbHeuresTravailEtenduSpectacle(getNbHeuresTravailEtenduSpectacle());
    copie.setNbHeuresTravailPlafonneSpectacle(getNbHeuresTravailPlafonneSpectacle());
    copie.setNbJourContratSurPraSpectacle(getNbJourContratSurPraSpectacle());
    copie.setSaisieCasGeneralDonneesTemporaire(isSaisieCasGeneralDonneesTemporaire());
    copie.setSaisieCasSpectacleDonneesTemporaire(isSaisieCasSpectacleDonneesTemporaire());
    copie.setABeneficeDroitAt12Mois(isABeneficeDroitAt12Mois());
    copie.setDureeAncienneteIntermittantSpectacle(getDureeAncienneteIntermittantSpectacle());
    copie.setEstDemandeAt(isEstDemandeAt());
    copie.setEstDemandeAfd(isEstDemandeAfd());
    copie.setConditionAffiliationSatisfaiteForcee(isConditionAffiliationSatisfaiteForcee());
    copie.setConditionAncienneteSatisfaiteForcee(isConditionAncienneteSatisfaiteForcee());
    copie.setNombreJourTotalA8A10Force(getNombreJourTotalA8A10Force());
    copie.setDateFinPeriodeAncienneteForcee(getDateFinPeriodeAncienneteForcee());
    
    copie.setLeverConditionBeneficeAutreProduit(isLeverConditionBeneficeAutreProduit());
    
    copie.setQuantiteJourICCP(getQuantiteJourICCP());
    copie.setQuantiteJourISLR(getQuantiteJourISLR());
    copie.setRejetChomageVolontaireGARP(isRejetChomageVolontaireGARP());
    copie.setIdentifiantFCTCarenceExpatries(getIdentifiantFCTCarenceExpatries());
    copie.setSaisieCasExpatriesDonneesTemporaire(isSaisieCasExpatriesDonneesTemporaire());
    
    copie.setMontantContributionPourNonCTP(getMontantContributionPourNonCTP());
    copie.setTopPremiereODARE(getTopPremiereODARE());
    
    copie.setSaisieCasFinancementDonneesTemporaire(isSaisieCasFinancementDonneesTemporaire());
    copie.setDateFinPreavisLegal(getDateFinPreavisLegal());
    copie.setDureeFinancement(getDureeFinancement());
    
    copie.setTypeContexteDemandeDonneesTemporaires(getTypeContexteDemandeDonneesTemporaires());
    
    copie.setFctDansLesDeuxMoisAvantFddAre(isFctDansLesDeuxMoisAvantFddAre());
    
    copie.setEtatForcageDelaiAttente(getEtatForcageDelaiAttente());
    
    copie.setNumeroConventionPE(getNumeroConventionPE());
    copie.setCodeAffectationConvention(getCodeAffectationConvention());
    copie.setIdExterneEmployeurSp(getIdExterneEmployeurSp());
    copie.setEstDerogationCsp(isEstDerogationCsp());
    copie.setEstSalarieHandicapeChomageTotalSansRupture(isEstSalarieHandicapeChomageTotalSansRupture());
    copie.setDjiSpFinDroit(getDjiSpFinDroit());
    
    copie.clearCollectionPensionInvalidite();
    Iterator<?> iter = getListePensionInvalidite().iterator();
    while (iter.hasNext())
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      copie.ajouterPensionInvalidite((PensionInvaliditeChainee)element.copie());
    }
    copie.setEstLeveeControlePANSSuiteARCE(isEstLeveeControlePANSSuiteARCE());
    copie.setEstLeveeConditionACMemeEmployeur(isEstLeveeConditionACMemeEmployeur());
    
    copie.setDureeImputationSP(getDureeImputationSP());
    copie.setNbjImputationDroitAServir(getNbjImputationDroitAServir());
    copie.setMotifMontantImputationDroitAServir(getMotifMontantImputationDroitAServir());
    copie.setMotifNbJourImputationDroitAServir(getMotifNbJourImputationDroitAServir());
    copie.setMotifNbJourImputationDroitCourant(getMotifNbJourImputationDroitCourant());
    copie.setMotifNbJourImputationDroitPrecedent(getMotifNbJourImputationDroitPrecedent());
    copie.setMontantImputationDroitAServir(getMontantImputationDroitAServir());
    copie.setEstIgnorerAttribPrecCSR(isEstIgnorerAttribPrecCSR());
    
    copie.setEstPCRCForceDroitCourant(isEstPCRCForceDroitCourant());
    copie.setEstPCRCForceDroitPrecedent(isEstPCRCForceDroitPrecedent());
    
    copie.setDateDepartICCP(getDateDepartICCP());
    copie.setEstDemarcheReintegrationEffectuee(isEstDemarcheReintegrationEffectuee());
    copie.setDureeTheoriqueForcee(getDureeTheoriqueForcee());
    
    copie.setDateExamenForcee(getDateExamenForcee());
    copie.setDateAttributionForcee(getDateAttributionForcee());
    copie.setDelaiAttenteForce(isDelaiAttenteForce());
    copie.setConditionChomageInvolontaireSatistaite(isConditionChomageInvolontaireSatistaite());
    copie.setDroitOptionForce(isDroitOptionForce());
    copie.setDjiDroitSpContexteRechargement(getDjiDroitSpContexteRechargement());
    copie.setFgdDroitSpContexteRechargement(getFgdDroitSpContexteRechargement());
    copie.setRepriseForceeSurDemandeExpresse(isRepriseForceeSurDemandeExpresse());
    copie.setEstDesactivationPnds(isEstDesactivationPnds());
    copie.setDateLimiteIndemnisationDonneeForcee(getDateLimiteIndemnisationDonneeForcee());
    copie.setDureeImputation(getDureeImputation());
    copie.setLeveeConditionCLCA(isLeveeConditionCLCA());
    
    copie.setCompetenceFinanciere(getCompetenceFinanciere());
    copie.setEmployeurSecteurPublicCompetent(getEmployeurSecteurPublicCompetent());
    copie.setMontantIndemnitePreavisContrib(getMontantIndemnitePreavisContrib());
    copie.setContributionAdhesionVolontaire(getContributionAdhesionVolontaire());
    copie.setPresenceDerniersSalaires(isPresenceDerniersSalaires());
    copie.setNombreMoisPreavis(getNombreMoisPreavis());
    
    copie.setDroitInterimaireForce(isDroitInterimaireForce());
    copie.setDiviseurSjrForce(getDiviseurSjrForce());
    copie.setDureeAllongementAREFForcee(getDureeAllongementAREFForcee());
    
    copie.setRejetConditionChomageInvolontaire(isRejetConditionChomageInvolontaire());
  }
  
  public void setPeriodeRevision(TravailSpec travailSpec)
  {
    periodeRevision = travailSpec;
  }
  
  public void setListePeriodesRepriseActiviteMemeEmployeur(Collection listePeriodesRepriseActiviteMemeEmployeur)
  {
    Collection<?> collectionASupprimer = getListePeriodesRepriseActiviteMemeEmployeur();
    if (collectionASupprimer != null)
    {
      Iterator<?> iter = collectionASupprimer.iterator();
      while (iter.hasNext()) {
        DomManager.supprimer(iter.next());
      }
      super.clearCollectionPeriodeRepriseActiviteMemeEmployeurPossible();
    }
    super.remplacerCollectionPeriodeRepriseActiviteMemeEmployeurPossible(listePeriodesRepriseActiviteMemeEmployeur);
  }
  
  public void addPeriodeRepriseActiviteMemeEmployeur(PeriodeRepriseActiviteMemeEmployeurPossible periode)
  {
    super.ajouterPeriodeRepriseActiviteMemeEmployeurPossible(periode);
  }
  
  public Collection getListePeriodesRepriseActiviteMemeEmployeur()
  {
    return super.getCollectionPeriodeRepriseActiviteMemeEmployeurPossible();
  }
  
  public TravailSpec getPeriodeFctARetenir()
  {
    if (periodeFctARetenir == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeFctARetenir = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeFctARetenir()));
      if (periodeFctARetenir == null) {
        setIdentifiantPeriodeFctARetenir(null);
      }
    }
    return periodeFctARetenir;
  }
  
  public TravailSpec getPeriodeCarenceExpatrie()
  {
    if (periodeCarenceExpatrie == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeCarenceExpatrie = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIndentifiantFctPMC()));
      if (periodeCarenceExpatrie == null) {
        setIndentifiantFctPMC(null);
      }
    }
    return periodeCarenceExpatrie;
  }
  
  public TravailSpec getPeriodeRevision()
  {
    if (periodeRevision == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeRevision = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeActiviteConserveePerdue()));
      if (periodeRevision == null) {
        setIdentifiantPeriodeActiviteConserveePerdue(null);
      }
    }
    return periodeRevision;
  }
  
  public boolean estAvisFavorableCommissionParitaire()
  {
    return super.getAvisCommissionParitaire() == 1;
  }
  
  public boolean estAvisDefavorableCommissionParitaire()
  {
    return super.getAvisCommissionParitaire() == 2;
  }
  
  public void setEstAvisFavorableCPChomageTotalSansRupture(boolean estAvisFavorableCPChomageTotalSansRupture)
  {
    super.setAvisFavorableCPChomageTotalSansRupture(estAvisFavorableCPChomageTotalSansRupture);
  }
  
  public void setEstDecisionCPRenseigneeChomageTotalSansRupture(boolean estDecisionCPRenseigneeChomageTotalSansRupture)
  {
    super.setDecisionCPRenseigneeChomageTotalSansRupture(estDecisionCPRenseigneeChomageTotalSansRupture);
  }
  
  public void setEstSinistreOuCalamiteNaturelleChomageTotalSansRupture(boolean estSinistreOuCalamiteNaturelleChomageTotalSansRupture)
  {
    super.setSinistreOuCalamiteNaturelleChomageTotalSansRupture(estSinistreOuCalamiteNaturelleChomageTotalSansRupture);
  }
  
  public TravailSpec getPeriodeFctARetenirRuptureContratTravail()
  {
    if (periodeFctARetenirRuptureContratTravail == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeFctARetenirRuptureContratTravail = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeFinContratDeTravailChomageTotalSansRupture()));
      if (periodeFctARetenirRuptureContratTravail == null) {
        setIdentifiantPeriodeFinContratDeTravailChomageTotalSansRupture(null);
      }
    }
    return periodeFctARetenirRuptureContratTravail;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estPremiereODAre()
  {
    return getTopPremiereODARE() == 1;
  }
  
  public boolean estNonPremiereODAre()
  {
    return getTopPremiereODARE() == 2;
  }
  
  public boolean estTopPremiereODAreRenseignee()
  {
    return getTopPremiereODARE() != 0;
  }
  
  public boolean isEstCoordCee()
  {
    boolean coordCee;
    switch (super.getTypeCoordinationEuropeenne())
    {
    case 1: 
    case 2: 
      coordCee = true;
      break;
    default: 
      coordCee = false;
    }
    return coordCee;
  }
  
  public Collection getListePensionInvalidite()
  {
    return super.getCollectionPensionInvalidite();
  }
  
  public void clearCollectionPensionInvalidite()
  {
    for (Iterator<?> iter = getCollectionPensionInvalidite().iterator(); iter.hasNext();)
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionPensionInvalidite();
  }
  
  public void remplacerCollectionPensionInvalidite(Collection collectionACopier)
  {
    for (Iterator<?> iter = getCollectionPensionInvalidite().iterator(); iter.hasNext();)
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPensionInvalidite(collectionACopier);
  }
  
  public void setListePensionInvalidite(Collection listePensionInvalidite)
  {
    remplacerCollectionPensionInvalidite(listePensionInvalidite);
  }
  
  public void addPensionInvalidite(PensionInvaliditeChainee pensionInvalidite)
  {
    super.ajouterPensionInvalidite(pensionInvalidite);
  }
  
  public void remplacerCollectionPeriodeRepriseActiviteMemeEmployeurPossible(Collection collectionACopier)
  {
    for (Iterator<?> iter = super.getCollectionPeriodeRepriseActiviteMemeEmployeurPossible().iterator(); iter.hasNext();)
    {
      PeriodeRepriseActiviteMemeEmployeurPossible element = (PeriodeRepriseActiviteMemeEmployeurPossible)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPeriodeRepriseActiviteMemeEmployeurPossible(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     DonneesTemporaires
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */