package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUSpectacleClauseRattrapage;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourGamme;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreClauseRattrapageSpectacle
  extends EreGammeAsu
{
  private static final long serialVersionUID = 1L;
  private AttributionAssuranceSpec cacheAttributionPrecedente = null;
  
  public String getLibelle()
  {
    return "CRA_SPE";
  }
  
  public String getLibelleLong()
  {
    return "Clause de rattrapage Spectacle";
  }
  
  public String getTypeExamen()
  {
    return "ASU_31";
  }
  
  public int getPriorite()
  {
    return 7;
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    if (estEnContexteEnCoursClauseRattrapage(demande)) {
      DetectionContexteParticulierLiquidation.getInstance().ajouterContexteDemande((DemandeAssuranceSpec)demande, "ENCOURSCRA");
    } else {
      DetectionContexteParticulierLiquidation.getInstance().ajouterContexteDemande((DemandeAssuranceSpec)demande, "ENTREECRA");
    }
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeASUSpectacleClauseRattrapage();
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        if (estEnContexteEnCoursClauseRattrapage(demande)) {
          setDateEvenement(determinerDateExamenEnCoursClauseRattrapage(demande));
        } else {
          setDateEvenement(determinerDateExamenEntreeClauseRattrapage(demande));
        }
      }
      catch (CoucheLogiqueException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  public boolean estEnContexteEntreeClauseRattrapage(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    return !estEnContexteEnCoursClauseRattrapage(demande);
  }
  
  protected boolean estEnContexteEnCoursClauseRattrapage(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    boolean estEnCoursClauseRattrapage = false;
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getFormulaire().getDateDepot(), new FiltreAttributionAssurance(true, true, false, true, demande));
    
    cacheAttributionPrecedente = attributionPrecedente;
    if ((attributionPrecedente != null) && ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionPrecedente.getDemande(), "ENTREECRA")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionPrecedente.getDemande(), "ENCOURSCRA"))))
    {
      estEnCoursClauseRattrapage = demande.getFormulaire().getDateDepot().estAvantOuCoincideAvec(attributionPrecedente.getDateLimiteIndemnisation());
      
      cacheAttributionPrecedente = attributionPrecedente;
    }
    return estEnCoursClauseRattrapage;
  }
  
  protected Damj determinerDateExamenEnCoursClauseRattrapage(DemandeSpec demande)
  {
    ObjetChronoPeriodePriseEnCharge pec = OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), demande.getFormulaire().getDateDepot());
    
    return pec.getDateDebut();
  }
  
  protected Damj determinerDateExamenEntreeClauseRattrapage(DemandeSpec demande)
  {
    DecisionAssuranceSpec decision = recupererDerniereDecisionAssurance(demande);
    return decision.getDateEffetDecision();
  }
  
  protected DecisionAssuranceSpec recupererDerniereDecisionAssurance(DemandeSpec demande)
  {
    FiltreET filtreDecisionPrecedente = new FiltreET();
    filtreDecisionPrecedente.ajouterFiltre(new FiltreDecisionPourGamme("ASU"));
    filtreDecisionPrecedente.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande("SORTIECRA")));
    filtreDecisionPrecedente.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    return (DecisionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getFormulaire().getDateDepot().lendemain(), filtreDecisionPrecedente);
  }
  
  protected AttributionAssuranceSpec recupererDerniereAttributionAssurance(DemandeSpec demande)
  {
    FiltreET filtreAttributionPrecedente = new FiltreET();
    filtreAttributionPrecedente.ajouterFiltre(new FiltreAttributionStandardAssurance(false, true, false, false, null));
    filtreAttributionPrecedente.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande("SORTIECRA")));
    
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getFormulaire().getDateDepot(), filtreAttributionPrecedente);
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    if (estEnContexteEnCoursClauseRattrapage(demande)) {
      verifierContexteEnCoursClauseDeRattrapage(demande);
    } else {
      verifierContexteEntreeClauseRattrapage(demande);
    }
  }
  
  protected void verifierContexteEnCoursClauseDeRattrapage(DemandeSpec demande)
    throws ApplicativeException
  {
    ObjetChronoPeriodePriseEnCharge pec = OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), demande.getFormulaire().getDateDepot());
    if (pec == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DATE_DEPOT_HORS_PEC");
    } else if (pec.getDateDebut().estAvantOuCoincideAvec(cacheAttributionPrecedente.getDateExamen())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DOUBLE_ATTRIBUTION");
    }
    cacheAttributionPrecedente = null;
  }
  
  protected void verifierContexteEntreeClauseRattrapage(DemandeSpec demande)
    throws ApplicativeException
  {
    DecisionAssuranceSpec derniereDecisionAssurance = recupererDerniereDecisionAssurance(demande);
    if (derniereDecisionAssurance == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DERNIERE_DECISION_ABSENTE");
    }
    boolean estUnRejetAffi = (derniereDecisionAssurance.getConditionAffiliation() != null) && (!derniereDecisionAssurance.getConditionAffiliation().estSatisfait());
    if (!estUnRejetAffi) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DERNIERE_DECISION_REJET_AFFI");
    }
    if (!"ASU_08".equals(derniereDecisionAssurance.getDemande().getEvenementReferenceExamen().getTypeExamen())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DERNIERE_DECISION_MAUVAISE_DEMANDE");
    }
    if (derniereDecisionAssurance.getDateEffetDecision().estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention Spectacle 2016"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DATE_EXAMEN_AVANT_AOUT_2016");
    }
    AttributionAssuranceSpec derniereAttributionAssurance = recupererDerniereAttributionAssurance(demande);
    if ((derniereAttributionAssurance == null) || (!estAreSpectacle(derniereAttributionAssurance.getProduit()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_DERNIERE_DECISION_ABSENTE");
    }
  }
  
  private boolean estAreSpectacle(ProduitSpec produit)
  {
    return (produit != null) && (ProduitAbstrait.estDuType(6, produit)) && (ProduitAbstrait.estDuType(5, produit));
  }
  
  public ObjetMetierSpec copie()
  {
    EreClauseRattrapageSpectacle copie = new EreClauseRattrapageSpectacle();
    copieElements(copie);
    return copie;
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
}

/* Location:
 * Qualified Name:     EreClauseRattrapageSpectacle
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */