package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.parcours.AffectationDemandeAtp;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreIdeAtpSuiteBascule
  extends EreGammeAsu
{
  private static final long serialVersionUID = -3775766185065874193L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    Damj dateIde = null;
    if ((getDateEvenement() != null) && ((p_demande.estDecisionnee()) || (p_demande.estDemandeLiquidee())) && (!p_demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else if (p_demande.getDateDepot() != null) {
        setDateDeclenchementExamen(p_demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dateIde = null;
    if (getDateEvenement() == null)
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateEvenement(dateIde);
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws ApplicativeException
  {
    Damj dateIde = null;
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
    if ((periodePEC != null) && (!periodePEC.isAnnulee())) {
      dateIde = periodePEC.getDateDebut();
    }
    if (dateIde == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_CONTEXTE_LIQUIDATION_IMPOSSIBLE");
    }
  }
  
  public String getLibelle()
  {
    return "BASCULECTP";
  }
  
  public String getLibelleLong()
  {
    return "Bascule CRP/CTP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_20";
  }
  
  public ObjetMetierSpec copie()
  {
    EreIdeAtpSuiteBascule copie = new EreIdeAtpSuiteBascule();
    copieElements(copie);
    return copie;
  }
  
  public int getPriorite()
  {
    return 19;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreOU filtreAttributionASR = new FiltreOU();
    filtreAttributionASR.ajouterFiltre(new FiltreDecisionPourProduit(37));
    filtreAttributionASR.ajouterFiltre(new FiltreDecisionPourProduit(36));
    return filtreAttributionASR;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    return new AffectationDemandeAtp();
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    ContexteDemande contexte = new ContexteDemande();
    contexte.setTypeContexteDemande("BASCULEATP");
    ((Demande)p_demande).ajouterContexteDemande(contexte);
    if (((Demande)p_demande).getDonneesDemandeAssociee() != null)
    {
      EvenementReferenceExamenSpec ereAssocie = ((Demande)p_demande).getDonneesDemandeAssociee().getDemandeAssociee().getEvenementReferenceExamen();
      ((EreGammeAsu)ereAssocie).determinerContexteDemande(p_demande);
    }
  }
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreIdeAtpSuiteBascule
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */