package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUPassageCPSuiteRejetDV;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class ErePassageCPSuiteRejetDV
  extends EreGammeAsu
  implements EreTypeRechargementSpec
{
  private static final long serialVersionUID = 8650114445328552029L;
  private Reglement reglementForce;
  
  public String getLibelle()
  {
    return "DEX122";
  }
  
  public String getLibelleLong()
  {
    return "demande d'Examen DV au 122ème jour";
  }
  
  public String getTypeExamen()
  {
    return "ASU_04";
  }
  
  public int getPriorite()
  {
    return 6;
  }
  
  public ObjetMetierSpec copie()
  {
    ErePassageCPSuiteRejetDV copie = new ErePassageCPSuiteRejetDV();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    ErePassageCPSuiteRejetDV copieEre = (ErePassageCPSuiteRejetDV)copie;
    super.copieElements(copie);
    reglementForce = reglementForce;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null) {
      setDateEvenement(GestionDemandeDv122eJour.constituerDateExamen(demande));
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    Demande demandeAssurance = (Demande)demande;
    DemandeAssuranceSpec demandePortantDv = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande);
    if (demandePortantDv == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_LIQUIDATION_DEMANDE_DV");
    }
    if (demandePortantDv.estEnReExamen()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_DV_EN_REEXAMEN");
    }
    if ((demandePortantDv.getDonneesTemporaires().isEstCoordCee()) && (!demandeAssurance.getDonneesTemporaires().isEstCoordCee())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_DV_E301");
    }
    if ((!demandePortantDv.getDonneesTemporaires().isEstCoordCee()) && (demandeAssurance.getDonneesTemporaires().isEstCoordCee())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_DV_E301_EXAMEN");
    }
    if ((demandePortantDv.getDonneesTemporaires().isDroitOptionForce()) && ("ASU_30".equals(demandePortantDv.getEvenementReferenceExamen().getTypeExamen()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_DROIT_OPTION_INTERDIT");
    }
    verifierPresenceFaitGenerateurSurDemandePortantDv(demandePortantDv);
    
    Damj datePointDepart = GestionDemandeDv122eJour.recupererPeriodePointDepart((Demande)demandePortantDv, demande);
    if (datePointDepart == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_PERIODE_SUPPR_GAEC", new Object[] { demandePortantDv.getDateRecherche().toString() });
    }
  }
  
  private void verifierPresenceFaitGenerateurSurDemandePortantDv(DemandeAssuranceSpec demandePortantDv)
    throws CoucheLogiqueException
  {
    boolean estObjectifOdSurRejetDv = NaturesDecisions.estdeTypeOd(demandePortantDv.getObjectifDecisionne().getSousType());
    if (estObjectifOdSurRejetDv)
    {
      boolean estFaitGenerateurAbsentSurRejetDv = (demandePortantDv.getDossierAffectationAdmission() == null) || (demandePortantDv.getDossierAffectationAdmission().getDossierExamen() == null) || (((DossierExamenAssuranceSpec)demandePortantDv.getDossierAffectationAdmission().getDossierExamen()).getFaitGenerateur() == null) || (((DossierExamenAssuranceSpec)demandePortantDv.getDossierAffectationAdmission().getDossierExamen()).getFaitGenerateur().getPeriodeFaitGenerateur() == null);
      if (estFaitGenerateurAbsentSurRejetDv) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_FAIT_GENERATEUR_INTROUVABLE", new Object[] { demandePortantDv.getDateExamen() });
      }
    }
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeASUPassageCPSuiteRejetDV();
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ContexteDemande contexteDemande = new ContexteDemande();
    contexteDemande.setTypeContexteDemande("EXAMENIPR");
    ((Demande)demande).ajouterContexteDemande(contexteDemande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnCoursCSPouPAP(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
    
    Demande demandePortantDv = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande);
    boolean estContexteRechargement = DetectionContexteParticulierLiquidation.getInstance().detectionContexteRechargement(demande, demandePortantDv);
    if (estContexteRechargement) {
      reglementForce = demandePortantDv.getDossierAffectationAdmission().getValidationProduit().getReglementApplicable();
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCspExamenDv(demande, demandePortantDv);
    
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteDisponibiliteExamenDv(demande, demandePortantDv);
  }
  
  public Reglement getReglementForcePourRechargement()
  {
    return reglementForce;
  }
  
  public String getNomReglementARecharger()
  {
    String retour = "";
    if (reglementForce != null) {
      retour = reglementForce.getNomReglement();
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     ErePassageCPSuiteRejetDV
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */