package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuRechargement;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.utilitaire.comparateurs.ComparateurDecisionDecroissante;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionneeSurDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionsSuivantesSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourClassement;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandesSuivantesSurDemandes;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionPourCompetence;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;

public class EreRechargement
  extends EreGammeAsu
  implements EreTypeRechargementSpec
{
  private static final long serialVersionUID = -7853582049154907746L;
  private AttributionAssuranceSpec attributionAssurancePrecedente;
  private String nomReglementARecharger;
  private boolean estAncienDroitInterimaire;
  private boolean reglementInterimaireActive;
  private Reglement reglementForce;
  private Reglement reglementForceInterimaire;
  
  public String getLibelle()
  {
    return "RECHARGT";
  }
  
  public String getLibelleLong()
  {
    return "Rechargement";
  }
  
  public String getTypeExamen()
  {
    return "ASU_29";
  }
  
  public int getPriorite()
  {
    return 12;
  }
  
  public ObjetMetierSpec copie()
  {
    EreRechargement copie = new EreRechargement();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    EreRechargement copieEre = (EreRechargement)copie;
    super.copieElements(copieEre);
    attributionAssurancePrecedente = attributionAssurancePrecedente;
    nomReglementARecharger = nomReglementARecharger;
    reglementForce = reglementForce;
    estAncienDroitInterimaire = estAncienDroitInterimaire;
    reglementInterimaireActive = reglementInterimaireActive;
    reglementForceInterimaire = reglementForceInterimaire;
  }
  
  public boolean mettreEnBasePivot()
  {
    return true;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        setDateEvenement(calculerDateExamen(demande));
      }
      catch (ApplicativeException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    setDateEvenement(null);
    AttributionAssuranceSpec attributionPrecedente = recupererDernierDroitAsuRechargeable(demande);
    Damj dji = recupererDjiParEpuisement(demande, attributionPrecedente);
    controlePresenceDroitSp(dji, demande);
    
    controleDjiAttributionPrecedente(dji);
    
    controleRechargementDecisionneMemeJour(demande, dji);
  }
  
  private void controleRechargementDecisionneMemeJour(DemandeSpec demande, Damj djiParEpuisement)
    throws CoucheLogiqueException
  {
    Chronologie chronoDemandesDuDemandeur = demande.getChronologieDemandesAssuranceSansCourante();
    
    Damj dateRecherche = djiParEpuisement.lendemain();
    
    FiltreET filtreRechargementDecisionne = new FiltreET();
    filtreRechargementDecisionne.ajouterFiltre(new FiltreDemandePourERE("ASU_29"));
    filtreRechargementDecisionne.ajouterFiltre(new FiltreDecisionneeSurDemande());
    filtreRechargementDecisionne.ajouterFiltre(new FiltreDecisionsSuivantesSurDecisions(dateRecherche.veille()));
    
    Chronologie chronologiesRechargement = OutilRecherche.rechercherDemandesPrecedentes(chronoDemandesDuDemandeur, dateRecherche.lendemain(), filtreRechargementDecisionne);
    if (!chronologiesRechargement.estVide()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DOUBLON_DEMANDE_RECHARGEMENT", new Object[] { dateRecherche });
    }
  }
  
  public void controleDjiAttributionPrecedente(Damj djiParEpuisement)
    throws ApplicativeException
  {
    Damj dateApplicationConvention2014 = FabriqueConvention2014.DATE_APPLICATION;
    if (djiParEpuisement.estAvant(dateApplicationConvention2014)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_DJI_RECHARGEMENT_ARE14_KO");
    }
  }
  
  public void controlePresenceDroitSp(Damj djiParEpuisementDroiRac, DemandeSpec demande)
    throws ApplicativeException
  {
    FiltreOU filtre = new FiltreOU();
    filtre.ajouterFiltre(new FiltreDecisionPourCompetence(2, 0));
    
    filtre.ajouterFiltre(new FiltreDemandePourClassement("SP"));
    
    FiltreET filtreDemandeClasseesSp = new FiltreET();
    filtreDemandeClasseesSp.ajouterFiltre(filtre);
    filtreDemandeClasseesSp.ajouterFiltre(new FiltreDemandesSuivantesSurDemandes(djiParEpuisementDroiRac));
    
    DemandeSpec demandePrecedente = OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreDemandeClasseesSp);
    if (demandePrecedente != null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_SUITE_SP_KO");
    }
  }
  
  private Damj recupererDjiParEpuisement(DemandeSpec demande, AttributionAssuranceSpec attributionAssurancePrecedente)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)attributionAssurancePrecedente.getProduit();
    
    Damj djiParEpuisement = produit.recupererDJIParEpuisement(demande, attributionAssurancePrecedente, false);
    if (djiParEpuisement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_CONTEXTE_DROIT_RAC_NON_EPUISE", new Object[] { attributionAssurancePrecedente.getDateAttribution() });
    }
    return djiParEpuisement;
  }
  
  private AttributionAssuranceSpec recupererDernierDroitAsuRechargeable(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    FiltreCaliSpec filtreAttributionAssurance = new FiltreAttributionStandardAssurance(false, true, false, false, null);
    AttributionAssuranceSpec attributionAssurancePrecedenteTrouvee = null;
    
    Damj dateDeclenchementExamen = getDateDeclenchementExamen(demande);
    Chronologie chronoAttributionsPrecedentes = OutilRecherche.rechercherDecisionsPrecedentes(demande.getChronologieDemandesAssuranceSansCourante(), dateDeclenchementExamen.lendemain(), filtreAttributionAssurance);
    
    chronoAttributionsPrecedentes.setComparateur(new ComparateurDecisionDecroissante());
    chronoAttributionsPrecedentes.iterer();
    while (chronoAttributionsPrecedentes.encoreSuivant())
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)chronoAttributionsPrecedentes.elementSuivant();
      if ((!attribution.getDateEffetDecision().equals(dateDeclenchementExamen)) || ("ASU_25".equals(attribution.getDemande().getEvenementReferenceExamen().getTypeExamen())))
      {
        attributionAssurancePrecedenteTrouvee = attribution;
        break;
      }
    }
    if (attributionAssurancePrecedenteTrouvee == null)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_DROIT_ANTECEDENT_RAC", new Object[] { demande.getDateDeclenchementExamen() });
    }
    else
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)attributionAssurancePrecedenteTrouvee.getProduit();
      if (!ProduitAbstrait.estDuType(8, produit)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DROIT_ANTECEDENT_NON_RECHARG", new Object[] { demande.getDateDeclenchementExamen() });
      }
      attributionAssurancePrecedente = attributionAssurancePrecedenteTrouvee;
      nomReglementARecharger = attributionAssurancePrecedenteTrouvee.getReglementApplicable().getReglement().getNomReglement();
    }
    return attributionAssurancePrecedenteTrouvee;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsuRechargement();
  }
  
  private Damj calculerDateExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    Demande demandeAsu = (Demande)demande;
    Damj dateExamen;
    Damj dateExamen;
    if ((demandeAsu.getDonneesTemporaires() != null) && (demandeAsu.getDonneesTemporaires().getDateExamenForcee() != null))
    {
      dateExamen = demandeAsu.getDonneesTemporaires().getDateExamenForcee();
    }
    else
    {
      AttributionAssuranceSpec attributionAssurancePrecedenteTrouvee = recupererDernierDroitAsuRechargeable(demande);
      Damj dji = recupererDjiParEpuisement(demande, attributionAssurancePrecedenteTrouvee);
      dateExamen = dji.lendemain();
    }
    return dateExamen;
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public AttributionAssuranceSpec getAttributionAssurancePrecedente()
  {
    return attributionAssurancePrecedente;
  }
  
  public String getNomReglementARecharger()
  {
    return nomReglementARecharger;
  }
  
  public Reglement getReglementForcePourRechargement()
  {
    if ((estAncienDroitInterimaire) && (reglementInterimaireActive)) {
      return reglementForceInterimaire;
    }
    return reglementForce;
  }
  
  public Reglement initialiserReglementForce(DecorReglementaire pDecorReglementaire)
  {
    ProduitAsuSpec produitPourReglement = ConstitutionDecorReglementaire.determinerProduitPourReglement(nomReglementARecharger, pDecorReglementaire);
    if ((nomReglementARecharger.equals("A4")) && (produitPourReglement == null))
    {
      estAncienDroitInterimaire = true;
      nomReglementARecharger = "RG";
      produitPourReglement = ConstitutionDecorReglementaire.determinerProduitPourReglement(nomReglementARecharger, pDecorReglementaire);
      
      reglementForceInterimaire = Reglement.getInstance("RG5", produitPourReglement);
    }
    reglementForce = Reglement.getInstance(nomReglementARecharger, produitPourReglement);
    
    return reglementForce;
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnCoursCSPouPAP(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
    
    ContexteDemande contexteDemandeEnCoursDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "COURSDISPO");
    if (contexteDemandeEnCoursDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnCoursDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursDeDisponibilite(demande);
    
    ContexteDemande contexteDemandeEnSortieDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "POSTDISPO");
    if (contexteDemandeEnSortieDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnSortieDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnSortieDeDisponibilite(demande);
  }
  
  public void activerReglementInterimaire()
  {
    reglementInterimaireActive = true;
  }
  
  public void desactiverReglementInterimaire()
  {
    reglementInterimaireActive = false;
  }
}

/* Location:
 * Qualified Name:     EreRechargement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */