package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreRepriseVersement
  extends EreGammeAsu
{
  private static final long serialVersionUID = -7853582049154907746L;
  
  public String getLibelle()
  {
    return "DRV";
  }
  
  public String getLibelleLong()
  {
    return "Demande de Reprise des Versements";
  }
  
  public String getTypeExamen()
  {
    return "ASU_27";
  }
  
  public int getPriorite()
  {
    return 12;
  }
  
  public ObjetMetierSpec copie()
  {
    EreRepriseVersement copie = new EreRepriseVersement();
    copieElements(copie);
    return copie;
  }
  
  public boolean mettreEnBasePivot()
  {
    return true;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    if ((getDateEvenement() != null) && ((p_demande.estDecisionnee()) || (p_demande.estDemandeLiquidee())) && (!p_demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else if (p_demande.getDateDepot() != null)
    {
      Damj dateDeclenchementExamen = null;
      AttributionAssuranceSpec attribPrecedente = retrouverAttributionPrecedente((Demande)p_demande);
      if (attribPrecedente != null) {
        try
        {
          dateDeclenchementExamen = AppelCalculParLiquidation.recupererDateRepriseDeVersement(attribPrecedente);
        }
        catch (CoucheLogiqueException ex)
        {
          dateDeclenchementExamen = null;
        }
      }
      if (dateDeclenchementExamen != null) {
        setDateDeclenchementExamen(dateDeclenchementExamen);
      } else {
        setDateDeclenchementExamen(p_demande.getDateDepot());
      }
    }
    else
    {
      setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        AttributionAssuranceSpec attributionPrecedente = retrouverAttributionPrecedente((Demande)p_demande);
        if (attributionPrecedente != null)
        {
          Damj dateRepriseVersement = AppelCalculParLiquidation.recupererDateRepriseDeVersement(attributionPrecedente);
          setDateEvenement(dateRepriseVersement);
        }
      }
      catch (CoucheLogiqueException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws ApplicativeException
  {
    AttributionAssuranceSpec attributionPrecedente = retrouverAttributionPrecedente((Demande)p_demande);
    if (attributionPrecedente == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_DRV_INEXISTANT");
    }
    Damj dateRepriseVersement = AppelCalculParLiquidation.recupererDateRepriseDeVersement(attributionPrecedente);
    if (dateRepriseVersement == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REPRISE_ACTIVITE_INEXISTANTE");
    }
  }
  
  private AttributionAssuranceSpec retrouverAttributionPrecedente(Demande p_demande)
  {
    FiltreET filtreAttributionAssurance = getFiltreCsr(p_demande, new FiltreAttributionStandardAssurance(true, true, false, true, p_demande));
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande.getDateDepot(), filtreAttributionAssurance);
  }
  
  private FiltreET getFiltreCsr(Demande p_demande, FiltreCaliSpec p_filtre)
  {
    FiltreET filtreOdAssurance = new FiltreET();
    
    filtreOdAssurance.ajouterFiltre(p_filtre);
    if (p_demande.getDonneesTemporaires().isEstIgnorerAttribPrecCSR())
    {
      FiltreOU filtreCsr = new FiltreOU();
      filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("CSRSUSP"));
      filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("RUPCTRSUSP"));
      FiltreNegation filtreNonCsr = new FiltreNegation(filtreCsr);
      filtreOdAssurance.ajouterFiltre(filtreNonCsr);
    }
    return filtreOdAssurance;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
  }
}

/* Location:
 * Qualified Name:     EreRepriseVersement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */