package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeASURevisionAdmission;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssuranceRevisionAdmission;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuAbstrait;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionneeSurDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.Iterator;

public class EreRevisionConvention2014
  extends EreGammeAsu
{
  private String contexteDemande = null;
  private Damj dateExamenForcee = null;
  private static final long serialVersionUID = -7853582049154907746L;
  
  public String getLibelle()
  {
    return "REV_2014";
  }
  
  public String getLibelleLong()
  {
    return "Demande de Perte act. cons.";
  }
  
  public String getTypeExamen()
  {
    return "ASU_28";
  }
  
  public int getPriorite()
  {
    return 20;
  }
  
  public ObjetMetierSpec copie()
  {
    EreRevisionConvention2014 copie = new EreRevisionConvention2014();
    copieElements(copie);
    return copie;
  }
  
  public boolean mettreEnBasePivot()
  {
    return true;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    Demande demandeRevision = (Demande)demande;
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else if ((demandeRevision.getDemandeur().getDonneesChargementGaec().getAgregatGaec().getCodeService() != 3) && (((IndividuAbstrait)demandeRevision.getDemandeur()).estIndividuGaecCharge()))
    {
      ActiviteSalarie periode = (ActiviteSalarie)demandeRevision.getDonneesTemporaires().getPeriodeRevision();
      if ((periode != null) && (periode.getDateFin() != null) && (!periode.getDateFin().coincideAvec(Damj.FIN_DES_TEMPS)))
      {
        setDateDeclenchementExamen(periode.getDateFin().lendemain());
      }
      else
      {
        Damj dateDepot = demandeRevision.getDateDepot();
        if (dateDepot != null)
        {
          setDateDeclenchementExamen(dateDepot);
        }
        else
        {
          Damj dateCreationDemande = demandeRevision.getFormulaire().getDateCreationDal();
          setDateDeclenchementExamen(dateCreationDemande);
        }
      }
    }
    else
    {
      return demandeRevision.getDateDepot();
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        if ((contexteDemande != null) && ("REVAUTO".equals(contexteDemande)))
        {
          setDateEvenement(dateExamenForcee);
        }
        else
        {
          ActiviteSalarie periode = recupererActiviteConserveePerdue((Demande)demande);
          setDateEvenement(periode.getDateFin().lendemain());
        }
      }
      catch (CoucheLogiqueException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  private ActiviteSalarie recupererActiviteConserveePerdue(Demande demande)
    throws CoucheLogiqueException
  {
    if ((demande.getDonneesTemporaires() == null) || (demande.getDonneesTemporaires().getPeriodeRevision() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CTX_REVISION_ABS_ACT_CONSERVEE", 1);
    }
    return (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeRevision();
  }
  
  private void testerFCTTopeNonLiquidable(ActiviteSalarie activiteConserve)
    throws CoucheLogiqueException
  {
    if (!activiteConserve.estLiquidable()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_REVISION_FCT_NON_LIQUIDABLE");
    }
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    ActiviteSalarie fctRevisionCourante;
    Iterator iter;
    if ((contexteDemande == null) || (!"REVAUTO".equals(contexteDemande)))
    {
      fctRevisionCourante = recupererActiviteConserveePerdue((Demande)demande);
      
      Damj dateFCT = fctRevisionCourante.getDateFin();
      if (FabriqueConvention2014.DATE_APPLICATION.estApres(dateFCT)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_ARE14_2");
      }
      testerFCTTopeNonLiquidable(fctRevisionCourante);
      
      FiltreAttributionStandardAssurance filtreAsu = new FiltreAttributionStandardAssurance(true, true, false, true, demande);
      
      AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreAsu);
      if (attributionAssurancePrecedente != null)
      {
        if (!((ProduitAsuSpec)attributionAssurancePrecedente.getProduit()).estUnProduitRevisable()) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_SUR_PRODUIT_NON_AUTORISE", new Object[] { attributionAssurancePrecedente.getProduit().getLibelleCourt(), attributionAssurancePrecedente.getDateAttribution() });
        }
      }
      else {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_SANS_OD_ORIGINE");
      }
      ProduitSpec produit = attributionAssurancePrecedente.getProduit();
      if ((produit != null) && ((produit.getCode() == 1) || (produit.getCode() == 13))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_ARE14_RELIQUAT");
      }
      Chronologie listeActivitesConservees = attributionAssurancePrecedente.getListeActiviteConservee();
      if ((listeActivitesConservees == null) || (!listeActivitesConservees.contientElement(fctRevisionCourante))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ACTIVITE_NON_CONSERVEE");
      }
      FiltreET filtre = new FiltreET();
      filtre.ajouterFiltre(new FiltreDemandePourERE("ASU_28"));
      filtre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
      Chronologie listeRevisionPrecedente = OutilRecherche.rechercherDecisionsPrecedentes(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtre);
      for (iter = listeRevisionPrecedente.iterer(); iter.hasNext();)
      {
        DecisionSpec revisionPrecedente = (DecisionSpec)iter.next();
        ActiviteSalarie fctRevisionPrecedente = recupererActiviteConserveePerdue((Demande)revisionPrecedente.getDemande());
        if ((fctRevisionPrecedente != null) && (fctRevisionCourante.getDateFin().coincideAvec(fctRevisionPrecedente.getDateFin()))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_REVISION_ARE14_MEME_DATE_FCT", new Object[] { fctRevisionCourante.getDateFin() }, 1);
        }
      }
    }
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreOU filtre = new FiltreOU();
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(37));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(36));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(50));
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(51));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(39));
    
    filtre.ajouterFiltre(new FiltreDecisionARESurDecision());
    return filtre;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeASURevisionAdmission();
  }
  
  public ParcoursLiquidationAssurance determinerParcoursLiquidationDemandeAssurance(DemandeSpec demande)
  {
    return new ParcoursLiquidationAssuranceRevisionAdmission();
  }
  
  public void verifierPostContexte(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DecisionSpec revisionCourante = (DecisionSpec)demande.getDossierAffectation().getDossierExamen();
    Iterator iter;
    if ((revisionCourante instanceof RevisionSpec))
    {
      FiltreET filtreEt = new FiltreET();
      filtreEt.ajouterFiltre(new FiltreDemandePourERE("ASU_07"));
      filtreEt.ajouterFiltre(new FiltreDecisionneeSurDemande());
      Chronologie listeRevisionPrecedente = OutilRecherche.rechercherDemandesPrecedentes(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreEt);
      for (iter = listeRevisionPrecedente.iterer(); iter.hasNext();)
      {
        DemandeSpec demandePrecedente = (DemandeSpec)iter.next();
        DecisionSpec revisionPrecedente = (DecisionSpec)demandePrecedente.getDossierAffectation().getDossierExamen();
        if ((revisionPrecedente.getNatureDecision() == 30) && (revisionCourante != null) && (revisionPrecedente.getDateAttribution().estApresOuCoincideAvec(revisionCourante.getDateAttribution()))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_REVISION_DATE_REVISION_POSTERIEURE", new Object[] { revisionPrecedente.getDateEffetDecision(), demande.getDateExamen(), revisionPrecedente.getDemande().getDateExamen() }, 1);
        }
      }
    }
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionOdprecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreOuvertureDroitStandardAssurance(true, true, false, true, demande));
    if ((attributionOdprecedente != null) && (ProduitAbstrait.estDuType(2, attributionOdprecedente.getProduit().getCode())))
    {
      ContexteDemande contexteOdPrec = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)attributionOdprecedente.getDemande(), 1);
      ((Demande)demande).ajouterContexteDemande((ContexteDemande)contexteOdPrec.copie());
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteParticulierCsr((Demande)demande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnCoursCSPouPAP(demande);
    
    ContexteDemande contexteDemandeEnCoursDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "COURSDISPO");
    if (contexteDemandeEnCoursDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnCoursDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursDeDisponibilite(demande);
    
    ContexteDemande contexteDemandeEnSortieDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "POSTDISPO");
    if (contexteDemandeEnSortieDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnSortieDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnSortieDeDisponibilite(demande);
  }
  
  public String getContexteDemande()
  {
    return contexteDemande;
  }
  
  public void setContexteDemande(String contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public Damj getDateExamenForcee()
  {
    return dateExamenForcee;
  }
  
  public void setDateExamenForcee(Damj dateExamenForcee)
  {
    this.dateExamenForcee = dateExamenForcee;
  }
}

/* Location:
 * Qualified Name:     EreRevisionConvention2014
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */