package fr.unedic.cali.asu.dom;

import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.dom.gen.FormulaireAsuGen;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;

public class FormulaireAsu
  extends FormulaireAsuGen
{
  private static final long serialVersionUID = 8673320714936140442L;
  private transient DemandeSpec m_demandeAssurance;
  private transient String m_motifEnvoiFormulaireAsu;
  private transient String m_presenceCarteSs;
  private transient String m_presenceAe;
  private transient String m_demandeLiquidable;
  private transient String m_refusFNE;
  private transient boolean m_droitAuCongeReclassement;
  private transient String m_pareCrpCtpPropose;
  private transient int m_referenceExterneDemandeLiee = 0;
  private transient String m_deploiementInstruction = "N";
  
  public FormulaireAsu(DomPCSpec p_pc)
  {
    super(p_pc);
    initInstance();
  }
  
  private void initInstance()
  {
    m_presenceCarteSs = "";
    m_demandeLiquidable = "";
    m_presenceAe = "";
    m_referenceExterneDemandeLiee = -1;
    setDateCreationDal(null);
  }
  
  protected DomPCSpec createPC()
  {
    throw ExceptionUtil.shouldNotPassHere("Dans un composant on ne devrait pas avoir à creer le PC de fusion");
  }
  
  public void jdoPreDelete() {}
  
  public void setDemandeAssurance(DemandeSpec p_demande)
  {
    m_demandeAssurance = p_demande;
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    FormulaireAsu copie = (FormulaireAsu)p_copie;
    
    super.copieElements(copie);
    copie.setIdPec(getIdPec());
    copie.setIdPecSigma(getIdPecSigma());
    copie.setReferenceExterne(getReferenceExterne());
    copie.setDateEvenement(getDateEvenement());
    copie.setTypeExamen(getTypeExamen());
    copie.setPresenceAe(getPresenceAe());
    copie.setDemandeLiquidable(getDemandeLiquidable());
    copie.setPresenceAe(getPresenceAe());
    copie.setRefusFNE(getRefusFNE());
    copie.setDroitAuCongeReclassement(isDroitAuCongeReclassement());
    copie.setPareCrpCtpPropose(getPareCrpCtpPropose());
    copie.setReferenceExterneDemandeLiee(getReferenceExterneDemandeLiee());
    copie.setDeploiementInstruction(getDeploiementInstruction());
    copie.setDateDepotOrigine(getDateDepotOrigine());
  }
  
  public DemandeSpec getDemande()
  {
    return m_demandeAssurance;
  }
  
  public int getIdPec()
  {
    return super.getIdPecSigma();
  }
  
  public void setIdPec(int p_string)
  {
    super.setIdPecSigma(p_string);
  }
  
  public DemandeSpec getDemandeAssurance()
  {
    return m_demandeAssurance;
  }
  
  public GammeSpec getGamme()
  {
    return GammeAsu.getInstance();
  }
  
  public String getPresenceCarteSs()
  {
    return m_presenceCarteSs;
  }
  
  public void setPresenceAe(String p_presenceAe)
  {
    m_presenceAe = p_presenceAe;
  }
  
  public String getPresenceAe()
  {
    return m_presenceAe;
  }
  
  public String getDemandeLiquidable()
  {
    return m_demandeLiquidable;
  }
  
  public void setDemandeLiquidable(String p_demandeLiquidable)
  {
    m_demandeLiquidable = p_demandeLiquidable;
  }
  
  public void setPresenceCarteSs(String p_presenceCarteSs)
  {
    m_presenceCarteSs = p_presenceCarteSs;
  }
  
  public boolean isDroitAuCongeReclassement()
  {
    return m_droitAuCongeReclassement;
  }
  
  public void setDroitAuCongeReclassement(boolean p_droitAuCongeReclassement)
  {
    m_droitAuCongeReclassement = p_droitAuCongeReclassement;
  }
  
  public String getPareCrpCtpPropose()
  {
    return m_pareCrpCtpPropose;
  }
  
  public void setPareCrpCtpPropose(String p_pareOuCrpPropose)
  {
    m_pareCrpCtpPropose = p_pareOuCrpPropose;
  }
  
  public boolean isCrpOuCtpPropose()
  {
    return ("O".equals(getPareCrpCtpPropose())) || ("C".equals(getPareCrpCtpPropose()));
  }
  
  public String getRefusFNE()
  {
    return m_refusFNE;
  }
  
  public void setRefusFNE(String p_refusFNE)
  {
    m_refusFNE = p_refusFNE;
  }
  
  public void setReferenceExterneDemandeLiee(int p_lienRejetDv)
  {
    m_referenceExterneDemandeLiee = p_lienRejetDv;
  }
  
  public int getReferenceExterneDemandeLiee()
  {
    return m_referenceExterneDemandeLiee;
  }
  
  public void miseAjour(FormulaireSpec p_formulaire)
  {
    if (controlerFormulaire(p_formulaire))
    {
      FormulaireAsu formulaire = (FormulaireAsu)p_formulaire;
      setDemandeLiquidable(formulaire.getDemandeLiquidable());
      setDroitAuCongeReclassement(formulaire.isDroitAuCongeReclassement());
      setPareCrpCtpPropose(formulaire.getPareCrpCtpPropose());
      setPresenceAe(formulaire.getPresenceAe());
      setPresenceCarteSs(formulaire.getPresenceCarteSs());
      setRefusFNE(formulaire.getRefusFNE());
      setReferenceExterneDemandeLiee(formulaire.getReferenceExterneDemandeLiee());
      setDeploiementInstruction(formulaire.getDeploiementInstruction());
      super.miseAjour(formulaire);
    }
  }
  
  public void setMotifEnvoi(String p_motifEnvoi)
  {
    m_motifEnvoiFormulaireAsu = p_motifEnvoi;
  }
  
  public String getMotifEnvoi()
  {
    return m_motifEnvoiFormulaireAsu;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public String getDeploiementInstruction()
  {
    return m_deploiementInstruction;
  }
  
  public void setDeploiementInstruction(String p_deploiementInstruction)
  {
    m_deploiementInstruction = p_deploiementInstruction;
  }
}

/* Location:
 * Qualified Name:     FormulaireAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */