package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.JustificationAffiliationGen;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class JustificationAffiliation
  extends JustificationAffiliationGen
  implements ObjetPersistantSpec, JustificationAffiliationSpec, fr.unedic.cali.dom.spec.JustificationAffiliationSpec
{
  private static final long serialVersionUID = -4589050850536228743L;
  private Chronologie m_chronologieActivitesParticipantes;
  
  public JustificationAffiliation() {}
  
  public JustificationAffiliation(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ObjetMetierSpec copie()
  {
    JustificationAffiliation copie = new JustificationAffiliation();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    JustificationAffiliation copie = (JustificationAffiliation)p_copie;
    copie.setEstAffiliationPlafonnee(isEstAffiliationPlafonnee());
    copie.setPeriodeRechercheAffiliation(getPeriodeRechercheAffiliation());
    copie.setPlafondAssimilation(getPlafondAssimilation());
    copie.setQuantiteAffiliation(getQuantiteAffiliation());
    copie.setQuantiteAssimilation(getQuantiteAssimilation());
    copie.setQuantiteDernierJourFevrier(getQuantiteDernierJourFevrier());
    copie.setTopConflits(isTopConflits());
    copie.setQuantiteImputee(getQuantiteImputee());
    
    Iterator it = getListAffiliationAssimilee().iterator();
    while (it.hasNext())
    {
      AffiliationAssimilee affiliationAssimilee = (AffiliationAssimilee)it.next();
      copie.ajouterAffiliationAssimilee((AffiliationAssimilee)affiliationAssimilee.copie());
    }
    it = getListAffiliationSupplementaire().iterator();
    while (it.hasNext())
    {
      AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
      copie.ajouterAffiliationSupplementaire((AffiliationSupplementaire)affiliationSupplementaire.copie());
    }
    it = getListPeriodeElementaire().iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      copie.ajouterPeriodeElementaire((PeriodeElementaire)periodeElementaire.copie());
    }
    it = getListPlafonnementAffiliation().iterator();
    while (it.hasNext())
    {
      PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
      copie.ajouterPlafonnementAffiliation((PlafonnementAffiliation)plafonnementAffiliation.copie());
    }
    it = getListZoneMemeExercice().iterator();
    while (it.hasNext())
    {
      ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
      copie.ajouterZoneMemeExercice((ZoneMemeExercice)zoneMemeExercice.copie());
    }
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionAffiliationAssimilee());
    DomManager.persisterEnProfondeur(super.getCollectionAffiliationSupplementaire());
    DomManager.persisterEnProfondeur(super.getCollectionPeriodeElementaire());
    DomManager.persisterEnProfondeur(super.getCollectionPlafonnementAffiliation());
    DomManager.persisterEnProfondeur(super.getCollectionZoneMemeExercice());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public String getTypeJustificationAffiliation()
  {
    return "justifCGENouveauModele";
  }
  
  public Chronologie getChronoZmes()
  {
    Chronologie chrono = new ChronologiePeriodes();
    chrono.ajouter(getListZoneMemeExercice());
    return chrono;
  }
  
  public UniteAffiliation getUniteJustification()
  {
    if (getQuantiteAffiliation() != null) {
      return (UniteAffiliation)getQuantiteAffiliation().getUnite();
    }
    return null;
  }
  
  public Chronologie getChronologieActivitesParticipantes()
  {
    return m_chronologieActivitesParticipantes;
  }
  
  public void setChronologieActivitesParticipantes(Chronologie p_activitesParticipantes)
  {
    m_chronologieActivitesParticipantes = p_activitesParticipantes;
  }
  
  public void remplacerCollectionPeriodeElementaire(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionPeriodeElementaire().iterator(); iter.hasNext();)
    {
      PeriodeElementaire element = (PeriodeElementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPeriodeElementaire(collectionACopier);
  }
  
  public void remplacerCollectionZoneMemeExercice(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionZoneMemeExercice().iterator(); iter.hasNext();)
    {
      ZoneMemeExercice element = (ZoneMemeExercice)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionZoneMemeExercice(collectionACopier);
  }
  
  public void remplacerCollectionAffiliationSupplementaire(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionAffiliationSupplementaire().iterator(); iter.hasNext();)
    {
      AffiliationSupplementaire element = (AffiliationSupplementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionAffiliationSupplementaire(collectionACopier);
  }
  
  public void remplacerCollectionAffiliationAssimilee(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionAffiliationAssimilee().iterator(); iter.hasNext();)
    {
      AffiliationAssimilee element = (AffiliationAssimilee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionAffiliationAssimilee(collectionACopier);
  }
  
  public void remplacerCollectionPlafonnementAffiliation(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionPlafonnementAffiliation().iterator(); iter.hasNext();)
    {
      PlafonnementAffiliation element = (PlafonnementAffiliation)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPlafonnementAffiliation(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     JustificationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */