package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.SaisieAntecedentGen;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;

public class SaisieAntecedent
  extends SaisieAntecedentGen
  implements ObjetPersistantSpec
{
  public static final String TYPE_MONTANT_RETENU_AUCUN = "0";
  public static final String A8_A10 = "1";
  public static final String FORMULE_ARE_2011_OU_ANTERIEUR = "2";
  public static final int VALEUR_DEFAUT = 0;
  public static final int CODE_PRODUIT_CAS_GENERAL = 1;
  public static final int CODE_PRODUIT_CAS_SPECTACLE = 2;
  public static final int CODE_PRODUIT_CAS_APS = 3;
  public static final int CODE_PRODUIT_CAS_AFD = 4;
  public static final int CODE_PRODUIT_CAS_CLAUSE_SAUVEGARDE = 5;
  public static final int CODE_PRODUIT_CAS_EXPATRIE = 9;
  public static final int CODE_PRODUIT_CAS_ASP = 12;
  public static final int CODE_CONTEXTE_TRANSFERT_PE_IMPOSSIBLE = 1;
  public static final int CODE_CONTEXTE_ECHEC_MIGRATION = 2;
  public static final int CODE_CONTEXTE_FIN_DROIT_SP = 3;
  public static final int CODE_CONTEXTE_DROIT_SPECTACLE_EPUISE = 4;
  public static final int CODE_CONTEXTE_MIGRATION_SP_EN_COURS = 5;
  public static final int CODE_CONTEXTE_MIGRATION_SP_RADIE = 6;
  public static final int CODE_CONTEXTE_TRANSFERT_IMPOSSIBLE_MAINTIEN_EUROPEEN = 7;
  public static final int CODE_CONTEXTE_CONVERSION_DROIT_MAYOTTE = 8;
  public static final int CODE_CONTEXTE_SP_POUR_ASP_ARE = 9;
  private transient TravailSpec periodeFctCompetence;
  private transient TravailSpec periodeFGD;
  private transient TravailSpec periodeFctRetenue;
  private transient String referenceExterne;
  private static final long serialVersionUID = 1L;
  
  public SaisieAntecedent()
  {
    initialiser();
  }
  
  public SaisieAntecedent(DomPCSpec pc)
  {
    super(pc);
  }
  
  private void initialiser()
  {
    setCodeEmploiA2B(Integer.valueOf(0));
    setTypeCaractereSaisonnier(Integer.valueOf(0));
    setMontantReadmissionRetenu("0");
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    SaisieAntecedent copie = new SaisieAntecedent();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    SaisieAntecedent copieSaisie = (SaisieAntecedent)copie;
    
    super.copieElements(copieSaisie);
    
    copieSaisie.setA3ansActiviteEn5ans(isA3ansActiviteEn5ans());
    copieSaisie.setCodeEmploiA2B(getCodeEmploiA2B());
    copieSaisie.setCodeProduit(getCodeProduit());
    copieSaisie.setCoefficientSaisonnier(getCoefficientSaisonnier());
    copieSaisie.setCoefficientTempsPartiel(getCoefficientTempsPartiel());
    copieSaisie.setContexteDemande(getContexteDemande());
    copieSaisie.setCumulMoisActiviteReduite(getCumulMoisActiviteReduite());
    copieSaisie.setDateAttribution(getDateAttribution());
    copieSaisie.setDateDernierJourCalcule(getDateDernierJourCalcule());
    copieSaisie.setDateFinPMC(getDateFinPMC());
    copieSaisie.setDureeInitialeDroit(getDureeInitialeDroit());
    copieSaisie.setEstDroitMaintenu(isEstDroitMaintenu());
    copieSaisie.setEstEnFormationAuDJC(isEstEnFormationAuDJC());
    copieSaisie.setIdentifiantFaitGenerateur(getIdentifiantFaitGenerateur());
    copieSaisie.setIdentifiantFCTRetenue(getIdentifiantFCTRetenue());
    copieSaisie.setNbHeuresTravailEtendu(getNbHeuresTravailEtendu());
    copieSaisie.setNbHeuresTravailPlafonne(getNbHeuresTravailPlafonne());
    copieSaisie.setNbJourContratSurPra(getNbJourContratSurPra());
    copieSaisie.setNombreJourIndemniseARE(getNombreJourIndemniseARE());
    copieSaisie.setNombreJourIndemniseAREF(getNombreJourIndemniseAREF());
    copieSaisie.setNombreMoisIndemnisationAssurance(getNombreMoisIndemnisationAssurance());
    copieSaisie.setNomReglementApplicable(getNomReglementApplicable());
    copieSaisie.setPremierJourIndemnisable(getPremierJourIndemnisable());
    copieSaisie.setRangAllongementPraSpectacle(getRangAllongementPraSpectacle());
    copieSaisie.setReliquatDuree(getReliquatDuree());
    copieSaisie.setReliquatDureeRenouvellement(getReliquatDureeRenouvellement());
    copieSaisie.setReliquatJourDiffereStandard(getReliquatJourDiffereStandard());
    copieSaisie.setReliquatJoursDelaiAttente(getReliquatJoursDelaiAttente());
    copieSaisie.setReliquatJoursICCP(getReliquatJoursICCP());
    copieSaisie.setReliquatJoursISLR(getReliquatJoursISLR());
    copieSaisie.setSalaireReferenceInitialPlafonne(getSalaireReferenceInitialPlafonne());
    copieSaisie.setSalaireReferenceSurBaseSMIC(isSalaireReferenceSurBaseSMIC());
    copieSaisie.setSalaireJournalierConservePlafonne(getSalaireJournalierConservePlafonne());
    copieSaisie.setSalaireJournalierReferencePlafonne(getSalaireJournalierReferencePlafonne());
    copieSaisie.setTermePRC(getTermePRC());
    copieSaisie.setTypeCaractereSaisonnier(getTypeCaractereSaisonnier());
    copieSaisie.setIdentifiantCompetence(getIdentifiantCompetence());
    copieSaisie.setTypeCoordinationEuropeenne(getTypeCoordinationEuropeenne());
    copieSaisie.setDateDebutPRC(getDateDebutPRC());
    copieSaisie.setDelaiAttente(isDelaiAttente());
    copieSaisie.setCodeAffectation(getCodeAffectation());
    copieSaisie.setEtablissementFinanceur(getEtablissementFinanceur());
    copieSaisie.setEstSituationParticuliereAre2001(isEstSituationParticuliereAre2001());
    copieSaisie.setMontantReadmissionRetenu(getMontantReadmissionRetenu());
    copieSaisie.setRevenuMensuelANSConservee(getRevenuMensuelANSConservee());
    copieSaisie.setDateAdmission(getDateAdmission());
    copieSaisie.setNbMoisCivilsNonPayes(getNbMoisCivilsNonPayes());
    
    copieSaisie.setDateLimite(getDateLimite());
    copieSaisie.setEntreeCra(isEntreeCra());
    copieSaisie.setMontantCra(getMontantCra());
    copieSaisie.setSjmCra(getSjmCra());
    copieSaisie.setFranchiseCPTotale(getFranchiseCPTotale());
    copieSaisie.setFranchiseCPMensuelle(getFranchiseCPMensuelle());
    copieSaisie.setFranchiseSalaireMensuelle(getFranchiseSalaireMensuelle());
    copieSaisie.setFranchiseSalaireTotale(getFranchiseSalaireTotale());
    copieSaisie.setSortieCra(isSortieCra());
    
    copieSaisie.setReliquatFCPDJC(getReliquatFCPDJC());
    copieSaisie.setReliquatFSDJC(getReliquatFSDJC());
    copieSaisie.setQuantiteFCPConsoDJC(getQuantiteFCPConsoDJC());
    copieSaisie.setQuantiteFSConsoDJC(getQuantiteFSConsoDJC());
    copieSaisie.setQuantiteReportFCP(getQuantiteReportFCP());
    copieSaisie.setQuantiteReportFS(getQuantiteReportFS());
    copieSaisie.setDureeAllongementAREF(getDureeAllongementAREF());
    copieSaisie.setReliquatDureeAllongementAREF(getReliquatDureeAllongementAREF());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public TravailSpec getPeriodeFctRetenue()
  {
    if (periodeFctRetenue == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeFctRetenue = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantFCTRetenue()));
    }
    return periodeFctRetenue;
  }
  
  public TravailSpec getPeriodeFctCompetence()
  {
    if (periodeFctCompetence == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeFctCompetence = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantCompetence()));
    }
    return periodeFctCompetence;
  }
  
  public TravailSpec getPeriodeFGD()
  {
    if (periodeFGD == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      periodeFGD = ((TravailSpec)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantFaitGenerateur()));
    }
    return periodeFGD;
  }
  
  public String getReferenceExterne()
  {
    return referenceExterne;
  }
  
  public void setReferenceExterne(String referenceExterne)
  {
    this.referenceExterne = referenceExterne;
  }
  
  public boolean estAntecedentAsp()
  {
    return (getCodeProduit() != null) && (getCodeProduit().intValue() == 12);
  }
  
  public boolean estAntecedentMayotte()
  {
    boolean estMayotte = false;
    if (getContexteDemande() != null) {
      estMayotte = getContexteDemande().intValue() == 8;
    }
    return estMayotte;
  }
  
  public boolean estClauseRattrapage()
  {
    return (isEntreeCra()) || (isSortieCra());
  }
  
  public Damj getDateDebutPRC()
  {
    if (super.getDateDebutPRC() == null) {
      super.setDateDebutPRC(super.getTermePRC());
    }
    return super.getDateDebutPRC();
  }
}

/* Location:
 * Qualified Name:     SaisieAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */