package fr.unedic.cali.asu.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.cali.asu.dom.pc.SaisieAntecedentPC;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public abstract class SaisieAntecedentGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_saisieAntecedentPC;
  private Integer m_contexteDemande;
  private Integer m_codeProduit;
  private String m_nomReglementApplicable;
  private Damj m_dateAttribution;
  private String m_identifiantFaitGenerateur;
  private String m_identifiantFCTRetenue;
  private Quantite m_salaireJournalierReferencePlafonne;
  private Damj m_termePRC;
  private Quantite m_salaireJournalierConservePlafonne;
  private Quantite m_dureeInitialeDroit;
  private BigDecimal m_coefficientTempsPartiel;
  private BigDecimal m_coefficientSaisonnier;
  private Integer m_typeCaractereSaisonnier;
  private Integer m_codeEmploiA2B;
  private Integer m_rangAllongementPraSpectacle;
  private Quantite m_salaireReferenceInitialPlafonne;
  private BigDecimal m_nbHeuresTravailEtendu;
  private BigDecimal m_nbHeuresTravailPlafonne;
  private Integer m_nbJourContratSurPra;
  private Damj m_dateDernierJourCalcule;
  private Integer m_nombreJourIndemniseARE;
  private Integer m_nombreJourIndemniseAREF;
  private Damj m_premierJourIndemnisable;
  private Quantite m_reliquatDuree;
  private Integer m_cumulMoisActiviteReduite;
  private Integer m_nombreMoisIndemnisationAssurance;
  private Quantite m_reliquatDureeRenouvellement;
  private Damj m_dateFinPMC;
  private Integer m_reliquatJoursICCP;
  private Integer m_reliquatJoursISLR;
  private Integer m_reliquatJoursDelaiAttente;
  private Integer m_reliquatJourDiffereStandard;
  private String m_identifiantCompetence;
  private Damj m_dateDebutPRC;
  private Damj m_dateBanalisee1;
  private Damj m_dateBanalisee2;
  private Damj m_dateBanalisee3;
  private Quantite m_quantiteBanalisee1;
  private Quantite m_quantiteBanalisee2;
  private Quantite m_quantiteBanalisee3;
  private String m_chaineBanalisee1;
  private String m_chaineBanalisee2;
  private String m_chaineBanalisee3;
  private String m_etablissementFinanceur;
  private String m_codeAffectation;
  private String m_montantReadmissionRetenu;
  private String m_idExterneEmployeurSp;
  private BigDecimal m_revenuMensuelANSConservee;
  private Damj m_dateAdmission;
  private String m_contexteLimiteIndemnisation;
  private Damj m_dateLimite;
  private QuantiteEuro m_montantCra;
  private QuantiteEuro m_sjmCra;
  
  public SaisieAntecedentGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public SaisieAntecedentGen()
  {
    setPC(createPC());
  }
  
  protected DomPCSpec createPC()
  {
    return new SaisieAntecedentPC();
  }
  
  public DomPCSpec getPC()
  {
    return m_saisieAntecedentPC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_saisieAntecedentPC)
  {
    m_saisieAntecedentPC = p_saisieAntecedentPC;
  }
  
  protected Integer rawGetContexteDemande()
  {
    return ((SaisieAntecedentPC)getPC()).getContexteDemande();
  }
  
  public Integer getContexteDemande()
  {
    return ((SaisieAntecedentPC)getPC()).getContexteDemande();
  }
  
  public void setContexteDemande(Integer p_contexteDemande)
  {
    if ((m_contexteDemande == null) || (p_contexteDemande == null))
    {
      m_contexteDemande = p_contexteDemande;
      ((SaisieAntecedentPC)getPC()).setContexteDemande(p_contexteDemande);
    }
    else if ((m_contexteDemande != null) && (p_contexteDemande != null) && (!p_contexteDemande.equals(m_contexteDemande)))
    {
      m_contexteDemande = p_contexteDemande;
      ((SaisieAntecedentPC)getPC()).setContexteDemande(p_contexteDemande);
    }
  }
  
  protected Integer rawGetCodeProduit()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeProduit();
  }
  
  public Integer getCodeProduit()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeProduit();
  }
  
  public void setCodeProduit(Integer p_codeProduit)
  {
    if ((m_codeProduit == null) || (p_codeProduit == null))
    {
      m_codeProduit = p_codeProduit;
      ((SaisieAntecedentPC)getPC()).setCodeProduit(p_codeProduit);
    }
    else if ((m_codeProduit != null) && (p_codeProduit != null) && (!p_codeProduit.equals(m_codeProduit)))
    {
      m_codeProduit = p_codeProduit;
      ((SaisieAntecedentPC)getPC()).setCodeProduit(p_codeProduit);
    }
  }
  
  protected String rawGetNomReglementApplicable()
  {
    return ((SaisieAntecedentPC)getPC()).getNomReglementApplicable();
  }
  
  public String getNomReglementApplicable()
  {
    return ((SaisieAntecedentPC)getPC()).getNomReglementApplicable();
  }
  
  public void setNomReglementApplicable(String p_nomReglementApplicable)
  {
    if ((m_nomReglementApplicable == null) || (p_nomReglementApplicable == null))
    {
      m_nomReglementApplicable = p_nomReglementApplicable;
      ((SaisieAntecedentPC)getPC()).setNomReglementApplicable(p_nomReglementApplicable);
    }
    else if ((m_nomReglementApplicable != null) && (p_nomReglementApplicable != null) && (!p_nomReglementApplicable.equals(m_nomReglementApplicable)))
    {
      m_nomReglementApplicable = p_nomReglementApplicable;
      ((SaisieAntecedentPC)getPC()).setNomReglementApplicable(p_nomReglementApplicable);
    }
  }
  
  protected Damj rawGetDateAttribution()
  {
    return ((SaisieAntecedentPC)getPC()).getDateAttribution();
  }
  
  public Damj getDateAttribution()
  {
    return ((SaisieAntecedentPC)getPC()).getDateAttribution();
  }
  
  public void setDateAttribution(Damj p_dateAttribution)
  {
    if ((m_dateAttribution == null) || (p_dateAttribution == null))
    {
      m_dateAttribution = p_dateAttribution;
      ((SaisieAntecedentPC)getPC()).setDateAttribution(p_dateAttribution);
    }
    else if ((m_dateAttribution != null) && (p_dateAttribution != null) && (!p_dateAttribution.equals(m_dateAttribution)))
    {
      m_dateAttribution = p_dateAttribution;
      ((SaisieAntecedentPC)getPC()).setDateAttribution(p_dateAttribution);
    }
  }
  
  protected String rawGetIdentifiantFaitGenerateur()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantFaitGenerateur();
  }
  
  public String getIdentifiantFaitGenerateur()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantFaitGenerateur();
  }
  
  public void setIdentifiantFaitGenerateur(String p_identifiantFaitGenerateur)
  {
    if ((m_identifiantFaitGenerateur == null) || (p_identifiantFaitGenerateur == null))
    {
      m_identifiantFaitGenerateur = p_identifiantFaitGenerateur;
      ((SaisieAntecedentPC)getPC()).setIdentifiantFaitGenerateur(p_identifiantFaitGenerateur);
    }
    else if ((m_identifiantFaitGenerateur != null) && (p_identifiantFaitGenerateur != null) && (!p_identifiantFaitGenerateur.equals(m_identifiantFaitGenerateur)))
    {
      m_identifiantFaitGenerateur = p_identifiantFaitGenerateur;
      ((SaisieAntecedentPC)getPC()).setIdentifiantFaitGenerateur(p_identifiantFaitGenerateur);
    }
  }
  
  protected String rawGetIdentifiantFCTRetenue()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantFCTRetenue();
  }
  
  public String getIdentifiantFCTRetenue()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantFCTRetenue();
  }
  
  public void setIdentifiantFCTRetenue(String p_identifiantFCTRetenue)
  {
    if ((m_identifiantFCTRetenue == null) || (p_identifiantFCTRetenue == null))
    {
      m_identifiantFCTRetenue = p_identifiantFCTRetenue;
      ((SaisieAntecedentPC)getPC()).setIdentifiantFCTRetenue(p_identifiantFCTRetenue);
    }
    else if ((m_identifiantFCTRetenue != null) && (p_identifiantFCTRetenue != null) && (!p_identifiantFCTRetenue.equals(m_identifiantFCTRetenue)))
    {
      m_identifiantFCTRetenue = p_identifiantFCTRetenue;
      ((SaisieAntecedentPC)getPC()).setIdentifiantFCTRetenue(p_identifiantFCTRetenue);
    }
  }
  
  protected Quantite rawGetSalaireJournalierReferencePlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireJournalierReferencePlafonne();
  }
  
  public Quantite getSalaireJournalierReferencePlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireJournalierReferencePlafonne();
  }
  
  public void setSalaireJournalierReferencePlafonne(Quantite p_salaireJournalierReferencePlafonne)
  {
    if ((m_salaireJournalierReferencePlafonne == null) || (p_salaireJournalierReferencePlafonne == null))
    {
      m_salaireJournalierReferencePlafonne = p_salaireJournalierReferencePlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireJournalierReferencePlafonne(p_salaireJournalierReferencePlafonne);
    }
    else if ((m_salaireJournalierReferencePlafonne != null) && (p_salaireJournalierReferencePlafonne != null) && (!p_salaireJournalierReferencePlafonne.equals(m_salaireJournalierReferencePlafonne)))
    {
      m_salaireJournalierReferencePlafonne = p_salaireJournalierReferencePlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireJournalierReferencePlafonne(p_salaireJournalierReferencePlafonne);
    }
  }
  
  protected Damj rawGetTermePRC()
  {
    return ((SaisieAntecedentPC)getPC()).getTermePRC();
  }
  
  public Damj getTermePRC()
  {
    return ((SaisieAntecedentPC)getPC()).getTermePRC();
  }
  
  public void setTermePRC(Damj p_termePRC)
  {
    if ((m_termePRC == null) || (p_termePRC == null))
    {
      m_termePRC = p_termePRC;
      ((SaisieAntecedentPC)getPC()).setTermePRC(p_termePRC);
    }
    else if ((m_termePRC != null) && (p_termePRC != null) && (!p_termePRC.equals(m_termePRC)))
    {
      m_termePRC = p_termePRC;
      ((SaisieAntecedentPC)getPC()).setTermePRC(p_termePRC);
    }
  }
  
  protected Quantite rawGetSalaireJournalierConservePlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireJournalierConservePlafonne();
  }
  
  public Quantite getSalaireJournalierConservePlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireJournalierConservePlafonne();
  }
  
  public void setSalaireJournalierConservePlafonne(Quantite p_salaireJournalierConservePlafonne)
  {
    if ((m_salaireJournalierConservePlafonne == null) || (p_salaireJournalierConservePlafonne == null))
    {
      m_salaireJournalierConservePlafonne = p_salaireJournalierConservePlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireJournalierConservePlafonne(p_salaireJournalierConservePlafonne);
    }
    else if ((m_salaireJournalierConservePlafonne != null) && (p_salaireJournalierConservePlafonne != null) && (!p_salaireJournalierConservePlafonne.equals(m_salaireJournalierConservePlafonne)))
    {
      m_salaireJournalierConservePlafonne = p_salaireJournalierConservePlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireJournalierConservePlafonne(p_salaireJournalierConservePlafonne);
    }
  }
  
  protected Quantite rawGetDureeInitialeDroit()
  {
    return ((SaisieAntecedentPC)getPC()).getDureeInitialeDroit();
  }
  
  public Quantite getDureeInitialeDroit()
  {
    return ((SaisieAntecedentPC)getPC()).getDureeInitialeDroit();
  }
  
  public void setDureeInitialeDroit(Quantite p_dureeInitialeDroit)
  {
    if ((m_dureeInitialeDroit == null) || (p_dureeInitialeDroit == null))
    {
      m_dureeInitialeDroit = p_dureeInitialeDroit;
      ((SaisieAntecedentPC)getPC()).setDureeInitialeDroit(p_dureeInitialeDroit);
    }
    else if ((m_dureeInitialeDroit != null) && (p_dureeInitialeDroit != null) && (!p_dureeInitialeDroit.equals(m_dureeInitialeDroit)))
    {
      m_dureeInitialeDroit = p_dureeInitialeDroit;
      ((SaisieAntecedentPC)getPC()).setDureeInitialeDroit(p_dureeInitialeDroit);
    }
  }
  
  protected BigDecimal rawGetCoefficientTempsPartiel()
  {
    return ((SaisieAntecedentPC)getPC()).getCoefficientTempsPartiel();
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    return ((SaisieAntecedentPC)getPC()).getCoefficientTempsPartiel();
  }
  
  public void setCoefficientTempsPartiel(BigDecimal p_coefficientTempsPartiel)
  {
    if ((m_coefficientTempsPartiel == null) || (p_coefficientTempsPartiel == null))
    {
      m_coefficientTempsPartiel = p_coefficientTempsPartiel;
      ((SaisieAntecedentPC)getPC()).setCoefficientTempsPartiel(p_coefficientTempsPartiel);
    }
    else if ((m_coefficientTempsPartiel != null) && (p_coefficientTempsPartiel != null) && (!p_coefficientTempsPartiel.equals(m_coefficientTempsPartiel)))
    {
      m_coefficientTempsPartiel = p_coefficientTempsPartiel;
      ((SaisieAntecedentPC)getPC()).setCoefficientTempsPartiel(p_coefficientTempsPartiel);
    }
  }
  
  protected BigDecimal rawGetCoefficientSaisonnier()
  {
    return ((SaisieAntecedentPC)getPC()).getCoefficientSaisonnier();
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    return ((SaisieAntecedentPC)getPC()).getCoefficientSaisonnier();
  }
  
  public void setCoefficientSaisonnier(BigDecimal p_coefficientSaisonnier)
  {
    if ((m_coefficientSaisonnier == null) || (p_coefficientSaisonnier == null))
    {
      m_coefficientSaisonnier = p_coefficientSaisonnier;
      ((SaisieAntecedentPC)getPC()).setCoefficientSaisonnier(p_coefficientSaisonnier);
    }
    else if ((m_coefficientSaisonnier != null) && (p_coefficientSaisonnier != null) && (!p_coefficientSaisonnier.equals(m_coefficientSaisonnier)))
    {
      m_coefficientSaisonnier = p_coefficientSaisonnier;
      ((SaisieAntecedentPC)getPC()).setCoefficientSaisonnier(p_coefficientSaisonnier);
    }
  }
  
  protected Integer rawGetTypeCaractereSaisonnier()
  {
    return ((SaisieAntecedentPC)getPC()).getTypeCaractereSaisonnier();
  }
  
  public Integer getTypeCaractereSaisonnier()
  {
    return ((SaisieAntecedentPC)getPC()).getTypeCaractereSaisonnier();
  }
  
  public void setTypeCaractereSaisonnier(Integer p_typeCaractereSaisonnier)
  {
    if ((m_typeCaractereSaisonnier == null) || (p_typeCaractereSaisonnier == null))
    {
      m_typeCaractereSaisonnier = p_typeCaractereSaisonnier;
      ((SaisieAntecedentPC)getPC()).setTypeCaractereSaisonnier(p_typeCaractereSaisonnier);
    }
    else if ((m_typeCaractereSaisonnier != null) && (p_typeCaractereSaisonnier != null) && (!p_typeCaractereSaisonnier.equals(m_typeCaractereSaisonnier)))
    {
      m_typeCaractereSaisonnier = p_typeCaractereSaisonnier;
      ((SaisieAntecedentPC)getPC()).setTypeCaractereSaisonnier(p_typeCaractereSaisonnier);
    }
  }
  
  protected boolean rawIsA3ansActiviteEn5ans()
  {
    return ((SaisieAntecedentPC)getPC()).isA3ansActiviteEn5ans();
  }
  
  public boolean isA3ansActiviteEn5ans()
  {
    return ((SaisieAntecedentPC)getPC()).isA3ansActiviteEn5ans();
  }
  
  public void setA3ansActiviteEn5ans(boolean p_a3ansActiviteEn5ans)
  {
    ((SaisieAntecedentPC)getPC()).setA3ansActiviteEn5ans(p_a3ansActiviteEn5ans);
  }
  
  protected boolean rawIsSalaireReferenceSurBaseSMIC()
  {
    return ((SaisieAntecedentPC)getPC()).isSalaireReferenceSurBaseSMIC();
  }
  
  public boolean isSalaireReferenceSurBaseSMIC()
  {
    return ((SaisieAntecedentPC)getPC()).isSalaireReferenceSurBaseSMIC();
  }
  
  public void setSalaireReferenceSurBaseSMIC(boolean p_salaireReferenceSurBaseSMIC)
  {
    ((SaisieAntecedentPC)getPC()).setSalaireReferenceSurBaseSMIC(p_salaireReferenceSurBaseSMIC);
  }
  
  protected Integer rawGetCodeEmploiA2B()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeEmploiA2B();
  }
  
  public Integer getCodeEmploiA2B()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeEmploiA2B();
  }
  
  public void setCodeEmploiA2B(Integer p_codeEmploiA2B)
  {
    if ((m_codeEmploiA2B == null) || (p_codeEmploiA2B == null))
    {
      m_codeEmploiA2B = p_codeEmploiA2B;
      ((SaisieAntecedentPC)getPC()).setCodeEmploiA2B(p_codeEmploiA2B);
    }
    else if ((m_codeEmploiA2B != null) && (p_codeEmploiA2B != null) && (!p_codeEmploiA2B.equals(m_codeEmploiA2B)))
    {
      m_codeEmploiA2B = p_codeEmploiA2B;
      ((SaisieAntecedentPC)getPC()).setCodeEmploiA2B(p_codeEmploiA2B);
    }
  }
  
  protected Integer rawGetRangAllongementPraSpectacle()
  {
    return ((SaisieAntecedentPC)getPC()).getRangAllongementPraSpectacle();
  }
  
  public Integer getRangAllongementPraSpectacle()
  {
    return ((SaisieAntecedentPC)getPC()).getRangAllongementPraSpectacle();
  }
  
  public void setRangAllongementPraSpectacle(Integer p_rangAllongementPraSpectacle)
  {
    if ((m_rangAllongementPraSpectacle == null) || (p_rangAllongementPraSpectacle == null))
    {
      m_rangAllongementPraSpectacle = p_rangAllongementPraSpectacle;
      ((SaisieAntecedentPC)getPC()).setRangAllongementPraSpectacle(p_rangAllongementPraSpectacle);
    }
    else if ((m_rangAllongementPraSpectacle != null) && (p_rangAllongementPraSpectacle != null) && (!p_rangAllongementPraSpectacle.equals(m_rangAllongementPraSpectacle)))
    {
      m_rangAllongementPraSpectacle = p_rangAllongementPraSpectacle;
      ((SaisieAntecedentPC)getPC()).setRangAllongementPraSpectacle(p_rangAllongementPraSpectacle);
    }
  }
  
  protected Quantite rawGetSalaireReferenceInitialPlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireReferenceInitialPlafonne();
  }
  
  public Quantite getSalaireReferenceInitialPlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getSalaireReferenceInitialPlafonne();
  }
  
  public void setSalaireReferenceInitialPlafonne(Quantite p_salaireReferenceInitialPlafonne)
  {
    if ((m_salaireReferenceInitialPlafonne == null) || (p_salaireReferenceInitialPlafonne == null))
    {
      m_salaireReferenceInitialPlafonne = p_salaireReferenceInitialPlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireReferenceInitialPlafonne(p_salaireReferenceInitialPlafonne);
    }
    else if ((m_salaireReferenceInitialPlafonne != null) && (p_salaireReferenceInitialPlafonne != null) && (!p_salaireReferenceInitialPlafonne.equals(m_salaireReferenceInitialPlafonne)))
    {
      m_salaireReferenceInitialPlafonne = p_salaireReferenceInitialPlafonne;
      ((SaisieAntecedentPC)getPC()).setSalaireReferenceInitialPlafonne(p_salaireReferenceInitialPlafonne);
    }
  }
  
  protected BigDecimal rawGetNbHeuresTravailEtendu()
  {
    return ((SaisieAntecedentPC)getPC()).getNbHeuresTravailEtendu();
  }
  
  public BigDecimal getNbHeuresTravailEtendu()
  {
    return ((SaisieAntecedentPC)getPC()).getNbHeuresTravailEtendu();
  }
  
  public void setNbHeuresTravailEtendu(BigDecimal p_nbHeuresTravailEtendu)
  {
    if ((m_nbHeuresTravailEtendu == null) || (p_nbHeuresTravailEtendu == null))
    {
      m_nbHeuresTravailEtendu = p_nbHeuresTravailEtendu;
      ((SaisieAntecedentPC)getPC()).setNbHeuresTravailEtendu(p_nbHeuresTravailEtendu);
    }
    else if ((m_nbHeuresTravailEtendu != null) && (p_nbHeuresTravailEtendu != null) && (!p_nbHeuresTravailEtendu.equals(m_nbHeuresTravailEtendu)))
    {
      m_nbHeuresTravailEtendu = p_nbHeuresTravailEtendu;
      ((SaisieAntecedentPC)getPC()).setNbHeuresTravailEtendu(p_nbHeuresTravailEtendu);
    }
  }
  
  protected BigDecimal rawGetNbHeuresTravailPlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getNbHeuresTravailPlafonne();
  }
  
  public BigDecimal getNbHeuresTravailPlafonne()
  {
    return ((SaisieAntecedentPC)getPC()).getNbHeuresTravailPlafonne();
  }
  
  public void setNbHeuresTravailPlafonne(BigDecimal p_nbHeuresTravailPlafonne)
  {
    if ((m_nbHeuresTravailPlafonne == null) || (p_nbHeuresTravailPlafonne == null))
    {
      m_nbHeuresTravailPlafonne = p_nbHeuresTravailPlafonne;
      ((SaisieAntecedentPC)getPC()).setNbHeuresTravailPlafonne(p_nbHeuresTravailPlafonne);
    }
    else if ((m_nbHeuresTravailPlafonne != null) && (p_nbHeuresTravailPlafonne != null) && (!p_nbHeuresTravailPlafonne.equals(m_nbHeuresTravailPlafonne)))
    {
      m_nbHeuresTravailPlafonne = p_nbHeuresTravailPlafonne;
      ((SaisieAntecedentPC)getPC()).setNbHeuresTravailPlafonne(p_nbHeuresTravailPlafonne);
    }
  }
  
  protected Integer rawGetNbJourContratSurPra()
  {
    return ((SaisieAntecedentPC)getPC()).getNbJourContratSurPra();
  }
  
  public Integer getNbJourContratSurPra()
  {
    return ((SaisieAntecedentPC)getPC()).getNbJourContratSurPra();
  }
  
  public void setNbJourContratSurPra(Integer p_nbJourContratSurPra)
  {
    if ((m_nbJourContratSurPra == null) || (p_nbJourContratSurPra == null))
    {
      m_nbJourContratSurPra = p_nbJourContratSurPra;
      ((SaisieAntecedentPC)getPC()).setNbJourContratSurPra(p_nbJourContratSurPra);
    }
    else if ((m_nbJourContratSurPra != null) && (p_nbJourContratSurPra != null) && (!p_nbJourContratSurPra.equals(m_nbJourContratSurPra)))
    {
      m_nbJourContratSurPra = p_nbJourContratSurPra;
      ((SaisieAntecedentPC)getPC()).setNbJourContratSurPra(p_nbJourContratSurPra);
    }
  }
  
  protected Damj rawGetDateDernierJourCalcule()
  {
    return ((SaisieAntecedentPC)getPC()).getDateDernierJourCalcule();
  }
  
  public Damj getDateDernierJourCalcule()
  {
    return ((SaisieAntecedentPC)getPC()).getDateDernierJourCalcule();
  }
  
  public void setDateDernierJourCalcule(Damj p_dateDernierJourCalcule)
  {
    if ((m_dateDernierJourCalcule == null) || (p_dateDernierJourCalcule == null))
    {
      m_dateDernierJourCalcule = p_dateDernierJourCalcule;
      ((SaisieAntecedentPC)getPC()).setDateDernierJourCalcule(p_dateDernierJourCalcule);
    }
    else if ((m_dateDernierJourCalcule != null) && (p_dateDernierJourCalcule != null) && (!p_dateDernierJourCalcule.equals(m_dateDernierJourCalcule)))
    {
      m_dateDernierJourCalcule = p_dateDernierJourCalcule;
      ((SaisieAntecedentPC)getPC()).setDateDernierJourCalcule(p_dateDernierJourCalcule);
    }
  }
  
  protected Integer rawGetNombreJourIndemniseARE()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreJourIndemniseARE();
  }
  
  public Integer getNombreJourIndemniseARE()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreJourIndemniseARE();
  }
  
  public void setNombreJourIndemniseARE(Integer p_nombreJourIndemniseARE)
  {
    if ((m_nombreJourIndemniseARE == null) || (p_nombreJourIndemniseARE == null))
    {
      m_nombreJourIndemniseARE = p_nombreJourIndemniseARE;
      ((SaisieAntecedentPC)getPC()).setNombreJourIndemniseARE(p_nombreJourIndemniseARE);
    }
    else if ((m_nombreJourIndemniseARE != null) && (p_nombreJourIndemniseARE != null) && (!p_nombreJourIndemniseARE.equals(m_nombreJourIndemniseARE)))
    {
      m_nombreJourIndemniseARE = p_nombreJourIndemniseARE;
      ((SaisieAntecedentPC)getPC()).setNombreJourIndemniseARE(p_nombreJourIndemniseARE);
    }
  }
  
  protected Integer rawGetNombreJourIndemniseAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreJourIndemniseAREF();
  }
  
  public Integer getNombreJourIndemniseAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreJourIndemniseAREF();
  }
  
  public void setNombreJourIndemniseAREF(Integer p_nombreJourIndemniseAREF)
  {
    if ((m_nombreJourIndemniseAREF == null) || (p_nombreJourIndemniseAREF == null))
    {
      m_nombreJourIndemniseAREF = p_nombreJourIndemniseAREF;
      ((SaisieAntecedentPC)getPC()).setNombreJourIndemniseAREF(p_nombreJourIndemniseAREF);
    }
    else if ((m_nombreJourIndemniseAREF != null) && (p_nombreJourIndemniseAREF != null) && (!p_nombreJourIndemniseAREF.equals(m_nombreJourIndemniseAREF)))
    {
      m_nombreJourIndemniseAREF = p_nombreJourIndemniseAREF;
      ((SaisieAntecedentPC)getPC()).setNombreJourIndemniseAREF(p_nombreJourIndemniseAREF);
    }
  }
  
  protected Damj rawGetPremierJourIndemnisable()
  {
    return ((SaisieAntecedentPC)getPC()).getPremierJourIndemnisable();
  }
  
  public Damj getPremierJourIndemnisable()
  {
    return ((SaisieAntecedentPC)getPC()).getPremierJourIndemnisable();
  }
  
  public void setPremierJourIndemnisable(Damj p_premierJourIndemnisable)
  {
    if ((m_premierJourIndemnisable == null) || (p_premierJourIndemnisable == null))
    {
      m_premierJourIndemnisable = p_premierJourIndemnisable;
      ((SaisieAntecedentPC)getPC()).setPremierJourIndemnisable(p_premierJourIndemnisable);
    }
    else if ((m_premierJourIndemnisable != null) && (p_premierJourIndemnisable != null) && (!p_premierJourIndemnisable.equals(m_premierJourIndemnisable)))
    {
      m_premierJourIndemnisable = p_premierJourIndemnisable;
      ((SaisieAntecedentPC)getPC()).setPremierJourIndemnisable(p_premierJourIndemnisable);
    }
  }
  
  protected Quantite rawGetReliquatDuree()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDuree();
  }
  
  public Quantite getReliquatDuree()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDuree();
  }
  
  public void setReliquatDuree(Quantite p_reliquatDuree)
  {
    if ((m_reliquatDuree == null) || (p_reliquatDuree == null))
    {
      m_reliquatDuree = p_reliquatDuree;
      ((SaisieAntecedentPC)getPC()).setReliquatDuree(p_reliquatDuree);
    }
    else if ((m_reliquatDuree != null) && (p_reliquatDuree != null) && (!p_reliquatDuree.equals(m_reliquatDuree)))
    {
      m_reliquatDuree = p_reliquatDuree;
      ((SaisieAntecedentPC)getPC()).setReliquatDuree(p_reliquatDuree);
    }
  }
  
  protected Integer rawGetCumulMoisActiviteReduite()
  {
    return ((SaisieAntecedentPC)getPC()).getCumulMoisActiviteReduite();
  }
  
  public Integer getCumulMoisActiviteReduite()
  {
    return ((SaisieAntecedentPC)getPC()).getCumulMoisActiviteReduite();
  }
  
  public void setCumulMoisActiviteReduite(Integer p_cumulMoisActiviteReduite)
  {
    if ((m_cumulMoisActiviteReduite == null) || (p_cumulMoisActiviteReduite == null))
    {
      m_cumulMoisActiviteReduite = p_cumulMoisActiviteReduite;
      ((SaisieAntecedentPC)getPC()).setCumulMoisActiviteReduite(p_cumulMoisActiviteReduite);
    }
    else if ((m_cumulMoisActiviteReduite != null) && (p_cumulMoisActiviteReduite != null) && (!p_cumulMoisActiviteReduite.equals(m_cumulMoisActiviteReduite)))
    {
      m_cumulMoisActiviteReduite = p_cumulMoisActiviteReduite;
      ((SaisieAntecedentPC)getPC()).setCumulMoisActiviteReduite(p_cumulMoisActiviteReduite);
    }
  }
  
  protected Integer rawGetNombreMoisIndemnisationAssurance()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreMoisIndemnisationAssurance();
  }
  
  public Integer getNombreMoisIndemnisationAssurance()
  {
    return ((SaisieAntecedentPC)getPC()).getNombreMoisIndemnisationAssurance();
  }
  
  public void setNombreMoisIndemnisationAssurance(Integer p_nombreMoisIndemnisationAssurance)
  {
    if ((m_nombreMoisIndemnisationAssurance == null) || (p_nombreMoisIndemnisationAssurance == null))
    {
      m_nombreMoisIndemnisationAssurance = p_nombreMoisIndemnisationAssurance;
      ((SaisieAntecedentPC)getPC()).setNombreMoisIndemnisationAssurance(p_nombreMoisIndemnisationAssurance);
    }
    else if ((m_nombreMoisIndemnisationAssurance != null) && (p_nombreMoisIndemnisationAssurance != null) && (!p_nombreMoisIndemnisationAssurance.equals(m_nombreMoisIndemnisationAssurance)))
    {
      m_nombreMoisIndemnisationAssurance = p_nombreMoisIndemnisationAssurance;
      ((SaisieAntecedentPC)getPC()).setNombreMoisIndemnisationAssurance(p_nombreMoisIndemnisationAssurance);
    }
  }
  
  protected Quantite rawGetReliquatDureeRenouvellement()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDureeRenouvellement();
  }
  
  public Quantite getReliquatDureeRenouvellement()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDureeRenouvellement();
  }
  
  public void setReliquatDureeRenouvellement(Quantite p_reliquatDureeRenouvellement)
  {
    if ((m_reliquatDureeRenouvellement == null) || (p_reliquatDureeRenouvellement == null))
    {
      m_reliquatDureeRenouvellement = p_reliquatDureeRenouvellement;
      ((SaisieAntecedentPC)getPC()).setReliquatDureeRenouvellement(p_reliquatDureeRenouvellement);
    }
    else if ((m_reliquatDureeRenouvellement != null) && (p_reliquatDureeRenouvellement != null) && (!p_reliquatDureeRenouvellement.equals(m_reliquatDureeRenouvellement)))
    {
      m_reliquatDureeRenouvellement = p_reliquatDureeRenouvellement;
      ((SaisieAntecedentPC)getPC()).setReliquatDureeRenouvellement(p_reliquatDureeRenouvellement);
    }
  }
  
  protected boolean rawIsEstDroitMaintenu()
  {
    return ((SaisieAntecedentPC)getPC()).isEstDroitMaintenu();
  }
  
  public boolean isEstDroitMaintenu()
  {
    return ((SaisieAntecedentPC)getPC()).isEstDroitMaintenu();
  }
  
  public void setEstDroitMaintenu(boolean p_estDroitMaintenu)
  {
    ((SaisieAntecedentPC)getPC()).setEstDroitMaintenu(p_estDroitMaintenu);
  }
  
  protected boolean rawIsEstEnFormationAuDJC()
  {
    return ((SaisieAntecedentPC)getPC()).isEstEnFormationAuDJC();
  }
  
  public boolean isEstEnFormationAuDJC()
  {
    return ((SaisieAntecedentPC)getPC()).isEstEnFormationAuDJC();
  }
  
  public void setEstEnFormationAuDJC(boolean p_estEnFormationAuDJC)
  {
    ((SaisieAntecedentPC)getPC()).setEstEnFormationAuDJC(p_estEnFormationAuDJC);
  }
  
  protected Damj rawGetDateFinPMC()
  {
    return ((SaisieAntecedentPC)getPC()).getDateFinPMC();
  }
  
  public Damj getDateFinPMC()
  {
    return ((SaisieAntecedentPC)getPC()).getDateFinPMC();
  }
  
  public void setDateFinPMC(Damj p_dateFinPMC)
  {
    if ((m_dateFinPMC == null) || (p_dateFinPMC == null))
    {
      m_dateFinPMC = p_dateFinPMC;
      ((SaisieAntecedentPC)getPC()).setDateFinPMC(p_dateFinPMC);
    }
    else if ((m_dateFinPMC != null) && (p_dateFinPMC != null) && (!p_dateFinPMC.equals(m_dateFinPMC)))
    {
      m_dateFinPMC = p_dateFinPMC;
      ((SaisieAntecedentPC)getPC()).setDateFinPMC(p_dateFinPMC);
    }
  }
  
  protected Integer rawGetReliquatJoursICCP()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursICCP();
  }
  
  public Integer getReliquatJoursICCP()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursICCP();
  }
  
  public void setReliquatJoursICCP(Integer p_reliquatJoursICCP)
  {
    if ((m_reliquatJoursICCP == null) || (p_reliquatJoursICCP == null))
    {
      m_reliquatJoursICCP = p_reliquatJoursICCP;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursICCP(p_reliquatJoursICCP);
    }
    else if ((m_reliquatJoursICCP != null) && (p_reliquatJoursICCP != null) && (!p_reliquatJoursICCP.equals(m_reliquatJoursICCP)))
    {
      m_reliquatJoursICCP = p_reliquatJoursICCP;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursICCP(p_reliquatJoursICCP);
    }
  }
  
  protected Integer rawGetReliquatJoursISLR()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursISLR();
  }
  
  public Integer getReliquatJoursISLR()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursISLR();
  }
  
  public void setReliquatJoursISLR(Integer p_reliquatJoursISLR)
  {
    if ((m_reliquatJoursISLR == null) || (p_reliquatJoursISLR == null))
    {
      m_reliquatJoursISLR = p_reliquatJoursISLR;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursISLR(p_reliquatJoursISLR);
    }
    else if ((m_reliquatJoursISLR != null) && (p_reliquatJoursISLR != null) && (!p_reliquatJoursISLR.equals(m_reliquatJoursISLR)))
    {
      m_reliquatJoursISLR = p_reliquatJoursISLR;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursISLR(p_reliquatJoursISLR);
    }
  }
  
  protected Integer rawGetReliquatJoursDelaiAttente()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursDelaiAttente();
  }
  
  public Integer getReliquatJoursDelaiAttente()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJoursDelaiAttente();
  }
  
  public void setReliquatJoursDelaiAttente(Integer p_reliquatJoursDelaiAttente)
  {
    if ((m_reliquatJoursDelaiAttente == null) || (p_reliquatJoursDelaiAttente == null))
    {
      m_reliquatJoursDelaiAttente = p_reliquatJoursDelaiAttente;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursDelaiAttente(p_reliquatJoursDelaiAttente);
    }
    else if ((m_reliquatJoursDelaiAttente != null) && (p_reliquatJoursDelaiAttente != null) && (!p_reliquatJoursDelaiAttente.equals(m_reliquatJoursDelaiAttente)))
    {
      m_reliquatJoursDelaiAttente = p_reliquatJoursDelaiAttente;
      ((SaisieAntecedentPC)getPC()).setReliquatJoursDelaiAttente(p_reliquatJoursDelaiAttente);
    }
  }
  
  protected Integer rawGetReliquatJourDiffereStandard()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJourDiffereStandard();
  }
  
  public Integer getReliquatJourDiffereStandard()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatJourDiffereStandard();
  }
  
  public void setReliquatJourDiffereStandard(Integer p_reliquatJourDiffereStandard)
  {
    if ((m_reliquatJourDiffereStandard == null) || (p_reliquatJourDiffereStandard == null))
    {
      m_reliquatJourDiffereStandard = p_reliquatJourDiffereStandard;
      ((SaisieAntecedentPC)getPC()).setReliquatJourDiffereStandard(p_reliquatJourDiffereStandard);
    }
    else if ((m_reliquatJourDiffereStandard != null) && (p_reliquatJourDiffereStandard != null) && (!p_reliquatJourDiffereStandard.equals(m_reliquatJourDiffereStandard)))
    {
      m_reliquatJourDiffereStandard = p_reliquatJourDiffereStandard;
      ((SaisieAntecedentPC)getPC()).setReliquatJourDiffereStandard(p_reliquatJourDiffereStandard);
    }
  }
  
  protected int rawGetTypeCoordinationEuropeenne()
  {
    return ((SaisieAntecedentPC)getPC()).getTypeCoordinationEuropeenne();
  }
  
  public int getTypeCoordinationEuropeenne()
  {
    return ((SaisieAntecedentPC)getPC()).getTypeCoordinationEuropeenne();
  }
  
  public void setTypeCoordinationEuropeenne(int p_typeCoordinationEuropeenne)
  {
    ((SaisieAntecedentPC)getPC()).setTypeCoordinationEuropeenne(p_typeCoordinationEuropeenne);
  }
  
  protected String rawGetIdentifiantCompetence()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantCompetence();
  }
  
  public String getIdentifiantCompetence()
  {
    return ((SaisieAntecedentPC)getPC()).getIdentifiantCompetence();
  }
  
  public void setIdentifiantCompetence(String p_identifiantCompetence)
  {
    if ((m_identifiantCompetence == null) || (p_identifiantCompetence == null))
    {
      m_identifiantCompetence = p_identifiantCompetence;
      ((SaisieAntecedentPC)getPC()).setIdentifiantCompetence(p_identifiantCompetence);
    }
    else if ((m_identifiantCompetence != null) && (p_identifiantCompetence != null) && (!p_identifiantCompetence.equals(m_identifiantCompetence)))
    {
      m_identifiantCompetence = p_identifiantCompetence;
      ((SaisieAntecedentPC)getPC()).setIdentifiantCompetence(p_identifiantCompetence);
    }
  }
  
  protected Damj rawGetDateDebutPRC()
  {
    return ((SaisieAntecedentPC)getPC()).getDateDebutPRC();
  }
  
  public Damj getDateDebutPRC()
  {
    return ((SaisieAntecedentPC)getPC()).getDateDebutPRC();
  }
  
  public void setDateDebutPRC(Damj p_dateDebutPRC)
  {
    if ((m_dateDebutPRC == null) || (p_dateDebutPRC == null))
    {
      m_dateDebutPRC = p_dateDebutPRC;
      ((SaisieAntecedentPC)getPC()).setDateDebutPRC(p_dateDebutPRC);
    }
    else if ((m_dateDebutPRC != null) && (p_dateDebutPRC != null) && (!p_dateDebutPRC.equals(m_dateDebutPRC)))
    {
      m_dateDebutPRC = p_dateDebutPRC;
      ((SaisieAntecedentPC)getPC()).setDateDebutPRC(p_dateDebutPRC);
    }
  }
  
  protected Damj rawGetDateBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee1();
  }
  
  public Damj getDateBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee1();
  }
  
  public void setDateBanalisee1(Damj p_dateBanalisee1)
  {
    if ((m_dateBanalisee1 == null) || (p_dateBanalisee1 == null))
    {
      m_dateBanalisee1 = p_dateBanalisee1;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee1(p_dateBanalisee1);
    }
    else if ((m_dateBanalisee1 != null) && (p_dateBanalisee1 != null) && (!p_dateBanalisee1.equals(m_dateBanalisee1)))
    {
      m_dateBanalisee1 = p_dateBanalisee1;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee1(p_dateBanalisee1);
    }
  }
  
  protected Damj rawGetDateBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee2();
  }
  
  public Damj getDateBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee2();
  }
  
  public void setDateBanalisee2(Damj p_dateBanalisee2)
  {
    if ((m_dateBanalisee2 == null) || (p_dateBanalisee2 == null))
    {
      m_dateBanalisee2 = p_dateBanalisee2;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee2(p_dateBanalisee2);
    }
    else if ((m_dateBanalisee2 != null) && (p_dateBanalisee2 != null) && (!p_dateBanalisee2.equals(m_dateBanalisee2)))
    {
      m_dateBanalisee2 = p_dateBanalisee2;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee2(p_dateBanalisee2);
    }
  }
  
  protected Damj rawGetDateBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee3();
  }
  
  public Damj getDateBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getDateBanalisee3();
  }
  
  public void setDateBanalisee3(Damj p_dateBanalisee3)
  {
    if ((m_dateBanalisee3 == null) || (p_dateBanalisee3 == null))
    {
      m_dateBanalisee3 = p_dateBanalisee3;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee3(p_dateBanalisee3);
    }
    else if ((m_dateBanalisee3 != null) && (p_dateBanalisee3 != null) && (!p_dateBanalisee3.equals(m_dateBanalisee3)))
    {
      m_dateBanalisee3 = p_dateBanalisee3;
      ((SaisieAntecedentPC)getPC()).setDateBanalisee3(p_dateBanalisee3);
    }
  }
  
  protected Quantite rawGetQuantiteBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee1();
  }
  
  public Quantite getQuantiteBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee1();
  }
  
  public void setQuantiteBanalisee1(Quantite p_quantiteBanalisee1)
  {
    if ((m_quantiteBanalisee1 == null) || (p_quantiteBanalisee1 == null))
    {
      m_quantiteBanalisee1 = p_quantiteBanalisee1;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee1(p_quantiteBanalisee1);
    }
    else if ((m_quantiteBanalisee1 != null) && (p_quantiteBanalisee1 != null) && (!p_quantiteBanalisee1.equals(m_quantiteBanalisee1)))
    {
      m_quantiteBanalisee1 = p_quantiteBanalisee1;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee1(p_quantiteBanalisee1);
    }
  }
  
  protected Quantite rawGetQuantiteBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee2();
  }
  
  public Quantite getQuantiteBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee2();
  }
  
  public void setQuantiteBanalisee2(Quantite p_quantiteBanalisee2)
  {
    if ((m_quantiteBanalisee2 == null) || (p_quantiteBanalisee2 == null))
    {
      m_quantiteBanalisee2 = p_quantiteBanalisee2;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee2(p_quantiteBanalisee2);
    }
    else if ((m_quantiteBanalisee2 != null) && (p_quantiteBanalisee2 != null) && (!p_quantiteBanalisee2.equals(m_quantiteBanalisee2)))
    {
      m_quantiteBanalisee2 = p_quantiteBanalisee2;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee2(p_quantiteBanalisee2);
    }
  }
  
  protected Quantite rawGetQuantiteBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee3();
  }
  
  public Quantite getQuantiteBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteBanalisee3();
  }
  
  public void setQuantiteBanalisee3(Quantite p_quantiteBanalisee3)
  {
    if ((m_quantiteBanalisee3 == null) || (p_quantiteBanalisee3 == null))
    {
      m_quantiteBanalisee3 = p_quantiteBanalisee3;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee3(p_quantiteBanalisee3);
    }
    else if ((m_quantiteBanalisee3 != null) && (p_quantiteBanalisee3 != null) && (!p_quantiteBanalisee3.equals(m_quantiteBanalisee3)))
    {
      m_quantiteBanalisee3 = p_quantiteBanalisee3;
      ((SaisieAntecedentPC)getPC()).setQuantiteBanalisee3(p_quantiteBanalisee3);
    }
  }
  
  protected String rawGetChaineBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee1();
  }
  
  public String getChaineBanalisee1()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee1();
  }
  
  public void setChaineBanalisee1(String p_chaineBanalisee1)
  {
    if ((m_chaineBanalisee1 == null) || (p_chaineBanalisee1 == null))
    {
      m_chaineBanalisee1 = p_chaineBanalisee1;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee1(p_chaineBanalisee1);
    }
    else if ((m_chaineBanalisee1 != null) && (p_chaineBanalisee1 != null) && (!p_chaineBanalisee1.equals(m_chaineBanalisee1)))
    {
      m_chaineBanalisee1 = p_chaineBanalisee1;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee1(p_chaineBanalisee1);
    }
  }
  
  protected String rawGetChaineBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee2();
  }
  
  public String getChaineBanalisee2()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee2();
  }
  
  public void setChaineBanalisee2(String p_chaineBanalisee2)
  {
    if ((m_chaineBanalisee2 == null) || (p_chaineBanalisee2 == null))
    {
      m_chaineBanalisee2 = p_chaineBanalisee2;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee2(p_chaineBanalisee2);
    }
    else if ((m_chaineBanalisee2 != null) && (p_chaineBanalisee2 != null) && (!p_chaineBanalisee2.equals(m_chaineBanalisee2)))
    {
      m_chaineBanalisee2 = p_chaineBanalisee2;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee2(p_chaineBanalisee2);
    }
  }
  
  protected String rawGetChaineBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee3();
  }
  
  public String getChaineBanalisee3()
  {
    return ((SaisieAntecedentPC)getPC()).getChaineBanalisee3();
  }
  
  public void setChaineBanalisee3(String p_chaineBanalisee3)
  {
    if ((m_chaineBanalisee3 == null) || (p_chaineBanalisee3 == null))
    {
      m_chaineBanalisee3 = p_chaineBanalisee3;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee3(p_chaineBanalisee3);
    }
    else if ((m_chaineBanalisee3 != null) && (p_chaineBanalisee3 != null) && (!p_chaineBanalisee3.equals(m_chaineBanalisee3)))
    {
      m_chaineBanalisee3 = p_chaineBanalisee3;
      ((SaisieAntecedentPC)getPC()).setChaineBanalisee3(p_chaineBanalisee3);
    }
  }
  
  protected boolean rawIsTopBanalise1()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise1();
  }
  
  public boolean isTopBanalise1()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise1();
  }
  
  public void setTopBanalise1(boolean p_topBanalise1)
  {
    ((SaisieAntecedentPC)getPC()).setTopBanalise1(p_topBanalise1);
  }
  
  protected boolean rawIsTopBanalise2()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise2();
  }
  
  public boolean isTopBanalise2()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise2();
  }
  
  public void setTopBanalise2(boolean p_topBanalise2)
  {
    ((SaisieAntecedentPC)getPC()).setTopBanalise2(p_topBanalise2);
  }
  
  protected boolean rawIsTopBanalise3()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise3();
  }
  
  public boolean isTopBanalise3()
  {
    return ((SaisieAntecedentPC)getPC()).isTopBanalise3();
  }
  
  public void setTopBanalise3(boolean p_topBanalise3)
  {
    ((SaisieAntecedentPC)getPC()).setTopBanalise3(p_topBanalise3);
  }
  
  protected boolean rawIsDelaiAttente()
  {
    return ((SaisieAntecedentPC)getPC()).isDelaiAttente();
  }
  
  public boolean isDelaiAttente()
  {
    return ((SaisieAntecedentPC)getPC()).isDelaiAttente();
  }
  
  public void setDelaiAttente(boolean p_delaiAttente)
  {
    ((SaisieAntecedentPC)getPC()).setDelaiAttente(p_delaiAttente);
  }
  
  protected String rawGetEtablissementFinanceur()
  {
    return ((SaisieAntecedentPC)getPC()).getEtablissementFinanceur();
  }
  
  public String getEtablissementFinanceur()
  {
    return ((SaisieAntecedentPC)getPC()).getEtablissementFinanceur();
  }
  
  public void setEtablissementFinanceur(String p_etablissementFinanceur)
  {
    if ((m_etablissementFinanceur == null) || (p_etablissementFinanceur == null))
    {
      m_etablissementFinanceur = p_etablissementFinanceur;
      ((SaisieAntecedentPC)getPC()).setEtablissementFinanceur(p_etablissementFinanceur);
    }
    else if ((m_etablissementFinanceur != null) && (p_etablissementFinanceur != null) && (!p_etablissementFinanceur.equals(m_etablissementFinanceur)))
    {
      m_etablissementFinanceur = p_etablissementFinanceur;
      ((SaisieAntecedentPC)getPC()).setEtablissementFinanceur(p_etablissementFinanceur);
    }
  }
  
  protected String rawGetCodeAffectation()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeAffectation();
  }
  
  public String getCodeAffectation()
  {
    return ((SaisieAntecedentPC)getPC()).getCodeAffectation();
  }
  
  public void setCodeAffectation(String p_codeAffectation)
  {
    if ((m_codeAffectation == null) || (p_codeAffectation == null))
    {
      m_codeAffectation = p_codeAffectation;
      ((SaisieAntecedentPC)getPC()).setCodeAffectation(p_codeAffectation);
    }
    else if ((m_codeAffectation != null) && (p_codeAffectation != null) && (!p_codeAffectation.equals(m_codeAffectation)))
    {
      m_codeAffectation = p_codeAffectation;
      ((SaisieAntecedentPC)getPC()).setCodeAffectation(p_codeAffectation);
    }
  }
  
  protected boolean rawIsEstSituationParticuliereAre2001()
  {
    return ((SaisieAntecedentPC)getPC()).isEstSituationParticuliereAre2001();
  }
  
  public boolean isEstSituationParticuliereAre2001()
  {
    return ((SaisieAntecedentPC)getPC()).isEstSituationParticuliereAre2001();
  }
  
  public void setEstSituationParticuliereAre2001(boolean p_estSituationParticuliereAre2001)
  {
    ((SaisieAntecedentPC)getPC()).setEstSituationParticuliereAre2001(p_estSituationParticuliereAre2001);
  }
  
  protected String rawGetMontantReadmissionRetenu()
  {
    return ((SaisieAntecedentPC)getPC()).getMontantReadmissionRetenu();
  }
  
  public String getMontantReadmissionRetenu()
  {
    return ((SaisieAntecedentPC)getPC()).getMontantReadmissionRetenu();
  }
  
  public void setMontantReadmissionRetenu(String p_montantReadmissionRetenu)
  {
    if ((m_montantReadmissionRetenu == null) || (p_montantReadmissionRetenu == null))
    {
      m_montantReadmissionRetenu = p_montantReadmissionRetenu;
      ((SaisieAntecedentPC)getPC()).setMontantReadmissionRetenu(p_montantReadmissionRetenu);
    }
    else if ((m_montantReadmissionRetenu != null) && (p_montantReadmissionRetenu != null) && (!p_montantReadmissionRetenu.equals(m_montantReadmissionRetenu)))
    {
      m_montantReadmissionRetenu = p_montantReadmissionRetenu;
      ((SaisieAntecedentPC)getPC()).setMontantReadmissionRetenu(p_montantReadmissionRetenu);
    }
  }
  
  protected String rawGetIdExterneEmployeurSp()
  {
    return ((SaisieAntecedentPC)getPC()).getIdExterneEmployeurSp();
  }
  
  public String getIdExterneEmployeurSp()
  {
    return ((SaisieAntecedentPC)getPC()).getIdExterneEmployeurSp();
  }
  
  public void setIdExterneEmployeurSp(String p_idExterneEmployeurSp)
  {
    if ((m_idExterneEmployeurSp == null) || (p_idExterneEmployeurSp == null))
    {
      m_idExterneEmployeurSp = p_idExterneEmployeurSp;
      ((SaisieAntecedentPC)getPC()).setIdExterneEmployeurSp(p_idExterneEmployeurSp);
    }
    else if ((m_idExterneEmployeurSp != null) && (p_idExterneEmployeurSp != null) && (!p_idExterneEmployeurSp.equals(m_idExterneEmployeurSp)))
    {
      m_idExterneEmployeurSp = p_idExterneEmployeurSp;
      ((SaisieAntecedentPC)getPC()).setIdExterneEmployeurSp(p_idExterneEmployeurSp);
    }
  }
  
  protected BigDecimal rawGetRevenuMensuelANSConservee()
  {
    return ((SaisieAntecedentPC)getPC()).getRevenuMensuelANSConservee();
  }
  
  public BigDecimal getRevenuMensuelANSConservee()
  {
    return ((SaisieAntecedentPC)getPC()).getRevenuMensuelANSConservee();
  }
  
  public void setRevenuMensuelANSConservee(BigDecimal p_revenuMensuelANSConservee)
  {
    if ((m_revenuMensuelANSConservee == null) || (p_revenuMensuelANSConservee == null))
    {
      m_revenuMensuelANSConservee = p_revenuMensuelANSConservee;
      ((SaisieAntecedentPC)getPC()).setRevenuMensuelANSConservee(p_revenuMensuelANSConservee);
    }
    else if ((m_revenuMensuelANSConservee != null) && (p_revenuMensuelANSConservee != null) && (!p_revenuMensuelANSConservee.equals(m_revenuMensuelANSConservee)))
    {
      m_revenuMensuelANSConservee = p_revenuMensuelANSConservee;
      ((SaisieAntecedentPC)getPC()).setRevenuMensuelANSConservee(p_revenuMensuelANSConservee);
    }
  }
  
  protected Damj rawGetDateAdmission()
  {
    return ((SaisieAntecedentPC)getPC()).getDateAdmission();
  }
  
  public Damj getDateAdmission()
  {
    return ((SaisieAntecedentPC)getPC()).getDateAdmission();
  }
  
  public void setDateAdmission(Damj p_dateAdmission)
  {
    if ((m_dateAdmission == null) || (p_dateAdmission == null))
    {
      m_dateAdmission = p_dateAdmission;
      ((SaisieAntecedentPC)getPC()).setDateAdmission(p_dateAdmission);
    }
    else if ((m_dateAdmission != null) && (p_dateAdmission != null) && (!p_dateAdmission.equals(m_dateAdmission)))
    {
      m_dateAdmission = p_dateAdmission;
      ((SaisieAntecedentPC)getPC()).setDateAdmission(p_dateAdmission);
    }
  }
  
  protected int rawGetNbMoisCivilsNonPayes()
  {
    return ((SaisieAntecedentPC)getPC()).getNbMoisCivilsNonPayes();
  }
  
  public int getNbMoisCivilsNonPayes()
  {
    return ((SaisieAntecedentPC)getPC()).getNbMoisCivilsNonPayes();
  }
  
  public void setNbMoisCivilsNonPayes(int p_nbMoisCivilsNonPayes)
  {
    ((SaisieAntecedentPC)getPC()).setNbMoisCivilsNonPayes(p_nbMoisCivilsNonPayes);
  }
  
  protected String rawGetContexteLimiteIndemnisation()
  {
    return ((SaisieAntecedentPC)getPC()).getContexteLimiteIndemnisation();
  }
  
  public String getContexteLimiteIndemnisation()
  {
    return ((SaisieAntecedentPC)getPC()).getContexteLimiteIndemnisation();
  }
  
  public void setContexteLimiteIndemnisation(String p_contexteLimiteIndemnisation)
  {
    if ((m_contexteLimiteIndemnisation == null) || (p_contexteLimiteIndemnisation == null))
    {
      m_contexteLimiteIndemnisation = p_contexteLimiteIndemnisation;
      ((SaisieAntecedentPC)getPC()).setContexteLimiteIndemnisation(p_contexteLimiteIndemnisation);
    }
    else if ((m_contexteLimiteIndemnisation != null) && (p_contexteLimiteIndemnisation != null) && (!p_contexteLimiteIndemnisation.equals(m_contexteLimiteIndemnisation)))
    {
      m_contexteLimiteIndemnisation = p_contexteLimiteIndemnisation;
      ((SaisieAntecedentPC)getPC()).setContexteLimiteIndemnisation(p_contexteLimiteIndemnisation);
    }
  }
  
  protected Damj rawGetDateLimite()
  {
    return ((SaisieAntecedentPC)getPC()).getDateLimite();
  }
  
  public Damj getDateLimite()
  {
    return ((SaisieAntecedentPC)getPC()).getDateLimite();
  }
  
  public void setDateLimite(Damj p_dateLimite)
  {
    if ((m_dateLimite == null) || (p_dateLimite == null))
    {
      m_dateLimite = p_dateLimite;
      ((SaisieAntecedentPC)getPC()).setDateLimite(p_dateLimite);
    }
    else if ((m_dateLimite != null) && (p_dateLimite != null) && (!p_dateLimite.equals(m_dateLimite)))
    {
      m_dateLimite = p_dateLimite;
      ((SaisieAntecedentPC)getPC()).setDateLimite(p_dateLimite);
    }
  }
  
  protected boolean rawIsEntreeCra()
  {
    return ((SaisieAntecedentPC)getPC()).isEntreeCra();
  }
  
  public boolean isEntreeCra()
  {
    return ((SaisieAntecedentPC)getPC()).isEntreeCra();
  }
  
  public void setEntreeCra(boolean p_entreeCra)
  {
    ((SaisieAntecedentPC)getPC()).setEntreeCra(p_entreeCra);
  }
  
  protected QuantiteEuro rawGetMontantCra()
  {
    return ((SaisieAntecedentPC)getPC()).getMontantCra();
  }
  
  public QuantiteEuro getMontantCra()
  {
    return ((SaisieAntecedentPC)getPC()).getMontantCra();
  }
  
  public void setMontantCra(QuantiteEuro p_montantCra)
  {
    if ((m_montantCra == null) || (p_montantCra == null))
    {
      m_montantCra = p_montantCra;
      ((SaisieAntecedentPC)getPC()).setMontantCra(p_montantCra);
    }
    else if ((m_montantCra != null) && (p_montantCra != null) && (!p_montantCra.equals(m_montantCra)))
    {
      m_montantCra = p_montantCra;
      ((SaisieAntecedentPC)getPC()).setMontantCra(p_montantCra);
    }
  }
  
  protected QuantiteEuro rawGetSjmCra()
  {
    return ((SaisieAntecedentPC)getPC()).getSjmCra();
  }
  
  public QuantiteEuro getSjmCra()
  {
    return ((SaisieAntecedentPC)getPC()).getSjmCra();
  }
  
  public void setSjmCra(QuantiteEuro p_sjmCra)
  {
    if ((m_sjmCra == null) || (p_sjmCra == null))
    {
      m_sjmCra = p_sjmCra;
      ((SaisieAntecedentPC)getPC()).setSjmCra(p_sjmCra);
    }
    else if ((m_sjmCra != null) && (p_sjmCra != null) && (!p_sjmCra.equals(m_sjmCra)))
    {
      m_sjmCra = p_sjmCra;
      ((SaisieAntecedentPC)getPC()).setSjmCra(p_sjmCra);
    }
  }
  
  protected int rawGetFranchiseCPTotale()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseCPTotale();
  }
  
  public int getFranchiseCPTotale()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseCPTotale();
  }
  
  public void setFranchiseCPTotale(int p_franchiseCPTotale)
  {
    ((SaisieAntecedentPC)getPC()).setFranchiseCPTotale(p_franchiseCPTotale);
  }
  
  protected int rawGetFranchiseCPMensuelle()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseCPMensuelle();
  }
  
  public int getFranchiseCPMensuelle()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseCPMensuelle();
  }
  
  public void setFranchiseCPMensuelle(int p_franchiseCPMensuelle)
  {
    ((SaisieAntecedentPC)getPC()).setFranchiseCPMensuelle(p_franchiseCPMensuelle);
  }
  
  protected int rawGetFranchiseSalaireTotale()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseSalaireTotale();
  }
  
  public int getFranchiseSalaireTotale()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseSalaireTotale();
  }
  
  public void setFranchiseSalaireTotale(int p_franchiseSalaireTotale)
  {
    ((SaisieAntecedentPC)getPC()).setFranchiseSalaireTotale(p_franchiseSalaireTotale);
  }
  
  protected int rawGetFranchiseSalaireMensuelle()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseSalaireMensuelle();
  }
  
  public int getFranchiseSalaireMensuelle()
  {
    return ((SaisieAntecedentPC)getPC()).getFranchiseSalaireMensuelle();
  }
  
  public void setFranchiseSalaireMensuelle(int p_franchiseSalaireMensuelle)
  {
    ((SaisieAntecedentPC)getPC()).setFranchiseSalaireMensuelle(p_franchiseSalaireMensuelle);
  }
  
  protected boolean rawIsSortieCra()
  {
    return ((SaisieAntecedentPC)getPC()).isSortieCra();
  }
  
  public boolean isSortieCra()
  {
    return ((SaisieAntecedentPC)getPC()).isSortieCra();
  }
  
  public void setSortieCra(boolean p_sortieCra)
  {
    ((SaisieAntecedentPC)getPC()).setSortieCra(p_sortieCra);
  }
  
  protected int rawGetReliquatFCPDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatFCPDJC();
  }
  
  public int getReliquatFCPDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatFCPDJC();
  }
  
  public void setReliquatFCPDJC(int p_reliquatFCPDJC)
  {
    ((SaisieAntecedentPC)getPC()).setReliquatFCPDJC(p_reliquatFCPDJC);
  }
  
  protected int rawGetReliquatFSDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatFSDJC();
  }
  
  public int getReliquatFSDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatFSDJC();
  }
  
  public void setReliquatFSDJC(int p_reliquatFSDJC)
  {
    ((SaisieAntecedentPC)getPC()).setReliquatFSDJC(p_reliquatFSDJC);
  }
  
  protected int rawGetQuantiteFCPConsoDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteFCPConsoDJC();
  }
  
  public int getQuantiteFCPConsoDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteFCPConsoDJC();
  }
  
  public void setQuantiteFCPConsoDJC(int p_quantiteFCPConsoDJC)
  {
    ((SaisieAntecedentPC)getPC()).setQuantiteFCPConsoDJC(p_quantiteFCPConsoDJC);
  }
  
  protected int rawGetQuantiteFSConsoDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteFSConsoDJC();
  }
  
  public int getQuantiteFSConsoDJC()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteFSConsoDJC();
  }
  
  public void setQuantiteFSConsoDJC(int p_quantiteFSConsoDJC)
  {
    ((SaisieAntecedentPC)getPC()).setQuantiteFSConsoDJC(p_quantiteFSConsoDJC);
  }
  
  protected int rawGetQuantiteReportFCP()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteReportFCP();
  }
  
  public int getQuantiteReportFCP()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteReportFCP();
  }
  
  public void setQuantiteReportFCP(int p_quantiteReportFCP)
  {
    ((SaisieAntecedentPC)getPC()).setQuantiteReportFCP(p_quantiteReportFCP);
  }
  
  protected int rawGetQuantiteReportFS()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteReportFS();
  }
  
  public int getQuantiteReportFS()
  {
    return ((SaisieAntecedentPC)getPC()).getQuantiteReportFS();
  }
  
  public void setQuantiteReportFS(int p_quantiteReportFS)
  {
    ((SaisieAntecedentPC)getPC()).setQuantiteReportFS(p_quantiteReportFS);
  }
  
  protected int rawGetDureeAllongementAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getDureeAllongementAREF();
  }
  
  public int getDureeAllongementAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getDureeAllongementAREF();
  }
  
  public void setDureeAllongementAREF(int p_dureeAllongementAREF)
  {
    ((SaisieAntecedentPC)getPC()).setDureeAllongementAREF(p_dureeAllongementAREF);
  }
  
  protected int rawGetReliquatDureeAllongementAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDureeAllongementAREF();
  }
  
  public int getReliquatDureeAllongementAREF()
  {
    return ((SaisieAntecedentPC)getPC()).getReliquatDureeAllongementAREF();
  }
  
  public void setReliquatDureeAllongementAREF(int p_reliquatDureeAllongementAREF)
  {
    ((SaisieAntecedentPC)getPC()).setReliquatDureeAllongementAREF(p_reliquatDureeAllongementAREF);
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     SaisieAntecedentGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */