package fr.unedic.cali.asu.eur05.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.AttributionARISpec;
import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.asu.eur05.p01.liquidation.dom.MontantSegmentation;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;

public class OutilCalculDonneesNonPersistantes
  implements OutilFonctionnel
{
  private static final DureeCalendaire DECALAGE_DATE_LIMITE_INDEMNISATION = new DureeCalendaire(0, 3, 0);
  private static final BigDecimal NB_JOURS_SEMAINE = new BigDecimal(7);
  private static final BigDecimal NB_JOURS_ANNEE = new BigDecimal(365);
  private static final BigDecimal NB_JOURS_MOIS = new BigDecimal(12);
  private static final int CODE_ERREUR_POUR_NOMBRE = -1;
  private static final int NB_DECIMALES_ARRONDI = 2;
  
  public static Collection recupererCollectionElementDroit(Demande p_demande)
  {
    return ((AttributionARISpec)p_demande.getDossierExamen()).getCollectionElementsDroits();
  }
  
  public static Damj trouverPji(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "PJI" });
    if (eltDroit != null) {
      return eltDroit.getDate1Generique();
    }
    return null;
  }
  
  public static Damj trouverDji(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DJI" });
    if (eltDroit != null) {
      return eltDroit.getDate1Generique();
    }
    return null;
  }
  
  public static String trouverPaysOrigine(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "PAYS_ORIGINE" });
    if (eltDroit != null) {
      return eltDroit.getStringGenerique();
    }
    return null;
  }
  
  public static Damj trouverDateDebutPrestationPossible(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DATE_DEBUT_PRESTATION" });
    if (eltDroit != null) {
      return eltDroit.getDate1Generique();
    }
    return null;
  }
  
  public static int trouverNbJoursSemaine(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "NB_JOURS_SEMAINE" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      return eltDroit.getQuantiteGenerique().getValeurEntiere();
    }
    return -1;
  }
  
  public static int trouverNbJoursMois(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "NB_JOURS_MOIS" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      return eltDroit.getQuantiteGenerique().getValeurEntiere();
    }
    return -1;
  }
  
  public static int trouverNbJoursReliquat(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "NB_JOURS_RELIQUAT" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      return eltDroit.getQuantiteGenerique().getValeurEntiere();
    }
    return -1;
  }
  
  public static BigDecimal trouverMontantJournalier(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "MONTANT_JOURNALIER" });
    if (eltDroit.getQuantiteGenerique() != null)
    {
      BigDecimal montant = eltDroit.getQuantiteGenerique().getValeur();
      return Mathematiques.arrondiASup(montant, 2);
    }
    return new BigDecimal(-1);
  }
  
  public static BigDecimal trouverMontantJournalierCalcule(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "MONTANT_J_CALCULE" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      BigDecimal montant = eltDroit.getQuantiteGenerique().getValeur();
      return Mathematiques.arrondiASup(montant, 2);
    }
    return new BigDecimal(-1);
  }
  
  public static BigDecimal trouverMontantJournalierChangementTaux(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "MT_JOURNALIER_CHANGEMENT_TAUX" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      BigDecimal montant = eltDroit.getQuantiteGenerique().getValeur();
      return Mathematiques.arrondiASup(montant, 2);
    }
    return new BigDecimal(-1);
  }
  
  public static Damj trouverDateChangementTauxConv(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DATE_CHANGEMENT_TAUX_CONVERSION" });
    if (eltDroit != null) {
      return eltDroit.getDate1Generique();
    }
    return null;
  }
  
  public static Damj trouverDateExamen(Demande p_demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DATE_EXAMEN" });
    if (eltDroit != null) {
      return eltDroit.getDate1Generique();
    }
    return null;
  }
  
  public static Collection calculerListeMontantSegmentation(Demande p_demande)
    throws CoucheLogiqueException
  {
    ArrayList listeMtSegment = new ArrayList();
    
    Damj pji = trouverPji(p_demande);
    BigDecimal montant = trouverMontantJournalier(p_demande);
    if ((pji != null) && (montant.intValue() != -1))
    {
      MontantSegmentation mtSegment = new MontantSegmentation(pji, new QuantiteEuro(montant));
      listeMtSegment.add(mtSegment);
    }
    Damj dateChangementTauxConv = trouverDateChangementTauxConv(p_demande);
    BigDecimal montantChangementTauxConv = trouverMontantJournalierChangementTaux(p_demande);
    if ((dateChangementTauxConv != null) && (montantChangementTauxConv != null))
    {
      MontantSegmentation mtSegment = new MontantSegmentation(dateChangementTauxConv, new QuantiteEuro(montantChangementTauxConv));
      listeMtSegment.add(mtSegment);
    }
    return listeMtSegment;
  }
  
  public static Damj calculerDateLimiteIndemnisation(Damj p_ddpp)
  {
    Damj dateLimiteIndem = null;
    if (p_ddpp != null) {
      dateLimiteIndem = p_ddpp.deplacerVersAvant(DECALAGE_DATE_LIMITE_INDEMNISATION).veille();
    }
    return dateLimiteIndem;
  }
  
  public static Damj calculerDateLimiteIndemnisation(Demande p_demande)
    throws CoucheLogiqueException
  {
    Damj dateLimiteIndem = null;
    Collection listeEltDroit = recupererCollectionElementDroit(p_demande);
    Damj ddpp = null;
    ElementDroit eltDdpp = OutilElementDroit.rechercherElement(listeEltDroit, new String[] { "DATE_DEBUT_PRESTATION" });
    if (eltDdpp != null) {
      ddpp = eltDdpp.getDate1Generique();
    }
    if (ddpp != null) {
      dateLimiteIndem = calculerDateLimiteIndemnisation(ddpp);
    }
    return dateLimiteIndem;
  }
  
  public static int calculerDureeIndemnisation(Demande p_demande)
    throws CoucheLogiqueException
  {
    int dureeIndemnisation = 0;
    
    Collection collectionElementDroit = recupererCollectionElementDroit(p_demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "NB_JOURS_RELIQUAT" });
    
    boolean isReliquatSaisi = eltDroit != null;
    
    Damj dateLimiteIndemnisation = calculerDateLimiteIndemnisation(p_demande);
    Damj pji = trouverPji(p_demande);
    int dureeEntrePjiEtDateLimiteIndemnisation = 0;
    if ((dateLimiteIndemnisation != null) && (pji != null)) {
      dureeEntrePjiEtDateLimiteIndemnisation = pji.joursEntre(dateLimiteIndemnisation.lendemain());
    }
    int dureeIndemnisationCalculee = 0;
    BigDecimal duree = null;
    if (isReliquatSaisi)
    {
      BigDecimal frequenceIndemnisation = calculerFrequenceIndemnisation(p_demande);
      
      BigDecimal coeff = Mathematiques.diviseParDefaut(new BigDecimal(1), frequenceIndemnisation);
      
      BigDecimal nbJoursReliquat = eltDroit.getQuantiteGenerique().getValeur();
      duree = nbJoursReliquat.multiply(coeff);
      dureeIndemnisationCalculee = duree.intValue();
      
      dureeIndemnisation = Math.min(dureeIndemnisationCalculee, dureeEntrePjiEtDateLimiteIndemnisation);
    }
    else
    {
      dureeIndemnisation = dureeEntrePjiEtDateLimiteIndemnisation;
    }
    return dureeIndemnisation;
  }
  
  private static BigDecimal calculerFrequenceIndemnisation(Demande p_demande)
    throws CoucheLogiqueException
  {
    BigDecimal nbJoursSemaine = new BigDecimal(trouverNbJoursSemaine(p_demande));
    BigDecimal nbJoursMois = new BigDecimal(trouverNbJoursMois(p_demande));
    
    BigDecimal frequenceIndemnisation = new BigDecimal(1);
    if (nbJoursSemaine.intValue() != -1) {
      frequenceIndemnisation = Mathematiques.diviseParDefaut(nbJoursSemaine, NB_JOURS_SEMAINE);
    }
    if (nbJoursMois.intValue() != -1) {
      frequenceIndemnisation = Mathematiques.diviseParDefaut(nbJoursMois.multiply(NB_JOURS_MOIS), NB_JOURS_ANNEE);
    }
    return frequenceIndemnisation;
  }
}

/* Location:
 * Qualified Name:     OutilCalculDonneesNonPersistantes
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */