package fr.unedic.cali.asu.exp03.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilTraitementReliquat;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;

public class DeterminationDureeReglementaire
  implements OutilFonctionnel
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  
  public static DeterminationDureeReglementaire getInstance()
  {
    return new DeterminationDureeReglementaire();
  }
  
  public DureeIndemnisation determinerDureeReglementaire(Demande p_demande)
    throws CoucheLogiqueException
  {
    DureeIndemnisation dureeIndemnisation = null;
    
    int dureeTheoriqueDroitCourant = determinerDureeReglementaireDroitCourant(p_demande);
    Quantite qteDureeTheorique = new Quantite(dureeTheoriqueDroitCourant, DureeReglementaire.UNITE_DEFAUT);
    
    Quantite qteDureeImputationDroitCourant = OutilTraitementReliquat.determinerDureeImputationFormationDroitCourant(p_demande.getDossierAffectation().getProduit(), p_demande, qteDureeTheorique, OutilTraitementReliquat.determinerPeriodeImputationFormationDroitCourant(p_demande, p_demande.getDateExamen().veille()), dureeTheoriqueDroitCourant);
    
    qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputationDroitCourant);
    
    int dureeImputationDroitCourant = 0;
    Quantite qteDureeImputation = new Quantite(dureeImputationDroitCourant, DureeReglementaire.UNITE_DEFAUT);
    if (p_demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteDureeImputation = new Quantite(p_demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputation);
    }
    ConstitutionDurees constitutionDurees = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionElementsActifs().getConstitutionDurees();
    
    dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
    dureeIndemnisation.setDureeImputation(qteDureeImputationDroitCourant);
    
    Quantite qteTotalJourImputation = qteDureeImputationDroitCourant.ajouter(qteDureeImputation);
    dureeIndemnisation.setQuantiteTotalJourImputation(qteTotalJourImputation);
    dureeIndemnisation.setQuantiteJourImputationForce(qteDureeImputation);
    
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeReglementairePourRepriseRevision(Demande p_demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    ConstitutionDurees constitutionDurees = dossierExamen.getConstitutionDurees();
    
    Quantite qteNbJourImputer = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    Reliquat reliquat = p_demande.getReliquat();
    Quantite quantiteReliquat = new Quantite(reliquat.getQuantiteReliquat().getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    if (p_demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteNbJourImputer = new Quantite(p_demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      quantiteReliquat = quantiteReliquat.soustraire(qteNbJourImputer);
    }
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    Quantite qteTotalJourImputation = reliquat.getQuantiteImputee().ajouter(qteNbJourImputer);
    dureeIndemnisation.setQuantiteJourImputationForce(qteNbJourImputer);
    dureeIndemnisation.setQuantiteTotalJourImputation(qteTotalJourImputation);
    dureeIndemnisation.setDureeTheorique(quantiteReliquat);
    dureeIndemnisation.setDureeImputation(qteTotalJourImputation);
    
    dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(p_demande.getDemandeur(), dossierExamen.getDateAttribution(), quantiteReliquat, DureeReglementaire.UNITE_DEFAUT, true));
    
    return dureeIndemnisation;
  }
  
  private int determinerDureeReglementaireDroitCourant(Demande p_demande)
  {
    IndividuSpec individu = p_demande.getDemandeur();
    
    FaitGenerateurSpec faitGenerateur = p_demande.getFaitGenerateur();
    Damj dateFG = faitGenerateur.getDateFaitGenerateur();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    JustificationAffiliationSpec justification = dossierExamen.getJustificationAffiliation();
    Pra pra;
    Pra pra;
    if ("justifCGENouveauModele".equals(justification.getTypeJustificationAffiliation())) {
      pra = (Pra)((fr.unedic.cali.asu.dom.JustificationAffiliation)justification).getPeriodeRechercheAffiliation();
    } else {
      pra = ((fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justification).getPeriodePraRetenue();
    }
    DureeCalendaire ageFG = individu.getAgeALaDate(dateFG);
    int codeAge = determinerCodeAge(ageFG.getAnnees());
    
    int codeCentTrimestres = 0;
    if ((p_demande.getDemandeur().getDateCentTrimestres() != null) && 
      (p_demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(dateFG))) {
      codeCentTrimestres = 1;
    }
    CleAccesDureeDroit cle = new CleAccesDureeDroit(codeAge, codeCentTrimestres);
    
    DureeDroitPourPRA duree = pra.getDureeDroit(cle);
    int dureeTheoriqueDroitCourant = duree.getDuree();
    
    return dureeTheoriqueDroitCourant;
  }
  
  private static int determinerCodeAge(int p_ageDemandeurAuFg)
  {
    if (p_ageDemandeurAuFg < 50) {
      return 1;
    }
    if (p_ageDemandeurAuFg >= 57) {
      return 3;
    }
    return 2;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */