package fr.unedic.cali.asu.exp03.p01.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRA
  implements ParametrageListePRASpec
{
  private static final int PRA_72_MOIS = 72;
  private static final int PRA_48_MOIS = 48;
  private static final int PRA_24_MOIS = 24;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int SUP_EGAL_50ANS = 2;
  private static final int SUP_EGAL_57ANS = 3;
  public static final int DUREE_DROIT_1277 = 1277;
  private static final int DUREE_DROIT_912 = 912;
  private static final int DUREE_DROIT_546 = 546;
  private static final int CENT_TRIMESTRES_ACQUIS = 1;
  private Collection m_listePRA;
  private static ParametrageListePRA s_instance;
  
  public static ParametrageListePRA getInstance()
  {
    if (s_instance == null) {
      s_instance = new ParametrageListePRA();
    }
    return s_instance;
  }
  
  private ParametrageListePRA()
  {
    initInstance();
  }
  
  private void initInstance()
  {
    m_listePRA = new ArrayList();
    
    initInstanceA9B();
  }
  
  public List getListePra(CleAccesPRA p_cle)
  {
    List resultatListePRA = new ArrayList();
    
    Iterator it = m_listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(p_cle)) {
        resultatListePRA.add(pra.copie());
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceA9B()
  {
    Pra pra = new Pra("A9B", new int[] { 3 }, 72, 3, 1, 1);
    pra.setArticle3("i");
    positionnerQuantiteAffiliationRequise(pra, 1642, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1094, "jour d'affiliation");
    positionnerDureeDroit(pra, 1277, 1);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9B", new int[] { 2, 3 }, 48, 2, 2);
    pra.setArticle3("h");
    positionnerQuantiteAffiliationRequise(pra, 1095, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 730, "jour d'affiliation");
    positionnerDureeDroit(pra, 912, 2);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9B", 24, 1, 3);
    pra.setArticle3("g");
    positionnerQuantiteAffiliationRequise(pra, 546, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 365, "jour d'affiliation");
    positionnerDureeDroit(pra, 546, 3);
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra p_pra)
  {
    m_listePRA.add(p_pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra p_pra, int p_quantite, String p_uniteAffiliation)
  {
    Unite unite = Unite.get(p_uniteAffiliation);
    Quantite quantite = new Quantite(p_quantite, unite);
    p_pra.getListeQuantitesAffiliationRequises().put(unite, quantite);
  }
  
  private void positionnerQuantiteAssimilationMax(Pra p_pra, int p_quantite, String p_uniteAffiliation)
  {
    Unite unite = Unite.get(p_uniteAffiliation);
    Quantite quantite = new Quantite(p_quantite, unite);
    p_pra.getListeQuantitesAssimilationMaximales().put(unite, quantite);
  }
  
  private void positionnerDureeDroit(Pra p_pra, int p_duree, int p_ordre)
  {
    positionnerDureeDroit(p_pra, p_duree, p_ordre, -1, -1);
  }
  
  private void positionnerDureeDroit(Pra p_pra, int p_duree, int p_ordre, int p_codeAge, int p_nombreTrimestre)
  {
    DureeDroitPourPRA duree = new DureeDroitPourPRA(p_duree, p_ordre);
    
    CleAccesDureeDroit cle = new CleAccesDureeDroit(p_codeAge, p_nombreTrimestre);
    
    duree.setCleAcces(cle);
    
    p_pra.ajouterDureeDroit(duree);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */