package fr.unedic.cali.asu.liquidation.antecedent;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.List;

public class VerificationDonneesSaisieAntecedentMayotte
  implements VerificationDonneesSaisieAntecedentSpec
{
  private static final Integer ZERO = Integer.valueOf(0);
  private static final Integer MAX_DELAI_ATTENTE = Integer.valueOf(7);
  private static final Integer MAX_ISLR = Integer.valueOf(180);
  private static final BigDecimal BD_ZERO = new BigDecimal("0");
  private static final BigDecimal BD_UN = new BigDecimal("1");
  private static final Damj DATE_ATTRIB_ANTECEDENT_MAYOTTE = new Damj(2013, 1, 2);
  private static final int AGE_MAINTIEN = 60;
  
  public static VerificationDonneesSaisieAntecedentMayotte getInstance()
  {
    return new VerificationDonneesSaisieAntecedentMayotte();
  }
  
  public void verifierDonneesForcees(Demande demande, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((saisieAntecedent == null) || (saisieAntecedent.getCodeProduit() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_CODE_PRODUIT");
    }
    verifierDonneesContexte(saisieAntecedent);
    
    verifierDonneesConstituants(saisieAntecedent, demande);
    
    verifierDonneesReliquat(saisieAntecedent, demande, dateTraitement);
  }
  
  private static void verifierDonneesContexte(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getCodeProduit() == null) || (saisieAntecedent.getCodeProduit().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_PRODUIT");
    }
    if ((saisieAntecedent.getContexteDemande() == null) || (saisieAntecedent.getContexteDemande().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_CONTEXTE");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(8)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_MAYOTTE");
    }
  }
  
  private static void verifierDonneesConstituants(SaisieAntecedent saisieAntecedent, Demande demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    ActiviteSalarie faitGenerateur = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFaitGenerateur());
    
    ActiviteSalarie periodeCompetence = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantCompetence());
    if (faitGenerateur == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FGD_INCONNUE");
    }
    if ((saisieAntecedent.getDateAttribution() == null) || (saisieAntecedent.getDateAttribution().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DTE_ATTRIB");
    }
    if (fctRetenue == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FCT_INCONNUE");
    }
    if ((saisieAntecedent.getIdentifiantCompetence() != null) && (periodeCompetence == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FCT_COMPETENCE_INCONNUE");
    }
    if ((fctRetenue.getDateFin() != null) && (faitGenerateur.getDateFin() != null) && (fctRetenue.getDateFin().estApres(faitGenerateur.getDateFin()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FCT");
    }
    if (saisieAntecedent.getCodeProduit().intValue() == 1) {
      if (saisieAntecedent.getDureeInitialeDroit() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DUREE_INIT");
      } else if (saisieAntecedent.getDureeInitialeDroit().getValeur().equals(BD_ZERO)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE");
      }
    }
    if ((saisieAntecedent.getDateAttribution() != null) && (fctRetenue != null) && (saisieAntecedent.getDateAttribution().estAvant(fctRetenue.getDateFin()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB");
    }
    verifierDonneesConstituantsCG(saisieAntecedent, faitGenerateur, periodeCompetence);
  }
  
  private static void verifierDonneesConstituantsCG(SaisieAntecedent saisieAntecedent, ActiviteSalarie faitGenerateur, PeriodeGaecSpec periodeCompetence)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateAttribution().estAvant(DATE_ATTRIB_ANTECEDENT_MAYOTTE))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB_MIN");
    }
    if (faitGenerateur != null)
    {
      if (!faitGenerateur.isEstPeriodeMayotte()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_CHAMP_APPLICATION");
      }
      if (!faitGenerateur.getDateFin().estApresOuCoincideAvec(DATE_ATTRIB_ANTECEDENT_MAYOTTE.veille())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DATE_FGD_MAYOTTE");
      }
      if ((periodeCompetence != null) && (periodeCompetence.getDateFin().estApres(faitGenerateur.getDateFin()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FCT_FINANCIERE");
      }
    }
    if (saisieAntecedent.getSalaireJournalierReferencePlafonne() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_SJRP");
    }
    if ((saisieAntecedent.getTermePRC() == null) || (saisieAntecedent.getTermePRC().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_FIN_PRC");
    }
    if ((saisieAntecedent.getDateDebutPRC() == null) || (saisieAntecedent.getDateDebutPRC().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DEBUT_PRC");
    }
    if ((saisieAntecedent.getDateDebutPRC() != null) && (saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getTermePRC().estAvant(saisieAntecedent.getDateDebutPRC()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_CORH_PRC");
    }
    if ((saisieAntecedent.getCoefficientTempsPartiel() != null) && ((saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_UN) > 0) || (saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_ZERO) <= 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_COEF_TP");
    }
    if ((saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getTermePRC().estApresOuCoincideAvec(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PRC_DATE_ATTRIB");
    }
  }
  
  private static void verifierDonneesReliquat(SaisieAntecedent saisieAntecedent, Demande demande, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getDateDernierJourCalcule() == null) || (saisieAntecedent.getDateDernierJourCalcule().equals(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DJC");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (dateTraitement != null) && (saisieAntecedent.getDateDernierJourCalcule().estApres(dateTraitement))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_SP_FIN_DROIT");
    }
    if ((!saisieAntecedent.estAntecedentAsp()) && ((saisieAntecedent.getPremierJourIndemnisable() == null) || (saisieAntecedent.getPremierJourIndemnisable().equals(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_PJI");
    }
    if ((saisieAntecedent.getReliquatDuree() == null) && ((saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursICCP() == null) || (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursISLR() == null) || (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_RELIQUAT_DUREE");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateDernierJourCalcule().estAvant(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_COHR_DJC");
    }
    if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estApres(saisieAntecedent.getDateDernierJourCalcule())) && ((saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursICCP() == null) || (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJourDiffereStandard() == null) || (saisieAntecedent.getReliquatJourDiffereStandard().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursISLR() == null) || (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) == 0)) && (saisieAntecedent.getDateFinPMC() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PJI_DELAI");
    }
    if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estAvant(saisieAntecedent.getDateDernierJourCalcule())) && (((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursICCP() != null) && (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJourDiffereStandard() != null) && (saisieAntecedent.getReliquatJourDiffereStandard().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) > 0)) || (saisieAntecedent.getDateFinPMC() != null))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PJI");
    }
    if ((saisieAntecedent.getNombreJourIndemniseARE() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseARE().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_ARE");
    }
    if ((saisieAntecedent.getNombreJourIndemniseAREF() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseAREF().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_AREF");
    }
    if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estApres(saisieAntecedent.getDateDernierJourCalcule())) && (saisieAntecedent.getNombreJourIndemniseAREF() != null) && (saisieAntecedent.getNombreJourIndemniseAREF().compareTo(ZERO) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_AREF_2");
    }
    if ((saisieAntecedent.getReliquatDuree() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getReliquatDuree().compareTo(saisieAntecedent.getDureeInitialeDroit()) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_RELIQUAT_DUREE");
    }
    if ((saisieAntecedent.getDateFinPMC() != null) && (!saisieAntecedent.getDateFinPMC().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateAttribution() != null) && (!saisieAntecedent.getDateAttribution().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateFinPMC().estAvant(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PMC");
    }
    if ((saisieAntecedent.getDateFinPMC() != null) && (!saisieAntecedent.getDateFinPMC().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (!saisieAntecedent.getDateDernierJourCalcule().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateFinPMC().estAvantOuCoincideAvec(saisieAntecedent.getDateDernierJourCalcule()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PMC_DJC");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(MAX_DELAI_ATTENTE) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DELAI_ATTENTE");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().intValue() != 0) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(MAX_DELAI_ATTENTE) < 0) && (((saisieAntecedent.getReliquatJoursICCP() != null) && (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) > 0)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTE_COHR_DELAI_ATTENTE_DELAIS");
    }
    if ((saisieAntecedent.isEstEnFormationAuDJC()) && ((saisieAntecedent.getNombreJourIndemniseAREF() == null) || (saisieAntecedent.getNombreJourIndemniseAREF().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FORMATION_DJC");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (!saisieAntecedent.isDelaiAttente())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DELAI_ATTENTE_2");
    }
    if ((saisieAntecedent.isEstDroitMaintenu()) && (saisieAntecedent.getDateDernierJourCalcule() != null))
    {
      DureeCalendaire ageDateOuvertureDroit = demande.getDemandeur().getAgeALaDate(saisieAntecedent.getDateDernierJourCalcule());
      if (ageDateOuvertureDroit.getAnnees() < 60) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AGE_MAINTENU");
      }
    }
    verifierDonneesReliquatCG(saisieAntecedent);
  }
  
  private static void verifierDonneesReliquatCG(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if (saisieAntecedent.getCumulMoisActiviteReduite() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_CUMUL_AR");
    }
    if ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(MAX_ISLR) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_ISLR");
    }
  }
  
  public void verifierDonneesForceesPostLiquidation(Demande demande)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)dossierAffectation.getValidationProduit().getProduitValide();
    
    BigDecimal dureeMaximale = produit.determinerDureeMaximumPourProduit();
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((saisieAntecedent.getCodeProduit().intValue() == 1) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_CG");
    }
    verifierDonneesForceesPensionInvaliditePostLiquidation(demande);
  }
  
  public void verifierDonneesForceesPensionInvaliditePostLiquidation(Demande demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    if (!produit.estProduitGerantPensionInvalidite(demande))
    {
      DonneesTemporaires donneesTemporaires = demande.getDonneesTemporaires();
      if ((donneesTemporaires.getListPensionInvalidite() != null) && (donneesTemporaires.getListPensionInvalidite().size() != 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_N_PENSION_INVALIDITE_NON_GERE", 1);
      }
    }
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesSaisieAntecedentMayotte
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */