package fr.unedic.cali.asu.liquidation.pnds;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.liquidation.pnds.dom.CriteresStrategiePNDS;
import fr.unedic.cali.asu.liquidation.pnds.outilsfonctionnels.FabriqueStrategiePNDS;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIntersectionPeriode;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.OutilOptimisationChronologie;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilDeterminationPNDS
{
  public static PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec individu, ActiviteSalarie activite, Damj dateDebut, Damj dateFin, Damj dateDeterminationPNDS, Damj dateExamen)
    throws ApplicativeException
  {
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\tDétermination des PNDS pour l'activité : ", activite });
    
    PeriodeNonDeclareeSanction resultat = PeriodeNonDeclareeSanction.creerInstance();
    resultat.setPeriodeActivite(activite);
    if (individu.estPndsActive())
    {
      Damj dateMaxRechercheMoisCivil = dateFin;
      if (dateExamen != null)
      {
        dateMaxRechercheMoisCivil = Damj.min(dateExamen.getFinMois(), dateFin);
      }
      else
      {
        Damj dateTheoriqueRetraite = OutilRetraite.getInstance().determinerRetraite(individu).getDate();
        if (dateTheoriqueRetraite != null) {
          dateMaxRechercheMoisCivil = Damj.min(dateTheoriqueRetraite.getFinMois(), dateFin);
        }
      }
      List listeMoisCivils = determinerMoisCivilsSurPeriode(dateDebut, dateMaxRechercheMoisCivil);
      Iterator itMoisCivils = listeMoisCivils.iterator();
      while (itMoisCivils.hasNext())
      {
        Periode moisCivilCourant = (Periode)itMoisCivils.next();
        
        int population = determinerPopulationIndividu(individu, moisCivilCourant.getDebut());
        
        CriteresStrategiePNDS criteres = CriteresStrategiePNDS.creerInstance(dateDeterminationPNDS, population, dateExamen);
        
        StrategiePNDSSpec strategieDeterminationPNDSSurMoisCivil = FabriqueStrategiePNDS.determinerStrategiePNDS(criteres);
        
        PeriodeNonDeclareeSanction pndsSurMoisCivil = strategieDeterminationPNDSSurMoisCivil.determinerPNDS(individu, activite, moisCivilCourant.getDebut(), moisCivilCourant.getFin(), dateExamen);
        if (pndsSurMoisCivil != null) {
          resultat.ajouterChronologiePeriode(pndsSurMoisCivil.getChronoPeriodePNDS());
        }
      }
      resultat.fusionnerChevauchementPeriode();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\tPNDS déterminées pour l'activité : ", resultat });
    return resultat;
  }
  
  public static Collection determinerPNDS(IndividuSpec p_individu, Collection p_listeAttributions, Damj p_dateDebut, Damj p_dateFin, Damj p_dateDeterminationPNDS, Damj dateExamen)
    throws ApplicativeException
  {
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\tDétermination des PNDS pour la liste d'attribution : ", p_listeAttributions });
    
    Collection resultat = new ArrayList();
    if (p_individu.estPndsActive())
    {
      Map mapPNDS = new HashMap();
      PeriodeNonDeclareeSanction pndsPourToutesActivites = PeriodeNonDeclareeSanction.creerInstance();
      
      List listeMoisCivils = determinerMoisCivilsSurPeriode(p_dateDebut, p_dateFin);
      Iterator itMoisCivils = listeMoisCivils.iterator();
      while (itMoisCivils.hasNext())
      {
        Periode moisCivilCourant = (Periode)itMoisCivils.next();
        
        int population = determinerPopulationIndividu(p_individu, moisCivilCourant.getDebut());
        
        CriteresStrategiePNDS criteres = CriteresStrategiePNDS.creerInstance(p_dateDeterminationPNDS, population, dateExamen);
        
        StrategiePNDSSpec strategieDeterminationPNDSSurMoisCivil = FabriqueStrategiePNDS.determinerStrategiePNDS(criteres);
        
        Collection resultatSurMoisCivil = strategieDeterminationPNDSSurMoisCivil.determinerPNDS(p_individu, p_listeAttributions, p_dateDebut, p_dateFin, dateExamen);
        if (resultatSurMoisCivil != null)
        {
          Iterator itSurMoisCivil = resultatSurMoisCivil.iterator();
          while (itSurMoisCivil.hasNext())
          {
            PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)itSurMoisCivil.next();
            if (pnds.getPeriodeActivite() == null)
            {
              pndsPourToutesActivites.ajouterChronologiePeriode(pnds.getChronoPeriodePNDS());
            }
            else
            {
              PeriodeNonDeclareeSanction pndsExistante = recupererPNDSPourActivite(mapPNDS, pnds.getPeriodeActivite());
              if (pndsExistante != null) {
                pndsExistante.ajouterChronologiePeriode(pnds.getChronoPeriodePNDS());
              } else {
                mapPNDS.put(pnds.getPeriodeActivite(), pnds);
              }
            }
          }
        }
      }
      resultat.addAll(mapPNDS.values());
      
      resultat.add(pndsPourToutesActivites);
      
      Iterator itResultat = resultat.iterator();
      while (itResultat.hasNext())
      {
        PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)itResultat.next();
        pnds.fusionnerChevauchementPeriode();
      }
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\tPNDS déterminées : ", resultat });
    return resultat;
  }
  
  public static ChronologiePeriodes fusionnerChronologiePeriodeSurToutesPNDS(Collection p_listePNDS)
  {
    ChronologiePeriodes chronologie = new ChronologiePeriodes();
    if (p_listePNDS != null)
    {
      Iterator it = p_listePNDS.iterator();
      while (it.hasNext())
      {
        PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)it.next();
        chronologie.ajouter(pnds.getChronoPeriodePNDS());
      }
      if (!chronologie.estVide()) {
        return chronologie.fusionnerChevauchementPeriodes();
      }
      return chronologie;
    }
    return chronologie;
  }
  
  public static Collection recherchePeriodePNDS(Demande p_demande, Periode p_periodePNDS, Periode p_periodeReference)
    throws CoucheLogiqueException, ApplicativeException
  {
    Damj debut = null;
    Damj fin = null;
    Collection collectionPNDS = null;
    if (!p_periodePNDS.getDebut().equals(Damj.NUIT_DES_TEMPS))
    {
      if (!p_periodeReference.coincideAvec(p_periodePNDS)) {
        if (!p_periodeReference.estContenueDans(p_periodePNDS)) {
          if (p_periodeReference.chevauche(p_periodePNDS))
          {
            if (p_periodeReference.getDebut().estAvant(p_periodePNDS.getDebut()))
            {
              debut = p_periodeReference.getDebut();
              fin = p_periodePNDS.getDebut().veille();
              p_periodePNDS.setDebut(debut);
              collectionPNDS = determinerPNDS(p_demande, new Periode(debut, fin));
            }
            if (p_periodeReference.getFin().estApres(p_periodePNDS.getFin()))
            {
              debut = p_periodePNDS.getFin().lendemain();
              fin = p_periodeReference.getFin();
              p_periodePNDS.setFin(fin);
              collectionPNDS = determinerPNDS(p_demande, new Periode(debut, fin));
            }
          }
          else
          {
            if (p_periodeReference.getDebut().estAvant(p_periodePNDS.getDebut()))
            {
              debut = p_periodeReference.getDebut();
              fin = p_periodePNDS.getDebut().veille();
              p_periodePNDS.setDebut(debut);
            }
            else
            {
              debut = p_periodePNDS.getFin().lendemain();
              fin = p_periodeReference.getFin();
              p_periodePNDS.setFin(fin);
            }
            collectionPNDS = determinerPNDS(p_demande, new Periode(debut, fin));
          }
        }
      }
    }
    else
    {
      collectionPNDS = determinerPNDS(p_demande, p_periodeReference);
      p_periodePNDS.setDebut(p_periodeReference.getDebut());
      p_periodePNDS.setFin(p_periodeReference.getFin());
    }
    return collectionPNDS;
  }
  
  private static Collection determinerPNDS(Demande p_demande, Periode p_periodeReference)
    throws CoucheLogiqueException, ApplicativeException
  {
    Collection collectionPNDS = null;
    Damj dateFaitGenerateur = p_demande.getDateFaitGenerateurOuDernierSinistre();
    
    List listeAttributions = p_demande.getDemandeur().getListeAttributionsChevauchantPeriode(p_periodeReference, p_demande.getDateExamen());
    if ((dateFaitGenerateur != null) && (p_demande.getDemandeur() != null)) {
      collectionPNDS = determinerPNDS(p_demande.getDemandeur(), listeAttributions, p_periodeReference.getDebut(), p_periodeReference.getFin(), dateFaitGenerateur, p_demande.getDateExamen());
    }
    return collectionPNDS;
  }
  
  public static ChronologiePeriodes filtreParPeriodePNDS(Collection collectionPNDS, Periode periodeReference)
  {
    Chronologie pnds = fusionnerChronologiePeriodeSurToutesPNDS(collectionPNDS);
    
    ObjetChronoPeriode elementPeriodeSuivant = null;
    Periode elementPeriode = null;
    ChronologiePeriodes chronologie = new ChronologiePeriodes();
    
    FiltreIntersectionPeriode filtre = new FiltreIntersectionPeriode(periodeReference);
    pnds = pnds.copier(filtre);
    
    OutilOptimisationChronologie outilOptimisationChronologie = new OutilOptimisationChronologie(chronologie);
    pnds.iterer();
    while (pnds.encoreSuivant())
    {
      elementPeriodeSuivant = (ObjetChronoPeriode)pnds.elementSuivant();
      elementPeriode = periodeReference.periodeIntersection(new Periode(elementPeriodeSuivant.getDateDebut(), elementPeriodeSuivant.getDateFin()));
      
      elementPeriodeSuivant = new ObjetChronoPeriodeConcrete(elementPeriode.getDebut(), elementPeriode.getFin());
      outilOptimisationChronologie.ajouter(elementPeriodeSuivant);
    }
    return (ChronologiePeriodes)outilOptimisationChronologie.getChronologieTriee();
  }
  
  private static PeriodeNonDeclareeSanction recupererPNDSPourActivite(Map p_listePNDS, PeriodeGaecSpec p_periodeActivite)
  {
    return (PeriodeNonDeclareeSanction)p_listePNDS.get(p_periodeActivite);
  }
  
  private static List determinerMoisCivilsSurPeriode(Damj p_dateDebut, Damj p_dateFin)
  {
    Periode periode = new Periode(p_dateDebut, p_dateFin);
    return periode.decouperEnMoisCivils();
  }
  
  private static int determinerPopulationIndividu(IndividuSpec p_individu, Damj p_date)
  {
    return p_individu.determinerPopulationIndividu(p_date);
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationPNDS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */