package fr.unedic.cali.asu.liquidation.pnds.outilsfonctionnels;

import fr.unedic.cali.asu.liquidation.pnds.StrategiePNDSSpec;
import fr.unedic.cali.asu.liquidation.pnds.dom.PeriodeNonDeclaree;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.DeclareTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.TravailSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.SalarieSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.pnds.CachePndsSpectacle;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDsmSpectacle;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSalarie;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class StrategiePNDSSpe
  implements StrategiePNDSSpec
{
  private static final double FACTEUR_MULTIPLICATION = 1.1D;
  private static final BigDecimal REMUNERATION_NULL = BigDecimal.ZERO;
  
  public PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec individu, ActiviteSalarie activite, Damj dateDebut, Damj dateFin, Damj dateExamen)
  {
    if (activite != null)
    {
      Chronologie chronoPeriodesSalaire = rechercherChronologieSalaire(activite);
      if (chronoPeriodesSalaire != null)
      {
        Collection listePeriodeAvecPnd = new ArrayList();
        determinerPeriodePNDPourChronoSalaire(activite, chronoPeriodesSalaire, listePeriodeAvecPnd);
        Collection listPnds = determinerChronoPNDS(individu, listePeriodeAvecPnd, new Periode(activite.getDateDebut(), activite.getDateFin()));
        if ((listPnds != null) && (!listPnds.isEmpty())) {
          return (PeriodeNonDeclareeSanction)listPnds.iterator().next();
        }
      }
    }
    return null;
  }
  
  public Collection determinerPNDS(IndividuSpec individu, Collection listeAttributions, Damj dateDebut, Damj dateFin, Damj dateExamen)
  {
    Collection listePeriodeAvecPnd = new ArrayList();
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(new Periode(dateDebut, dateFin)));
    Chronologie chronoPasseProfessionnel = individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    Iterator iteratorPeriode = chronoPasseProfessionnel.iterer();
    while (iteratorPeriode.hasNext())
    {
      PeriodeGaecSpec periodeActivite = (PeriodeGaecSpec)iteratorPeriode.next();
      Chronologie chronoPeriodesSalaire = rechercherChronologieSalaire(periodeActivite);
      if (chronoPeriodesSalaire != null) {
        determinerPeriodePNDPourChronoSalaire(periodeActivite, chronoPeriodesSalaire, listePeriodeAvecPnd);
      }
    }
    return determinerChronoPNDS(individu, listePeriodeAvecPnd, new Periode(dateDebut, dateFin));
  }
  
  private static Chronologie rechercherChronologieSalaire(PeriodeGaecSpec periodeActivite)
  {
    if ((periodeActivite instanceof TravailSalarie)) {
      return ((TravailSalarie)periodeActivite).getListeSalaires();
    }
    if ((periodeActivite instanceof ActiviteSalarie))
    {
      PeriodeActiviteSalarie periodeActiviteSalariee = ((ActiviteSalarie)periodeActivite).getPeriodeActiviteSalarieGaec();
      return periodeActiviteSalariee.getListeSalaires();
    }
    return null;
  }
  
  private static void determinerPeriodePNDPourChronoSalaire(PeriodeGaecSpec periodeActivite, Chronologie chronoPeriodesSalaire, Collection listePnd)
  {
    if (chronoPeriodesSalaire != null)
    {
      Iterator it = chronoPeriodesSalaire.iterer();
      while (it.hasNext())
      {
        Salaire periodeSalaire = (Salaire)it.next();
        if ((periodeSalaire.getCollectionPND() != null) && (!periodeSalaire.getCollectionPND().isEmpty())) {
          listePnd.addAll(creerCollectionPND(periodeActivite, periodeSalaire));
        }
      }
    }
  }
  
  private static Collection creerCollectionPND(PeriodeGaecSpec periodeActivite, Salaire periodeSalaire)
  {
    Collection collectionPND = periodeSalaire.getCollectionPND();
    Collection listeResultat = new ArrayList();
    if (collectionPND != null)
    {
      Iterator it = collectionPND.iterator();
      while (it.hasNext())
      {
        ObjetChronoPeriode periodePnd = (ObjetChronoPeriode)it.next();
        PeriodeNonDeclaree pnd = PeriodeNonDeclaree.creerInstance();
        pnd.setPeriodeActivite(periodeActivite);
        pnd.setPeriodePND(new Periode(periodePnd.getDateDebut(), periodePnd.getDateFin()));
        listeResultat.add(pnd);
      }
    }
    return listeResultat;
  }
  
  private static Collection determinerChronoPNDS(IndividuSpec individu, Collection listePnd, Periode periodeEtude)
  {
    Collection resultat = new ArrayList();
    Map mapPNDS = new HashMap();
    
    Damj dateFinPnds = determinerDateFinDuDernierPNDS(listePnd);
    if (dateFinPnds != null) {
      periodeEtude.setFin(dateFinPnds.lendemain());
    }
    if ((listePnd != null) && (!listePnd.isEmpty()))
    {
      List listeMoisCivils = periodeEtude.decouperEnMoisCivils();
      if (listeMoisCivils != null)
      {
        Iterator it = listeMoisCivils.iterator();
        while (it.hasNext())
        {
          Periode moisCivilCourant = (Periode)it.next();
          
          QuantiteEuro remunerationJustifiees = calculerQuantiteRemunerationsJustifieesSurPeriode(individu, moisCivilCourant);
          QuantiteEuro remunerationActivitesDeclarees = calculerQuantiteRemunerationsActivitesDeclareesSurPeriode(individu, moisCivilCourant);
          
          double remActDeclarees = remunerationActivitesDeclarees.getValeur().doubleValue();
          QuantiteEuro plafond = new QuantiteEuro(new BigDecimal(remActDeclarees * 1.1D));
          if (remunerationJustifiees.soustraire(plafond).getValeur().doubleValue() > 0.0D)
          {
            Iterator itListePND = listePnd.iterator();
            while (itListePND.hasNext())
            {
              PeriodeNonDeclaree pnd = (PeriodeNonDeclaree)itListePND.next();
              if (moisCivilCourant.inter(pnd.getPeriodePND()) > 0)
              {
                PeriodeNonDeclareeSanction pndsARetenir = recupererPNDSPourActivite(mapPNDS, pnd.getPeriodeActivite());
                
                Periode periodeIntersection = moisCivilCourant.periodeIntersection(pnd.getPeriodePND());
                ObjetChronoPeriode periodePNDS = new ObjetChronoPeriodeConcrete(periodeIntersection.getDebut(), periodeIntersection.getFin());
                
                pndsARetenir.ajouterPeriodePNDS(periodePNDS);
              }
            }
          }
        }
      }
      resultat = mapPNDS.values();
      
      Iterator itResultat = resultat.iterator();
      while (itResultat.hasNext())
      {
        PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)itResultat.next();
        pnds.fusionnerChevauchementPeriode();
      }
    }
    return resultat;
  }
  
  private static PeriodeNonDeclareeSanction recupererPNDSPourActivite(Map listePNDS, PeriodeGaecSpec periodeActivite)
  {
    PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)listePNDS.get(periodeActivite);
    if (pnds == null)
    {
      pnds = PeriodeNonDeclareeSanction.creerInstance();
      pnds.setPeriodeActivite(periodeActivite);
      listePNDS.put(periodeActivite, pnds);
    }
    return pnds;
  }
  
  private static QuantiteEuro calculerQuantiteRemunerationsJustifieesSurPeriode(IndividuSpec individu, Periode periodeEtude)
  {
    CachePndsSpectacle cachePnds = individu.getCachePndsSpectacle();
    QuantiteEuro quantiteARetourner = cachePnds.recupererQuantiteRemunerationJustifiee(periodeEtude);
    if (quantiteARetourner == null)
    {
      FiltresTemporel filtre = new FiltresTemporel();
      filtre.ajouterFiltre(new FiltreChevauchePeriode(periodeEtude));
      filtre.ajouterFiltre(new FiltreTravailSalarie());
      
      Chronologie chronoPeriode = individu.getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ().copier(filtre);
      Iterator it = chronoPeriode.iterer();
      Quantite total = new QuantiteEuro(REMUNERATION_NULL);
      while (it.hasNext())
      {
        SalarieSpec periodeJustifiee = (SalarieSpec)it.next();
        BigDecimal montant = DeterminationRemuneration.determinerRemunerationActiviteSalarie(periodeJustifiee, periodeEtude);
        total = total.ajouter(new QuantiteEuro(montant));
      }
      quantiteARetourner = new QuantiteEuro(total.getValeur());
      cachePnds.ajouterQuantiteRemunerationJustifiee(periodeEtude, quantiteARetourner);
    }
    return quantiteARetourner;
  }
  
  private static QuantiteEuro calculerQuantiteRemunerationsActivitesDeclareesSurPeriode(IndividuSpec individu, Periode periodeEtude)
  {
    CachePndsSpectacle cachePnds = individu.getCachePndsSpectacle();
    QuantiteEuro quantiteARetourner = cachePnds.recupererQuantiteRemunerationActiviteDeclaree(periodeEtude);
    if (quantiteARetourner == null)
    {
      FiltresTemporel filtre = new FiltresTemporel();
      filtre.ajouterFiltre(new FiltreChevauchePeriode(periodeEtude));
      
      filtre.ajouterFiltre(new FiltrePeriodesDsmSpectacle());
      
      Chronologie chronoPeriode = individu.getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ().copier(filtre);
      Iterator it = chronoPeriode.iterer();
      Quantite total = new QuantiteEuro(REMUNERATION_NULL);
      while (it.hasNext())
      {
        DeclareTravail periodeJustifiee = (DeclareTravail)it.next();
        BigDecimal quantiteARetenir = null;
        if (periodeEtude.equals(periodeJustifiee))
        {
          quantiteARetenir = determinerRemunerationPourPeriode(periodeJustifiee);
        }
        else
        {
          int nombreJoursChevauchantPeriodeRef = periodeJustifiee.inter(periodeEtude);
          if (nombreJoursChevauchantPeriodeRef != 0)
          {
            BigDecimal nominateur1 = BigDecimal.valueOf(nombreJoursChevauchantPeriodeRef);
            BigDecimal nominateur2 = determinerRemunerationPourPeriode(periodeJustifiee);
            BigDecimal denominateur = BigDecimal.valueOf(periodeJustifiee.getDuree());
            BigDecimal montantProratiseSurPeriodeRef = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
            quantiteARetenir = montantProratiseSurPeriodeRef;
          }
        }
        if (quantiteARetenir != null) {
          total = total.ajouter(new QuantiteEuro(quantiteARetenir));
        }
      }
      quantiteARetourner = new QuantiteEuro(total.getValeur());
      cachePnds.ajouterQuantiteRemunerationActiviteDeclaree(periodeEtude, quantiteARetourner);
    }
    return quantiteARetourner;
  }
  
  private static BigDecimal determinerRemunerationPourPeriode(DeclareTravail periodeDeclaree)
  {
    if (periodeDeclaree.getMontant() != null) {
      return periodeDeclaree.getMontant().getValeur();
    }
    return REMUNERATION_NULL;
  }
  
  private static Damj determinerDateFinDuDernierPNDS(Collection listePNDS)
  {
    Damj dateFinDernierPNDS = null;
    if ((listePNDS != null) && (!listePNDS.isEmpty()))
    {
      Iterator it = listePNDS.iterator();
      while (it.hasNext())
      {
        PeriodeNonDeclaree pnd = (PeriodeNonDeclaree)it.next();
        if ((dateFinDernierPNDS == null) || (pnd.getPeriodePND().getFin().estApres(dateFinDernierPNDS))) {
          dateFinDernierPNDS = pnd.getPeriodePND().getFin();
        }
      }
    }
    return dateFinDernierPNDS;
  }
}

/* Location:
 * Qualified Name:     StrategiePNDSSpe
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */