package fr.unedic.cali.asu.may17.p02.calcul.dom;

import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantPremiereTranche
  implements FormuleMontantSpec
{
  private static final BigDecimal FACTEUR_PLAFOND = new BigDecimal("0.75");
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation constituantsIndemnisation, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Montant leMontant = new Montant();
    BigDecimal resultat = null;
    BigDecimal resultatSansAv = null;
    BigDecimal plafond = null;
    BigDecimal plancher = null;
    BigDecimal plancherSansAv = null;
    BigDecimal mini = null;
    BigDecimal montantAVDeduit = null;
    
    ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    EvenementParametre evenementParametre = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateCalcul);
    
    montantAVDeduit = ebi.getTauxAvantageVieillesse().multiply(ebi.getCoefficientAvantageVieillesse().multiply(ebi.getSjr().getSalaire()));
    
    plafond = calculPlafond(ebi.getSjr().getSalaire());
    mini = evenementParametre.getAllocationMinimaleMayotte().multiply(ebi.getCoefficientTempsPartiel());
    plancherSansAv = calculFacteurPlancher(ebi.getSjr().getSalaire());
    plancher = plancherSansAv.subtract(montantAVDeduit).max(new BigDecimal(0));
    resultatSansAv = plancherSansAv.max(mini).min(plafond);
    resultat = plancher.max(mini).min(plafond);
    if (resultat.equals(plafond)) {
      leMontant.setJustificationCalculMontant("17");
    } else if (resultat.equals(plancher)) {
      leMontant.setJustificationCalculMontant("17");
    } else if (resultat.equals(mini)) {
      leMontant.setJustificationCalculMontant("02");
    }
    leMontant.setMontantJournalierAvantageVieillesseDeduit(new QuantiteEuro(Mathematiques.arrondiASup(resultatSansAv.subtract(Mathematiques.arrondiASup(resultat, 2)), 2).max(new BigDecimal(0))));
    leMontant.setMontantBrutSansPensionInvaliditeADeduire(formateQuantite(resultat));
    leMontant.setMontantBrutSansAvantageVieillesseDeduit(formateQuantite(resultatSansAv));
    leMontant.setPensionInvaliditeADeduirePriseEnCompte(new QuantiteEuro(ebi.getMontantPensionInvaliditeADeduire()));
    leMontant.setMontantJournalierAvantageVieillesse(new QuantiteEuro(ebi.getMontantAvantageVieillesse()));
    leMontant.setPlafond(formateQuantite(plafond));
    leMontant.setPlancher(formateQuantite(plancher));
    leMontant.setMini(formateQuantite(mini));
    
    resultat = resultat.subtract(ebi.getMontantPensionInvaliditeADeduire()).max(new BigDecimal("0"));
    leMontant.setMontantBrut(formateQuantite(resultat));
    if ((ebi.getCoefficientSanctionReduction() != null) && (!ebi.getCoefficientSanctionReduction().equals(new BigDecimal("1.00"))))
    {
      BigDecimal montantAvecCoeffSR = resultat.multiply(ebi.getCoefficientSanctionReduction());
      leMontant.setMontantBrut(formateQuantite(montantAvecCoeffSR));
    }
    return leMontant;
  }
  
  protected BigDecimal calculPlafond(BigDecimal salaire)
  {
    return FACTEUR_PLAFOND.multiply(salaire);
  }
  
  protected BigDecimal calculFacteurPlancher(BigDecimal salaire)
  {
    return FACTEUR_PLAFOND.multiply(salaire);
  }
  
  public void setFormuleMontantApplicable(int formuleMontantApplicable) {}
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec formuleMontantDroitAssocie) {}
  
  private Quantite formateQuantite(BigDecimal value)
  {
    return new Quantite(Mathematiques.arrondiASup(value, 2), UniteMonaitaire.EUROS);
  }
}

/* Location:
 * Qualified Name:     FormuleMontantPremiereTranche
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */