package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Rejet;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.ConditionAttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import java.util.ArrayList;
import java.util.Collection;

public class GrapheRejet
  extends GrapheDecision
{
  protected void creerCaps(DossierExamen p_dossierExamen) {}
  
  protected void creerCeps(DossierExamen p_dossierExamen) {}
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    
    nouvelleDecision = new Rejet();
    nouvelleDecision.setNatureDecision(16);
    
    return nouvelleDecision;
  }
  
  protected DossierAffectation creerDossierAffectation()
  {
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    
    return dossierAffectation;
  }
  
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    
    objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(10, null);
    objectifExamen.setEtat(22);
    
    return objectifExamen;
  }
  
  protected Collection getListRecalcule()
  {
    return new ArrayList();
  }
  
  protected void alimenterValidationProduit(DemandeMigreeAsuV1 p_demandeTemporaireSource, Decision p_decision)
  {
    DecisionMigreeAsuV1 decisionTemporaireSource = p_demandeTemporaireSource.getDecision();
    switch (decisionTemporaireSource.getCodeRejet())
    {
    case 91: 
    case 92: 
    case 93: 
      ((DossierAffectation)p_decision.getDossierAffecte()).setValidationProduit(new ValidationProduit());
      
      super.alimenterValidationProduit(p_demandeTemporaireSource, p_decision);
      break;
    default: 
      ((DossierAffecte)p_decision.getDossierAffecte()).setProduitSecours(Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit()));
      
      ((DossierAffecte)p_decision.getDossierAffecte()).setValidationProduit(new ValidationProduit());
      alimenterReglementApplicable(p_demandeTemporaireSource, p_decision);
    }
  }
  
  protected void alimenterCaps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConditionAttributionSpec capEchec = null;
    
    p_dossierExamen.getDemande().setCodeMotifEchecPourSigma(Integer.valueOf(p_decisionTemporaireSource.getCodeRejet()).toString());
    switch (p_decisionTemporaireSource.getCodeRejet())
    {
    case 11: 
      capEchec = p_dossierExamen.getConditionsAttributionActives().createConditionRechercheEmploi();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 21: 
      break;
    case 41: 
    case 42: 
    case 43: 
    case 44: 
    case 45: 
      capEchec = p_dossierExamen.createConditionFaitGenerateur();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 51: 
      capEchec = p_dossierExamen.createConditionChomageTotal();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 61: 
    case 62: 
    case 63: 
    case 64: 
    case 625: 
      capEchec = p_dossierExamen.getConditionsAttributionActives().createConditionAge();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 71: 
      capEchec = p_dossierExamen.createConditionQuantiteAffiliation();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      
      ConditionQuantiteAffiliation capaQteAffi = (ConditionQuantiteAffiliation)capEchec;
      alimenterQuantiteAffiliationEchec(capaQteAffi, p_decisionTemporaireSource);
      break;
    case 91: 
    case 92: 
      capEchec = p_dossierExamen.createConditionChomageInvolontaire();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      
      capEchec = p_dossierExamen.createConditionFaitGenerateur();
      capEchec.setEtatSatisfait(true);
      alimenterConditionFaitGenerateur(p_decisionTemporaireSource, p_dossierExamen);
      
      capEchec = p_dossierExamen.createConditionQuantiteAffiliation();
      capEchec.setEtatSatisfait(true);
      
      break;
    case 93: 
      capEchec = p_dossierExamen.createConditionChomageInvolontaire();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      
      capEchec = p_dossierExamen.createConditionFaitGenerateur();
      capEchec.setEtatSatisfait(true);
      alimenterConditionFaitGenerateur(p_decisionTemporaireSource, p_dossierExamen);
      
      Demande demande = (Demande)p_dossierExamen.getDemande();
      demande.getDonneesTemporaires().setAvisCommissionParitaire((short)2);
      
      capEchec = p_dossierExamen.createConditionQuantiteAffiliation();
      capEchec.setEtatSatisfait(true);
      
      break;
    case 121: 
    case 122: 
      capEchec = p_dossierExamen.createConditionActiviteConservee();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 171: 
    case 172: 
      capEchec = p_dossierExamen.getConditionsAttributionActives().createConditionCumulPrestationFamiliale();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    case 181: 
      capEchec = p_dossierExamen.getConditionsAttributionActives().createConditionMontantNonNul();
      capEchec.setEtatSatisfait(false);
      capEchec.setCodeMotifEchec(p_decisionTemporaireSource.getCodeRejet());
      break;
    default: 
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MOTIF_REJET"));
    }
  }
  
  protected void alimenterQuantiteAffiliationEchec(ConditionQuantiteAffiliation p_conditionQuantiteAffiliation, DecisionMigreeAsuV1 p_decisionTemporaireSource)
  {
    if (p_decisionTemporaireSource.getQteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_QTE_AFFI_1"));
    }
    if (p_decisionTemporaireSource.getUniteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1"));
    }
    if ((p_decisionTemporaireSource.getQteAffiliation1() != null) && (p_decisionTemporaireSource.getUniteAffiliation1() != null))
    {
      Unite uniteAffiliation1 = null;
      try
      {
        uniteAffiliation1 = Unite.getParCode(p_decisionTemporaireSource.getUniteAffiliation1());
      }
      catch (NullPointerException e) {}
      if (uniteAffiliation1 == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1", p_decisionTemporaireSource.getUniteAffiliation1()));
      } else {
        p_conditionQuantiteAffiliation.setQuantiteAppartenance(new Quantite(p_decisionTemporaireSource.getQteAffiliation1(), uniteAffiliation1));
      }
    }
    if (p_decisionTemporaireSource.getQteAffiliation2() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_QTE_AFFI_2"));
    }
    if (p_decisionTemporaireSource.getUniteAffiliation2() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_UNITE_AFFI_2"));
    }
    if ((p_decisionTemporaireSource.getQteAffiliation2() != null) && (p_decisionTemporaireSource.getUniteAffiliation2() != null))
    {
      Unite uniteAffiliation2 = null;
      try
      {
        uniteAffiliation2 = Unite.getParCode(p_decisionTemporaireSource.getUniteAffiliation2());
      }
      catch (NullPointerException e) {}
      if (uniteAffiliation2 == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_2"));
      } else {
        p_conditionQuantiteAffiliation.setQuantiteAppartenanceSecondaire(new Quantite(p_decisionTemporaireSource.getQteAffiliation2(), uniteAffiliation2));
      }
    }
  }
  
  protected void alimenterCeps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen) {}
  
  protected void alimenterIdentifiant(DecisionMigreeAsuV1 p_decisionTemporaireSource, Decision p_decisionInstallee) {}
  
  protected void alimenterDonneesImposees(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande) {}
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec p_demande)
  {
    DemandeMigreeAsuV1 demandeLue = (DemandeMigreeAsuV1)super.lireDonnees(p_demande);
    
    DecisionMigreeAsuV1 decisionLue = demandeLue.getDecision();
    
    Demande demandeAsu = (Demande)p_demande;
    Decision decision = (Decision)demandeAsu.getDossierAffectation().getDossierExamen();
    
    lireValidationProduit(decision, decisionLue);
    
    lireDecision(decision, decisionLue);
    
    lireDonneesSimples(decision, decisionLue);
    
    lireCompetences(decision, decisionLue);
    
    return demandeLue;
  }
  
  protected void lireValidationProduit(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ProduitSpec produitSpec = ((DossierAffecte)p_decision.getDossierAffecte()).getProduitSecours();
    p_decisionLue.getDemandeMigree().setCodeProduit(produitSpec.getNomUnique());
  }
  
  protected void lireIdentifiant(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue) {}
  
  protected void lireCaps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue) {}
  
  protected void lireCeps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue) {}
  
  protected Chronologie getChronoActivitesConservees(DossierExamen p_dossierExamen)
  {
    return null;
  }
  
  protected Prc getPrcSjr(DossierExamen p_dossierExamen)
  {
    return null;
  }
  
  private void alimenterReglementApplicable(DemandeMigreeAsuV1 p_demandeTemporaireSource, Decision p_decision)
  {
    ValidationProduit validationProduit = ((DossierAffecte)p_decision.getDossierAffecte()).getValidationProduit();
    
    ProduitSpec produit = Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    validationProduit.setProduitValide(produit);
    if ((p_demandeTemporaireSource.getDecision().getReglementApplicable() != null) || (produit.getReglement(p_demandeTemporaireSource.getDecision().getReglementApplicable()) != null)) {
      validationProduit.setReglementApplicable(produit.getReglement(p_demandeTemporaireSource.getDecision().getReglementApplicable()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_RA"));
    }
  }
}

/* Location:
 * Qualified Name:     GrapheRejet
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */