package fr.unedic.cali.asu.mnt.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.ConditionActiviteMaintien;
import fr.unedic.cali.asu.mnt.dom.ConditionAppartenanceMaintien;
import fr.unedic.cali.asu.mnt.dom.ConditionDecisionCPMaintien;
import fr.unedic.cali.asu.mnt.dom.ConditionNombreTrimestresMaintien;
import fr.unedic.cali.asu.mnt.dom.Decision;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.asu.mnt.dom.EreDemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.Examen;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.ComparateurDecision;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.OutilVerificationPreconditionsMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilPasseProfessionel;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AppelGaecReduit;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.ClassementSansObjet;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.EvenementReferenceExamenAbstrait;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;

public class ParcoursExaminerMaintien
  extends ParcoursLiquidation
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    IndividuSpec individuCourant = getIndividu(p_contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent du contexte");
    }
    String idDemande = ((DomLiquidationDemande)p_contexte.getDonnees()).getIdDemande();
    
    DemandeSpec demande = ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
    if ((idDemande != null) || (demande != null)) {
      mettreAJourContexte(p_contexte);
    }
  }
  
  protected ArrayList alimenterDecisionsReexamen(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if ((p_contexte != null) && (p_contexte.getDonnees() != null))
    {
      DomLiquidationMaintien domCourant = (DomLiquidationMaintien)p_contexte.getDonnees();
      Decision decisionAvantReexamen = (Decision)((DemandeMaintien)domCourant.getDemandeAvantReexamen()).getDossierExamen();
      Decision decisionApresReexamen = (Decision)((DemandeMaintien)domCourant.getDemandeSpec()).getDossierExamen();
      return ComparateurDecision.rechercheDifferencesComparaisonDecision(decisionAvantReexamen, decisionApresReexamen);
    }
    return null;
  }
  
  private DemandeMaintien getDemandeMaintienAvantReexamen(Contexte p_contexte)
  {
    return (DemandeMaintien)getDom(p_contexte).getDemandeAvantReexamen();
  }
  
  private DomLiquidationMaintien getDom(Contexte p_contexte)
  {
    return (DomLiquidationMaintien)p_contexte.getDonnees();
  }
  
  protected boolean verifierPrecondition(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean preconditionSatisfaite = false;
    
    Damj dateExamenDemandeCourante = getDemande(p_contexte).getDateExamen();
    IndividuSpec individu = getIndividu(p_contexte);
    
    ObjetChronoPeriodePriseEnCharge pec = OutillagePEC.getPeriodePECIndemnisableContenant(individu, dateExamenDemandeCourante);
    if (pec == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DEMANDEUR_NON_INSCRIT");
    }
    return preconditionSatisfaite;
  }
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    traitementPreLiquidation(p_contexte);
    
    ResultatExamenMaintien resultat = new ResultatExamenMaintien(2);
    
    initialisationPasseProfessionnelLiquidation(p_contexte);
    
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    DomLiquidationMaintien domExamenMaintien = getDom(p_contexte);
    
    verifierDemandeMaintenue(demande);
    
    constaterContexteInitial(p_contexte);
    
    verifierContexte(demande);
    if (demande.estEnReExamen()) {
      sauvegarderDonneesAvantReexamen(p_contexte);
    }
    demande.setDossierExamen(new Examen());
    
    verifierPreconditions(p_contexte);
    
    Damj dateExamen = determinerDateExamen(p_contexte);
    if ((dateExamen == null) && (!domExamenMaintien.estExamenAutomatique())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
    if (dateExamen != null) {
      liquider(p_contexte);
    }
    if ((getDemandeMaintienAvantReexamen(p_contexte) != null) && (getDemandeMaintienAvantReexamen(p_contexte).estEnReExamen()))
    {
      ArrayList listeDifferencesReexamen = alimenterDecisionsReexamen(p_contexte);
      if (listeDifferencesReexamen != null) {
        resultat.setListeDifferencesReexamen(listeDifferencesReexamen);
      }
      resultat.setListeMotifsReexamenAvantReexamen(getDemandeMaintienAvantReexamen(p_contexte).getListeMotifsReexamen());
      resultat.setMotifPrincipalReexamenAvantReexamen(getDemandeMaintienAvantReexamen(p_contexte).getMotifReexamenPrincipal());
    }
    determinerCREMModificationLiquidation(p_contexte, resultat);
    resultat.setDemande(demande);
    OutilTrace.tracerFinParcours();
    
    super.traitementPostLiquidation(p_contexte);
    
    return resultat;
  }
  
  protected Damj determinerDateExamen(Contexte p_contexte)
    throws ApplicativeException
  {
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    
    EvenementReferenceExamenAbstrait ere = (EvenementReferenceExamenAbstrait)demande.getEvenementReferenceExamen();
    ere.setDateEvenement(null);
    Damj dateExamen = ere.getDateExamen(getDemande(p_contexte));
    if (demande.getProduitMaintenu() == null)
    {
      demande.setClassementAdministratif(new ClassementSansObjet());
      dateExamen = null;
    }
    else if ((dateExamen != null) && (
      (!demande.getProduitMaintenu().verifierConditionAgePourMaintien(p_contexte).estSatisfait()) || (!demande.getProduitMaintenu().verifierConditionDureeIndemnisationPourMaintien(p_contexte).estSatisfait())))
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  private boolean estReliquatPresent(Contexte p_contexte, Damj p_dateExamen)
    throws ApplicativeException
  {
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(demande.getAttributionAssurance(), p_dateExamen.veille(), true, true);
    if (resultatCalcul.isReliquatPresent()) {
      demande.setQuantiteJourReliquat(resultatCalcul.getReliquatDureeIndemnisation());
    }
    if ((!resultatCalcul.isReliquatPresent()) && (!getDom(p_contexte).estExamenAutomatique())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_ECHEC_RELIQUAT", new Object[] { ((EreDemandeMaintien)demande.getEvenementReferenceExamen()).getLibelleDateExamenChoisie(demande), p_dateExamen });
    }
    return resultatCalcul.isReliquatPresent();
  }
  
  private boolean estDecisionCPFavorable(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean estDecisionFavorable = false;
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    demande.getProduitMaintenu().verifierConditionDecisionCPPourMaintien(p_contexte);
    if (demande.getDonneesForcees().getDecisionCPFavorable() != 0) {
      estDecisionFavorable = demande.getDossierExamen().getConditionDecisionCP().estDecisionCPFavorable();
    } else if (getDom(p_contexte).estAttenteCP()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_ECHEC_ATTENTE_DEC_CP");
    } else {
      estDecisionFavorable = true;
    }
    if ((!estDecisionFavorable) && (demande.getDonneesForcees().getDecisionCPFavorable() != 0)) {
      demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(16));
    }
    return estDecisionFavorable;
  }
  
  private boolean controlerConditionAttributionMaintien(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean conditionOk = false;
    
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    
    demande.getProduitMaintenu().verifierConditionAppartenancePourMaintien(p_contexte);
    demande.getProduitMaintenu().verifierConditionActivitePourMaintien(p_contexte);
    demande.getProduitMaintenu().verifierConditionNombreTrimestresPourMaintien(p_contexte);
    
    DossierExamen dossierExamen = demande.getDossierExamen();
    
    conditionOk = (dossierExamen.getConditionActivite().estSatisfait()) && (dossierExamen.getConditionAppartenance().estSatisfait()) && (dossierExamen.getConditionNombreTrimestres().estSatisfait());
    if (!conditionOk) {
      if ((getDom(p_contexte).estAttenteCP()) || (getDom(p_contexte).estAttenteQuestionnaire()) || (getDom(p_contexte).estRefusMaintien())) {
        demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(16));
      } else {
        demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(25));
      }
    }
    return conditionOk;
  }
  
  public boolean controlerFNE(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    boolean resultat = false;
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    
    ConditionDecisionCPMaintien decisionCP = demande.getDossierExamen().getConditionDecisionCP();
    if (decisionCP.estSatisfait()) {
      resultat = true;
    } else if (decisionCP.getCodeMotifEchec() == 987)
    {
      if (getDom(p_contexte).estAttenteQuestionnaire()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_ECHEC_ATTENTE_INFO_FNE");
      } else if ((getDom(p_contexte).estAttenteDecision()) || (getDom(p_contexte).estExamenAutomatique()) || (getDom(p_contexte).estAdmissionMaintien()) || (getDom(p_contexte).estRefusMaintien())) {
        demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(25));
      }
    }
    else if (decisionCP.estRefusFNE()) {
      demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(24));
    }
    return resultat;
  }
  
  public boolean controlerRejetDV(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    boolean resultat = false;
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    
    ConditionDecisionCPMaintien decisionCP = demande.getDossierExamen().getConditionDecisionCP();
    if (((decisionCP != null) && (decisionCP.estDecisionCPFavorable())) || (!demande.getDemandeMaintenue().estExamenSuiteRejetDV())) {
      resultat = true;
    } else if (demande.getDemandeMaintenue().estExamenSuiteRejetDV()) {
      demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(24));
    }
    return resultat;
  }
  
  public void constaterContexteInitial(Contexte p_contexte)
  {
    getDom(p_contexte).determinerContexteExamenMaintien();
  }
  
  public void liquider(Contexte p_contexte)
    throws ApplicativeException, CoucheLogiqueException
  {
    DemandeMaintien demande = (DemandeMaintien)getDemande(p_contexte);
    if (estReliquatPresent(p_contexte, demande.getDateExamen()))
    {
      boolean conditionMaintienOk = controlerConditionAttributionMaintien(p_contexte);
      boolean decisionCPOk = estDecisionCPFavorable(p_contexte);
      if ((decisionCPOk) && (conditionMaintienOk) && (controlerFNE(p_contexte)) && (controlerRejetDV(p_contexte))) {
        demande.setDossierExamen((DossierExamen)demande.getDossierExamen().changerEtat(23));
      }
    }
    if ((demande.getDossierExamen() instanceof Decision)) {
      demande.setListeMotifsReexamen(null);
    }
  }
  
  protected void verifierPreconditions(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    try
    {
      OutilVerificationPreconditionsMaintien.getInstancePourMaintien().verifierPreconditions(getDemande(p_contexte));
    }
    catch (CoucheLogiqueException e)
    {
      if (!getDom(p_contexte).estExamenAutomatique()) {
        throw e;
      }
    }
  }
  
  private void initialisationPasseProfessionnelLiquidation(Contexte p_contexte)
  {
    IndividuSpec individu = getIndividu(p_contexte);
    
    ChronologiePeriodes chronoPeriodesGa = OutilPasseProfessionel.trouverChronoPasseProfessionelAvecFiltrageDNJ(individu);
    
    individu.setChronoPeriodePasseProfessionnelLiquidation(chronoPeriodesGa);
  }
  
  protected void verifierDemandeMaintenue(DemandeMaintien p_demandeMaintien)
    throws CoucheLogiqueException
  {
    Demande demandeMaintenue = (Demande)p_demandeMaintien.getDemandeMaintenue();
    if (demandeMaintenue == null)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_MNT_CONTEXTE_DEMANDE_MAINTENUE");
    }
    else
    {
      ClassementAdministratif classementAdministratif = demandeMaintenue.getClassementAdministratif();
      if ((classementAdministratif != null) && ((classementAdministratif instanceof ClassementSansObjet))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_CTX_DEMANDE_MAINTENUE_SO", new Object[] { demandeMaintenue.getDateDeclenchementExamen() });
      }
      if ((demandeMaintenue.getDossierExamen() == null) || (!(demandeMaintenue.getDossierExamen() instanceof AttributionSpec))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_MNT_CTX_DROIT_MAINTENU_INEXISTANT", new Object[] { demandeMaintenue.getDateDeclenchementExamen() });
      }
      if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeMaintenue, "ENTREECRA")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeMaintenue, "ENCOURSCRA"))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_MAINTIEN_EN_COURS_CRA");
      }
    }
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    if (p_individu != null)
    {
      Collection typePeriodesGaec = new ArrayList();
      ajouterSiNouveau("999", typePeriodesGaec);
      
      int modeAppel = 1;
      modeAppel = getModeAppelContexteSimulation(modeAppel);
      p_individu.getDonneesChargementGaec().getAgregatGaec().setDomaine(1);
      p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(modeAppel);
      p_individu.getDonneesChargementGaec().getAgregatGaec().setTypePeriodesGaec(typePeriodesGaec);
    }
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    AppelGaecReduit gaecReduit = p_individu.getDonneesChargementGaec().getAppelGaecReduit();
    
    int modeAppel = 1;
    modeAppel = getModeAppelContexteSimulation(modeAppel);
    controlerModeAppel(gaecReduit, modeAppel);
    
    controlerTypePeriode(gaecReduit.getTypePeriodes(), "999");
  }
}

/* Location:
 * Qualified Name:     ParcoursExaminerMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */