package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.CodesMotifsEchec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionValiditeReliquatSpec;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesSortieNPDE;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreTypeRechargementSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.CompteurIndexPASContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.ConditionAttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenAntecedentSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.ExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.NovationSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.PoursuiteIndemnisationSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.RepriseSecteurPublicSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pivot.Attribution;
import fr.unedic.cali.dom.pivot.Decision;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.cali.dom.pivot.PeriodeAffiliation;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.TracesBouchon;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourSpec;
import fr.unedic.util.QuantiteJoursCalendaires;
import fr.unedic.util.QuantiteJoursOuvrables;
import fr.unedic.util.QuantiteJoursOuvres;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

public class AlimentationBasePivot
  extends fr.unedic.cali.outilsfonctionnels.AlimentationBasePivot
{
  private static final Damj DATE_FIN_ARE_2009 = new Damj(2011, 5, 31);
  private static final String TOP_ARE_2011 = "T";
  private static final String FORMATION = "1";
  private static final String ACTIVITE_SALARIEE = "2";
  private static final String PERIODE_EVENEMENT_PERSONNEL = "3";
  private static final String TYPE_INCONNU = "4";
  private static final String SP = "SP";
  private static final String RAC = "RAC";
  private static final String NPDE_AUTO = "A";
  private static final String NPDE_SIMPLIFIE = "B";
  private static final String NPDE_STANDARD = "C";
  
  public static void enregistrerBasePivotGamme(DemandeSpec demande)
    throws ApplicativeException
  {
    fr.unedic.cali.outilsfonctionnels.AlimentationBasePivot.sauvegarderCodeMotifRejet(demande);
    
    Demande demandeAssurance = (Demande)demande;
    
    ProduitSpec produitDecisionne = demande.getDossierAffectation().getProduit();
    if (((estPrescriteNonOpposable(demande)) && (produitDecisionne == null)) || (((Demande)demande).isEstNonExecutable()))
    {
      demande.setDemandePivot(null);
    }
    else
    {
      if (demande.getDemandePivot() == null) {
        demande.setDemandePivot(new DemandePivot());
      }
      if (demande.getDemandePivot().getDecision() == null) {
        demande.getDemandePivot().setDecision(new Decision());
      } else {
        demande.getDemandePivot().getDecision().initInstance();
      }
      if (estClassementValide(demande)) {
        demande.getDemandePivot().setAttribution(null);
      } else if ((produitDecisionne != null) && (!(demandeAssurance.getDossierExamen() instanceof ExamenSpec))) {
        if (((demandeAssurance.getDossierExamen() instanceof RejetSpec)) || ((demandeAssurance.getDossierExamen() instanceof PoursuiteIndemnisationSpec)) || (((demandeAssurance.getDossierExamen() instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)demandeAssurance.getDossierExamen()).estTopeeRenoncement())))
        {
          demande.getDemandePivot().setAttribution(null);
          produitDecisionne.alimenterBasePivotProduit(demande.getDossierAffectation().getDossierExamen(), demande.getDemandePivot());
        }
        else
        {
          boolean estUnAntecedentFinDroitSP = "ASU_23".equals(demandeAssurance.getEvenementReferenceExamen().getTypeExamen());
          
          boolean estRevisionAre14EnRejetDv = OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(demande);
          
          CompetenceSpec competence = ((DossierExamenAssuranceSpec)demandeAssurance.getDossierExamen()).getCompetence();
          if (((competence == null) || (competence.getCompetenceAdministrative() != 2) || (estUnAntecedentFinDroitSP)) && (!estRevisionAre14EnRejetDv))
          {
            if (demande.getDemandePivot().getAttribution() == null) {
              demande.getDemandePivot().setAttribution(new Attribution());
            } else {
              demande.getDemandePivot().getAttribution().initInstance();
            }
            produitDecisionne.alimenterBasePivotProduit(demande.getDossierAffectation().getDossierExamen(), demande.getDemandePivot());
          }
          boolean estRead = estReadmission(demande);
          if ((competence != null) && (competence.getCompetenceAdministrative() == 2) && (!estUnAntecedentFinDroitSP))
          {
            demande.getDemandePivot().setAttribution(null);
            if ("ASU_24".equals(demande.getEvenementReferenceExamen().getTypeExamen()))
            {
              demande.getDemandePivot().getDecision().setMotifRejet(17);
            }
            else
            {
              DossierAffectation dossierAffectation = demandeAssurance.getDossierAffectationAdmission();
              if ((dossierAffectation != null) && (dossierAffectation.getValidationProduit() != null))
              {
                ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
                Periode pra = validationProduit.getPeriodePra();
                if (pra != null)
                {
                  demande.getDemandePivot().getDecision().setDateDebutPra(pra.getDebut());
                  demande.getDemandePivot().getDecision().setDateFinPra(pra.getFin());
                }
              }
              int affiRac = competence.getDureeActiviteSecteurPrive() + competence.getDureeActiviteSecteurPublicAffilie();
              int affiSP = competence.getDureeActiviteSecteurPublicAutoAssurance() + competence.getDureeActiviteSecteurPublicConventionGestion();
              if (competence.estCompetenceFinanciereSecteurPublic()) {
                demande.getDemandePivot().getDecision().setMotifRejet(13);
              }
              if ((affiRac == affiSP) && (competence.estCompetenceFinanciereSecteurPublic())) {
                demande.getDemandePivot().getDecision().setMotifRejet(14);
              }
              if ((competence.estCompetenceFinanciereSecteurPublic()) && (affiRac == 0)) {
                demande.getDemandePivot().getDecision().setMotifRejet(12);
              }
              if ((demandeAssurance.getDossierExamen() instanceof RepriseSecteurPublicSpec)) {
                demande.getDemandePivot().getDecision().setMotifRejet(18);
              }
              if (estRead)
              {
                DossierExamenAssuranceSpec dossierExamenPrecedent = demandeAssurance.getAttribution().getAttributionPrecedente();
                if ((dossierExamenPrecedent != null) && (dossierExamenPrecedent.getCompetence() != null) && (dossierExamenPrecedent.getCompetence().getCompetenceAdministrative() == 1)) {
                  demande.getDemandePivot().getDecision().setMotifRejet(15);
                }
              }
            }
          }
          else if (estRevisionAre14EnRejetDv)
          {
            demande.getDemandePivot().setAttribution(null);
            demande.getDemandePivot().getDecision().setMotifRejet(91);
          }
          if ((competence != null) && ((demandeAssurance.getDossierExamen() instanceof AttributionAssuranceSpec)))
          {
            AttributionSpec attribution = (AttributionAssuranceSpec)demandeAssurance.getDossierExamen();
            boolean estCapitalPrecedent = ((ProduitAsuSpec)produitDecisionne).estCapitalPrecedentRetenu(attribution);
            if ((estRead) && (competence.getCompetenceAdministrativeDroitCourant() == 1) && (((DemandeAssuranceSpec)demande).estEnContexteDroitAnterieurSecteurPublicValide()) && (estCapitalPrecedent)) {
              demande.getDemandePivot().getDecision().setMotifRejet(16);
            }
          }
        }
      }
      alimenterDonneesHorsGamme(demande, demande.getDemandePivot());
      
      alimenterDonneesGamme((Demande)demande, demande.getDemandePivot());
    }
  }
  
  private static boolean estReadmission(DemandeSpec demande)
  {
    int natureDecision = ((DecisionSpec)demande.getDossierAffectation().getDossierExamen()).getNatureDecision();
    
    boolean estUneReadmission = (natureDecision == 12) || (natureDecision == 11) || (natureDecision == 26);
    
    boolean estReliquatNonValide = (((Demande)demande).getReliquat() != null) && (!((Demande)demande).getReliquat().isReliquatValide());
    
    return (!estReliquatNonValide) && (estUneReadmission) && (!"ASU_29".equals(demande.getEvenementReferenceExamen().getTypeExamen())) && (!((Demande)demande).estDroitOptionReadmission());
  }
  
  public static void alimenterDonneesGamme(Demande demandeCali, DemandePivot demandePivot)
    throws CoucheLogiqueException
  {
    Attribution attribution = demandePivot.getAttribution();
    Decision decision = demandePivot.getDecision();
    if (attribution != null) {
      renseignerAttribution(attribution, demandeCali);
    }
    renseignerDecision(decision, demandeCali);
    renseignerPeriodesAffiliation(decision, attribution, demandeCali);
  }
  
  private static void renseignerAttribution(Attribution attribution, Demande demandeCali)
    throws CoucheLogiqueException
  {
    DecisionSpec decision = (DecisionSpec)demandeCali.getDossierExamen();
    
    attribution.setReferenceExterneDemande(demandeCali.getFormulaire().getReferenceExterne());
    
    calculIdentifiants(attribution, (AttributionSpec)decision, getRsod((AttributionSpec)decision));
    
    initPeriodeValidation(decision, attribution, demandeCali);
    if (((decision instanceof RevisionSpec)) && (((RevisionSpec)decision).getType() == 2)) {
      attribution.setFctRetenueOD(((RevisionSpec)decision).getDateExamen().veille());
    }
    alimentationSpecificiteASP(attribution, demandeCali);
    
    attribution.setCodeValidation(determineValidee(demandeCali));
    
    attribution.setCodeValidationComplementaire(determineEnRexamen(demandeCali));
    
    attribution.setNbJoursNonConsoDelaiDechance(determineNonConsoDelaiDecheance(demandeCali));
    
    attribution.setCodeMetierDroitCourant(determineCodeMetier(decision));
    
    attribution.setCodeMetier(determineCodeMetier(decision));
    
    attribution.setOrigineDecision(determineOrigineDecision(demandeCali));
    
    attribution.setIdGaecPeriodeFg(determineIdGaecFG((DossierExamenAssuranceSpec)demandeCali.getDossierExamen()));
    
    attribution.setDateDerniereFctDansDelaiForclusion(getDateFgdOuDernierSinistre((DossierExamenAssuranceSpec)demandeCali.getDossierExamen()));
    
    attribution.setMotifDerniereFctDansDelaiForclusion(determineMotifFG((DossierExamenAssuranceSpec)demandeCali.getDossierExamen()));
    
    attribution.setCodeQualificationDroitCourant(determineCodeQualification((DossierExamenAssuranceSpec)demandeCali.getDossierExamen()));
    
    attribution.setCodeQualification(determineCodeQualification((DossierExamenAssuranceSpec)demandeCali.getDossierExamen()));
    
    attribution.setCodeStatutIndividu(0);
    
    attribution.setPrcSjrForces(determinerSiDonneesForcees(demandeCali));
    
    attribution.setNbJoursActiviteCourrierASS(demandeCali.getAttribution().getNbJoursActiviteCourrierASS());
    
    attribution.setSituationParticuliereDroitCourant(determineSituationParticuliere(decision));
    attribution.setSituationParticuliereDroitRetenu("");
    if (((decision instanceof OdSpec)) && (demandeCali.getDonneesTemporaires().isEstCoordCee()))
    {
      int nbreMoisRemboursesCoordEuropeenne = OutilGestionEESSI.getInstance().determinerNombreMoisARembourser(demandeCali);
      attribution.setNbMoisRemboursesCoordEuropeenne(new BigDecimal(nbreMoisRemboursesCoordEuropeenne));
    }
    if (((decision instanceof NovationSpec)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCali, "AREENTRCSP")))
    {
      TravailSpec sinistre = ((DossierExamenAssuranceSpec)decision).getDemandeAssurance().getDossierAffectationAdmission().getSinistre();
      String id = OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(sinistre.getIdentifiant(), 17);
      
      attribution.setIdGaecPeriodeRa(id);
      attribution.setIdGaecPeriodeFg(id);
      attribution.setFctEmployeurCompetent(id);
      attribution.setFctRetenueOD(sinistre.getDateFin());
      attribution.setMotifDerniereFctDansDelaiForclusion(((ActiviteSalarie)sinistre).getMotifFin());
    }
    attribution.setDateLimiteIndemnisation(demandeCali.getAttribution().getDateLimiteIndemnisation());
  }
  
  private static void alimentationSpecificiteASP(Attribution attribution, Demande demandeCali)
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCali, 6))
    {
      ProduitAsuSpec produitANotifier = OutilAsp.getInstance().recupererProduitReglementaire(demandeCali);
      attribution.setCodeProduit(produitANotifier.getNom());
      attribution.setCodeProduitDroitCourant(produitANotifier.getNom());
    }
    else
    {
      attribution.setCodeProduit(determineNomProduit(demandeCali));
      
      attribution.setCodeProduitDroitCourant(determineNomProduit(demandeCali));
    }
  }
  
  private static void initPeriodeValidation(DecisionSpec decision, Attribution attribution, Demande demandeCali)
  {
    ActiviteSalarie periodeValidation = determinePeriodeValidationProduit(decision);
    if (((decision instanceof NovationSpec)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCali, "AREENTRCSP"))) {
      periodeValidation = (ActiviteSalarie)demandeCali.getDossierAffectationAdmission().getSinistre();
    }
    if (periodeValidation != null) {
      renseignerDonneesPeriodeValidationProduit(periodeValidation, attribution);
    }
  }
  
  private static void determinerDonneesPmvs(Decision decision, Demande demandeCali)
  {
    if (NaturesDecisions.estdeTypeAttribution(((DecisionSpec)demandeCali.getDossierExamen()).getNatureDecision()))
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)demandeCali.getDossierExamen();
      ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent(demandeCali, 2);
      if (contexteDemande != null)
      {
        decision.setDateDebutEvenement(contexteDemande.getDateDebutJustifContexte());
        decision.setDateFinEvenement(contexteDemande.getDateFinJustifContexte());
      }
      contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demandeCali, "SUITEPMVS");
      
      determinerNbJoursAffiImputes(decision, attribution, contexteDemande);
    }
  }
  
  private static void determinerNbJoursAffiImputes(Decision decision, AttributionAssuranceSpec attribution, ContexteDemande contexteDemande)
  {
    if (contexteDemande != null)
    {
      ValidationProduit validationProduit = ((DossierAffecte)attribution.getDossierAffecte()).getValidationProduit();
      if (validationProduit != null)
      {
        Quantite quantite = validationProduit.getJustificationCalculAffiliation().getQuantiteImputee();
        if (quantite != null) {
          decision.setNbJoursAffiImputes(quantite.getValeurEntiere());
        }
      }
    }
  }
  
  private static void renseignerDecision(Decision decision, Demande demandeCali)
    throws CoucheLogiqueException
  {
    decision.setReferenceExterneDemande(demandeCali.getFormulaire().getReferenceExterne());
    
    decision.setDatePriseDecision(demandeCali.getDateDerniereValidation());
    
    decision.setDateEffetDecision(determineDateEffetDecision(demandeCali));
    
    decision.setDateExamen(demandeCali.getDateRecherche());
    
    decision.setOrigineDecision(determineOrigineDecision(demandeCali));
    
    decision.setCodeValidation(determineValidee(demandeCali));
    
    decision.setCodeReexamen(determineEnRexamen(demandeCali));
    
    decision.setTypeExamen(determineTypeExamen(demandeCali));
    
    decision.setDateValidationDecision(demandeCali.getDateDerniereValidation());
    
    TracesBouchon.ecrireTrace("NPDE AlimentationBasePivot : methode renseignerDecision : positionnement initiale du top à A");
    decision.setModeTraitementDemandeNPDE("C");
    if (demandeCali.isEstInstallationNPDEsurTransaction())
    {
      String modeTraitementDemande = demandeCali.getDonneesSortieNPDE().getModeTraitementDemande();
      if (("A".equalsIgnoreCase(modeTraitementDemande)) || ("AG".equalsIgnoreCase(modeTraitementDemande)))
      {
        TracesBouchon.ecrireTrace("NPDE AlimentationBasePivot : methode renseignerDecision : repositionnement du top à A");
        decision.setModeTraitementDemandeNPDE("A");
      }
      else if ("S".equalsIgnoreCase(modeTraitementDemande))
      {
        decision.setModeTraitementDemandeNPDE("B");
        TracesBouchon.ecrireTrace("NPDE AlimentationBasePivot : methode renseignerDecision : repositionnement du top à B");
      }
    }
    if ((demandeCali.getClassementAdministratif() != null) && (demandeCali.getClassementAdministratif().estClassementValide()))
    {
      String classementAdministratif = determineClassementAdministratif(demandeCali);
      decision.setClassementAdministratif(classementAdministratif);
      if ((classementAdministratif != null) && (classementAdministratif.equals("SP"))) {
        decision.setMotifRejet(DeterminerMotifRejetSecteurPublic.alimenterMotifRejetSecteurPublic(demandeCali));
      }
      decision.setCompetenceAdministrative("AC");
    }
    else
    {
      DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demandeCali.getDossierExamen();
      if ((dossierExamen instanceof DecisionSpec))
      {
        if (((DecisionSpec)dossierExamen).getNatureDecision() == 14) {
          decision.setNatureDecision(demandeCali.getDossierAffectationReprise().getTypeRepriseContextuellePourSuivi());
        } else {
          decision.setNatureDecision(determineNatureDecision(dossierExamen));
        }
        determinerDonneesPmvs(decision, demandeCali);
        if ((dossierExamen instanceof AttributionSpec)) {
          decision.setDateFctRetenue(determineDateFctRetenue(demandeCali));
        } else if (((demandeCali.getDossierExamen() instanceof DecisionSpec)) && (demandeCali.estEnContexteDemande(10))) {
          decision.setCodeSousProduitRejet(((DecisionSpec)demandeCali.getDossierExamen()).determinerCodeSousProduitPourSigma());
        }
        if (((dossierExamen instanceof RevisionSpec)) && (((RevisionSpec)dossierExamen).getType() == 2)) {
          decision.setDateFctRetenue(demandeCali.getDonneesTemporaires().getPeriodeRevision().getDateFin());
        }
        if ((dossierExamen instanceof AttributionAssuranceSpec)) {
          decision.setSituationParticuliere(((AttributionAssuranceSpec)dossierExamen).getSituationParticuliere());
        }
        if ((((DossierAffectation)dossierExamen.getDossierAffecte()).getProduit().estIdentiqueAuProduit(ProduitAsuCge01P04.getInstance())) || (((DossierAffectation)dossierExamen.getDossierAffecte()).getProduit().estIdentiqueAuProduit(ProduitAsuCsa06P03.getInstance()))) {
          determinerSituationTopAre11(decision, demandeCali, dossierExamen);
        }
        if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCali, 6))
        {
          ProduitAsuSpec produitANotifier = OutilAsp.getInstance().recupererProduitReglementaire(demandeCali);
          decision.setCodeProduit(produitANotifier.getNom());
        }
        else
        {
          decision.setCodeProduit(determineNomProduit(demandeCali));
        }
        decision.setDateFctFG(getDateFgdOuDernierSinistre(dossierExamen));
        
        decision.setCompetenceAdministrative(determinerCompetenceAdministrative(demandeCali));
        if ((demandeCali.getCodeMotifEchecPourSigma() != null) && (!"".equalsIgnoreCase(demandeCali.getCodeMotifEchecPourSigma()))) {
          determinerMotifRejet(decision, demandeCali, dossierExamen);
        }
        decision.setEtablissementFinanceur(determinerEtablissementFinanceur(dossierExamen));
        decision.setIdExterneEmployeurSp(determinerIdExterneSP(dossierExamen));
      }
    }
  }
  
  private static void determinerSituationTopAre11(Decision decision, Demande demandeCali, DossierExamenAssuranceSpec dossierExamen)
  {
    TravailSpec dernierSinistre = ((DossierAffectation)dossierExamen.getDossierAffecte()).getSinistre();
    Damj dateDernierSinistreOuDateExamen;
    Damj dateDernierSinistreOuDateExamen;
    if (dernierSinistre == null)
    {
      dateDernierSinistreOuDateExamen = demandeCali.getDateExamen();
    }
    else
    {
      dateDernierSinistreOuDateExamen = dernierSinistre.getDateFin();
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
        if (activite.getDateEngagementProcedureLicenciement() != null) {
          dateDernierSinistreOuDateExamen = activite.getDateEngagementProcedureLicenciement();
        }
      }
    }
    if (dateDernierSinistreOuDateExamen.estApres(DATE_FIN_ARE_2009)) {
      decision.setSituationParticuliere("T");
    }
  }
  
  private static void determinerMotifRejet(Decision decision, Demande demandeCali, DossierExamenAssuranceSpec dossierExamen)
  {
    int motifRejet = Integer.parseInt(demandeCali.getCodeMotifEchecPourSigma());
    if (motifRejet == 71) {
      decision.setMotifRejet(determineCodeRejetAffi(dossierExamen));
    } else if ((((DecisionSpec)demandeCali.getDossierExamen()).getNatureDecision() == 16) || (((DecisionSpec)demandeCali.getDossierExamen()).getNatureDecision() == 33) || (((DecisionSpec)demandeCali.getDossierExamen()).getNatureDecision() == 28) || (((DecisionSpec)demandeCali.getDossierExamen()).getNatureDecision() == 29)) {
      determiner(demandeCali, decision);
    }
    if (motifRejet == 272)
    {
      ConditionValiditeReliquatSpec capr27 = ((DossierExamenAssuranceSpec)demandeCali.getDossierAffectationReprise().getDossierExamen()).getConditionValiditeReliquat();
      
      decision.setDateFinDecheance(capr27.getDateDecheance());
    }
    if (motifRejet == 42)
    {
      DelaiRechercheProduit delaiRecherche = ((DossierAffectation)demandeCali.getDossierAffectation()).getDelaiRecherche();
      if (delaiRecherche != null)
      {
        decision.setDateDebutPra(delaiRecherche.getDebut());
        decision.setDateFinPra(delaiRecherche.getFin());
      }
    }
  }
  
  public static int determineNatureDecision(DossierExamenSpec dossier)
  {
    int natureDecision = fr.unedic.cali.outilsfonctionnels.AlimentationBasePivot.determineNatureDecision(dossier);
    DemandeSpec demande = dossier.getDemande();
    if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(demande)) {
      natureDecision = 29;
    }
    return natureDecision;
  }
  
  private static void renseignerPeriodesAffiliation(Decision decision, Attribution attribution, Demande demandeCali)
  {
    if ((demandeCali != null) && (attribution != null))
    {
      Collection<PeriodeAffiliation> periodesAffiliation = new ArrayList();
      Chronologie chronoPeriodesAffiliation = demandeCali.getPeriodesAffiliation();
      if ((chronoPeriodesAffiliation == null) || (chronoPeriodesAffiliation.estVide()) || (!NaturesDecisions.estdeTypeOd(decision.getNatureDecision())))
      {
        if (attribution.getCollectionPeriodeAffiliation() != null) {
          attribution.clearCollectionPeriodeAffiliation();
        }
      }
      else
      {
        Chronologie chronoFiltree = filtrerPeriodesAffiliation(chronoPeriodesAffiliation);
        for (Iterator<?> iter = chronoFiltree.iterer(); iter.hasNext();)
        {
          PeriodeGaecSpec chronoPeriodeAffiliation = (PeriodeGaecSpec)iter.next();
          PeriodeAffiliation periodeAffiliation = creerPeriodeAffiliation(chronoPeriodeAffiliation, demandeCali, attribution.getIdentifiantOuvertureDroit());
          
          periodesAffiliation.add(periodeAffiliation);
        }
        attribution.remplacerCollectionPeriodeAffiliation(periodesAffiliation);
      }
    }
  }
  
  private static Chronologie filtrerPeriodesAffiliation(Chronologie chronoPeriodesAffiliation)
  {
    Chronologie chronoFiltree = new ChronologiePeriodes();
    
    String prefixeCourant = "";
    for (Iterator<?> iter = chronoPeriodesAffiliation.iterer(); iter.hasNext();)
    {
      Temporel periode = (Temporel)iter.next();
      if ((periode instanceof PeriodeGaecSpec)) {
        prefixeCourant = traiterPeriodeGaec(chronoPeriodesAffiliation, chronoFiltree, prefixeCourant, periode);
      }
    }
    return chronoFiltree;
  }
  
  private static String traiterPeriodeGaec(Chronologie chronoPeriodesAffiliation, Chronologie chronoFiltree, String prefixeCourant, Temporel periode)
  {
    String prefixeResultant = prefixeCourant;
    
    PeriodeGaecSpec chronoPeriodeAffiliation = (PeriodeGaecSpec)periode;
    if (((chronoPeriodeAffiliation instanceof ActiviteSalarie)) && (CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(chronoPeriodeAffiliation.getIdentifiant()) != null) && (!prefixeResultant.equals(CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(chronoPeriodeAffiliation.getIdentifiant()))))
    {
      Chronologie chronoTmp = chronoPeriodesAffiliation.copier(new FiltreActiviteSalarieSurMemeContratGAEC((ActiviteSalarie)chronoPeriodeAffiliation));
      if (!chronoFiltree.contientElement(chronoTmp.dernierElement())) {
        chronoFiltree.ajouter(chronoTmp.dernierElement());
      }
      prefixeResultant = CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(chronoPeriodeAffiliation.getIdentifiant());
    }
    else
    {
      chronoFiltree.ajouter(chronoPeriodeAffiliation);
      prefixeResultant = chronoPeriodeAffiliation.getIdentifiant();
    }
    return prefixeResultant;
  }
  
  private static PeriodeAffiliation creerPeriodeAffiliation(PeriodeGaecSpec chronoPeriodeAffiliation, Demande demandeCali, int idOD)
  {
    PeriodeAffiliation periodeAffiliation = new PeriodeAffiliation();
    
    periodeAffiliation.setDateDebut(chronoPeriodeAffiliation.getDateDebut());
    periodeAffiliation.setDateFin(chronoPeriodeAffiliation.getDateFin());
    
    String identifiant = chronoPeriodeAffiliation.getIdentifiant();
    String identifiantPourBasePivot;
    String identifiantPourBasePivot;
    if (CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(identifiant) != null) {
      identifiantPourBasePivot = bourrageA17Identifiant(CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(identifiant));
    } else {
      identifiantPourBasePivot = bourrageA17Identifiant(identifiant);
    }
    periodeAffiliation.setIdentifiantPeriode(identifiantPourBasePivot);
    if ((chronoPeriodeAffiliation instanceof PeriodeFormationAssimilable))
    {
      periodeAffiliation.setType("1");
    }
    else if ((chronoPeriodeAffiliation instanceof ActiviteSalarie))
    {
      periodeAffiliation.setType("2");
      periodeAffiliation.setQualification(((ActiviteSalarie)chronoPeriodeAffiliation).getReglement().getLibelleCourt());
      if ((((ActiviteSalarie)chronoPeriodeAffiliation).getChampApplication() == 3) || (((ActiviteSalarie)chronoPeriodeAffiliation).getChampApplication() == 4))
      {
        periodeAffiliation.setCompetenceFinanciere("SP");
        periodeAffiliation.setCompetenceAdministrative("SP");
      }
      else
      {
        periodeAffiliation.setCompetenceFinanciere("RAC");
        periodeAffiliation.setCompetenceAdministrative("RAC");
      }
    }
    else if ((chronoPeriodeAffiliation instanceof PeriodeEvenementPersonnel))
    {
      periodeAffiliation.setType("3");
    }
    else
    {
      periodeAffiliation.setType("4");
    }
    periodeAffiliation.setReferenceExterneDemande(demandeCali.getFormulaire().getReferenceExterne());
    periodeAffiliation.setIdentifiantOD(Integer.valueOf(idOD));
    
    return periodeAffiliation;
  }
  
  private static String bourrageA17Identifiant(String identifiant)
  {
    int nombreDeCaractereIdentifiantPeriode = 17;
    return StringUtils.leftPad(identifiant, 17, "0");
  }
  
  protected static void determiner(DemandeSpec demandeCali, Decision decision)
  {
    int motifRejet = determinerCodeRejet(demandeCali);
    if (motifRejet == 0)
    {
      List<?> listConditionsAttribution = demandeCali.getDossierAffectation().getDossierExamen().getListConditionsAttribution();
      motifRejet = trouverPremierMotifEchec(motifRejet, listConditionsAttribution);
    }
    decision.setMotifRejet(motifRejet);
  }
  
  private static int trouverPremierMotifEchec(int motifRejet, List<?> listConditionsAttribution)
  {
    int resultat = motifRejet;
    if (listConditionsAttribution != null)
    {
      Iterator<?> iter = listConditionsAttribution.iterator();
      while (iter.hasNext())
      {
        ConditionAttributionSpec condition = (ConditionAttributionSpec)iter.next();
        if ((condition != null) && (!condition.estSatisfait()))
        {
          resultat = condition.getCodeMotifEchec();
          break;
        }
      }
    }
    return resultat;
  }
  
  private static void renseignerDonneesPeriodeValidationProduit(ActiviteSalarie periodeValidation, Attribution attribution)
  {
    attribution.setDjtp(periodeValidation.getDernierJourTravaillePaye());
    
    attribution.setIdGaecPeriodeRa(OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(periodeValidation.getIdentifiant(), 17));
    
    attribution.setFctRetenueOD(periodeValidation.getDateFin());
    
    attribution.setMotifFctRetenueOD(periodeValidation.getMotifFin());
    
    attribution.setRegimeSs(periodeValidation.getMetier().getRegimeSecu());
    
    attribution.setUniteDureeIccp(determineUniteDureeIccp(periodeValidation));
    
    attribution.setMontantIslr(periodeValidation.getQuantiteEuroIslr().getValeur());
  }
  
  private static String determineIdGaecFG(DossierExamenAssuranceSpec dossier)
  {
    String id = null;
    if ((dossier instanceof NovationSpec)) {
      id = determineIdGaecFG((DossierExamenAssuranceSpec)((NovationSpec)dossier).getOuvertureDroit());
    } else if ((dossier.getFaitGenerateur() != null) && (dossier.getFaitGenerateur().getPeriodeFaitGenerateur() != null)) {
      id = OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(dossier.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant(), 17);
    }
    return id;
  }
  
  private static String determineSituationParticuliere(DecisionSpec dossier)
  {
    String situationParticuliere = "";
    if ((dossier instanceof AttributionAssuranceSpec)) {
      situationParticuliere = ((AttributionAssuranceSpec)dossier).getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  private static String determinerSiDonneesForcees(Demande demande)
  {
    String force = " ";
    if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getTermePrc() != null)) {
      force = "A";
    }
    return force;
  }
  
  private static String determineCodeQualification(DossierExamenAssuranceSpec dossier)
  {
    int dix = 10;
    int code = 0;
    if ((((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().isEstProduitValide()) && (((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit() != null)) {
      code = ((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit().getContrat().getNiveauQualification();
    }
    if (code < 10) {
      return "0" + Integer.toString(code);
    }
    return Integer.toString(code);
  }
  
  private static int determineCodeMetier(DossierExamenSpec dossier)
  {
    if ((((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().isEstProduitValide()) && (((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit() != null)) {
      return ((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit().getMetier().getCodeEmploi();
    }
    return 0;
  }
  
  private static int determineNonConsoDelaiDecheance(Demande demande)
  {
    int jours = 0;
    if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getAllongementDelaiDecheance() != null)) {
      jours = demande.getDonneesTemporaires().getAllongementDelaiDecheance().getJours();
    }
    return jours;
  }
  
  private static String determineUniteDureeIccp(ActiviteSalarie pas)
  {
    String type = "";
    QuantiteJourSpec quantite = pas.getQuantiteJourIccp();
    if ((quantite instanceof QuantiteJoursCalendaires)) {
      type = "C";
    } else if ((quantite instanceof QuantiteJoursOuvrables)) {
      type = "O";
    } else if ((quantite instanceof QuantiteJoursOuvres)) {
      type = "T";
    }
    return type;
  }
  
  private static int getRsod(AttributionSpec attribution)
  {
    String rsod = null;
    if (((attribution instanceof OdSpec)) || ((attribution instanceof NovationSpec))) {
      rsod = attribution.getReferenceExterne();
    } else if (((attribution instanceof RepriseSpec)) || (((attribution instanceof RevisionSpec)) && (((RevisionSpec)attribution).getType() == 2))) {
      rsod = attribution.getRsod();
    }
    return Integer.parseInt(rsod);
  }
  
  private static int determineCodeRejetAffi(DossierExamenAssuranceSpec rejet)
  {
    int codeRejet = 71;
    
    ActiviteSalarie periodeReglementARetenir = (ActiviteSalarie)((Demande)rejet.getDemande()).getDonneesTemporaires().getPeriodeFctARetenir();
    if ((periodeReglementARetenir == null) && (rejet.getFaitGenerateur() != null)) {
      periodeReglementARetenir = rejet.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    Reglement reglementARetenir;
    Reglement reglementARetenir;
    if (periodeReglementARetenir != null)
    {
      EvenementReferenceExamenSpec ereDemande = ((Demande)rejet.getDemande()).getEvenementReferenceExamen();
      Reglement reglementARetenir;
      if ("ASU_29".equals(ereDemande.getTypeExamen())) {
        reglementARetenir = Reglement.getInstance(((EreTypeRechargementSpec)ereDemande).getNomReglementARecharger(), rejet.getDossierAffecte().getProduit());
      } else {
        reglementARetenir = periodeReglementARetenir.getReglement();
      }
    }
    else
    {
      Reglement reglementRejet = null;
      if ((((DossierAffectation)rejet.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffectation)rejet.getDossierAffecte()).getValidationProduit().isEstProduitValide())) {
        reglementRejet = ((DossierAffectation)rejet.getDossierAffecte()).getValidationProduit().getReglementApplicable();
      }
      Reglement reglementARetenir;
      if (reglementRejet != null) {
        reglementARetenir = Reglement.getInstance(reglementRejet.getNomReglement(), rejet.getDossierAffecte().getProduit());
      } else {
        reglementARetenir = Reglement.getInstance("RG", rejet.getDossierAffecte().getProduit());
      }
    }
    if (reglementARetenir != null) {
      codeRejet = ((Integer)CodesMotifsEchec.s_codeMotifRejetAffi.get(reglementARetenir.getNomReglement())).intValue();
    }
    return codeRejet;
  }
  
  private static String determinerCompetenceAdministrative(Demande demande)
  {
    String competencePivot = "";
    CompetenceSpec competence = ((DossierExamenAssuranceSpec)demande.getDossierExamen()).getCompetence();
    if (competence != null)
    {
      if (competence.getCompetenceAdministrative() == 1) {
        competencePivot = "AC";
      } else if (competence.getCompetenceAdministrative() == 2) {
        competencePivot = "SP";
      }
      if ((competence.getConventionGestion() != null) && ("2".equals(competence.getConventionGestion().getSignataire()))) {
        competencePivot = "CG";
      }
    }
    return competencePivot;
  }
  
  private static Damj determineDateEffetDecision(Demande demande)
  {
    Damj dateEffet;
    Damj dateEffet;
    if (demande.getAttribution() != null) {
      dateEffet = demande.getAttribution().getDateEffet();
    } else {
      dateEffet = demande.getDateRecherche();
    }
    return dateEffet;
  }
  
  private static Damj determineDateFctRetenue(Demande demande)
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    
    Damj date = null;
    ActiviteSalarie periodeValidation = determinePeriodeValidationProduit(dossierExamen);
    if (periodeValidation != null) {
      date = periodeValidation.getDateFin();
    }
    return date;
  }
  
  private static ActiviteSalarie determinePeriodeValidationProduit(DossierExamenSpec dossier)
  {
    ActiviteSalarie pas = null;
    if ((((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().isEstProduitValide())) {
      pas = ((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit();
    }
    return pas;
  }
  
  public static String determineOrigineDecision(Demande demande)
  {
    String origineDecision = null;
    
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    boolean demandeAntecedent = ere.estType(EvenementReferenceExamenAntecedentSpec.class);
    if (demande.getDecisionAutomatique() == 1) {
      origineDecision = "AU";
    } else if (demandeAntecedent)
    {
      if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().getContexteDemande() != null)) {
        origineDecision = determinerOrigineDecisionAntecedent(demande.getSaisieAntecedent().getContexteDemande().intValue(), origineDecision);
      }
    }
    else if (demande.getDecisionAutomatique() == 2) {
      origineDecision = "RA";
    } else {
      origineDecision = "AS";
    }
    return origineDecision;
  }
  
  private static String determinerOrigineDecisionAntecedent(int contexteDemande, String origineDecision)
  {
    String resultat = origineDecision;
    switch (contexteDemande)
    {
    case 2: 
      resultat = "AM";
      break;
    case 1: 
      resultat = "AT";
      break;
    case 3: 
      resultat = "AP";
      break;
    case 5: 
      resultat = "AE";
      break;
    case 6: 
      resultat = "AR";
      break;
    }
    return resultat;
  }
  
  private static boolean estPrescriteNonOpposable(DemandeSpec demande)
  {
    return (demande.getClassementAdministratif() != null) && (!demande.getClassementAdministratif().estClassementValide());
  }
  
  public static Damj getDateFgdOuDernierSinistre(DossierExamenAssuranceSpec dossierExamen)
    throws CoucheLogiqueException
  {
    Damj date = null;
    if (((NaturesDecisions.estdeTypeReprise(((Demande)dossierExamen.getDemandeAssurance()).getObjectifDecisionne().getSousType())) || (NaturesDecisions.estdeTypePoursuite(((Demande)dossierExamen.getDemandeAssurance()).getObjectifDecisionne().getSousType()))) && (dossierExamen.estRejetDV()) && (!"ASU_04".equals(dossierExamen.getDemandeAssurance().getEvenementReferenceExamen().getTypeExamen())))
    {
      date = GestionDemandeDv122eJour.calculerPointDepart((Demande)dossierExamen.getDemandeAssurance(), (Demande)dossierExamen.getDemandeAssurance());
    }
    else if ((dossierExamen instanceof NovationSpec))
    {
      date = getDateFgdOuDernierSinistre((DossierExamenAssuranceSpec)((NovationSpec)dossierExamen).getOuvertureDroit());
    }
    else
    {
      if (dossierExamen.getFaitGenerateur() != null) {
        date = dossierExamen.getFaitGenerateur().getDateFaitGenerateur();
      }
      if ((date == null) && (((DossierAffecte)dossierExamen.getDossierAffecte()).getSinistre() != null)) {
        date = ((DossierAffecte)dossierExamen.getDossierAffecte()).getSinistre().getDateFin();
      }
    }
    return date;
  }
  
  private static String determineMotifFG(DossierExamenAssuranceSpec dossierExamen)
  {
    String motif = null;
    if (dossierExamen.getFaitGenerateur() != null) {
      motif = dossierExamen.getFaitGenerateur().getMotifFinPeriode();
    }
    return motif;
  }
  
  private static String determinerEtablissementFinanceur(DossierExamenAssuranceSpec dossierExamen)
  {
    String etablissementFinanceur = null;
    if ((dossierExamen.getCompetence() != null) && (dossierExamen.getCompetence().getNumeroConventionGestion() != null)) {
      etablissementFinanceur = dossierExamen.getCompetence().getNumeroConventionGestion();
    }
    return etablissementFinanceur;
  }
  
  private static String determinerIdExterneSP(DossierExamenAssuranceSpec dossierExamen)
  {
    String identifiantExterne = null;
    if ((dossierExamen.getCompetence() != null) && (dossierExamen.getCompetence().getNumeroConventionGestion() != null)) {
      identifiantExterne = dossierExamen.getCompetence().getIdExterneEmployeurSp();
    }
    return identifiantExterne;
  }
  
  public static Damj determineDateTheoriqueFinDroit(AttributionAssuranceSpec attribution)
  {
    Damj dateTheoriqueFinDroit = null;
    
    Demande demande = (Demande)attribution.getDemande();
    if (demande.estUneDemandeAntecedentFinDroitSp())
    {
      SaisieAntecedent antecedent = demande.getSaisieAntecedent();
      if (antecedent != null) {
        dateTheoriqueFinDroit = antecedent.getDateDernierJourCalcule();
      }
    }
    else
    {
      dateTheoriqueFinDroit = attribution.getPremierJourIndemnisable();
      Quantite dureeEffective = attribution.getDureeIndemnisationEffective();
      if ((dureeEffective != null) && (dureeEffective.getValeurEntiere() != 0) && (dateTheoriqueFinDroit != null)) {
        dateTheoriqueFinDroit = dateTheoriqueFinDroit.deplacerVersAvant(new DureeCalendaire(0, 0, dureeEffective.getValeurEntiere() - 1));
      }
    }
    return dateTheoriqueFinDroit;
  }
}

/* Location:
 * Qualified Name:     AlimentationBasePivot
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */