package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.fabriques.FabriquePositionnementCriteresQualification;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.spec.StrategiePositionnementCriteresQualificationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.util.Iterator;
import java.util.List;

public class ConstitutionDecorReglementaire
  implements OutilFonctionnel
{
  public static DecorReglementaire recupererDecor(DossierAffectation p_dossier)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_dossier.getDemande();
    TravailSpec dernierSinistre = p_dossier.getSinistre();
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    
    conteneur.setDemande(demande);
    conteneur.setDernierSinistre(dernierSinistre);
    if (demande.getSaisieAntecedent() != null) {
      conteneur.setEstSituationParticuliereAre2001(demande.getSaisieAntecedent().isEstSituationParticuliereAre2001());
    }
    if ((OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) && (demande.getDonneesTemporaires().getDateChomageTotalSansRupture() != null))
    {
      conteneur.setDateRecherche(demande.getDonneesTemporaires().getDateChomageTotalSansRupture());
      conteneur.setDateFinContrat(demande.getDonneesTemporaires().getDateChomageTotalSansRupture());
    }
    else
    {
      if (demande.getDonneesTemporaires() != null) {
        conteneur.setDerogation(demande.getDonneesTemporaires().isEstDerogationCsp());
      }
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)dernierSinistre;
        conteneur.setDateRuptureContrat(activiteSalarie.getDateRuptureContratTravail());
        conteneur.setDateEngagementProcedureLicenciement(activiteSalarie.getDateEngagementProcedureLicenciement());
        if (activiteSalarie.getContrat() != null) {
          conteneur.setCodeMotifRupture(activiteSalarie.getContrat().getCodeMotifFin());
        }
      }
      conteneur.setDateFinContrat(dernierSinistre.getDateFin());
    }
    conteneur.setBesoinCritereQualif(true);
    return recupererDecor(conteneur);
  }
  
  public static DecorReglementaire recupererDecor(ConteneurAccesDecorReglementaire pConteneur)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)pConteneur.getDemande();
    if (pConteneur.getDateFinContrat() == null)
    {
      if (Log.isTraceActive(ConstitutionDecorReglementaire.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, ConstitutionDecorReglementaire.class, "recupererDecor", "Le paramètre date fin de sinistre est null");
      }
      return null;
    }
    DecorReglementaire decor = AccesDecorReglementaire.getInstance().getDecor(pConteneur);
    
    StrategiePositionnementCriteresQualificationSpec strategiePositionnement = recupererStrategiePositionnementCriteresQualification(demande);
    strategiePositionnement.positionnerCriteresQualifications(pConteneur, decor);
    return decor;
  }
  
  private static StrategiePositionnementCriteresQualificationSpec recupererStrategiePositionnementCriteresQualification(Demande pDemande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(pDemande.getDateRecherche());
    FabriquePositionnementCriteresQualification fabrique = FabriquePositionnementCriteresQualification.getInstance();
    return (StrategiePositionnementCriteresQualificationSpec)fabrique.getStrategie(critere);
  }
  
  public static ProduitAsuSpec determinerProduitSinistre(ActiviteSalarie p_sinistre, DecorReglementaire p_decorReglementaire)
  {
    ProduitAsuSpec produitARetourner = null;
    Reglement reglement = p_sinistre.getReglement();
    if (p_sinistre.getReglement() != null) {
      produitARetourner = determinerProduitPourReglement(reglement.getNomReglement(), p_decorReglementaire);
    }
    return produitARetourner;
  }
  
  public static ProduitAsuSpec determinerProduitPourReglement(String pReglement, DecorReglementaire p_decorReglementaire)
  {
    Iterator listeProduits;
    if (pReglement != null) {
      for (listeProduits = p_decorReglementaire.getListeProduits().iterator(); listeProduits.hasNext();)
      {
        ProduitAsuSpec produit = (ProduitAsuSpec)listeProduits.next();
        if (produit.contientReglement(pReglement)) {
          return produit;
        }
      }
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDecorReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */