package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieDroitOptionElargiApres;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieDroitOptionElargiAvant;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.spec.StrategieDroitOptionElargiSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateFinCoincideAvecDate;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFctPrincipale;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAsp;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourNumeroGamme;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreRepriseSurDecisions;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinApresOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class ConstitutionListeEre
  implements OutilFonctionnel
{
  protected static final Damj DATE_010103 = new Damj(2003, 1, 1);
  private static ConstitutionListeEre instance = null;
  
  public static ConstitutionListeEre getInstance()
  {
    if (instance == null) {
      instance = new ConstitutionListeEre();
    }
    return instance;
  }
  
  public List<EvenementReferenceExamenSpec> determinerPourDemandeExpresse(Contexte contexte)
    throws ApplicativeException
  {
    List<EvenementReferenceExamenSpec> listeEre = new ArrayList();
    Demande demande = getDemandeAsu(contexte);
    Damj dateDepot = demande.getFormulaire().getDateDepot();
    
    EreDemandeExpresse ereParDefaut = (EreDemandeExpresse)demande.getEvenementReferenceExamen();
    ereParDefaut.setDateEvenement(dateDepot);
    
    Chronologie chronoPeriodesParticipantes = determinerChronologiePourDeterminationContexte(demande);
    
    constituterContexte(demande, demande.estEnContexteDroitAnterieurSecteurPublic(), chronoPeriodesParticipantes, (DomLiquidationAssurance)contexte.getDonnees());
    if (chronoPeriodesParticipantes.estVide()) {
      listeEre.add(ereParDefaut);
    } else if (getDom(contexte).isContexteOuvertureDroitAuPlusTot()) {
      determinerListeErePourOuvertureDroitAuPlusTot(demande, listeEre, chronoPeriodesParticipantes, ereParDefaut);
    } else {
      determinerListeErePourOuvertureDroitAuPlusTard(demande, listeEre, chronoPeriodesParticipantes, ereParDefaut);
    }
    return listeEre;
  }
  
  protected Damj getBorneSuperieure(Demande demande)
  {
    return demande.getFormulaire().getDateDepot();
  }
  
  public Chronologie determinerChronologiePourDeterminationContexte(Demande demande)
    throws CoucheLogiqueException
  {
    Damj borneInferieure = getDecisionAvant(demande);
    Damj borneSup = getBorneSuperieure(demande);
    
    Damj dateFaitGenerateurOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
    Damj borneInf = borneInferieure;
    if ((demande.getDonneesTemporaires().getPeriodeFctARetenir() != null) && (dateFaitGenerateurOdPrecedente != null) && (demande.getDonneesTemporaires().getPeriodeFctARetenir().getDateFin().estAvantOuCoincideAvec(dateFaitGenerateurOdPrecedente))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_EXPRESSE_FCT_FORCEE");
    }
    if (demande.getDonneesTemporaires().getPeriodeFctARetenir() != null) {
      borneInf = Damj.max(borneInferieure, demande.getDonneesTemporaires().getPeriodeFctARetenir().getDateFin());
    }
    Chronologie chronoPeriodePasseProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    FiltresTemporel filtreActiviteSalarieeDemandeExpresse = new FiltresTemporel();
    filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(borneSup.veille()));
    filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltreFinApresOuCoincideAvecDate(borneInf));
    filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltrePeriodesLiquidables());
    filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301NonFrontalier(false));
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
      filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltreActiviteSalarie());
    } else {
      filtreActiviteSalarieeDemandeExpresse.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
    }
    Chronologie chronoPeriodesParticipantes = chronoPeriodePasseProfessionnel.copier(filtreActiviteSalarieeDemandeExpresse);
    
    chronoPeriodesParticipantes.setComparateur(new ComparateurTemporelsSurDateFin());
    return chronoPeriodesParticipantes;
  }
  
  protected void positionnerDateEvenement(Demande demande, EreDemandeExpresse ereParDefaut, Damj dateFct)
    throws CoucheLogiqueException
  {
    ObjetChronoPeriodePriseEnCharge pecRetenue = OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), dateFct.lendemain());
    
    boolean droitOptionReadmissionForce = estDroitOptionForce(demande);
    if (droitOptionReadmissionForce) {
      ereParDefaut.setDateEvenement(demande.getDateDepot());
    } else if (pecRetenue != null) {
      ereParDefaut.setDateEvenement(dateFct.lendemain());
    } else {
      ereParDefaut.setDateEvenement(OutillagePEC.getPremierJourPECDemandeurMayotteExclu(demande.getDemandeur(), dateFct.lendemain()));
    }
  }
  
  protected void constituterContexte(Demande demande, boolean estContexteDroitAnterieurSecteurPublic, Chronologie chronoFCTParticipantes, DomLiquidationAssurance donnees)
    throws ApplicativeException
  {
    if (chronoFCTParticipantes.estVide())
    {
      donnees.setContexteOuvertureDroitAuPlusTot(true);
      donnees.setContexteExamenDdeExpresse(7);
    }
    else if (estContexteDroitAnterieurSecteurPublic)
    {
      donnees.setContexteOuvertureDroitAuPlusTot(false);
      donnees.setContexteExamenDdeExpresse(8);
    }
    else
    {
      ObjetChronoPeriode periodeIndemnisation = RechercherPeriodeIndemnisation.rechercherPeriodeIndemniseeEffectiveAssurance(demande.getDemandeur(), chronoFCTParticipantes.premierElement().getDateFin().lendemain());
      if (periodeIndemnisation == null)
      {
        donnees.setContexteOuvertureDroitAuPlusTot(true);
        donnees.setContexteExamenDdeExpresse(7);
      }
      else
      {
        donnees.setContexteOuvertureDroitAuPlusTot(false);
        donnees.setContexteExamenDdeExpresse(8);
      }
    }
  }
  
  private Chronologie determinerChronologiePourOuvertureDroitAuPlusTot(Demande demandeCourante, Chronologie chronoPeriodesParticipantes)
    throws ApplicativeException
  {
    Damj djiAttributionPrecedente = DATE_010103;
    
    AttributionSpec attributionAsuPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, new FiltreAttributionStandardAssurance(true, true, true, false, demandeCourante));
    if (attributionAsuPrecedente != null)
    {
      ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAsuPrecedente, null, true);
      if (!resultatCalcul.isCalendrierNul()) {
        djiAttributionPrecedente = resultatCalcul.getDernierJourIndemnisable();
      }
    }
    return chronoPeriodesParticipantes.copier(new FiltreFinApresOuCoincideAvecDate(djiAttributionPrecedente));
  }
  
  protected void determinerListeErePourOuvertureDroitAuPlusTard(Demande demande, List<EvenementReferenceExamenSpec> listeEre, Chronologie chronoPeriodesParticipantes, EreDemandeExpresse ereParDefaut)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeFct = (ActiviteSalarie)chronoPeriodesParticipantes.premierElement();
    Damj dateFct = periodeFct.getDateFin();
    
    ereParDefaut.setPeriodeExamen(periodeFct);
    
    Chronologie chronoFctConcomittante = detecterFctConcomittante(chronoPeriodesParticipantes, periodeFct);
    if (periodeFct.estUneFctConcomittante())
    {
      if (periodeFct.estFctPrincipale())
      {
        positionnerDateEvenement(demande, ereParDefaut, dateFct);
        listeEre.add(ereParDefaut);
      }
      else
      {
        Chronologie chronoFctPrincipale = chronoFctConcomittante.copier(new FiltrePeriodeFctPrincipale(dateFct));
        if (!chronoFctPrincipale.estVide())
        {
          ActiviteSalarie periodeFctPrincipale = (ActiviteSalarie)chronoFctPrincipale.premierElement();
          ereParDefaut.setPeriodeExamen(periodeFctPrincipale);
          
          positionnerDateEvenement(demande, ereParDefaut, dateFct);
          listeEre.add(ereParDefaut);
        }
        else
        {
          positionnerDateEvenement(demande, ereParDefaut, dateFct);
          listeEre.add(ereParDefaut);
        }
      }
    }
    else
    {
      positionnerDateEvenement(demande, ereParDefaut, dateFct);
      listeEre.add(ereParDefaut);
    }
  }
  
  private void determinerListeErePourOuvertureDroitAuPlusTot(Demande demandeCourante, List<EvenementReferenceExamenSpec> listeEre, Chronologie chronoPeriodesParticipantes, EreDemandeExpresse ereParDefaut)
    throws ApplicativeException
  {
    Chronologie chronologiePourOuvertureDroitAuPlusTot = null;
    if (estDroitOptionForce(demandeCourante)) {
      chronologiePourOuvertureDroitAuPlusTot = chronoPeriodesParticipantes;
    } else {
      chronologiePourOuvertureDroitAuPlusTot = determinerChronologiePourOuvertureDroitAuPlusTot(demandeCourante, chronoPeriodesParticipantes);
    }
    int taille = chronologiePourOuvertureDroitAuPlusTot.getTaille();
    ListIterator<?> iter = chronologiePourOuvertureDroitAuPlusTot.mapperVersListe().listIterator(taille);
    while (iter.hasPrevious())
    {
      ActiviteSalarie periode = (ActiviteSalarie)iter.previous();
      Damj dateFinPeriode = periode.getDateFin();
      EreDemandeExpresse ereDemandeExpresse = new EreDemandeExpresse();
      ereDemandeExpresse.setPeriodeExamen(periode);
      
      Chronologie chronoFctConcomittante = detecterFctConcomittante(chronologiePourOuvertureDroitAuPlusTot, periode);
      if (periode.estUneFctConcomittante())
      {
        gererFctConcomittante(demandeCourante, listeEre, periode, dateFinPeriode, ereDemandeExpresse, chronoFctConcomittante);
      }
      else
      {
        positionnerDateEvenement(demandeCourante, ereDemandeExpresse, dateFinPeriode);
        listeEre.add(ereDemandeExpresse);
      }
    }
    if (listeEre.isEmpty()) {
      listeEre.add(ereParDefaut);
    }
  }
  
  protected Chronologie detecterFctConcomittante(Chronologie chronologieParticipantes, ActiviteSalarie periode)
  {
    FiltresTemporel filtreTemporel = new FiltresTemporel();
    filtreTemporel.ajouterFiltre(new FiltreDateFinCoincideAvecDate(periode.getDateFin()));
    Chronologie chronoFctConcomittante = chronologieParticipantes.copier(filtreTemporel);
    if (chronoFctConcomittante.getTaille() > 1) {
      periode.setEstUneFctConcomittante(true);
    }
    return chronoFctConcomittante;
  }
  
  private void gererFctConcomittante(Demande demandeCourante, List<EvenementReferenceExamenSpec> listeEre, ActiviteSalarie periode, Damj dateFinPeriode, EreDemandeExpresse ereDemandeExpresse, Chronologie chronoFctConcomittante)
    throws CoucheLogiqueException
  {
    if (periode.estFctPrincipale())
    {
      positionnerDateEvenement(demandeCourante, ereDemandeExpresse, dateFinPeriode);
      listeEre.add(ereDemandeExpresse);
    }
    else
    {
      Chronologie chronoFctPrincipale = chronoFctConcomittante.copier(new FiltrePeriodeFctPrincipale(dateFinPeriode));
      if (chronoFctPrincipale.estVide())
      {
        positionnerDateEvenement(demandeCourante, ereDemandeExpresse, dateFinPeriode);
        listeEre.add(ereDemandeExpresse);
      }
    }
  }
  
  protected Damj getDecisionAvant(DemandeSpec demandeSpec)
    throws CoucheLogiqueException
  {
    FiltreET filtreET = new FiltreET();
    
    filtreET.ajouterFiltre(new FiltreDemandePourNumeroGamme(1));
    
    filtreET.ajouterFiltre(new FiltreNegation(new FiltreDemandePourERE("ASU_07")));
    filtreET.ajouterFiltre(OutilFinDroit.getFiltreExclureFinDeDroit());
    
    FiltreET filtreRepriseAsp = new FiltreET();
    filtreRepriseAsp.ajouterFiltre(new FiltreRepriseSurDecisions());
    filtreRepriseAsp.ajouterFiltre(new FiltreAttributionAsp());
    filtreET.ajouterFiltre(new FiltreNegation(filtreRepriseAsp));
    
    Demande demandeAsu = (Demande)demandeSpec;
    boolean droitOptionReadmissionForce = estDroitOptionForce(demandeAsu);
    if (droitOptionReadmissionForce) {
      filtreET.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
    }
    Chronologie chronoDemandesPrecedentes = OutilRecherche.rechercherDemandesPrecedentes(demandeSpec.getChronologieDemandesAssuranceSansCourante(), demandeSpec, filtreET);
    
    chronoDemandesPrecedentes = chronoDemandesPrecedentes.copier(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(demandeSpec.getDateDeclenchementExamen(), demandeSpec, demandeSpec.getEvenementReferenceExamen()));
    
    chronoDemandesPrecedentes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    
    Iterator<?> iterateurDemandes = chronoDemandesPrecedentes.iterer();
    DemandeSpec demande = null;
    while (iterateurDemandes.hasNext())
    {
      demande = (DemandeSpec)iterateurDemandes.next();
      if (demande.getDossierAffectation() != null)
      {
        if ((demande.getClassementAdministratif() != null) && ("SP".equals(demande.getClassementAdministratif().getTypeClassement()))) {
          return demande.getDateDeclenchementExamen();
        }
        if ((demande.getDossierAffectation().getDossierExamen() != null) && (demande.estDecisionnee())) {
          return demande.getDateExamen();
        }
      }
    }
    return DATE_010103;
  }
  
  private DomLiquidationAssurance getDom(Contexte contexte)
  {
    return (DomLiquidationAssurance)contexte.getDonnees();
  }
  
  private Demande getDemandeAsu(Contexte contexte)
  {
    return getDom(contexte).getDemande();
  }
  
  protected boolean estDroitOptionForce(Demande demandeAsu)
    throws CoucheLogiqueException
  {
    boolean droitOptionReadmissionForce = false;
    if (demandeAsu.getDonneesTemporaires() != null)
    {
      StrategieDroitOptionElargiSpec strategie = (StrategieDroitOptionElargiSpec)FabriqueStrategieGenerique.choisirStrategie(demandeAsu.getDateDepot(), "Application du droit d'option élargi.", new StrategieDroitOptionElargiAvant(), new StrategieDroitOptionElargiApres());
      
      droitOptionReadmissionForce = strategie.estDroitOptionForce(demandeAsu);
    }
    return droitOptionReadmissionForce;
  }
}

/* Location:
 * Qualified Name:     ConstitutionListeEre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */