package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesGammeAsu;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRevision;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.Iterator;

public class ConstitutionListeEreDdeExprForcageMotifExamen
  extends ConstitutionListeEre
{
  private static ConstitutionListeEreDdeExprForcageMotifExamen s_instance = null;
  
  public static ConstitutionListeEre getInstance()
  {
    if (s_instance == null) {
      s_instance = new ConstitutionListeEreDdeExprForcageMotifExamen();
    }
    return s_instance;
  }
  
  protected Damj getDecisionAvant(DemandeSpec p_demande)
  {
    Chronologie chronologieDemandes = p_demande.getDemandeur().getChronoDemandes();
    
    FiltresTemporel filtresTemporel = new FiltresTemporel();
    if ((chronologieDemandes != null) && (p_demande != null))
    {
      filtresTemporel.ajouterFiltre(new FiltreDemandesGammeAsu());
      
      filtresTemporel.ajouterFiltre(new FiltreNegation(new FiltreRevision()));
      filtresTemporel.ajouterFiltre(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(p_demande.getDateDeclenchementExamen(), p_demande));
    }
    if (chronologieDemandes != null)
    {
      chronologieDemandes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
      chronologieDemandes = chronologieDemandes.copier(filtresTemporel);
    }
    if (chronologieDemandes != null)
    {
      Iterator iterateurDemandes = chronologieDemandes.iterer();
      DemandeSpec demande = null;
      while (iterateurDemandes.hasNext())
      {
        demande = (DemandeSpec)iterateurDemandes.next();
        if (demande.getDossierAffectation() != null)
        {
          if ((demande.getClassementAdministratif() != null) && ("SP".equals(demande.getClassementAdministratif().getTypeClassement()))) {
            return demande.getDateDeclenchementExamen();
          }
          if ((demande.getDossierAffectation().getDossierExamen() != null) && ((demande.getDossierAffectation().getDossierExamen() instanceof AttributionAssuranceSpec))) {
            return demande.getDateExamen();
          }
        }
      }
    }
    return DATE_010103;
  }
  
  protected void constituterContexte(Contexte p_contexte, Chronologie p_chronoFCTParticipantes)
    throws CoucheLogiqueException
  {
    ((DomLiquidationAssurance)p_contexte.getDonnees()).setContexteOuvertureDroitAuPlusTot(false);
    ((DomLiquidationAssurance)p_contexte.getDonnees()).setContexteExamenDdeExpresse(8);
  }
  
  protected void positionnerDateEvenement(Demande p_demande, EreDemandeExpresse p_ereParDefaut, Damj p_dateFct)
  {
    Damj lendemainFinEvt = p_demande.getDonneesTemporaires().getDateFinEvenement().lendemain();
    ObjetChronoPeriodePriseEnCharge pecRetenue = OutillagePEC.getPeriodePECIndemnisableContenant(p_demande.getDemandeur(), lendemainFinEvt);
    if (pecRetenue != null) {
      p_ereParDefaut.setDateEvenement(lendemainFinEvt);
    } else {
      p_ereParDefaut.setDateEvenement(OutillagePEC.getPremierJourPECNonAnnuleesApresDate(p_demande.getDemandeur(), lendemainFinEvt));
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionListeEreDdeExprForcageMotifExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */