package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriqueStategieDateDebutMaxActiviteConservee;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieActiviteConservee;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StategieDateDebutMaxActiviteConserveeSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieActiviteConserveeSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteNonSalariePeriodique;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEtatNonProfessionnel;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAutreQueFormationCifCdd;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreInvestigationFrauduleuse;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalarieePeriodique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeDsmTravailActiviteConservee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeDsmTravailNonJustifiee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationImputableSurDuree;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreSurMotifFinActivite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSalarie;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalariePourIdentifiant;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeChevauchePeriode;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeDebutAvantDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinApresDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinAvantDate;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;

public class ConstructionChronologie
{
  private static final int DUREE_13_MOIS = 13;
  
  public static Chronologie determinerPeriodesDeclareesNonJustifiees(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    
    filtres.ajouterFiltre(new FiltrePeriodeDsmTravailNonJustifiee());
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static Chronologie determinerPeriodesEnConflit(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    filtres.ajouterFiltre(new FiltrePeriodesAvecConflit());
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static Chronologie determinerPeriodesNonQualifiees(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    filtres.ajouterFiltre(new FiltreTravailSalarie());
    filtres.ajouterFiltre(new FiltrePeriodesQualifiables(false));
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static Chronologie determinerPeriodesQualifieesNonLiquidables(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    filtres.ajouterFiltre(new FiltreTravailSalarie());
    filtres.ajouterFiltre(new FiltrePeriodesQualifiables());
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables(false));
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static Chronologie determinerPeriodesNonAttestees(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    filtres.ajouterFiltre(new FiltreTravailSalarie());
    filtres.ajouterFiltre(new FiltrePeriodesAttestees(false));
    filtres.ajouterFiltre(new FiltrePeriodesQualifiables());
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static Chronologie determinerPeriodesFermetureDefinitiveEtablissement(Periode p_periodeRecherche, Chronologie p_chronoActivites)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(p_periodeRecherche));
    filtres.ajouterFiltre(new FiltreSurMotifFinActivite(3));
    
    return p_chronoActivites.copier(filtres);
  }
  
  public static FiltreTemporel filtreChevauchePeriodeAvecPriseEnComptePmvs(List<ContexteDemandeSpec> p_listeContexte, Periode p_periode, boolean p_forcerSelectionActiviteAvecPmvsEnContextePmvs)
  {
    return gestionBooleanForcagePmvs(p_listeContexte, p_forcerSelectionActiviteAvecPmvsEnContextePmvs, new FiltreObjetChronoPeriodeChevauchePeriode(p_periode, "MVS"));
  }
  
  public static FiltreTemporel filtreFinAvantDateAvecPriseEnComptePmvs(List<ContexteDemandeSpec> p_listeContexte, Damj p_date, boolean p_forcerSelectionActiviteAvecPmvsEnContextePmvs)
  {
    return gestionBooleanForcagePmvs(p_listeContexte, p_forcerSelectionActiviteAvecPmvsEnContextePmvs, new FiltreObjetChronoPeriodeFinAvantDate(p_date, "MVS"));
  }
  
  public static FiltreTemporel filtreDebutAvantOuCoincideAvecDateAvecPriseEnComptePmvs(List<ContexteDemandeSpec> p_listeContexte, Damj p_date, boolean p_forcerSelectionActiviteAvecPmvsEnContextePmvs)
  {
    return gestionBooleanForcagePmvs(p_listeContexte, p_forcerSelectionActiviteAvecPmvsEnContextePmvs, new FiltreObjetChronoPeriodeDebutAvantDate(p_date.lendemain(), "MVS"));
  }
  
  public static FiltreTemporel filtreFinApresDateAvecPriseEnComptePmvs(List<ContexteDemandeSpec> p_listeContexte, Damj p_date, boolean p_forcerSelectionActiviteAvecPmvsEnContextePmvs)
  {
    return gestionBooleanForcagePmvs(p_listeContexte, p_forcerSelectionActiviteAvecPmvsEnContextePmvs, new FiltreObjetChronoPeriodeFinApresDate(p_date, "MVS"));
  }
  
  private static FiltreCaliSpec gestionBooleanForcagePmvs(List<ContexteDemandeSpec> p_listeContexte, boolean p_forcerSelectionActiviteAvecPmvsEnContextePmvs, FiltreCaliSpec p_filtreATraiter)
  {
    FiltreCaliSpec filtre = null;
    if (p_forcerSelectionActiviteAvecPmvsEnContextePmvs)
    {
      filtre = new FiltreOU();
      ((FiltreOU)filtre).ajouterFiltre(p_filtreATraiter);
      ((FiltreOU)filtre).ajouterFiltre(creerFiltreSelectionActivitePortantPmvs(p_listeContexte));
    }
    else
    {
      filtre = new FiltreET();
      ((FiltreET)filtre).ajouterFiltre(p_filtreATraiter);
      ((FiltreET)filtre).ajouterFiltre(new FiltreNegation(creerFiltreSelectionActivitePortantPmvs(p_listeContexte)));
    }
    return filtre;
  }
  
  private static FiltreCaliSpec creerFiltreSelectionActivitePortantPmvs(List<ContexteDemandeSpec> p_listeContexte)
  {
    return new FiltreActiviteSalariePourIdentifiant(recupererIdentifiantPeriodePmvs(p_listeContexte), "MVS");
  }
  
  public static String recupererIdentifiantPeriodePmvs(List<ContexteDemandeSpec> p_listeContexte)
  {
    String identifiant = null;
    ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContextePresent(p_listeContexte, 2);
    if (contexteDemande != null) {
      identifiant = contexteDemande.getIdentifiantPeriodeCaliJustifContexte();
    }
    return identifiant;
  }
  
  public static Chronologie determinerPeriodesParticipantesAffiliationRegle13Mois(List<ContexteDemandeSpec> p_listeContexte, Periode p_periodeRecherche, Chronologie p_chronoActivites, boolean p_avecPeriodeNonAttestee)
  {
    Chronologie chronoActivitesRetenues = null;
    
    Periode periode13DerniersMoisFct = new Periode(p_periodeRecherche.getFin().soustraireNombreMois(13).getDebut(), p_periodeRecherche.getFin());
    
    FiltresTemporel listeFiltres13DerniersMois = new FiltresTemporel();
    
    listeFiltres13DerniersMois.ajouterFiltre(filtreChevauchePeriodeAvecPriseEnComptePmvs(p_listeContexte, periode13DerniersMoisFct, true));
    
    listeFiltres13DerniersMois.ajouterFiltre(new FiltreObjetChronoPeriodeChevauchePeriode(periode13DerniersMoisFct, ""));
    if (!p_avecPeriodeNonAttestee) {
      listeFiltres13DerniersMois.ajouterFiltre(new FiltrePeriodesAttestees());
    }
    FiltresTemporel listeFiltresMoisAnterieurs13DerniersMois = new FiltresTemporel();
    
    listeFiltresMoisAnterieurs13DerniersMois.ajouterFiltre(new FiltreObjetChronoPeriodeFinAvantDate(periode13DerniersMoisFct.getDebut(), "MVS"));
    listeFiltresMoisAnterieurs13DerniersMois.ajouterFiltre(new FiltrePeriodesLiquidables());
    
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifsOriginePas = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresExclusifsOriginePas.ajouterFiltre(listeFiltres13DerniersMois);
    listeFiltresExclusifsOriginePas.ajouterFiltre(listeFiltresMoisAnterieurs13DerniersMois);
    
    FiltresTemporel listeFiltresOriginePas = new FiltresTemporel();
    listeFiltresOriginePas.ajouterFiltre(listeFiltresExclusifsOriginePas);
    listeFiltresOriginePas.ajouterFiltre(new FiltrePeriodesSansConflit());
    chronoActivitesRetenues = p_chronoActivites.copier(listeFiltresOriginePas);
    
    return chronoActivitesRetenues;
  }
  
  public static ActiviteSalarie retrouverFctAvecDvPourDemandeDv(DemandeSpec p_demandePortantDv)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    
    FiltrePeriodesSurFiltresExclusifs filtrePeriodesExclusif = new FiltrePeriodesSurFiltresExclusifs();
    filtrePeriodesExclusif.ajouterFiltre(new FiltreSurMotifFinActivite(16));
    filtrePeriodesExclusif.ajouterFiltre(new FiltreSurMotifFinActivite(14));
    filtrePeriodesExclusif.ajouterFiltre(new FiltreSurMotifFinActivite(40));
    filtrePeriodesExclusif.ajouterFiltre(new FiltreSurMotifFinActivite(19));
    
    filtres.ajouterFiltre(filtrePeriodesExclusif);
    filtres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
    filtres.ajouterFiltre(new FiltreActiviteSalarieAutreQueFormationCifCdd());
    filtres.ajouterFiltre(new FiltreFinDansBornes(p_demandePortantDv.getDateRecherche().deplacerVersArriere(new DureeCalendaire(1, 0, 0)), p_demandePortantDv.getDateRecherche()));
    
    Chronologie chronoActivitesDV = p_demandePortantDv.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    ActiviteSalarie dernierElement = null;
    if (!chronoActivitesDV.estVide()) {
      dernierElement = (ActiviteSalarie)chronoActivitesDV.dernierElement();
    }
    return dernierElement;
  }
  
  private static Chronologie determinerPansPeriodiquesActivitesConservees(Chronologie p_chronoPassePro, Damj p_borneExclusiveDebutActiviteConservee, Damj p_borneExclusiveFinActiviteConservee)
  {
    Chronologie chronoActivitesConservees = new ChronologiePeriodes();
    
    Chronologie chronoPansPeriodiques = p_chronoPassePro.copier(new FiltrePeriodeActiviteNonSalarieePeriodique());
    
    Collection listeSousPeriodes = null;
    PeriodeActiviteNonSalariePeriodique pansPeriodiqueCourante = null;
    Iterator iterSp = null;
    PeriodeEtatNonProfessionnel periodeEtatNonProPansPeriodiqueCourante = null;
    boolean pansPeriodiqueARetenir = false;
    boolean borneInferieurePRO = false;
    boolean borneSuperieurePRO = false;
    chronoPansPeriodiques.iterer();
    while (chronoPansPeriodiques.encoreSuivant())
    {
      pansPeriodiqueCourante = (PeriodeActiviteNonSalariePeriodique)chronoPansPeriodiques.elementSuivant();
      
      pansPeriodiqueARetenir = false;
      borneInferieurePRO = false;
      borneSuperieurePRO = false;
      
      listeSousPeriodes = pansPeriodiqueCourante.getCollectionPeriodeEtatNonProfessionnel();
      iterSp = listeSousPeriodes.iterator();
      while ((iterSp.hasNext()) && (!pansPeriodiqueARetenir))
      {
        periodeEtatNonProPansPeriodiqueCourante = (PeriodeEtatNonProfessionnel)iterSp.next();
        if ((periodeEtatNonProPansPeriodiqueCourante.isEtatProfessionnel()) && (p_borneExclusiveDebutActiviteConservee.estContenueDans(new Periode(periodeEtatNonProPansPeriodiqueCourante.getDateDebut(), periodeEtatNonProPansPeriodiqueCourante.getDateFin())))) {
          borneInferieurePRO = true;
        }
        if ((periodeEtatNonProPansPeriodiqueCourante.isEtatProfessionnel()) && (p_borneExclusiveFinActiviteConservee.estContenueDans(new Periode(periodeEtatNonProPansPeriodiqueCourante.getDateDebut(), periodeEtatNonProPansPeriodiqueCourante.getDateFin())))) {
          borneSuperieurePRO = true;
        }
      }
      pansPeriodiqueARetenir = (borneInferieurePRO) && (borneSuperieurePRO);
      if (pansPeriodiqueARetenir) {
        chronoActivitesConservees.ajouter(pansPeriodiqueCourante);
      }
    }
    return chronoActivitesConservees;
  }
  
  public static Chronologie determinerChronoFormationAImputer(Periode p_periodeRecherche, Chronologie p_chronoActivitesDom)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    
    FiltreFinDansBornes filtreFinDansPeriode = new FiltreFinDansBornes(p_periodeRecherche);
    filtres.ajouterFiltre(filtreFinDansPeriode);
    
    FiltrePeriodeFormationImputableSurDuree filtrePeriodeFormationImputableSurDuree = new FiltrePeriodeFormationImputableSurDuree();
    filtres.ajouterFiltre(filtrePeriodeFormationImputableSurDuree);
    
    Chronologie chronologieActivitesParticipantes = p_chronoActivitesDom.copier(filtres);
    
    Comparator comparateursurDateFin = new ComparateurTemporelsSurDateFin();
    chronologieActivitesParticipantes.setComparateur(comparateursurDateFin);
    
    return chronologieActivitesParticipantes;
  }
  
  public static Chronologie determinerPeriodesFrauduleuses(Demande p_demande)
  {
    FiltreInvestigationFrauduleuse filtrePF = new FiltreInvestigationFrauduleuse();
    filtrePF.ajouterStatusInvestigationFrauduleuse(4);
    
    Periode periodeRecherche = new Periode();
    if (p_demande.getDateFaitGenerateurOdPrecedente() != null) {
      periodeRecherche.setDebut(p_demande.getDateFaitGenerateurOdPrecedente());
    } else {
      periodeRecherche.setDebut(Damj.NUIT_DES_TEMPS);
    }
    periodeRecherche.setFin(p_demande.getDateExamen());
    FiltreChevauchePeriode filtreChevauchePeriode = new FiltreChevauchePeriode(periodeRecherche);
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(filtreChevauchePeriode);
    filtres.ajouterFiltre(filtrePF);
    
    return p_demande.getDemandeur().getChronoPeriodePasseProfessionnelEcartees().copier(filtres);
  }
  
  public static Chronologie determinerChronoActivitesConservees(DonneesEntreeConstructionChronologie p_donneesEntree)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesConservees = new ChronologiePeriodes();
    
    ActiviteSalarie pas = p_donneesEntree.getActiviteSalarie();
    if (pas != null)
    {
      Damj dateMin = ((ProduitAsuSpec)p_donneesEntree.getProduit()).determinerDateExclueAuPlusTardDebutActiviteConservee(pas, p_donneesEntree.getDateFgd());
      FiltresTemporel filtresDates = new FiltresTemporel();
      
      filtresDates.ajouterFiltre(filtreFinApresDateAvecPriseEnComptePmvs(p_donneesEntree.getListeContexteDemande(), p_donneesEntree.getDateExamen().veille(), false));
      
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(p_donneesEntree.getDateFgd());
      StrategieActiviteConserveeSpec strategie = (StrategieActiviteConserveeSpec)FabriqueStrategieActiviteConservee.getInstance().getStrategie(critere);
      
      filtresDates.ajouterFiltre(strategie.getFiltreDateDebut(p_donneesEntree.getListeContexteDemande(), dateMin));
      
      FiltrePeriodesSurFiltresExclusifs filtreTypesPeriodes = new FiltrePeriodesSurFiltresExclusifs();
      
      filtreTypesPeriodes.ajouterFiltre(new FiltreTravailSalarie());
      
      filtreTypesPeriodes.ajouterFiltre(new FiltrePeriodeDsmTravailActiviteConservee());
      
      Chronologie chronoPassePro = p_donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation();
      chronoActivitesConservees = chronoPassePro.copier(filtreTypesPeriodes);
      chronoActivitesConservees = chronoActivitesConservees.copier(filtresDates);
      
      chronoActivitesConservees.ajouter(determinerPansPeriodiquesActivitesConservees(chronoPassePro, dateMin, p_donneesEntree.getDateExamen()));
    }
    return chronoActivitesConservees;
  }
  
  public static Chronologie determinerChronoActivitesSalarieesConservees(Demande p_demande)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesSalarieesRetenues = null;
    
    Chronologie chronoActivitesConservees = determinerChronoActivitesConservees(mapperDemandeDonneesEntreeConstructionChronologie(p_demande));
    
    chronoActivitesSalarieesRetenues = chronoActivitesConservees.copier(new FiltreActiviteSalarie());
    
    return chronoActivitesSalarieesRetenues;
  }
  
  public static Damj determinerDateExclueAuPlusTardDebutActiviteConservee(ActiviteSalarie p_pas)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_pas.getDateFin());
    StategieDateDebutMaxActiviteConserveeSpec strategieDateDebutMaxActiviteConservee = (StategieDateDebutMaxActiviteConserveeSpec)FabriqueStategieDateDebutMaxActiviteConservee.getInstance().getStrategie(critereStrategie);
    
    Damj datedebutMaxAc = strategieDateDebutMaxActiviteConservee.determinerDateExclueAuPlusTardDebutActiviteConservee(p_pas);
    return datedebutMaxAc;
  }
  
  public static DonneesEntreeConstructionChronologie mapperDemandeDonneesEntreeConstructionChronologie(Demande p_demande)
    throws CoucheLogiqueException
  {
    DonneesEntreeConstructionChronologie donneesEntree = new DonneesEntreeConstructionChronologie();
    
    donneesEntree.setActiviteSalarie(null);
    DossierAffecte dossierAffecte = (DossierAffecte)p_demande.getDossierAffectation();
    if ((dossierAffecte.getValidationProduit() != null) && (dossierAffecte.getValidationProduit().isEstProduitValide()) && (dossierAffecte.getValidationProduit().getPeriodeValidationProduit() != null)) {
      donneesEntree.setActiviteSalarie(dossierAffecte.getValidationProduit().getPeriodeValidationProduit());
    }
    donneesEntree.setDateExamen(p_demande.getDateExamen());
    donneesEntree.setDateFgd(p_demande.getDateFaitGenerateurOuDernierSinistre());
    donneesEntree.setIndividu((Individu)p_demande.getDemandeur());
    donneesEntree.setProduit((ProduitAsuSpec)dossierAffecte.getProduit());
    donneesEntree.setListeContexteDemande(p_demande.getListContexteDemande());
    
    return donneesEntree;
  }
}

/* Location:
 * Qualified Name:     ConstructionChronologie
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */