package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.List;

public final class ControleAlertesBloquantesReglementsNonGeres
  implements OutilFonctionnel
{
  private static final String OUVERTE = "ouverte";
  private static final String DU = "du ";
  
  private static boolean leverAlerteA9aA9bA7(Reglement reglement, int pohf, boolean originesContainsAeAa13coBsCeBs, boolean originesContainsTesa)
  {
    boolean leverAlerte = false;
    if ((reglement.estNomReglementIdentique("A9A")) && (!((ProduitAsuSpec)reglement.getProduit()).estUnProduitGerantA9()) && (originesContainsAeAa13coBsCeBs) && (pohf == 2)) {
      leverAlerte = true;
    }
    if ((!leverAlerte) && (reglement.estNomReglementIdentique("A9B")) && (!((ProduitAsuSpec)reglement.getProduit()).estUnProduitGerantA9()) && (originesContainsAeAa13coBsCeBs) && ((pohf == 3) || (pohf == 5) || (pohf == 10))) {
      leverAlerte = true;
    }
    if ((!leverAlerte) && (reglement.estNomReglementIdentique("A7")) && ((originesContainsAeAa13coBsCeBs) || (originesContainsTesa))) {
      leverAlerte = true;
    }
    return leverAlerte;
  }
  
  public static boolean leverAlerteA8A10SaufSpe02P03(Reglement reglement, boolean originesContainsGusoAemAEAa13)
  {
    boolean leverAlerte = false;
    if (((reglement.estNomReglementIdentique("A8")) || (reglement.estNomReglementIdentique("A10"))) && (((ProduitAsuSpec)reglement.getProduit()).estUnProduitLevantAlerteA8A10()) && (originesContainsGusoAemAEAa13)) {
      leverAlerte = true;
    }
    return leverAlerte;
  }
  
  public static boolean leverAlerteA10SaufSpe02P03(Reglement reglement, int pohf, boolean originesContainsAeAa13coBsCeBs, boolean originesContainsE301)
  {
    boolean leverAlerte = false;
    if ((reglement.estNomReglementIdentique("A10")) && (((ProduitAsuSpec)reglement.getProduit()).estUnProduitLevantAlerteA8A10()) && ((originesContainsAeAa13coBsCeBs) || (originesContainsE301)) && (pohf == 8)) {
      leverAlerte = true;
    }
    return leverAlerte;
  }
  
  public static boolean leverAlerteRgParticulierAe(Reglement reglement, int pohf, boolean originesContainsAe)
  {
    boolean leverAlerte = false;
    if ((reglement.estNomReglementIdentique("RGP")) && (!((ProduitAsuSpec)reglement.getProduit()).estUnProduitGerantA9()) && (originesContainsAe) && (pohf == 8)) {
      leverAlerte = true;
    }
    return leverAlerte;
  }
  
  private static boolean originesContainsAeAa13coBsCeBs(List<Integer> origines)
  {
    return (origines.contains(Integer.valueOf(1))) || (origines.contains(Integer.valueOf(71))) || (origines.contains(Integer.valueOf(110))) || ((origines.contains(Integer.valueOf(3))) && (origines.contains(Integer.valueOf(12)))) || ((origines.contains(Integer.valueOf(11))) && (origines.contains(Integer.valueOf(12))));
  }
  
  private static boolean originesContainsGusoAemAEAa13(List<Integer> origines)
  {
    return (origines.contains(Integer.valueOf(4))) || (origines.contains(Integer.valueOf(5))) || (origines.contains(Integer.valueOf(1))) || (origines.contains(Integer.valueOf(71)));
  }
  
  private static boolean originesContainsE301(List<Integer> origines)
  {
    return origines.contains(Integer.valueOf(10));
  }
  
  private static boolean originesContainsTesa(List<Integer> origines)
  {
    return origines.contains(Integer.valueOf(74));
  }
  
  public static void controleFctEtudiee(ActiviteSalarie pas)
    throws CoucheLogiqueException
  {
    if ((verifiePopulationsNonTraitees(pas)) || (verifiePopulationsNonTraiteesCasParticuliers(pas)))
    {
      Damj dateFCTDamj = pas.getDateFin();
      String dateFCTString = "";
      if (dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
        dateFCTString = "ouverte";
      } else {
        dateFCTString = "du " + dateFCTDamj.formater();
      }
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB3", new String[] { dateFCTString, pas.getReglement().getLibelle() });
    }
  }
  
  public static void controlePeriodesDansPra(Chronologie chronoPas)
    throws CoucheLogiqueException
  {
    chronoPas.iterer();
    while (chronoPas.encoreSuivant())
    {
      TravailSpec pas = (TravailSpec)chronoPas.elementSuivant();
      if ((pas instanceof ActiviteSalarie)) {
        controleFctEtudieeDansPra((ActiviteSalarie)pas);
      }
    }
  }
  
  public static void controleFctEtudieeDansPra(ActiviteSalarie pas)
    throws CoucheLogiqueException
  {
    Reglement reglement = pas.getReglement();
    List<Integer> origines = (List)pas.getCollectionOrigineInformationPAS();
    if ((reglement != null) && (origines != null))
    {
      int pohf = pas.getContrat().getPohf();
      boolean leverAlerte = false;
      boolean originesContainsAeAa13coBsCeBs = originesContainsAeAa13coBsCeBs(origines);
      boolean originesContainsTesa = originesContainsTesa(origines);
      
      leverAlerte = (leverAlerteA9aA9bA7(reglement, pohf, originesContainsAeAa13coBsCeBs, originesContainsTesa)) || (leverAlerteRgParticulierAe(reglement, pohf, originesContainsAeAa13coBsCeBs));
      if (leverAlerte)
      {
        Damj dateFCTDamj = pas.getDateFin();
        String dateFCTString = "";
        if (dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
          dateFCTString = "ouverte";
        } else {
          dateFCTString = "du " + dateFCTDamj.formater();
        }
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB4", new String[] { dateFCTString });
      }
    }
  }
  
  public static void controleFaitGenerateur(ActiviteSalarie pas)
    throws CoucheLogiqueException
  {
    if (verifiePopulationsNonTraitees(pas))
    {
      Damj dateFCTDamj = pas.getDateFin();
      String dateFCTString = "";
      if (dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
        dateFCTString = "ouverte";
      } else {
        dateFCTString = "du " + dateFCTDamj.formater();
      }
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB3", new String[] { dateFCTString, pas.getReglement().getLibelle() });
    }
    if (verifiePopulationsNonTraiteesCasParticuliers(pas))
    {
      Damj dateFCTDamj = pas.getDateFin();
      String dateFCTString = "";
      if (dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
        dateFCTString = "ouverte";
      } else {
        dateFCTString = "du " + dateFCTDamj.formater();
      }
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB2", new String[] { dateFCTString });
    }
  }
  
  public static boolean verifiePopulationsNonTraitees(ActiviteSalarie pas)
  {
    boolean populationNonTraitee = false;
    
    Reglement reglement = pas.getReglement();
    List<Integer> origines = (List)pas.getCollectionOrigineInformationPAS();
    if ((reglement != null) && (origines != null))
    {
      int pohf = pas.getContrat().getPohf();
      boolean originesContainsAeAa13coBsCeBs = originesContainsAeAa13coBsCeBs(origines);
      boolean originesContainsTesa = originesContainsTesa(origines);
      boolean originesContainsGusoAemAEAa13 = originesContainsGusoAemAEAa13(origines);
      
      populationNonTraitee = (leverAlerteA9aA9bA7(reglement, pohf, originesContainsAeAa13coBsCeBs, originesContainsTesa)) || (leverAlerteA8A10SaufSpe02P03(reglement, originesContainsGusoAemAEAa13));
    }
    return populationNonTraitee;
  }
  
  public static boolean verifiePopulationsNonTraiteesCasParticuliers(ActiviteSalarie pas)
  {
    boolean populationNonTraitee = false;
    
    Reglement reglement = pas.getReglement();
    List<Integer> origines = (List)pas.getCollectionOrigineInformationPAS();
    if ((reglement != null) && (origines != null))
    {
      int pohf = pas.getContrat().getPohf();
      boolean originesContainsAeAa13coBsCeBs = originesContainsAeAa13coBsCeBs(origines);
      boolean originesContainsE301 = originesContainsE301(origines);
      
      populationNonTraitee = (leverAlerteA10SaufSpe02P03(reglement, pohf, originesContainsAeAa13coBsCeBs, originesContainsE301)) || (leverAlerteRgParticulierAe(reglement, pohf, originesContainsAeAa13coBsCeBs));
    }
    return populationNonTraitee;
  }
}

/* Location:
 * Qualified Name:     ControleAlertesBloquantesReglementsNonGeres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */