package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreTypeRechargementSpec;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P05;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P06;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P6B;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P01;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P02;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P03;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P04;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P05;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P5B;
import fr.unedic.cali.dom.affectation.ProduitAsuExp03P01;
import fr.unedic.cali.dom.affectation.ProduitAsuFds12P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSsp07P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSsp07P04;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.util.ArrayList;
import java.util.List;

public class ForcageAffiliation
  implements OutilFonctionnel
{
  private static List<Integer> listeCodeProduitAvantARE17 = new ArrayList();
  
  static
  {
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P02.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P03.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P04.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P05.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P6B.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCge01P06.getInstance().getCode()));
    
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuExp03P01.getInstance().getCode()));
    
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P01.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P02.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P03.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P04.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P5B.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuCsa06P05.getInstance().getCode()));
    
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuSpe02P03.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuSpe02P04.getInstance().getCode()));
    
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuSsp07P03.getInstance().getCode()));
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuSsp07P04.getInstance().getCode()));
    
    listeCodeProduitAvantARE17.add(Integer.valueOf(ProduitAsuFds12P02.getInstance().getCode()));
  }
  
  public static boolean controlerCoherenceAffiliationForcee(DemandeSpec demandeAControler, String idDecor)
    throws ContexteException, CoucheLogiqueException
  {
    boolean coherenceAffiliationForcee = true;
    
    DemandeAssuranceSpec demandeCourante = (DemandeAssuranceSpec)demandeAControler;
    if ((demandeCourante.getDonneesTemporaires() != null) && (demandeCourante.getDonneesTemporaires().getQuantiteAffiliation() != null) && (demandeCourante.getDonneesTemporaires().getPeriodeFctARetenir() != null)) {
      coherenceAffiliationForcee = controlerCoherenceAffiliationForcee(demandeAControler, idDecor, demandeCourante.getDonneesTemporaires().getPeriodeFctARetenir());
    }
    return coherenceAffiliationForcee;
  }
  
  public static boolean controlerCoherenceAffiliationForcee(DemandeSpec demandeAControler, String idDecor, TravailSpec fct)
    throws ContexteException, CoucheLogiqueException
  {
    boolean coherenceAffiliationForcee = true;
    
    DemandeAssuranceSpec demandeCourante = (DemandeAssuranceSpec)demandeAControler;
    if ((fct != null) && (demandeCourante.getDonneesTemporaires().getQuantiteAffiliation() != null) && ((!(demandeCourante.getEvenementReferenceExamen() instanceof EreTypeRechargementSpec)) || (demandeCourante.estDemandeLiquidee())))
    {
      DecorReglementaire decorReglementaire = AccesDecorReglementaire.getInstance().getDecorParId(idDecor);
      
      CriteresQualification criteresQualification = new CriteresQualification(decorReglementaire, fct, demandeCourante.getDonneesTemporaires().isEstCoordCee());
      
      AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)demandeAControler.getDemandeur());
      
      ActiviteSalarie periodeFctForcee = (ActiviteSalarie)fct;
      
      Reglement reglementApplicableForce = periodeFctForcee.getReglement();
      
      UniteAffiliation uniteQuantiteAffiliationForcee = (UniteAffiliation)demandeCourante.getDonneesTemporaires().getQuantiteAffiliation().getUnite();
      
      coherenceAffiliationForcee = verifierCoherenceUniteAffiliation(demandeAControler, reglementApplicableForce, uniteQuantiteAffiliationForcee);
    }
    return coherenceAffiliationForcee;
  }
  
  private static boolean verifierCoherenceUniteAffiliation(DemandeSpec demandeAControler, Reglement reglementApplicable, UniteAffiliation uniteAffiliation)
    throws CoucheLogiqueException
  {
    Reglement reglementApplicableDroit = reglementApplicable;
    
    boolean estContexteRechargement = demandeAControler.estEnContexteDemande("RECHARGE");
    if (estContexteRechargement)
    {
      EreTypeRechargementSpec ere = (EreTypeRechargementSpec)demandeAControler.getEvenementReferenceExamen();
      reglementApplicableDroit = ere.getReglementForcePourRechargement();
    }
    boolean estProduitApartirAre17 = !listeCodeProduitAvantARE17.contains(Integer.valueOf(reglementApplicableDroit.getProduit().getCode()));
    
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)demandeAControler;
    List<Unite> listeUnitesAffiliationPossibles;
    List<Unite> listeUnitesAffiliationPossibles;
    if (((!estProduitApartirAre17) && (estContexteRechargement)) || ((estProduitApartirAre17) && (Boolean.FALSE.equals(demande.getDonneesTemporaires().isConditionAffiliationSatisfaiteForcee())))) {
      listeUnitesAffiliationPossibles = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteRechercheReglementApplicable(reglementApplicableDroit.getNomReglement(), estContexteRechargement, reglementApplicableDroit.getProduit());
    } else {
      listeUnitesAffiliationPossibles = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteConstitutionQuantiteAffiliation(reglementApplicableDroit.getNomReglement(), reglementApplicableDroit.getProduit());
    }
    boolean coherenceUniteAffiliation = (listeUnitesAffiliationPossibles != null) && (listeUnitesAffiliationPossibles.contains(uniteAffiliation));
    
    return coherenceUniteAffiliation;
  }
}

/* Location:
 * Qualified Name:     ForcageAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */