package fr.unedic.cali.asu.outilsfonctionnels;

import fr.pe.cali.autresdoms.d01.outilsfonctionnels.OutilCodeRessortissant;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.conteneur.DonneesRessortissant;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.ConteneurCodeRessortissant;
import fr.unedic.cali.dom.ConteneurResultatCodeRessortissant;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuIdSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilGestionDate;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;

public class OutilCodeRessortissantAsu
{
  private static OutilCodeRessortissantAsu instance;
  protected static final String CR_RETOUR_OK = "0000";
  protected static final String CR_CXALA_NON_PRESENT = "0001";
  protected static final String CR_CODE_TRAITEMENT_ERRONE = "0002";
  protected static final String CR_INDIVIDU_NON_TROUVE = "0003";
  protected static final String CR_CODE_NATIONALITE_NON_TROUVE = "0004";
  protected static final String CR_CXALA_NON_PRESENT_LIB = "CXALA non présent";
  protected static final String CR_CODE_TRAITEMENT_ERRONE_LIB = "Code traitement erroné";
  protected static final String CR_INDIVIDU_NON_TROUVE_LIB = "Pas d’individu trouvé dans la table P0151F";
  protected static final String CR_CODE_NATIONALITE_NON_TROUVE_LIB = "Code nationalité inexistant en table H01S1G";
  
  public static OutilCodeRessortissantAsu getInstance()
  {
    if (instance == null) {
      instance = new OutilCodeRessortissantAsu();
    }
    return instance;
  }
  
  protected boolean verifierValiditeInfosRessortissant(ConteneurResultatCodeRessortissant conteneur)
  {
    boolean continuerVerification = false;
    if ((conteneur != null) && (conteneur.getCodeRetour() != null))
    {
      String codeRetour = conteneur.getCodeRetour();
      continuerVerification = true;
      String messageException = "Exception levée lors de l'appel de D01 / Code Ressortissant : ";
      if (codeRetour.equals("0001"))
      {
        continuerVerification = false;
        
        OutilTrace.ecrireTrace(Niveau.ERROR, new String[] { messageException + "CXALA non présent" });
      }
      else if (codeRetour.equals("0002"))
      {
        continuerVerification = false;
        OutilTrace.ecrireTrace(Niveau.ERROR, new String[] { messageException + "Code traitement erroné" });
      }
      else if (codeRetour.equals("0003"))
      {
        continuerVerification = false;
        OutilTrace.ecrireTrace(Niveau.ERROR, new String[] { messageException + "Pas d’individu trouvé dans la table P0151F" });
      }
      else if (codeRetour.equals("0004"))
      {
        continuerVerification = false;
        OutilTrace.ecrireTrace(Niveau.ERROR, new String[] { messageException + "Code nationalité inexistant en table H01S1G" });
      }
    }
    return continuerVerification;
  }
  
  public void verifierIncoherenceRessortissant(Demande demande)
  {
    if (demande.getDatePremiereValidation() == null)
    {
      ConteneurCodeRessortissant conteneurEntree = new ConteneurCodeRessortissant(demande.getDemandeur().getIndividuId().getId());
      
      ConteneurResultatCodeRessortissant conteneurSortie = appelerServiceInfosRessortissant(conteneurEntree);
      if (verifierValiditeInfosRessortissant(conteneurSortie))
      {
        String codeRessortissant = conteneurSortie.getCodeRessortissant();
        
        Damj dateVerification = conteneurSortie.getDateVerification();
        Damj dateExamen = demande.getDateExamen();
        if (verifierConditionContinuerTraitement(dateVerification, dateExamen)) {
          determinerIncoherence(demande, codeRessortissant, dateVerification, dateExamen);
        }
      }
    }
  }
  
  private void determinerIncoherence(Demande demande, String codeRessortissant, Damj dateVerification, Damj dateExamen)
  {
    Damj dateDecisionPrecedente = null;
    DecisionSpec decisionPrecedente = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), dateExamen, null);
    if (decisionPrecedente != null) {
      dateDecisionPrecedente = decisionPrecedente.getDemande().getDateExamen();
    }
    Damj dateDebutRecherche = determinerDateDebutRechercheIncoherence(dateExamen, dateDecisionPrecedente, dateVerification);
    rechercheIncoherenceDansListeActivites(demande, codeRessortissant, new Periode(dateDebutRecherche, dateExamen.veille()));
  }
  
  protected ConteneurResultatCodeRessortissant appelerServiceInfosRessortissant(ConteneurCodeRessortissant conteneur)
  {
    OutilCodeRessortissant outilService = OutilCodeRessortissant.getInstance();
    return outilService.trouverInfosRessortissant(conteneur);
  }
  
  protected boolean verifierConditionContinuerTraitement(Damj dateVerification, Damj dateExamen)
  {
    boolean continuerVerification = true;
    if ((dateExamen == null) || ((dateVerification != null) && (dateVerification.estApresOuCoincideAvec(dateExamen)))) {
      continuerVerification = false;
    }
    return continuerVerification;
  }
  
  protected void rechercheIncoherenceDansListeActivites(Demande demande, String codeRessortissant, Periode periodeRecherche)
  {
    ChronologiePeriodes chronoPeriodes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    boolean estIncoherenceTrouve = false;
    String idPeriodeIncoherente = null;
    FiltresTemporel filtre = new FiltresTemporel();
    
    filtre.ajouterFiltre(new FiltreActiviteSalarie());
    filtre.ajouterFiltre(new FiltrePeriodesAttestees());
    filtre.ajouterFiltre(new FiltreFinDansBornes(periodeRecherche.getDebut(), periodeRecherche.getFin()));
    Chronologie chronoFiltrees = chronoPeriodes.copier(filtre);
    chronoFiltrees.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
    if (!chronoFiltrees.estVide())
    {
      Iterator<ActiviteSalarie> itChronoFiltrees = chronoFiltrees.iterer();
      while ((itChronoFiltrees.hasNext()) && (!estIncoherenceTrouve))
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)itChronoFiltrees.next();
        String codeRessortissantGaec = activiteSalarie.getContrat().getRessortissant();
        if ((codeRessortissantGaec != null) && (!codeRessortissantGaec.equals(codeRessortissant)))
        {
          estIncoherenceTrouve = true;
          idPeriodeIncoherente = activiteSalarie.getIdentifiant();
        }
      }
    }
    demande.getDonneesRessortissant().setEstIncoherenceInfoRessortissant(estIncoherenceTrouve);
    demande.getDonneesRessortissant().setIdPeriodeIncoherenteRessortissant(idPeriodeIncoherente);
  }
  
  protected Damj determinerDateDebutRechercheIncoherence(Damj dateExamen, Damj dateExamenDecisionPrecedente, Damj dateVerification)
  {
    Damj dateRetour = OutilGestionDate.getInstance().calculerDecalage12moisVersArriere(dateExamen);
    if ((dateExamenDecisionPrecedente != null) && (dateExamenDecisionPrecedente.estApres(dateRetour))) {
      dateRetour = dateExamenDecisionPrecedente;
    }
    if ((dateVerification != null) && (dateVerification.estApres(dateRetour))) {
      dateRetour = dateVerification;
    }
    return dateRetour;
  }
}

/* Location:
 * Qualified Name:     OutilCodeRessortissantAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */