package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreApsFdd;
import fr.unedic.cali.asu.dom.EreApsSuiteRejetAsu;
import fr.unedic.cali.asu.dom.EreAsrSuiteIDE;
import fr.unedic.cali.asu.dom.EreAtAfdFdd;
import fr.unedic.cali.asu.dom.EreAtAfdSuiteRejetAsu;
import fr.unedic.cali.asu.dom.EreDemandeApsEfe;
import fr.unedic.cali.asu.dom.EreDemandeAreEfe;
import fr.unedic.cali.asu.dom.EreDemandeAtAfdEfe;
import fr.unedic.cali.asu.dom.EreFinDroitSpectacle;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.EreSuiteFinDroitAsr;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAfd;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAps;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAsrFinDeDroit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.CompteurIndexPASContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilsChomageSansRupture;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCSR04;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.LigneAsuCsa06;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCreationDemande;
import fr.unedic.cali.outilsfonctionnels.TracesBouchon;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandeAre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandeAsr;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandeAtp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreOu;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;
import java.util.List;
import org.apache.commons.lang.StringUtils;

public class OutilDemande
{
  public static boolean estUneDemandeV2(DemandeAssuranceSpec demande)
  {
    boolean estUneDemandeV2 = false;
    TracesBouchon.ecrireTrace();
    if (OutilsActiviteConserve.estUneDemandeDeRevision(demande)) {
      estUneDemandeV2 = true;
    } else if ((demande.getEvenementReferenceExamen() != null) && ("ASU_21".equals(demande.getEvenementReferenceExamen().getTypeExamen()))) {
      estUneDemandeV2 = true;
    } else if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(((Demande)demande).getListContexteDemande(), "ARESJASPDC")) {
      estUneDemandeV2 = true;
    }
    return estUneDemandeV2;
  }
  
  public static boolean estUneDemandeAntecedentFinDroitSp(DemandeSpec pDemande)
  {
    boolean estUneDemandeAntecedent = false;
    if (pDemande.getNumeroGamme() == 1)
    {
      Demande demande = (Demande)pDemande;
      if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().getContexteDemande() != null) && (demande.getSaisieAntecedent().getContexteDemande().intValue() == 3)) {
        estUneDemandeAntecedent = true;
      }
    }
    return estUneDemandeAntecedent;
  }
  
  public static boolean estUneDemandeAntecedentAsp(DemandeSpec pDemande)
  {
    boolean estUneDemandeAntecedentAsp = false;
    if (pDemande.getNumeroGamme() == 1)
    {
      Demande demande = (Demande)pDemande;
      if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().getCodeProduit() != null) && (demande.getSaisieAntecedent().getCodeProduit().intValue() == 12)) {
        estUneDemandeAntecedentAsp = true;
      }
    }
    return estUneDemandeAntecedentAsp;
  }
  
  public static boolean estUneDemandeApsFdd(DemandeSpec pDemande)
  {
    boolean estUneDemandeApsFdd = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreApsFdd)) {
      estUneDemandeApsFdd = true;
    }
    return estUneDemandeApsFdd;
  }
  
  public static boolean estUneDemandeAfdFdd(DemandeSpec pDemande)
  {
    boolean estUneDemandeAfdFdd = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreAtAfdFdd)) {
      estUneDemandeAfdFdd = true;
    }
    return estUneDemandeAfdFdd;
  }
  
  public static boolean estUneDemandeApsIde(DemandeAssuranceSpec pDemande)
  {
    boolean estUneDemandeApsIde = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreApsSuiteRejetAsu)) {
      estUneDemandeApsIde = true;
    }
    return estUneDemandeApsIde;
  }
  
  public static boolean estUneDemandeAps(DemandeSpec pDemande)
  {
    boolean estUneDemandeAps = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if (((ere instanceof EreDemandeApsEfe)) || ((ere instanceof EreApsSuiteRejetAsu)) || ((ere instanceof EreApsFdd))) {
      estUneDemandeAps = true;
    }
    return estUneDemandeAps;
  }
  
  public static boolean estUneDemandeAtAfd(DemandeSpec pDemande)
  {
    boolean estUneDemandeAtAfd = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if (((ere instanceof EreDemandeAtAfdEfe)) || ((ere instanceof EreAtAfdSuiteRejetAsu)) || ((ere instanceof EreAtAfdFdd))) {
      estUneDemandeAtAfd = true;
    }
    return estUneDemandeAtAfd;
  }
  
  public static boolean estUneDemandeAreEfe(DemandeAssuranceSpec pDemande)
  {
    boolean estUneDemandeAreEfe = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreDemandeAreEfe)) {
      estUneDemandeAreEfe = true;
    }
    return estUneDemandeAreEfe;
  }
  
  public static boolean estUneDemandeEfe(DemandeAssuranceSpec pDemande)
  {
    boolean estUneDemandeFpsEfe = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if (((ere instanceof EreDemandeAtAfdEfe)) || ((ere instanceof EreDemandeApsEfe)) || ((ere instanceof EreDemandeAreEfe))) {
      estUneDemandeFpsEfe = true;
    }
    return estUneDemandeFpsEfe;
  }
  
  public static boolean estUneDemandeAreFdd(DemandeSpec pDemande)
  {
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreFinDroitSpectacle)) {
      return true;
    }
    return false;
  }
  
  public static boolean estUneDemandeAre(LigneSpec pLigne)
  {
    return (LigneAsuCge01.getInstance().equals(pLigne)) || (LigneAsuSpe02.getInstance().equals(pLigne)) || (LigneAsuCsa06.getInstance().equals(pLigne)) || (LigneAsuCSR04.getInstance().equals(pLigne));
  }
  
  public static boolean estUneDemandeAreIde(DemandeSpec pDemande)
  {
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreInscriptionDemandeurEmploi)) {
      return true;
    }
    return false;
  }
  
  public static boolean estUneDemandeAreSpe(LigneSpec pLigne)
  {
    return LigneAsuSpe02.getInstance().equals(pLigne);
  }
  
  public static boolean estUneDemandeAsr(DemandeSpec pDemande)
  {
    boolean estUneDemandeAsr = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreAsrSuiteIDE)) {
      estUneDemandeAsr = true;
    }
    return estUneDemandeAsr;
  }
  
  public static boolean estUneDemandeFinDroitAsr(DemandeSpec pDemande)
  {
    boolean estUneDemandeAsr = false;
    EvenementReferenceExamenSpec ere = pDemande.getEvenementReferenceExamen();
    if ((ere instanceof EreSuiteFinDroitAsr)) {
      estUneDemandeAsr = true;
    }
    return estUneDemandeAsr;
  }
  
  public static void copieDonneesForcees(DemandeAssuranceSpec pDemandeOrigine, DemandeAssuranceSpec pDemandeCible)
  {
    if ((pDemandeOrigine != null) && (pDemandeCible != null))
    {
      DonneesTemporaires donneesForceesCibles = pDemandeCible.getDonneesTemporaires();
      DonneesTemporaires donneesForceesOrigines = pDemandeOrigine.getDonneesTemporaires();
      
      donneesForceesOrigines.copieElements(donneesForceesCibles);
    }
  }
  
  public static boolean estUneDemandeAre(DemandeSpec pDemande)
  {
    boolean retour = false;
    if (pDemande.getNumeroGamme() == 1)
    {
      DossierAffectationSpec dossierAffectation = pDemande.getDossierAffectation();
      ProduitSpec produit = dossierAffectation.getProduit();
      LigneSpec ligne = produit.getLigne();
      retour = estUneDemandeAre(ligne);
    }
    return retour;
  }
  
  public static FiltreTemporel getFiltreProduitAsuParEre(DemandeAssuranceSpec pDemandeOrigine)
  {
    FiltreOu filtreDemandeAreOuAsr = new FiltreOu();
    filtreDemandeAreOuAsr.ajouterFiltre(new FiltreDemandeAre());
    if (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeDeRevision(pDemandeOrigine)) {
      filtreDemandeAreOuAsr.ajouterFiltre(new FiltreDemandeAsr());
    }
    FiltreTemporel filtreParEre = filtreDemandeAreOuAsr;
    if (pDemandeOrigine.estUneDemandeAps())
    {
      filtreParEre = new FiltreDemandeAps();
    }
    else if (pDemandeOrigine.estUneDemandeAtAfd())
    {
      filtreParEre = new FiltreDemandeAfd();
    }
    else if (pDemandeOrigine.estUneDemandeFinDroitAsr())
    {
      filtreParEre = new FiltreDemandeAre();
    }
    else if (pDemandeOrigine.estUneDemandeAtp())
    {
      filtreParEre = new FiltreDemandeAtp();
    }
    else if (pDemandeOrigine.estUneDemandeFinDroitAtp())
    {
      FiltresTemporel filtreAreouAsrEtNonFinAsr = new FiltresTemporel();
      filtreAreouAsrEtNonFinAsr.ajouterFiltre(filtreDemandeAreOuAsr);
      filtreAreouAsrEtNonFinAsr.ajouterFiltre(new FiltreNegation(new FiltreDemandeAsrFinDeDroit()));
      filtreParEre = filtreAreouAsrEtNonFinAsr;
    }
    return filtreParEre;
  }
  
  public static boolean estUneDemandeAtp(DemandeSpec pDemande)
  {
    boolean estUneDemandeAtp = false;
    Demande demande = (Demande)pDemande;
    List<ContexteDemandeSpec> contextedemande = demande.getListContexteDemande();
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "IDEATP")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "BASCULEATP"))) {
      estUneDemandeAtp = true;
    }
    return estUneDemandeAtp;
  }
  
  public static boolean estUneDemandeAtpBasculeCrp(DemandeSpec pDemande)
  {
    boolean estUneDemandeAtpBasculeCrp = false;
    Demande demande = (Demande)pDemande;
    List<ContexteDemandeSpec> contextedemande = demande.getListContexteDemande();
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "BASCULEATP")) {
      estUneDemandeAtpBasculeCrp = true;
    }
    return estUneDemandeAtpBasculeCrp;
  }
  
  public static boolean estUneDemandeAssociee(DemandeSpec pDemande)
  {
    boolean estUneDemandeAssociee = false;
    if ((pDemande.getEvenementReferenceExamen() != null) && ("ASU_21".equalsIgnoreCase(pDemande.getEvenementReferenceExamen().getTypeExamen()))) {
      estUneDemandeAssociee = true;
    } else if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(((Demande)pDemande).getListContexteDemande(), "ARESJASPDC")) {
      estUneDemandeAssociee = true;
    }
    return estUneDemandeAssociee;
  }
  
  public static boolean estUneDemandeFinDroitAtp(DemandeSpec pDemande)
  {
    boolean estUneDemandeFinAtp = false;
    Demande demande = (Demande)pDemande;
    List<ContexteDemandeSpec> contextedemande = demande.getListContexteDemande();
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "FINATP")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "FINATPBASC"))) {
      estUneDemandeFinAtp = true;
    }
    return estUneDemandeFinAtp;
  }
  
  public static boolean estUneDemandeAspOuPap(DemandeSpec pDemande)
  {
    boolean estUneDemandeAsp = false;
    Demande demande = (Demande)pDemande;
    List<ContexteDemandeSpec> contextedemande = demande.getListContexteDemande();
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "IDEASP")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "ADHVOLARE")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextedemande, "ASPVOLSARE"))) {
      estUneDemandeAsp = true;
    }
    return estUneDemandeAsp;
  }
  
  public static boolean estUneDemandeFinDroitAsp(DemandeSpec pDemande)
  {
    boolean estUneDemandeFinAsp = false;
    Demande demande = (Demande)pDemande;
    List<ContexteDemandeSpec> contextedemande = demande.getListContexteDemande();
    if ((contextedemande != null) && (OutilGestionContexteDemande.trouverUnContextePresent(contextedemande, 5) != null)) {
      estUneDemandeFinAsp = true;
    }
    return estUneDemandeFinAsp;
  }
  
  public static boolean estUneDemandeSuiteCsr(Demande pDemande)
  {
    boolean estUneDemandeSuiteCsr = false;
    if ((pDemande.estUneDemandeAsr()) || (pDemande.estUneDemandeAsp()))
    {
      AttributionAssuranceSpec arePrecedenteCsr = getArePrecedentCsr(pDemande);
      if (arePrecedenteCsr != null)
      {
        String identifiantFaitGenerateurAre = arePrecedenteCsr.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant();
        identifiantFaitGenerateurAre = CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(identifiantFaitGenerateurAre);
        
        String identifiantFaitGenerateurAsr = ((ActiviteSalarie)((DossierAffectation)pDemande.getDossierAffectation()).getSinistre()).getIdentifiant();
        identifiantFaitGenerateurAsr = CompteurIndexPASContratTravail.recupererPrefixeIdentifiant(identifiantFaitGenerateurAsr);
        if (StringUtils.equals(identifiantFaitGenerateurAre, identifiantFaitGenerateurAsr)) {
          estUneDemandeSuiteCsr = true;
        }
      }
    }
    pDemande.setUneDemandeSuiteCsr(estUneDemandeSuiteCsr);
    
    return estUneDemandeSuiteCsr;
  }
  
  public static boolean estUneDemandeAspSurAERevision(Demande demande)
  {
    boolean estUneDemandeASPsurAErevise = false;
    if (demande.estUneDemandeAsp())
    {
      TravailSpec dernierSinistre = demande.getDossierAffectationAdmission().getSinistre();
      List<TravailSpec> listeAErevisions = OutilsRevisions.trouverListeFctReviseesAre14(demande);
      if (listeAErevisions != null)
      {
        Iterator<TravailSpec> it = listeAErevisions.iterator();
        while (it.hasNext())
        {
          TravailSpec periodeCourante = (TravailSpec)it.next();
          if (periodeCourante.getIdentifiant().equals(dernierSinistre.getIdentifiant())) {
            estUneDemandeASPsurAErevise = true;
          }
        }
      }
    }
    return estUneDemandeASPsurAErevise;
  }
  
  public static AttributionAssuranceSpec getArePrecedentCsr(Demande pDemandeAsr)
  {
    AttributionAssuranceSpec arePrecedenteCsr = null;
    
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(pDemandeAsr.getDemandeur().getChronoDemandeAssurance(), pDemandeAsr, new FiltreOuvertureDroitStandardAssurance(false, true, false, true, pDemandeAsr));
    if ((attributionPrecedente != null) && ((OutilsChomageSansRupture.estUnProduitDeChomageSansRupture(attributionPrecedente)) || (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(attributionPrecedente.getDemande())))) {
      arePrecedenteCsr = attributionPrecedente;
    }
    return arePrecedenteCsr;
  }
  
  public static boolean estUneDemandeRevisionAdmission(DemandeSpec pDemande)
  {
    boolean estUneDemandeRevisionAdmission = false;
    if ((pDemande.getEvenementReferenceExamen() != null) && ("ASU_28".equalsIgnoreCase(pDemande.getEvenementReferenceExamen().getTypeExamen()))) {
      estUneDemandeRevisionAdmission = true;
    }
    return estUneDemandeRevisionAdmission;
  }
  
  public static boolean estUneDemandeFinDeDroitSurEpuissement(AttributionSpec attribution, Periode periode)
  {
    return (!estUnProduitExclu(attribution)) && (!(attribution instanceof RepriseSpec)) && (estConditionSpecifiqueDateAttribution(attribution, periode));
  }
  
  private static boolean estUnProduitExclu(AttributionSpec attribution)
  {
    return (attribution.getProduit().getNom().equals("ASU_EUR05_01")) && (attribution.getProduit().getNom().equals("ASU_DDM16_01")) && (attribution.getProduit().getNom().equals("ASU_MAY17_02")) && (attribution.getProduit().getNom().equals("ASU_MAY17_03"));
  }
  
  private static boolean estConditionSpecifiqueDateAttribution(AttributionSpec attribution, Periode periode)
  {
    return ((attribution instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)attribution).estDemandeSuiteFinDeDroit()) && (periode.contient(((AttributionAssuranceSpec)attribution).getOuvertureDroit().getDateAttribution()));
  }
  
  public void creerDemandeAssocieeSurDemandeAtp(Demande pDemandeAssurance)
    throws ApplicativeException
  {
    if (pDemandeAssurance.estUneDemandeAtp())
    {
      String typeDemande = "ASU_21";
      Damj dateDepot = pDemandeAssurance.getDateDepot();
      IndividuSpec individu = pDemandeAssurance.getDemandeur();
      
      Demande demandeAssociee = (Demande)OutilCreationDemande.creerDemande("ASU_21", dateDepot, individu, pDemandeAssurance.getFormulaire().getIdPec(), null);
      
      demandeAssociee.setCommentaire("DESACTIVER_TRANCHE_EXEC");
      
      demandeAssociee.setDemandeur(pDemandeAssurance.getDemandeur());
      
      pDemandeAssurance.createDonneesDemandeAssociee();
      pDemandeAssurance.getDonneesDemandeAssociee().setDemandeAssociee(demandeAssociee);
    }
  }
}

/* Location:
 * Qualified Name:     OutilDemande
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */