package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementEtPrioriteDemande;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAppartientReglements;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAttribution;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDecisionNonEnReexamen;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesGammeAsu;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.List;

public class OutilDeterminationDateExamenPourFps
{
  private static OutilDeterminationDateExamenPourFps instance;
  protected static List<Reglement> listeReglementSpectacle = null;
  
  static
  {
    listeReglementSpectacle = new ArrayList();
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P03.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P03.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P01.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P01.getInstance()));
  }
  
  public static OutilDeterminationDateExamenPourFps getInstance()
  {
    if (instance == null) {
      instance = new OutilDeterminationDateExamenPourFps();
    }
    return instance;
  }
  
  public Damj getDateIde(IndividuSpec individu, Damj dateDepot)
  {
    Damj dateIde = OutillagePEC.getDebutPecAvantOuCoincideAvecDate(individu, dateDepot);
    
    return dateIde;
  }
  
  public Damj getLendemainDerniereFct(IndividuSpec individu, Damj dateDepot, boolean uniquementFctSpectacle)
  {
    Damj lendemainFct = null;
    if ((!individu.getChronoPeriodePasseProfessionnelLiquidation().estVide()) && (dateDepot != null))
    {
      FiltresTemporel filtre = new FiltresTemporel();
      
      filtre.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      filtre.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(dateDepot));
      if (uniquementFctSpectacle) {
        filtre.ajouterFiltre(new FiltreAppartientReglements(listeReglementSpectacle));
      }
      Chronologie chronoPasseProCinemaSpectacle = individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtre);
      if (!chronoPasseProCinemaSpectacle.estVide())
      {
        Temporel dernierElement = chronoPasseProCinemaSpectacle.dernierElement();
        if (dernierElement != null) {
          lendemainFct = dernierElement.getDateFin().lendemain();
        }
      }
    }
    return lendemainFct;
  }
  
  public Damj recupererLendemainFinDeDroitAreOuApsPrecedentDate(Damj date, DemandeSpec demande)
    throws CoucheLogiqueException, ApplicativeException
  {
    AttributionSpec attribution = recupererAttributionAreOuApsPrecedent(demande, date);
    
    Damj dateRetour = recupererLendemainFinDeDroitAttribution(attribution, date, demande);
    if ((dateRetour != null) && ((attribution.getProduit().getLigne() instanceof LigneAsuSsp07)) && (dateRetour.estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Date de debut des produits APS17 et AFD17")))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_APS17_SUITE_FDD_APS07");
    }
    return dateRetour;
  }
  
  protected AttributionSpec recupererAttributionAreOuApsPrecedent(DemandeSpec demande, Damj date)
  {
    FiltreET filtreAttributionSpectacleOuAps = new FiltreET();
    filtreAttributionSpectacleOuAps.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, demande));
    FiltreOU filtreSpectacleOuAps = new FiltreOU();
    filtreSpectacleOuAps.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuSpe02.getInstance().getNomUnique()));
    filtreSpectacleOuAps.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuSsp07.getInstance().getNomUnique()));
    filtreAttributionSpectacleOuAps.ajouterFiltre(filtreSpectacleOuAps);
    return (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), date, filtreAttributionSpectacleOuAps);
  }
  
  public Damj recupererLendemainFinDeDroitArePrecedentDate(Damj date, DemandeSpec demande, boolean desactiverRechercheCRA)
    throws ApplicativeException
  {
    FiltreET filtreAttributionSpectacle = new FiltreET();
    filtreAttributionSpectacle.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, demande));
    filtreAttributionSpectacle.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuSpe02.getInstance().getNomUnique()));
    if (desactiverRechercheCRA) {
      filtreAttributionSpectacle.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande(8)));
    }
    AttributionSpec attribution = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), date, filtreAttributionSpectacle);
    
    return recupererLendemainFinDeDroitAttribution(attribution, date, demande);
  }
  
  protected Damj recupererLendemainFinDeDroitAttribution(AttributionSpec attribution, Damj date, DemandeSpec demande)
    throws ApplicativeException
  {
    Damj dateFinDroitAre = null;
    if (attribution != null)
    {
      dateFinDroitAre = recupererDjiParEpuisement(demande, attribution);
      if (dateFinDroitAre == null) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_DERNIER_DROIT_NON_ARRETE_EPUISMT");
      }
    }
    else
    {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_CONTEXTE_PAS_D_ATTRIBUTION", new Object[] { date });
    }
    return dateFinDroitAre.lendemain();
  }
  
  public Damj recupererDjiParEpuisement(DemandeSpec demande, AttributionSpec dernierDroitAsu)
    throws ApplicativeException
  {
    return ((ProduitAsuSpec)dernierDroitAsu.getDossierAffecte().getProduit()).recupererDJIParEpuisement(demande, dernierDroitAsu, true);
  }
  
  public Damj determinerProchaineDateDansPECIndemnisable(DemandeSpec demande, Damj date)
    throws CoucheLogiqueException
  {
    Damj prochaineDateDansPECIndemnisable = date;
    if (date != null)
    {
      ObjetChronoPeriodePriseEnCharge periodePECDjiParEpuisement = OutillagePEC.getPeriodePECIndemnisableContenant(demande.getDemandeur(), date);
      if (periodePECDjiParEpuisement == null) {
        prochaineDateDansPECIndemnisable = OutillagePEC.getPremierJourPECNonAnnuleesApresDate(demande.getDemandeur(), date);
      }
    }
    if (prochaineDateDansPECIndemnisable == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_DATE_EXAMEN_PAS_PEC_INDEMNISABL", new Object[] { date });
    }
    return prochaineDateDansPECIndemnisable;
  }
  
  public Damj determinerProchaineDateDansPECDemandeurEmploi(DemandeSpec demande, Damj date)
    throws CoucheLogiqueException
  {
    Damj prochaineDateDansPECIndemnisable = date;
    if (date != null)
    {
      ObjetChronoPeriodePriseEnCharge periodePECDjiParEpuisement = OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), date);
      if (periodePECDjiParEpuisement == null) {
        prochaineDateDansPECIndemnisable = OutillagePEC.getPremierJourPECDemandeur(demande.getDemandeur(), date);
      }
    }
    if (prochaineDateDansPECIndemnisable == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_CTX_DEMAND_NON_INSCRIT_AVC_DATE", new Object[] { date.toString() });
    }
    return prochaineDateDansPECIndemnisable;
  }
  
  public Damj determinerFinDroitParEpuisementAttribution(DemandeSpec demande, AttributionSpec attribution)
    throws ApplicativeException
  {
    Chronologie chronologieDemandes = attribution.getDemandeur().getChronoDemandes();
    
    FiltresTemporel listeFiltresOdAssurance = new FiltresTemporel();
    listeFiltresOdAssurance.ajouterFiltre(new FiltreDemandesGammeAsu());
    listeFiltresOdAssurance.ajouterFiltre(new FiltreAttribution());
    listeFiltresOdAssurance.ajouterFiltre(new FiltreDecisionNonEnReexamen());
    chronologieDemandes.setComparateur(new ComparateurSurDateDeclenchementEtPrioriteDemande());
    chronologieDemandes = chronologieDemandes.copier(listeFiltresOdAssurance);
    
    AttributionSpec derniereAttributionPourOD = null;
    boolean derniereAttributionPourODTrouvee = false;
    chronologieDemandes.iterer();
    while ((chronologieDemandes.encoreSuivant()) && (!derniereAttributionPourODTrouvee))
    {
      DemandeSpec demandeEtudiee = (DemandeSpec)chronologieDemandes.elementSuivant();
      AttributionSpec attributionEtudiee = (AttributionSpec)demandeEtudiee.getListeDossiersExamen().get(0);
      if (attributionEtudiee.getDateEffet().estApres(attribution.getDateAttribution())) {
        if ((attributionEtudiee instanceof OdSpec)) {
          derniereAttributionPourODTrouvee = true;
        } else {
          derniereAttributionPourOD = attributionEtudiee;
        }
      }
    }
    if (derniereAttributionPourOD == null) {
      derniereAttributionPourOD = attribution;
    }
    return recupererDjiParEpuisement(demande, derniereAttributionPourOD);
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationDateExamenPourFps
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */