package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RechercheConditionDureeNonNulle;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ConditionAttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.UniteDuree;
import java.util.Iterator;
import java.util.List;

public class OutilFinDroit
  extends fr.unedic.cali.outilsfonctionnels.OutilFinDroit
{
  public static AttributionSpec rechercherAttributionOrigineCorrespondante(DemandeSpec demande)
  {
    AttributionSpec retour = null;
    if (OutilDemande.estUneDemandeFinDroitAsr(demande))
    {
      retour = OutilAsr.rechercherAttributionAsrPrecedent(demande);
    }
    else if (OutilDemande.estUneDemandeFinDroitAtp(demande))
    {
      retour = OutilAtp.rechercherAttributionAtpOrigine(demande, demande.getDateDeclenchementExamen());
    }
    else if (OutilDemande.estUneDemandeFinDroitAsp(demande))
    {
      Demande demandeAspLiee = (Demande)OutilAsp.getInstance().rechercherDemandeAspLiee(demande);
      if (demandeAspLiee != null) {
        retour = demandeAspLiee.getAttribution();
      }
    }
    return retour;
  }
  
  public static AttributionSpec rechercherAttributionCorrespondantePecedente(DemandeSpec demande)
  {
    AttributionSpec retour = null;
    if (OutilDemande.estUneDemandeFinDroitAsr(demande)) {
      retour = OutilAsr.rechercherDernierDroitAsr((Demande)demande);
    } else if (OutilDemande.estUneDemandeFinDroitAtp(demande)) {
      retour = OutilAtp.rechercherAttributionAtpPrecedent(demande, demande.getDateDepot());
    } else if (OutilDemande.estUneDemandeFinDroitAsp(demande)) {
      retour = OutilAsp.getInstance().rechercherAttributionAspPrecedent(demande, demande.getDateDepot());
    }
    return retour;
  }
  
  public static boolean estDemandeFinDroitContextePrecSuiteCsr(Demande demande)
    throws ApplicativeException
  {
    if ((!OutilDemande.estUneDemandeFinDroitAsr(demande)) && (!OutilDemande.estUneDemandeFinDroitAsp(demande))) {
      return false;
    }
    boolean estDemandeFinDroitContextePrecSuiteCsr = false;
    Demande demandePrec = (Demande)rechercherDemandeODPrecedenteCorrespondante(demande);
    if ((demandePrec != null) && (demandePrec.getContexteAffiliationValide() != null)) {
      estDemandeFinDroitContextePrecSuiteCsr = true;
    }
    return estDemandeFinDroitContextePrecSuiteCsr;
  }
  
  public static boolean estCasParticulierFinDroitEnAttributionAvecDuree0Jour(DemandeSpec demandeAss)
  {
    boolean estCasParticulier = false;
    if ((demandeAss instanceof DemandeAssuranceSpec))
    {
      Demande demande = (Demande)demandeAss;
      if ((demande.estUneDemandeFinDroit()) && (demande.getAttribution() != null)) {
        estCasParticulier = estUnCasParticulier(demande, demande.getAttribution());
      }
    }
    return estCasParticulier;
  }
  
  private static boolean estUnCasParticulier(Demande demande, AttributionAssuranceSpec attribution)
  {
    boolean estCasParticulier = false;
    Iterator<?> it = attribution.getListConditionsAttribution().iterator();
    while (it.hasNext())
    {
      ConditionAttributionSpec condition = (ConditionAttributionSpec)it.next();
      if ((condition != null) && (!condition.estSatisfait())) {
        estCasParticulier = true;
      }
    }
    if ((demande.estEnContexteDemande(5)) && ((attribution instanceof RepriseSpec)))
    {
      ResultatElementDroit resultatElementDroit = RechercheConditionDureeNonNulle.getInstance().rechercherConditionDureeNonNulle(demande);
      if (!resultatElementDroit.estSatisfait()) {
        estCasParticulier = true;
      }
    }
    return estCasParticulier;
  }
  
  public static Quantite trouverQuantiteAImputer(Demande demandeFinDroit, AttributionAssuranceSpec attributionAImputer)
    throws ApplicativeException
  {
    Quantite quantiteAImputer;
    Quantite quantiteAImputer;
    if (estUneDemandeFinDroitSuiteSP(demandeFinDroit))
    {
      quantiteAImputer = new Quantite(demandeFinDroit.getDonneesTemporaires().getDureeImputationSP(), UniteDuree.JOUR);
    }
    else
    {
      int nbJoursIndemnises = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAImputer, null, false, false).getCumulJourIndemnise();
      
      quantiteAImputer = new Quantite(nbJoursIndemnises, UniteDuree.JOUR);
    }
    return quantiteAImputer;
  }
  
  public static boolean estUneDemandeFinDroitSuiteSP(DemandeSpec demande)
  {
    boolean retour = false;
    if (OutilDemande.estUneDemandeFinDroitAsp(demande)) {
      retour = OutilAsp.getInstance().estUneDemandeFinDroitSP(demande);
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     OutilFinDroit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */