package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.parcours.ResultatTraitementReliquat;
import fr.unedic.cali.autresdoms.cohab.dom.DecisionSuivi;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.ResultatTraitementReliquatSpec;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalarieePeriodiqueAccordDDTE;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreDemandeDecisionneeOuClasseeSP;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.ListIterator;

public abstract class OutilTraitementReliquat
  extends fr.unedic.cali.outilsfonctionnels.OutilTraitementReliquat
{
  protected static final int DELAI_DECHEANCE_ANNEES = 3;
  
  public static Quantite determinerImputationNombreJoursDonneesForcees(DemandeSpec demande)
  {
    Quantite nbJourImpute = new Quantite(ZERO, UniteDuree.JOUR);
    if ((demande instanceof Demande))
    {
      Demande demandeAsu = (Demande)demande;
      BigDecimal nbJourImputationDonneesForcees = demandeAsu.getDonneesTemporaires().getNbJourImputationDroitPrecedent();
      if (nbJourImputationDonneesForcees != null) {
        nbJourImpute = new Quantite(nbJourImputationDonneesForcees, UniteDuree.JOUR);
      }
    }
    return nbJourImpute;
  }
  
  public ResultatTraitementReliquat traiterReliquat(ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude)
    throws CoucheLogiqueException, ApplicativeException
  {
    ResultatTraitementReliquat resultatTraitementReliquat = new ResultatTraitementReliquat();
    DecisionSpec attributionPrecedente = resultatExecutionCalcul.getAttributionEtudiee();
    DemandeSpec demandeCourante = ((AttributionAssuranceSpec)resultatExecutionCalcul.getAttributionEtudiee()).getDemandeSuivantePourTraitementReliquat();
    
    int etatAttribution = resultatExecutionCalcul.getEtatAttribution();
    
    alimenterEtatReliquatRetourCalcul(etatAttribution, resultatTraitementReliquat);
    if (!estDemandeSansTraitementReliquat(demandeCourante)) {
      traiterReliquat(resultatExecutionCalcul, dateEtude, resultatTraitementReliquat, attributionPrecedente, demandeCourante);
    }
    return resultatTraitementReliquat;
  }
  
  private boolean estDemandeSansTraitementReliquat(DemandeSpec demandeCourante)
  {
    return ((demandeCourante instanceof Demande)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeCourante, "DVFILEAU"));
  }
  
  private void traiterReliquat(ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude, ResultatTraitementReliquat resultatTraitementReliquat, DecisionSpec attributionPrecedente, DemandeSpec demandeCourante)
    throws CoucheLogiqueException, ApplicativeException
  {
    if (preTraitement(resultatTraitementReliquat, demandeCourante, attributionPrecedente, resultatExecutionCalcul))
    {
      if (!estAntecedentEpuise(demandeCourante, attributionPrecedente, resultatExecutionCalcul, resultatTraitementReliquat, dateEtude)) {
        estAntecedentDechu(demandeCourante, resultatTraitementReliquat, attributionPrecedente, dateEtude);
      }
      estAntecedentEteint(demandeCourante, attributionPrecedente, resultatTraitementReliquat, resultatExecutionCalcul, dateEtude);
    }
    postTraitement(resultatTraitementReliquat, resultatExecutionCalcul);
  }
  
  protected boolean estAntecedentDechu(DemandeSpec demande, ResultatTraitementReliquatSpec resultatTraitementReliquat, DecisionSpec decisionPrecedente, Damj dateEtude)
    throws CoucheLogiqueException
  {
    boolean estAntecedentDechu = false;
    if (estDemandeEligibleEtudeDecheance(demande)) {
      estAntecedentDechu = super.estAntecedentDechu(demande, resultatTraitementReliquat, decisionPrecedente, dateEtude);
    }
    return estAntecedentDechu;
  }
  
  private boolean estDemandeEligibleEtudeDecheance(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    boolean estDemandeEligibleEtudeDecheance = true;
    if ("ASU_04".equals(demande.getEvenementReferenceExamen().getTypeExamen()))
    {
      Demande demandePortantDv = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande);
      if (demandePortantDv != null) {
        estDemandeEligibleEtudeDecheance = !OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePortantDv, "DVFILEAU");
      }
    }
    return estDemandeEligibleEtudeDecheance;
  }
  
  protected abstract boolean preTraitement(ResultatTraitementReliquat paramResultatTraitementReliquat, DemandeSpec paramDemandeSpec, DecisionSpec paramDecisionSpec, ResultatExecutionCalculSpec paramResultatExecutionCalculSpec)
    throws CoucheLogiqueException;
  
  protected void postTraitement(ResultatTraitementReliquat resultatTraitement, ResultatExecutionCalculSpec resultatCalcul)
  {
    DemandeSpec demandeEnCours = ((AttributionAssuranceSpec)resultatCalcul.getAttributionEtudiee()).getDemandeSuivantePourTraitementReliquat();
    leverAlerteA9MNB1(demandeEnCours, resultatTraitement.isReliquatValide());
    ((AttributionAssuranceSpec)resultatCalcul.getAttributionEtudiee()).setDemandeSuivantePourTraitementReliquat(null);
  }
  
  protected void alimenterResultatEpuise(ResultatTraitementReliquatSpec resultatTraitementReliquat, ResultatExecutionCalculSpec resultatExecutionCalcul)
  {
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setCoupleContexteEtCauseNonValiditeReliquat(2, 2, false);
    
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setDateNonValidite(resultatExecutionCalcul.getDernierJourIndemnisable());
  }
  
  protected void alimenterResultatDechu(ResultatTraitementReliquatSpec resultatTraitementReliquat, DemandeSpec demande, Damj date)
  {
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setCoupleContexteEtCauseNonValiditeReliquat(2, 4, false);
    
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setDateNonValidite(date);
  }
  
  protected void alimenterResultatEteint(ResultatTraitementReliquatSpec resultatTraitementReliquat, Damj date)
  {
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setCoupleContexteEtCauseNonValiditeReliquat(2, 1, false);
    
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setDateNonValidite(date);
  }
  
  protected Quantite imputerQuantite(Quantite qteReliquatAvantImputation, Quantite qteAImputer)
  {
    Quantite qteReliquatApresImputation = qteReliquatAvantImputation.soustraire(qteAImputer);
    if (qteReliquatApresImputation.getValeurEntiere() < 0) {
      qteReliquatApresImputation = new Quantite(BigDecimal.valueOf(0L), UniteDuree.JOUR);
    }
    return qteReliquatApresImputation;
  }
  
  private void alimenterEtatReliquatRetourCalcul(int etatCalcul, ResultatTraitementReliquat resultatTraitement)
  {
    switch (etatCalcul)
    {
    case 3: 
      resultatTraitement.setCoupleContexteEtCauseNonValiditeReliquat(3, 0, true);
      
      break;
    case 2: 
      resultatTraitement.setCoupleContexteEtCauseNonValiditeReliquat(2, 2, false);
      
      break;
    case 1: 
      resultatTraitement.setCoupleContexteEtCauseNonValiditeReliquat(2, 1, false);
      
      break;
    case 4: 
      resultatTraitement.setCoupleContexteEtCauseNonValiditeReliquat(2, 4, false);
      
      break;
    default: 
      resultatTraitement.setCoupleContexteEtCauseNonValiditeReliquat(1, 0, false);
    }
  }
  
  public static ResultatTraitementReliquat traiterReliquatSecteurPublic(DemandeSpec demande, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Damj debutDelaiDecheance = null;
    DureeCalendaire dureeDecheance = null;
    Damj finDelaiDechance = null;
    Periode delaiDecheance = null;
    boolean produitDechu = false;
    ResultatTraitementReliquat resultatTraitementReliquat = new ResultatTraitementReliquat();
    if (((DemandeAssuranceSpec)demande).getDonneesTemporaires().getDateAttributionDroitAnterieurSp() == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_DATE_ATTRIB_DROIT");
    }
    debutDelaiDecheance = ((DemandeAssuranceSpec)demande).getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    if (((DemandeAssuranceSpec)demande).getDonneesTemporaires().getDureeInitialeDroitAnterieurSp() == 0) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_DUREE_INIT_DROIT");
    }
    dureeDecheance = new DureeCalendaire(0, 0, ((DemandeAssuranceSpec)demande).getDonneesTemporaires().getDureeInitialeDroitAnterieurSp());
    dureeDecheance = dureeDecheance.ajouter(new DureeCalendaire(3, 0, 0));
    
    DureeCalendaire allongement = ((DemandeAssuranceSpec)demande).getDonneesTemporaires().getAllongementDelaiDecheance();
    if (allongement != null) {
      dureeDecheance = dureeDecheance.ajouter(allongement);
    }
    finDelaiDechance = debutDelaiDecheance.deplacerVersAvant(dureeDecheance);
    delaiDecheance = new Periode(debutDelaiDecheance, finDelaiDechance);
    
    produitDechu = !dateEtude.estContenueDans(delaiDecheance);
    if (produitDechu)
    {
      resultatTraitementReliquat.setContexteExamen(2);
      resultatTraitementReliquat.setCauseNonvalidite(4);
    }
    else
    {
      resultatTraitementReliquat.setContexteExamen(4);
      resultatTraitementReliquat.setCauseNonvalidite(0);
    }
    return resultatTraitementReliquat;
  }
  
  public static Quantite determinerImputationPourSuppressionTemporaireRevenuDeRemplacement(DemandeSpec demande, ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Quantite nbJoursSuspension = new QuantiteJour(ZERO);
    
    Periode periodePriseEnCompteSanction = determinerPeriodeHorsPEC(resultatExecutionCalcul, dateEtude);
    
    Collection listeSanctions = getListeSanctionsPourDE(demande.getDemandeur());
    if ((periodePriseEnCompteSanction != null) && (listeSanctions != null) && (listeSanctions.size() > 0))
    {
      Iterator iterateurListeSanctions = listeSanctions.iterator();
      ChronologiePeriodes chronoPeriodesSanction = new ChronologiePeriodes();
      while (iterateurListeSanctions.hasNext())
      {
        DecisionSuivi decisionSuivi = (DecisionSuivi)iterateurListeSanctions.next();
        if (estSuppressionTemporaireRevenuRemplacement(decisionSuivi)) {
          if (estUneSuspensionPourAttribution(decisionSuivi, resultatExecutionCalcul.getAttributionEtudiee()))
          {
            Periode periodeEffetSanction = new Periode(decisionSuivi.getDateEffet(), decisionSuivi.getDateFin());
            
            Periode periodeAPrendreEnComptePourSanction = periodePriseEnCompteSanction.periodeIntersection(periodeEffetSanction);
            if (periodeAPrendreEnComptePourSanction != null) {
              chronoPeriodesSanction.ajouter(new ObjetChronoPeriodeConcrete(periodeAPrendreEnComptePourSanction));
            }
          }
        }
      }
      if (!chronoPeriodesSanction.estVide())
      {
        ChronologiePeriodes chronoPeriodeSanctionFusion = chronoPeriodesSanction.fusionnerChevauchementPeriodes();
        Iterator it = chronoPeriodeSanctionFusion.iterer();
        int nombreJoursSuspension = ZERO.intValue();
        while (it.hasNext())
        {
          ObjetChronoPeriode periode = (ObjetChronoPeriode)it.next();
          nombreJoursSuspension += periode.getDuree();
        }
        nbJoursSuspension = new Quantite(new BigDecimal(nombreJoursSuspension), UniteDuree.JOUR);
      }
    }
    return nbJoursSuspension;
  }
  
  protected static void leverAlerteA9MNB1(DemandeSpec demande, boolean reliquatValide)
  {
    if ((OutilDemande.estUneDemandeAreIde(demande)) && (((Demande)demande).getDonneesTemporaires() != null) && (reliquatValide))
    {
      DemandeSpec demandePrecedente = OutilRecherche.rechercherDemandePrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, new FiltreDemandeDecisionneeOuClasseeSP());
      if ((demandePrecedente != null) && (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsr(demandePrecedente)) && (((Demande)demande).getDonneesTemporaires().getMontantAide() == null))
      {
        AttributionSpec attributionAsrPrecedente = OutilAsr.rechercherAttributionAsrPrecedent(demandePrecedente);
        if (attributionAsrPrecedente != null)
        {
          Periode periodeIndemniseeAsr = RechercherPeriodeIndemnisation.getPeriodeIndemnisationPourAttribution(attributionAsrPrecedente);
          if (periodeIndemniseeAsr != null)
          {
            ChronologiePeriodes chronoIndividu = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
            FiltresTemporel filtre = new FiltresTemporel();
            filtre.ajouterFiltre(new FiltreChevauchePeriode(periodeIndemniseeAsr));
            filtre.ajouterFiltre(new FiltrePeriodeActiviteNonSalarieePeriodiqueAccordDDTE());
            Chronologie pansAccordDDTEChevaucheIndemnisationAsr = chronoIndividu.copier(filtre);
            if ((pansAccordDDTEChevaucheIndemnisationAsr != null) && (!pansAccordDDTEChevaucheIndemnisationAsr.estVide()))
            {
              TravailSpec premierePansChevauchant = (TravailSpec)pansAccordDDTEChevaucheIndemnisationAsr.iterer().next();
              ArrayList listeAlertesNonBloquantes = new ArrayList();
              listeAlertesNonBloquantes.add(new ObjetAlertesNonBloquantes(premierePansChevauchant));
              demande.getAlertesNonBloquantes().put("A9MNB1", listeAlertesNonBloquantes);
            }
          }
        }
      }
    }
  }
  
  protected static DureeCalendaire getDureeDecheance(int dureeIndemnisationPrecedente)
  {
    int zero = ZERO.intValue();
    
    DureeCalendaire duree = new DureeCalendaire(zero, zero, dureeIndemnisationPrecedente);
    
    duree = duree.ajouter(new DureeCalendaire(3, zero, zero));
    return duree;
  }
  
  public static Periode getDelaiDecheance(AttributionAssuranceSpec attributionPrecedente)
  {
    Damj debutDelaiDecheance = null;
    DureeCalendaire dureeDecheance = null;
    Damj finDelaiDechance = null;
    if (attributionPrecedente != null)
    {
      AttributionAssuranceSpec attributionAssurance = attributionPrecedente;
      debutDelaiDecheance = attributionAssurance.getDateDebutDelaiDecheance();
      dureeDecheance = getDureeDecheance(attributionAssurance.getDureeTheoriquePourDelaiDecheance().getValeurEntiere());
      finDelaiDechance = debutDelaiDecheance.deplacerVersAvant(dureeDecheance);
    }
    return new Periode(debutDelaiDecheance, finDelaiDechance);
  }
}

/* Location:
 * Qualified Name:     OutilTraitementReliquat
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */