package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionCSRAccordCP;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.Duree;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.asu.produits.liquidation.dom.SousTrancheExecutable;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public final class OutilTranchesExecutables
  implements OutilFonctionnel
{
  private static List<LigneSpec> ligneSpectacle = new ArrayList();
  public static final BigDecimal VALEUR_ZERO = BigDecimal.ZERO;
  
  static
  {
    ligneSpectacle.add(LigneAsuSpe02.getInstance());
    ligneSpectacle.add(LigneAsuSsp07.getInstance());
    ligneSpectacle.add(LigneAsuFds12.getInstance());
  }
  
  public static void alimenterTranches(AttributionAssuranceSpec attribution)
  {
    Attribution attributionCourante = (Attribution)attribution;
    if (((ProduitAsuSpec)attributionCourante.getProduit()).estTrancheActivee(attributionCourante.getDemande()))
    {
      Collection<TrancheExecutable> listeTranches = new ArrayList();
      TrancheExecutable tranchePrincipale = new TrancheExecutable();
      
      alimenterTrancheAvecAttribution(attributionCourante, tranchePrincipale);
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), 9))
      {
        Collection<SousTrancheExecutable> listeSousTranches = new ArrayList();
        SousTrancheExecutable sousTrancheAspSousJacent = new SousTrancheExecutable();
        
        alimenterSousTrancheAvecAspSousJacent(attributionCourante, sousTrancheAspSousJacent);
        listeSousTranches.add(sousTrancheAspSousJacent);
        
        alimenterListeSousTrancheAvecOdOuNovationOuRevision(attributionCourante, listeSousTranches);
        
        tranchePrincipale.remplacerCollectionListeSousTrancheExecutable(listeSousTranches);
      }
      listeTranches.add(tranchePrincipale);
      attributionCourante.remplacerCollectionTranchesExecutables(listeTranches);
    }
  }
  
  private static void alimenterListeSousTrancheAvecOdOuNovationOuRevision(AttributionAssuranceSpec attribution, Collection<SousTrancheExecutable> listeSousTranche)
  {
    Collection<DemandeAssuranceSpec> admissionsDurantDispositifCsp = OutilAsp.getInstance().recupererAdmissionsDurantDispositifCSP(attribution);
    if (!admissionsDurantDispositifCsp.isEmpty())
    {
      Iterator<DemandeAssuranceSpec> iterDemande = admissionsDurantDispositifCsp.iterator();
      while (iterDemande.hasNext())
      {
        DemandeAssuranceSpec demande = (DemandeAssuranceSpec)iterDemande.next();
        SousTrancheExecutable sousTranche = new SousTrancheExecutable();
        alimenterSousTrancheAvecAttribution((AttributionAssuranceCgeSpec)demande.getAttribution(), sousTranche);
        listeSousTranche.add(sousTranche);
      }
    }
  }
  
  private static void alimenterSousTrancheAvecAspSousJacent(AttributionAssuranceSpec attribution, SousTrancheExecutable sousTrancheAspSousJacent)
  {
    AttributionAssuranceCgeSpec attributionEntreeCsp = (AttributionAssuranceCgeSpec)OutilAsp.getInstance().recupererAttributionEntreeCsp(attribution);
    if (attributionEntreeCsp != null)
    {
      Attribution attributionDemandeSousJacente = (Attribution)attributionEntreeCsp.getAttributionAssociee();
      if (attributionDemandeSousJacente != null)
      {
        alimenterTrancheAvecAttribution(attributionDemandeSousJacente, sousTrancheAspSousJacent);
        
        sousTrancheAspSousJacent.setProduitMontantRetenu(attributionEntreeCsp.getProduitExecution().getCode());
        alimenterContextePap(attribution.getDemande(), sousTrancheAspSousJacent);
      }
    }
  }
  
  private static void alimenterTrancheAvecAttribution(Attribution attributionCourante, TrancheExecutable tranche)
  {
    alimenterDonneesCommunesTranche(attributionCourante, tranche);
    
    tranche.setAttribution(attributionCourante);
    if (attributionCourante.getConstitutionDelais() != null)
    {
      Collection listeCarences = attributionCourante.getListeCarences();
      if ((listeCarences != null) && (!listeCarences.isEmpty()))
      {
        Iterator it = listeCarences.iterator();
        while (it.hasNext())
        {
          CarencePrefixeAFixer carence = (CarencePrefixeAFixer)it.next();
          tranche.ajouterDelaisReports((CarencePrefixeAFixer)carence.copie());
        }
      }
    }
    alimenterDonneesdurees(attributionCourante, tranche);
    
    alimenterDonneesChomageSansRupture(attributionCourante, tranche);
    if (attributionCourante.getConditionCSRAccordCP() != null)
    {
      tranche.setEstSinistreOuCalamite(attributionCourante.getConditionCSRAccordCP().isEstSinistreOuCalamiteNaturelle());
      tranche.setEstAccordCp(attributionCourante.getConditionCSRAccordCP().estSatisfait());
    }
    if ((attributionCourante.getConstitutionDurees() != null) && (attributionCourante.getConstitutionDurees().getDureeIndemnisation() != null)) {
      tranche.setEstDecisionProlongation(attributionCourante.getConstitutionDurees().getDureeIndemnisation().isEstAccordPlusDe182jCsr());
    }
    if (attributionCourante.getSeuilMensuelPansConservees() != null) {
      tranche.setSeuilMensuelPansConservees(attributionCourante.getSeuilMensuelPansConservees());
    }
    alimenterContextePap(attributionCourante.getDemande(), tranche);
  }
  
  private static void alimenterDonneesCommunesTranche(AttributionAssuranceCgeSpec attributionCourante, TrancheExecutable tranche)
  {
    tranche.setRang(Integer.valueOf(1));
    
    alimenterDonneesMontant(attributionCourante, tranche);
    tranche.setA3ansActiviteEn5ans(attributionCourante.a3ansActiviteEn5ans());
    tranche.setCoefficientTempsPartiel(attributionCourante.getCoefficientTempsPartiel());
    tranche.setEstSjrBaseSmic(attributionCourante.estSjrBaseSmic());
    tranche.setCodeEmploiA2B(attributionCourante.getCategorieEmploiA2B());
    if (attributionCourante.getReglementApplicable() != null)
    {
      tranche.setReglementApplicable(attributionCourante.getReglementApplicable().getReglement().getNomReglement());
      tranche.setCodeProduitReglement(attributionCourante.getReglementApplicable().getReglement().getProduit().getCode());
    }
    tranche.setMontantPreavis(attributionCourante.getMontantPreavis());
    
    alimenterDonneesAttribution(attributionCourante, tranche);
    
    alimenterDonneesMaintienEuropeen(attributionCourante, tranche);
    
    alimenterDonneesSpectacle(attributionCourante, tranche);
    
    List<ContexteDemandeSpec> listeContexteTranche = new ArrayList();
    List<ContexteDemandeSpec> listeContexteDemande = ((Demande)attributionCourante.getDemande()).getListContexteDemande();
    Iterator<ContexteDemandeSpec> it = listeContexteDemande.iterator();
    while (it.hasNext()) {
      listeContexteTranche.add((ContexteDemande)((ContexteDemande)it.next()).copie());
    }
    tranche.setListeContextes(listeContexteTranche);
  }
  
  private static void alimenterDonneesCompetence(AttributionAssuranceCgeSpec attributionCourante, TrancheExecutable tranche)
  {
    if (attributionCourante.getConventionGestion() != null)
    {
      tranche.setCodeAffectationCG(attributionCourante.getConventionGestion().getCodeAffectation());
      tranche.setEtablissementFinanceurCG(attributionCourante.getConventionGestion().getNumeroConventionGestion());
    }
    tranche.setCompetenceFinanciere(attributionCourante.getCompetenceFinanciere());
    tranche.setCompetenceAdministrative(attributionCourante.getCompetenceAdministrative());
  }
  
  private static void alimenterDonneesAttribution(AttributionAssuranceCgeSpec attributionCourante, TrancheExecutable tranche)
  {
    int nature = attributionCourante.getNatureDecision();
    tranche.setNatureDecision(nature);
    tranche.setDateAttribution(attributionCourante.getDateAttribution());
    tranche.setCodeProduit(attributionCourante.getProduit().getCode());
    if (attributionCourante.getFaitGenerateur() != null) {
      tranche.setIdFaitGenerateur(attributionCourante.getFaitGenerateur().getIdentifiantPeriodeFaitGenerateur());
    }
  }
  
  private static void alimenterDonneesMontant(AttributionAssuranceCgeSpec attributionCourante, TrancheExecutable tranche)
  {
    alimenterDonneesSjrEtSjc(attributionCourante, tranche);
    tranche.setPrecompteCRC(attributionCourante.estAvecPrecompteCRC());
    
    BigDecimal valeurCoefficientSaisonnier = ((ProduitAsuSpec)attributionCourante.getProduit()).recupererCoefficientSaisonnierMontantRetenu(attributionCourante);
    if (valeurCoefficientSaisonnier == null) {
      valeurCoefficientSaisonnier = BigDecimal.ONE;
    }
    tranche.setCoefficientSaisonnier(valeurCoefficientSaisonnier);
    tranche.setNatureCoefficientSaisonnier(attributionCourante.getNatureCoefficientSaisonnier());
    if (attributionCourante.getProduitMontantRetenu() != null) {
      tranche.setProduitMontantRetenu(attributionCourante.getProduitMontantRetenu().getCode());
    }
    if ((attributionCourante.getReglementApplicableMontantRetenu() != null) && (attributionCourante.getReglementApplicableMontantRetenu().getReglement() != null)) {
      tranche.setReglementApplicableMontantRetenu(attributionCourante.getReglementApplicableMontantRetenu().getReglement().getNomReglement());
    }
    tranche.setCapitalAServir(attributionCourante.getCapitalAServir());
    
    Collection listePI = attributionCourante.getListePensionInvalidite();
    if ((listePI != null) && (!listePI.isEmpty()))
    {
      Iterator it = listePI.iterator();
      while (it.hasNext())
      {
        PeriodePensionInvaliditeChaineeSpec pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)it.next();
        tranche.ajouterPensionsInvalidites(OutilPensionInvalidite.conversionDomPensionInvaliditeEnDomLiquidation(pensionInvalidite));
      }
    }
    alimenterDonneesCompetence(attributionCourante, tranche);
    if ((attributionCourante instanceof OdSpec)) {
      tranche.setTypeCapitalRetenu(Integer.toString(attributionCourante.getTypeCapitalRetenu()));
    }
    tranche.setTypeMontantRetenu(Integer.toString(attributionCourante.getTypeMontantRetenu()));
  }
  
  private static void alimenterSousTrancheAvecAttribution(AttributionAssuranceCgeSpec attributionCourante, TrancheExecutable tranche)
  {
    alimenterDonneesCommunesTranche(attributionCourante, tranche);
  }
  
  private static void alimenterDonneesSjrEtSjc(AttributionAssuranceCgeSpec attribution, TrancheExecutable tranche)
  {
    if (attribution.getSalaireJournalierInitial() != null)
    {
      SalaireJournalierSpec salaireJournalier = attribution.getSalaireJournalierInitial();
      tranche.setMontantSJI(new QuantiteEuro(salaireJournalier.getSalaire()));
      tranche.setDateSJI(salaireJournalier.getDateDepart());
      tranche.setContexteParticulierSJI(salaireJournalier.getContexteParticulier());
    }
    if (attribution.getSalaireJournalierConserve() != null)
    {
      SalaireJournalierSpec salaireJournalier = attribution.getSalaireJournalierConserve();
      tranche.setMontantSJC(new QuantiteEuro(salaireJournalier.getSalaire()));
      tranche.setDateSJC(salaireJournalier.getDateDepart());
      tranche.setContexteParticulierSJC(salaireJournalier.getContexteParticulier());
    }
    if ((((Demande)attribution.getDemande()).estEnContexteDroitAnterieurSecteurPublicValide()) && (1 != attribution.getTypeMontantRetenu()))
    {
      String typeContexte = "AUCUN";
      ContexteDemande contexte = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance((Demande)attribution.getDemande(), "AREMAYOTTE");
      if (contexte != null) {
        typeContexte = contexte.getTypeContexteDemande();
      }
      tranche.setContexteParticulierSJI(typeContexte);
    }
  }
  
  private static void alimenterDonneesdurees(Attribution attribution, TrancheExecutable tranche)
  {
    if (attribution.getDureeTheorique() != null)
    {
      Integer nombreJours = Integer.valueOf(attribution.getDureeTheorique().getValeurEntiere());
      
      Duree duree = new Duree();
      duree.setTypeDuree(1);
      duree.setNombreJour(nombreJours);
      tranche.ajouterDurees(duree);
    }
    if (attribution.getDureeIndemnisationEffective() != null)
    {
      Integer nombreJours = Integer.valueOf(attribution.getDureeIndemnisationEffective().getValeurEntiere());
      
      Duree duree = new Duree();
      duree.setTypeDuree(2);
      duree.setNombreJour(nombreJours);
      tranche.ajouterDurees(duree);
    }
    if (attribution.getDureeProlongationTheorique() != null)
    {
      Integer nombreJours = Integer.valueOf(attribution.getDureeProlongationTheorique().getValeurEntiere());
      
      Duree duree = new Duree();
      duree.setTypeDuree(3);
      duree.setNombreJour(nombreJours);
      tranche.ajouterDurees(duree);
    }
    if (attribution.getDureeInitiale() != null)
    {
      Integer nombreJours = Integer.valueOf(attribution.getDureeInitiale().getValeurEntiere());
      
      Duree duree = new Duree();
      duree.setTypeDuree(4);
      duree.setNombreJour(nombreJours);
      tranche.ajouterDurees(duree);
    }
    Quantite dureePostPrime = attribution.getDureePostPrime();
    if (dureePostPrime != null)
    {
      Integer nombreJours = Integer.valueOf(dureePostPrime.getValeurEntiere());
      
      Duree duree = new Duree();
      duree.setTypeDuree(5);
      duree.setNombreJour(nombreJours);
      tranche.ajouterDurees(duree);
    }
    tranche.setDateLimiteIndemnisation(attribution.getDateLimiteIndemnisation());
    tranche.setContexteDateLimiteIndemnisation(attribution.getContexteDateLimiteIndemnisation());
    if ((attribution.getConstitutionDurees() != null) && (attribution.getConstitutionDurees().getDureeIndemnisation() != null))
    {
      DureeIndemnisation dureeIndemnisation = attribution.getConstitutionDurees().getDureeIndemnisation();
      Duree duree = new Duree();
      duree.setTypeDuree(3);
      duree.setNombreJour(Integer.valueOf(dureeIndemnisation.getDureeAllongementAREF()));
      tranche.ajouterDurees(duree);
      tranche.setEligibleAllongementAREF(dureeIndemnisation.isEligibleAllongementAREF());
    }
  }
  
  private static void alimenterDonneesChomageSansRupture(Attribution attribution, TrancheExecutable tranche)
  {
    attribution.viderCacheElementsChomageSansRupture();
    if (attribution.getElementChomageSansRupture() != null)
    {
      if (attribution.getElementChomageSansRupture().getDateMaxIndeminisation() != null) {
        tranche.setDateMaxIndemnisation(attribution.getElementChomageSansRupture().getDateMaxIndeminisation());
      }
      if (attribution.getElementChomageSansRupture().getDateDebutPeriodeSuspension() != null) {
        tranche.setDateDebutPeriodeSuspension(attribution.getElementChomageSansRupture().getDateDebutPeriodeSuspension());
      }
      if (attribution.getElementChomageSansRupture().getDateFinPeriodeSuspension() != null) {
        tranche.setDateFinPeriodeSuspension(attribution.getElementChomageSansRupture().getDateFinPeriodeSuspension());
      }
      if (attribution.getElementChomageSansRupture().getDateRepriseActivite() != null) {
        tranche.setDateRepriseActivite(attribution.getElementChomageSansRupture().getDateRepriseActivite());
      }
    }
  }
  
  private static void alimenterDonneesMaintienEuropeen(AttributionAssuranceCgeSpec attribution, TrancheExecutable tranche)
  {
    if ((!attribution.getDemandeAssurance().estMigree()) && (attribution.getMaintienEuropeen() != null) && (attribution.getMaintienEuropeen().getDuree() != null))
    {
      tranche.setJoursDureeMaintienEuropeen(attribution.getMaintienEuropeen().getDuree().getJours());
      tranche.setMoisDureeMaintienEuropeen(attribution.getMaintienEuropeen().getDuree().getMois());
      tranche.setAnneeDureeMaintienEuropeen(attribution.getMaintienEuropeen().getDuree().getAnnees());
      tranche.setDateDebutMaintientEuropeen(attribution.getMaintienEuropeen().getDepartPeriode());
    }
  }
  
  private static void alimenterDonneesSpectacle(AttributionAssuranceCgeSpec attribution, TrancheExecutable tranche)
  {
    if ((estUnProduitSpectacle(attribution.getProduitMontantRetenu())) && (attribution.getElementBaseIndemnisation() != null))
    {
      ElementBaseIndemnisation ebi = attribution.getElementBaseIndemnisation();
      tranche.setPrc(ebi.getPrc());
      tranche.setCoefficientHoraireJour(ebi.getCoefficientHoraireJour());
      tranche.setNombreHeuresTravailleesEtendu(ebi.getNombreHeureTravaillesEtendu());
      tranche.setNombreHeuresTravailleesPlafonne(ebi.getNombreHeuresTravailleesPlafonnees());
      tranche.setAffiliationRequisePourPRA(ebi.getAffiliationRequisePourPRA());
      tranche.setNombreJoursEmploiDansPRC(ebi.getNbJoursEmploiSurPrc());
      if (ebi.getSalaireReference() != null)
      {
        tranche.setMontantSJI(ebi.getSalaireReference().getMontant());
        tranche.setDateSJI(ebi.getSalaireReference().getDateDepart());
      }
    }
  }
  
  public static boolean estUnProduitSpectacle(ProduitSpec produit)
  {
    boolean estProduitSpectacle = false;
    if (produit != null)
    {
      LigneSpec ligneProduitRetenu = produit.getLigne();
      Iterator<LigneSpec> it = ligneSpectacle.iterator();
      while (it.hasNext())
      {
        LigneSpec ligneCourante = (LigneSpec)it.next();
        if (ligneCourante.getNomUnique().equals(ligneProduitRetenu.getNomUnique()))
        {
          estProduitSpectacle = true;
          break;
        }
      }
    }
    return estProduitSpectacle;
  }
  
  public static void alimenterTrancheExecutable(Attribution attribution)
    throws CoucheLogiqueException
  {
    if (attribution.getProduit() != null)
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      if (produit.estTrancheActivee(attribution.getDemande()))
      {
        Contexte contexte = new Contexte();
        DomLiquidationAssurance dom = new DomLiquidationAssurance();
        contexte.setDonnees(dom);
        dom.setDemande(attribution.getDemande());
        try
        {
          produit.constituerTranchesExecutables(contexte);
        }
        catch (ApplicativeException ex)
        {
          throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle());
        }
      }
    }
  }
  
  protected static void alimenterContextePap(DemandeSpec demande, TrancheExecutable tranche)
  {
    Demande demandeCourante = (Demande)demande;
    boolean estContextePAPPresent = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 10);
    
    tranche.setContextePAPPresent(estContextePAPPresent);
  }
}

/* Location:
 * Qualified Name:     OutilTranchesExecutables
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */