package fr.unedic.cali.asu.outilsfonctionnels.liquidationauto;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesSortieNPDE;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationSimplifieeFlux;
import fr.unedic.cali.autresdoms.d12i.dom.DonneesNPDE;
import fr.unedic.cali.autresdoms.ga.services.AppelServicesGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesSortieNPDESpec;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;

public class OutilLiquidationAutomatiqueDemandeNPDE
  extends OutilLiquidationAutomatiqueAbstrait
{
  public void demarerLiquidationAutomatique(DemandeSpec demande, Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeAssurance = (Demande)demande;
    OutilFonctionnelTraitementsErreurs outilTraitementErreurs = recupererOutilTraitementErreurs();
    
    demande.getDonneesSortieNPDE().setModeTraitementDemande("C");
    try
    {
      demande.getDonneesSortieNPDE().setDateTraitementDemande(getDateTraitement(contexte));
      traiterLiquidationNPDE(demandeAssurance, contexte);
    }
    catch (CoucheLogiqueException ex)
    {
      outilTraitementErreurs.traitementBlocagesFonctionnelsLiquidationAutoNPDE(demande, ex);
      
      outilTraitementErreurs.creerTraceCrem(demande, contexte);
    }
    catch (Exception ex)
    {
      outilTraitementErreurs.traitementBlocagesTechniquesLiquidationAuto(demande, ex);
      
      outilTraitementErreurs.creerTraceCrem(demande, contexte);
    }
  }
  
  protected void traiterLiquidationNPDE(Demande demande, Contexte contexte)
    throws ApplicativeException
  {
    DonneesNPDE donneesNPDE = demande.getDonneesNPDE();
    DomCreationDemandePrestation dom = (DomCreationDemandePrestation)contexte.getDonnees();
    
    demande.setEstInstallationNPDEsurTransaction(true);
    demande.setDecisionAuto(true);
    
    AppelServicesGaec.enregistrerAbonnementGaec(contexte);
    if (donneesNPDE.isEstDemandeComplete())
    {
      if (donneesNPDE.isEstLiquAuto()) {
        traiterLiquidationAutomatique(demande, contexte);
      }
    }
    else if (donneesNPDE.isEstLiquidable())
    {
      if (donneesNPDE.isLiquidationStandardAutoPossible())
      {
        demande.setLiquideeEnEtat(true);
        traiterLiquidationAutomatique(demande, contexte);
      }
      else
      {
        traiterLiquidationSimplifiee(demande, dom);
      }
    }
    else {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_TRAITEMENT_AUTO_NPDE");
    }
  }
  
  protected void traiterLiquidationAutomatique(Demande demande, Contexte contexte)
    throws ApplicativeException
  {
    DomCreationDemandePrestation dom = (DomCreationDemandePrestation)contexte.getDonnees();
    
    demande.getDonneesSortieNPDE().setModeTraitementDemande("A");
    
    liquiderDemande(demande, true);
    
    demande.setNotifieeCourrier(true);
    demande.setDateDerniereNotification(dom.getContexteService().getDateTraitement());
    validerDecision(demande, contexte);
    
    demande.supprimerDossiersAffectations();
  }
  
  protected void traiterLiquidationSimplifiee(Demande demande, DomCreationDemandePrestation dom)
    throws ApplicativeException
  {
    demande.getDonneesSortieNPDE().setModeTraitementDemande("S");
    
    Contexte contexte = new Contexte();
    DomLiquidationSimplifiee domLS = new DomLiquidationSimplifiee();
    domLS.setDemande(demande);
    domLS.setIndividu(demande.getDemandeur());
    domLS.setContexteService(dom.getContexteService());
    contexte.setDonnees(domLS);
    
    ParcoursLiquidationSimplifieeFlux parcoursLS = new ParcoursLiquidationSimplifieeFlux();
    parcoursLS.effectuerParcours(contexte);
  }
}

/* Location:
 * Qualified Name:     OutilLiquidationAutomatiqueDemandeNPDE
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */