package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreBulletinSalaire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreChequeEmploiService;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreFinActivite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePadRgSpeDpcAms;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteDeclaree;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinAvantDate;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriodeSpec;
import fr.unedic.util.temps.Periode;

public final class CalculAffiliation
{
  public static int calculerAffiliation(IndividuSpec individu, Periode pra)
  {
    Chronologie chronologiePeriodesParticipantes = determinerPeriodesParticipantes(individu, pra);
    
    int quantiteAffiSimplifieeAcquise = calculerAffiliation(chronologiePeriodesParticipantes, pra);
    
    quantiteAffiSimplifieeAcquise += calculerAffiliationDeclareHorsPec(individu, pra);
    
    return quantiteAffiSimplifieeAcquise;
  }
  
  public static Chronologie determinerPeriodesParticipantesAvecDeclare(IndividuSpec individu, Periode pra, Damj date)
  {
    FiltresTemporel filtrePeriodeParticipantes = new FiltresTemporel();
    
    FiltrePeriodesSurFiltresExclusifs filtreOU = getFiltrePeriodesJustifiees();
    
    FiltresTemporel filtreDeclare = new FiltresTemporel();
    filtreDeclare.ajouterFiltre(new FiltrePeriodeActiviteDeclaree());
    filtreDeclare.ajouterFiltre(new FiltrePadRgSpeDpcAms());
    
    filtreOU.ajouterFiltre(filtreDeclare);
    
    filtrePeriodeParticipantes.ajouterFiltre(new FiltreChevauchePeriode(pra));
    filtrePeriodeParticipantes.ajouterFiltre(new FiltreObjetChronoPeriodeFinAvantDate(date));
    filtrePeriodeParticipantes.ajouterFiltre(filtreOU);
    
    return individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePeriodeParticipantes);
  }
  
  private static Chronologie determinerPeriodesParticipantes(IndividuSpec individu, Periode pra)
  {
    FiltresTemporel filtrePeriodeParticipantes = new FiltresTemporel();
    
    FiltrePeriodesSurFiltresExclusifs filtreOU = getFiltrePeriodesJustifiees();
    
    filtrePeriodeParticipantes.ajouterFiltre(new FiltreChevauchePeriode(pra));
    filtrePeriodeParticipantes.ajouterFiltre(filtreOU);
    
    return individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePeriodeParticipantes);
  }
  
  private static FiltrePeriodesSurFiltresExclusifs getFiltrePeriodesJustifiees()
  {
    FiltresTemporel filtreContratTravailFermeCertifie = new FiltresTemporel();
    filtreContratTravailFermeCertifie.ajouterFiltre(new FiltreActiviteSalarie());
    filtreContratTravailFermeCertifie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtreContratTravailFermeCertifie.ajouterFiltre(new FiltreFinActivite());
    
    FiltresTemporel filtreBS = new FiltresTemporel();
    filtreBS.ajouterFiltre(new FiltreBulletinSalaire());
    
    FiltresTemporel filtreCES = new FiltresTemporel();
    filtreCES.ajouterFiltre(new FiltreChequeEmploiService());
    
    FiltrePeriodesSurFiltresExclusifs filtreOU = new FiltrePeriodesSurFiltresExclusifs();
    filtreOU.ajouterFiltre(filtreContratTravailFermeCertifie);
    filtreOU.ajouterFiltre(filtreBS);
    filtreOU.ajouterFiltre(filtreCES);
    
    return filtreOU;
  }
  
  private static int calculerAffiliationDeclareHorsPec(IndividuSpec individu, Periode pra)
  {
    FiltresTemporel filtreDeclareHorsPec = new FiltresTemporel();
    filtreDeclareHorsPec.ajouterFiltre(new FiltrePeriodeActiviteDeclaree());
    filtreDeclareHorsPec.ajouterFiltre(new FiltreChevauchePeriode(pra));
    Chronologie chronoPecs = individu.getChronologiePecFusionneesFinCI();
    int nombreJoursDeclare = 0;
    
    Chronologie chronoDeclareHorsPec = individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtreDeclareHorsPec);
    if (chronoDeclareHorsPec.getTaille() > 0)
    {
      ChronologiePeriodes chronoDeclareHorsPecFusionne = ((ChronologiePeriodes)chronoDeclareHorsPec).fusionnerChevauchementPeriodes();
      ChronologiePeriodes chronoPecEnChevauchement = null;
      
      chronoDeclareHorsPecFusionne.iterer();
      while (chronoDeclareHorsPecFusionne.encoreSuivant())
      {
        ObjetChronoPeriodeSpec declare = (ObjetChronoPeriodeSpec)chronoDeclareHorsPecFusionne.elementSuivant();
        Periode periodeDeclare = new Periode(declare.getDateDebut(), declare.getDateFin());
        chronoPecEnChevauchement = (ChronologiePeriodes)OutillagePEC.getPeriodesPecChevauchePeriode(chronoPecs, periodeDeclare);
        if (chronoPecEnChevauchement.getTaille() == 0) {
          nombreJoursDeclare += periodeDeclare.getDuree();
        } else {
          nombreJoursDeclare += proratiserDeclare(periodeDeclare, pra, chronoPecEnChevauchement);
        }
      }
    }
    return nombreJoursDeclare;
  }
  
  public static int calculerAffiliation(Chronologie chronologieActivitesParticipantes, Periode pra)
  {
    int nombreJours = 0;
    if ((chronologieActivitesParticipantes != null) && (chronologieActivitesParticipantes.getTaille() > 0))
    {
      ChronologiePeriodes chrono = ((ChronologiePeriodes)chronologieActivitesParticipantes).fusionnerChevauchementPeriodes();
      nombreJours = pra.inter(chrono);
    }
    return nombreJours;
  }
  
  private static int proratiserDeclare(Periode declare, Periode pra, Chronologie chronologiePec)
  {
    int nombreJoursChevauchePec = 0;
    Periode periodeDeclareBornePra = declare.periodeIntersection(pra);
    
    chronologiePec.iterer();
    while (chronologiePec.encoreSuivant())
    {
      ObjetChronoPeriodePriseEnCharge pec = (ObjetChronoPeriodePriseEnCharge)chronologiePec.elementSuivant();
      nombreJoursChevauchePec += periodeDeclareBornePra.inter(new Periode(pec.getDateDebut(), pec.getDateFin()));
    }
    return periodeDeclareBornePra.getDuree() - nombreJoursChevauchePec;
  }
}

/* Location:
 * Qualified Name:     CalculAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */