package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.autresdoms.cohab.outilsfonctionnels.CreationDemande;
import fr.unedic.cali.autresdoms.cohab.sigma.demande.dom.Demande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireAbstrait;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.fabriques.FabriqueIdentifiantDemandeCojac;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.cali.parcours.DomCreationFormulaires;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatCreationDemandePrestation;
import fr.unedic.cali.parcours.ResultatCreationFormulaires;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class InstallationDemande
{
  private static final int INDEX_DEBUT_CODE_PEC = 0;
  private static final int INDEX_FIN_CODE_PEC = 4;
  
  public static DemandeSpec installerDemande(DomLiquidationSimplifiee p_dom)
    throws ApplicativeException
  {
    Individu individu = (Individu)p_dom.getIndividu();
    ContexteService contexteService = p_dom.getContexteService();
    DemandeSpec demandeCreee = null;
    
    Collection listeNouveauxFormulairesNcp = CreationDemande.getInstance().creerFormulaires("ASU", contexteService, p_dom.getReferenceExterne(), individu);
    
    Collection listeNouvellesDemandesNcp = CreationDemande.getInstance().creerNouvellesDemandesNcp(individu, contexteService, listeNouveauxFormulairesNcp);
    
    Iterator iterDemandes = listeNouvellesDemandesNcp.iterator();
    DemandeSpec nouvelleDemande = null;
    while (iterDemandes.hasNext())
    {
      nouvelleDemande = (DemandeSpec)iterDemandes.next();
      if (nouvelleDemande.getFormulaire().getReferenceExterne().equalsIgnoreCase(p_dom.getReferenceExterne())) {
        demandeCreee = nouvelleDemande;
      }
    }
    if (demandeCreee == null)
    {
      Chronologie demandes = individu.getChronoDemandeAssurance();
      demandes.iterer();
      while (demandes.encoreSuivant())
      {
        DemandeAssuranceSpec demande = (DemandeAssuranceSpec)demandes.elementSuivant();
        if ((demande.getFormulaire().getReferenceExterne().equals(p_dom.getReferenceExterne())) && ("S".equalsIgnoreCase(demande.getModeLiquidation())))
        {
          demandeCreee = demande;
          break;
        }
      }
      if (demandeCreee == null) {
        leverBlocageInstallation(p_dom);
      }
    }
    if ((demandeCreee.estMigree()) || (demandeCreee.estDecisionnee())) {
      leverBlocageInstallation(p_dom);
    }
    demandeCreee.setEstFormulaireCharge(false);
    
    demandeCreee.setModeLiquidation("S");
    
    p_dom.setDemande(demandeCreee);
    
    return demandeCreee;
  }
  
  public static void leverBlocageInstallation(DomLiquidationSimplifiee p_dom)
    throws CoucheLogiqueException
  {
    String codePec = null;
    if (p_dom.getReferenceExterne() != null) {
      codePec = p_dom.getReferenceExterne().substring(0, 4);
    }
    Object[] params = { codePec };
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_IMPOSSIBLE_INSTALLER_DEMANDE", params);
  }
  
  public static DemandeSpec creerDemandeV2(Damj p_dateDeDepot, IndividuSpec p_individu, ContexteService p_contexteService, int p_idPec)
    throws ApplicativeException
  {
    Contexte contexte = new Contexte();
    
    GammeSpec gamme = GammeAsu.getInstance();
    String typeDemande = "ASU_01";
    
    Demande demandeCojac = new Demande();
    demandeCojac.setDateDepot(p_dateDeDepot);
    demandeCojac.setIdentifiantDemande(FabriqueIdentifiantDemandeCojac.getInstance().getIdentifiantDemandeCojac(p_individu, typeDemande));
    demandeCojac.setTypeExamen(ConstructionCSOIA.getCSOIADepuisTypeExamen(typeDemande));
    
    demandeCojac.setGamme("ASU");
    demandeCojac.setLigne(null);
    demandeCojac.setProduit(null);
    demandeCojac.setIdentifiantPec(p_idPec);
    
    DomCreationFormulaires domCreationFormulaire = new DomCreationFormulaires();
    domCreationFormulaire.setIndividu(p_individu);
    
    Collection collectionDemandesCojac = new ArrayList();
    collectionDemandesCojac.add(demandeCojac);
    
    domCreationFormulaire.setCollectionDemandesCojac(collectionDemandesCojac);
    
    contexte.setDonnees(domCreationFormulaire);
    
    Parcours parcoursFabricationFormulairesCali = gamme.getParcoursCreationFormulaire();
    ResultatCreationFormulaires resultatCreationFormulaire = (ResultatCreationFormulaires)parcoursFabricationFormulairesCali.demarrer(contexte);
    Collection listeNouveauxFormulairesNcp = resultatCreationFormulaire.getCollectionFormulairesCali();
    
    FormulaireAbstrait formulaire = (FormulaireAbstrait)listeNouveauxFormulairesNcp.iterator().next();
    
    FormulaireAsu formulaireASU = (FormulaireAsu)formulaire;
    formulaireASU.setDemandeLiquidable("O");
    formulaireASU.setDroitAuCongeReclassement(true);
    formulaireASU.setPareCrpCtpPropose("N");
    formulaireASU.setPresenceAe("O");
    formulaireASU.setRefusFNE("N");
    formulaireASU.setIdPec(p_idPec);
    
    DomCreationDemandePrestation domCreationDemande = new DomCreationDemandePrestation();
    domCreationDemande.setFormulaire(formulaire);
    domCreationDemande.setIndividu(p_individu);
    domCreationDemande.setContexteService(p_contexteService);
    contexte.setDonnees(domCreationDemande);
    
    ParcoursCali parcoursCreationDemande = formulaire.getGamme().getParcoursCreationDemande();
    ResultatCreationDemandePrestation resultatCreationDemandePrestation = (ResultatCreationDemandePrestation)parcoursCreationDemande.effectuerParcours(contexte);
    
    return resultatCreationDemandePrestation.getDemande();
  }
}

/* Location:
 * Qualified Name:     InstallationDemande
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */