package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux;

import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilLiquidationSimplifiee;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJoursCalendaires;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public final class OutilLiquidationSimplifiee
{
  private static final int DOUZE = 12;
  private static final int SEPT = 7;
  private static final int SIX = 6;
  
  public static DonneesSortieOutilLiquidationSimplifiee liquider(DonneesEntreeOutilLiquidationSimplifiee donnees)
    throws CoucheLogiqueException
  {
    DonneesSortieOutilLiquidationSimplifiee donneesSortie = new DonneesSortieOutilLiquidationSimplifiee();
    if (donnees.estPrimo()) {
      deciderPrimo(donnees, donneesSortie);
    } else if (donnees.getEtatReliquat() != 3) {
      deciderReinscritSansReliquat(donnees, donneesSortie);
    } else {
      deciderReinscritAvecReliquat(donnees, donneesSortie);
    }
    return donneesSortie;
  }
  
  private static void deciderReinscritAvecReliquat(DonneesEntreeOutilLiquidationSimplifiee donnees, DonneesSortieOutilLiquidationSimplifiee donneesSortie)
    throws CoucheLogiqueException
  {
    if (donnees.getDateInscription().coincideAvec(donnees.getDerniereCi())) {
      proposerReprise(donnees, donneesSortie);
    } else if (donnees.getAffiTotale() < donnees.getAffiRequise()) {
      proposerReprise(donnees, donneesSortie);
    } else {
      nePasProposerDecision();
    }
  }
  
  private static void deciderReinscritSansReliquat(DonneesEntreeOutilLiquidationSimplifiee donnees, DonneesSortieOutilLiquidationSimplifiee donneesSortie)
    throws CoucheLogiqueException
  {
    if (donnees.getDateInscription().coincideAvec(donnees.getDerniereCi())) {
      proposerRejetAbsenceFgd(donneesSortie);
    } else if (donnees.getAffiTotale() == 0) {
      proposerRejetAbsenceFgd(donneesSortie);
    } else if (donnees.getAffiTotale() < donnees.getAffiRequise()) {
      proposerRejetAffi(donneesSortie);
    } else {
      nePasProposerDecision();
    }
  }
  
  private static void deciderPrimo(DonneesEntreeOutilLiquidationSimplifiee donnees, DonneesSortieOutilLiquidationSimplifiee donneesSortie)
    throws CoucheLogiqueException
  {
    if (donnees.getAffiTotale() == 0) {
      proposerRejetAbsenceFgd(donneesSortie);
    } else if (donnees.getAffiTotale() < donnees.getAffiRequise()) {
      proposerRejetAffi(donneesSortie);
    } else {
      nePasProposerDecision();
    }
  }
  
  private static QuantiteJoursCalendaires calculerIccpConservatoire(DonneesEntreeOutilLiquidationSimplifiee donnees)
  {
    BigDecimal nbMois = BigDecimal.valueOf(12L);
    BigDecimal nbJours = BigDecimal.valueOf(7L);
    BigDecimal nbJoursOuvres = BigDecimal.valueOf(6L);
    BigDecimal nbJoursAffiliation = BigDecimal.valueOf(donnees.getAffiDeclare());
    BigDecimal iccp = Mathematiques.diviseASup(nbJoursAffiliation, nbMois, 0).multiply(Mathematiques.diviseASup(nbJours, nbJoursOuvres, 0));
    return new QuantiteJoursCalendaires(iccp);
  }
  
  private static void proposerRejetAffi(DonneesSortieOutilLiquidationSimplifiee donneesSortie)
  {
    donneesSortie.setNatureDecision(33);
    donneesSortie.setCodeMotifRejet(300);
  }
  
  private static void proposerRejetAbsenceFgd(DonneesSortieOutilLiquidationSimplifiee donneesSortie)
  {
    donneesSortie.setNatureDecision(33);
    donneesSortie.setCodeMotifRejet(41);
  }
  
  private static void proposerReprise(DonneesEntreeOutilLiquidationSimplifiee donnees, DonneesSortieOutilLiquidationSimplifiee donneesSortie)
  {
    donneesSortie.setNatureDecision(34);
    donneesSortie.setJoursIccpConservatoire(calculerIccpConservatoire(donnees));
  }
  
  private static void nePasProposerDecision()
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_ENVOI_DAL_AMB19BO");
  }
}

/* Location:
 * Qualified Name:     OutilLiquidationSimplifiee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */