package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.ControleAlertesBloquantesReglementsNonGeres;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.filtres.FiltreSuspensionChomageSansRupture;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCsa06;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilChronologie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieMayotte;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinApresDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinAvantDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateDebut;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;

public class AffectationDemandeASUClassique
  extends ParcoursAffectationDemandeAssurance
{
  public static final int JUSTIFICATION_AFFECTE_PRODUIT = 1;
  public static final int JUSTIFICATION_PAS_DE_DERNIER_SINISTRE = 2;
  public static final int JUSTIFICATION_DERNIER_SINISTRE_HORS_DELAI = 3;
  public static final int JUSTIFICATION_AFFECTATION_CLAUSE_DE_SAUVEGARDE = 4;
  public static final int JUSTIFICATION_AFFECTATION_PRODUIT_SECOURS = 5;
  public static final int JUSTIFICATION_AFFECTATION_PRODUIT_SECOURS_ORIGINE_PAS = 6;
  private static final Damj DATE_PIVOT_CONTROLE_MAYOTTE = new Damj(2013, 1, 1);
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeAssuranceExistante = getDemande(contexte);
    DossierAffectation dossierAffectation = preTraitementAffectationDemandeAsu(demandeAssuranceExistante);
    
    DureeCalendaire delaiAllongementExistant = recupererDelaiAllongement(demandeAssuranceExistante);
    
    Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demandeAssuranceExistante);
    
    boolean rejetAffectation = !rechercherDernierSinistre(demandeAssuranceExistante, chronoPeriodesParticipantesRechercherDernierSinistre);
    TravailSpec dernierSinistre = dossierAffectation.getSinistre();
    if (dernierSinistre != null) {
      rejetAffectation = recuperationDecorReglementaire(dossierAffectation, demandeAssuranceExistante, chronoPeriodesParticipantesRechercherDernierSinistre);
    } else {
      recuperationDecorReglementaire(dossierAffectation, demandeAssuranceExistante, chronoPeriodesParticipantesRechercherDernierSinistre);
    }
    if (rejetAffectation)
    {
      int justifRejetAffectation = dernierSinistre == null ? 2 : 6;
      
      dossierAffectation.setJustificationAffectation(justifRejetAffectation);
      dossierAffectation.setProduitSecours(determinerProduitParDefaut(demandeAssuranceExistante));
    }
    if (dernierSinistre != null)
    {
      if (dernierSinistre.estEnConflit()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB1");
      }
      controlerFgNonMayotte(dernierSinistre);
    }
    ProduitAsuSpec produitDernierSinistre = null;
    boolean dernierSinistreNeProposePasDecor = false;
    if (!rejetAffectation)
    {
      if (dossierAffectation.getDecorReglementaire() == null)
      {
        ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
        conteneur.setDateRecherche(demandeAssuranceExistante.getDateExamen());
        conteneur.setDateFinContrat(demandeAssuranceExistante.getDateExamen());
        conteneur.setBesoinCritereQualif(true);
        conteneur.setDernierSinistre(dernierSinistre);
        
        conteneur.setDemande(demandeAssuranceExistante);
        dossierAffectation.setDecorReglementaire(ConstitutionDecorReglementaire.recupererDecor(conteneur));
        
        dernierSinistreNeProposePasDecor = true;
      }
      produitDernierSinistre = determinerProduitRelatifAuSinistre(dernierSinistre, dossierAffectation);
    }
    boolean populationNonTraitee = false;
    if (!rejetAffectation)
    {
      populationNonTraitee = verifierPopulationsNonTraitees((ActiviteSalarie)dossierAffectation.getSinistre());
      if (populationNonTraitee) {
        produitDernierSinistre = determinerProduitParDefaut(demandeAssuranceExistante);
      }
    }
    determinerDelaiRecherche(dossierAffectation, delaiAllongementExistant, produitDernierSinistre);
    if (!rejetAffectation) {
      if (!dernierSinistre.getDateFin().estContenueDans(dossierAffectation.getDelaiRecherche()))
      {
        dossierAffectation.setJustificationAffectation(3);
        
        dossierAffectation.setProduitSecours(produitDernierSinistre);
        
        rejetAffectation = true;
      }
      else
      {
        if (dernierSinistreNeProposePasDecor) {
          lancerAlerteDernierSinistreProposeDecor(dossierAffectation);
        }
        ControleAlertesBloquantesReglementsNonGeres.controleFaitGenerateur((ActiviteSalarie)dernierSinistre);
        
        controlerPresencePeriodeMayotte(demandeAssuranceExistante, dernierSinistre);
      }
    }
    if (!rejetAffectation)
    {
      Chronologie chronoPeriodesParticipantesValidationProduit = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demandeAssuranceExistante);
      
      validerProduit(demandeAssuranceExistante, chronoPeriodesParticipantesValidationProduit, produitDernierSinistre);
    }
    OutilTrace.tracerFinParcours();
    return new Resultat(0);
  }
  
  protected void controlerPresencePeriodeMayotte(Demande demande, TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    boolean estSinitreRemplieCritereRecherche = dernierSinistre.getDateFin().estAvant(DATE_PIVOT_CONTROLE_MAYOTTE);
    if (estSinitreRemplieCritereRecherche)
    {
      Damj dateLimiteRecherche = Damj.NUIT_DES_TEMPS;
      Damj dateFaitGenerateurOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
      if (dateFaitGenerateurOdPrecedente != null) {
        dateLimiteRecherche = dateFaitGenerateurOdPrecedente.lendemain();
      }
      FiltreET filtreActiviteSalarieApresFgOdPrec = new FiltreET();
      filtreActiviteSalarieApresFgOdPrec.ajouterFiltre(new FiltreObjetChronoPeriodeFinApresDate(dateLimiteRecherche));
      filtreActiviteSalarieApresFgOdPrec.ajouterFiltre(new FiltreObjetChronoPeriodeFinAvantDate(dernierSinistre.getDateFin().lendemain()));
      filtreActiviteSalarieApresFgOdPrec.ajouterFiltre(new FiltreActiviteSalarieMayotte());
      
      FiltresTemporel filtreActivitesLiquidable = new FiltresTemporel();
      filtreActivitesLiquidable.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtreActivitesLiquidable.ajouterFiltre(filtreActiviteSalarieApresFgOdPrec);
      
      Chronologie chronologieActiviteMayotte = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtreActivitesLiquidable);
      if ((chronologieActiviteMayotte != null) && (!chronologieActiviteMayotte.estVide())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB14", new String[] { dernierSinistre.getDateFin().toString() });
      }
    }
  }
  
  protected void controlerFgNonMayotte(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    if (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).isEstPeriodeMayotte())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB8_MAYOTTE", new String[] { dernierSinistre.getDateFin().toString() });
    }
  }
  
  protected void lancerAlerteDernierSinistreProposeDecor(DossierAffectation dossierAffectation)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_NE_PROPOSE_PAS_DECOR_UN", new Object[] { dossierAffectation.getSinistre().getDateFin().toString() });
  }
  
  private DureeCalendaire recupererDelaiAllongement(DemandeAssuranceSpec demande)
  {
    DureeCalendaire delai = null;
    if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getAllongementDelaiForclusion() != null) && (demande.getDonneesTemporaires().getAllongementDelaiForclusion().getJours() != 0)) {
      delai = demande.getDonneesTemporaires().getAllongementDelaiForclusion();
    }
    return delai;
  }
  
  protected boolean rechercherDernierSinistre(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)demandeAssurance, 3);
    if ((contexteDemande != null) && (contexteDemande.estContexteDerniereAeCspAdhesionVolontaireForceeAspAdhesionVolontaire()))
    {
      ((DossierAffectation)demandeAssurance.getDossierAffectation()).setSinistre(contexteDemande.getDerniereAeCspVolontaire());
      return true;
    }
    TravailSpec dernierSinistre = fr.unedic.cali.asu.outilsfonctionnels.RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance, chronoPeriodesParticipantes);
    
    ((DossierAffectation)demandeAssurance.getDossierAffectation()).setSinistre(dernierSinistre);
    if (dernierSinistre == null) {
      return false;
    }
    return true;
  }
  
  protected boolean rechercherDernierSinistreCertifieQualifie(DemandeAssuranceSpec demandeAssurance)
  {
    TravailSpec dernierSinistre = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getSinistre();
    if ((((dernierSinistre instanceof CertifieSpec)) && (!((CertifieSpec)dernierSinistre).estQualifiable())) || (((dernierSinistre instanceof DeclareSpec)) && (!((DeclareSpec)dernierSinistre).estJustifie()))) {
      return false;
    }
    return true;
  }
  
  protected void recupererDecorReglementaire(DossierAffectation dossier)
    throws CoucheLogiqueException
  {
    DecorReglementaire decorReglementaire = null;
    
    decorReglementaire = ConstitutionDecorReglementaire.recupererDecor(dossier);
    dossier.setDecorReglementaire(decorReglementaire);
  }
  
  protected void determinerDelaiRecherche(DossierAffectation dossierAffectation, DureeCalendaire delaiAllongement, ProduitAsuSpec produit)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitCourant = produit;
    if (produitCourant == null) {
      produitCourant = (ProduitAsuSpec)dossierAffectation.getProduitSecours();
    }
    DelaiRechercheProduit delaiRechercheSinistres = (DelaiRechercheProduit)produitCourant.obtenirDelaiRechercheProduit(dossierAffectation, delaiAllongement);
    
    dossierAffectation.setDelaiRecherche(delaiRechercheSinistres);
  }
  
  protected boolean validerProduitSinistres(DemandeAssuranceSpec demandeAsuCourante, Chronologie chronoPeriodesParticipantes)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)dossierAffectationCourant.getSinistre();
    
    produitAffecte = validerProduitFct(demandeAsuCourante, dernierSinistre);
    if (!produitAffecte)
    {
      FiltresTemporel listeFiltres = new FiltresTemporel();
      listeFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(dernierSinistre.getDateFin()));
      listeFiltres.ajouterFiltre(new FiltreFinDansBornes(dossierAffectationCourant.getDelaiRecherche()));
      
      Chronologie chronoFctPrecedentes = chronoPeriodesParticipantes.copier(listeFiltres);
      
      OutilChronologie.supprimerPeriodeParIdentifiant(chronoFctPrecedentes, dernierSinistre);
      
      chronoFctPrecedentes.setComparateur(new ComparateurTemporelsSurDateFin());
      
      TravailSpec fctCourante = null;
      chronoFctPrecedentes.iterer();
      while ((!produitAffecte) && (chronoFctPrecedentes.encoreSuivant()))
      {
        fctCourante = (TravailSpec)chronoFctPrecedentes.elementSuivant();
        
        produitAffecte = validerProduitFct(demandeAsuCourante, fctCourante);
      }
    }
    return produitAffecte;
  }
  
  protected boolean gestionFctForcee(TravailSpec periodeFctForcee, DossierAffectation dossierAffectationCourant, DemandeAssuranceSpec demandeAsuCourante)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    if (periodeFctForcee != null)
    {
      if (periodeFctForcee.getDateFin().estAvant(dossierAffectationCourant.getDelaiRecherche().getDebut())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB2");
      }
      if (periodeFctForcee.getDateFin().estApres(dossierAffectationCourant.getDelaiRecherche().getFin())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB2_2");
      }
      produitAffecte = validerProduitFct(demandeAsuCourante, periodeFctForcee);
    }
    return produitAffecte;
  }
  
  protected void validerProduit(DemandeAssuranceSpec demandeAsuCourante, Chronologie chronoPeriodesParticipantes, ProduitAsuSpec produitDernierSinistre)
    throws ApplicativeException
  {
    boolean produitAffecte = validerProduitParFct(demandeAsuCourante, chronoPeriodesParticipantes);
    if (!produitAffecte) {
      affectationProduitSecours(demandeAsuCourante, produitDernierSinistre);
    }
  }
  
  protected boolean validerProduitParFct(DemandeAssuranceSpec demandeAsuCourante, Chronologie chronoPeriodesParticipantes)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    TravailSpec periodeFctForcee = demandeAsuCourante.getDonneesTemporaires().getPeriodeFctARetenir();
    if (periodeFctForcee != null)
    {
      produitAffecte = gestionFctForcee(periodeFctForcee, dossierAffectationCourant, demandeAsuCourante);
    }
    else
    {
      produitAffecte = validerProduitSinistres(demandeAsuCourante, chronoPeriodesParticipantes);
      if (!produitAffecte) {
        produitAffecte = validationClauseDeSauvegarde(demandeAsuCourante);
      }
    }
    return produitAffecte;
  }
  
  protected void affectationProduitSecours(DemandeAssuranceSpec demandeAsuCourante, ProduitAsuSpec produitDernierSinistre)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    TravailSpec periodeFctForcee = demandeAsuCourante.getDonneesTemporaires().getPeriodeFctARetenir();
    
    dossierAffectationCourant.setJustificationAffectation(5);
    if (periodeFctForcee != null)
    {
      ProduitAsuSpec produitFctForcee = determinerProduitRelatifAuSinistre(periodeFctForcee, dossierAffectationCourant);
      
      dossierAffectationCourant.setProduitSecours(produitFctForcee);
    }
    else
    {
      dossierAffectationCourant.setProduitSecours(produitDernierSinistre);
    }
  }
  
  protected boolean validationClauseDeSauvegarde(DemandeAssuranceSpec demandeAsuCourante)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    ProduitAsuSpec produitClauseSauvegardeEffectif = determinerProduitClauseSauvegardeEffectif(dossierAffectationCourant.getDecorReglementaire());
    if (produitClauseSauvegardeEffectif != null)
    {
      ValidationProduit validationProduit = (ValidationProduit)produitClauseSauvegardeEffectif.obtenirValidationProduit((ActiviteSalarie)dossierAffectationCourant.getSinistre(), demandeAsuCourante.getDemandeur(), demandeAsuCourante, false);
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        if (demandeAsuCourante.estEnContexteDroitAnterieurSecteurPublicValide()) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB12");
        }
        if (estDemandeExpresseEnCoursIndemnisation(demandeAsuCourante)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB13");
        }
        produitAffecte = true;
        validationProduit.setProduitValide(produitClauseSauvegardeEffectif);
        dossierAffectationCourant.setJustificationAffectation(4);
        
        dossierAffectationCourant.setValidationProduit(validationProduit);
      }
      else if (validationProduit != null)
      {
        dossierAffectationCourant.setValidationProduit(validationProduit);
      }
    }
    return produitAffecte;
  }
  
  protected boolean estDemandeExpresseEnCoursIndemnisation(DemandeAssuranceSpec demandeAsuCourante)
  {
    return false;
  }
  
  protected void verifierPeriodeCertifieEnConflit(TravailSpec periodeFct)
    throws CoucheLogiqueException
  {
    if (((periodeFct instanceof CertifieSpec)) && (periodeFct.estEnConflit())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB1");
    }
  }
  
  protected boolean validerProduitFct(DemandeAssuranceSpec demandeAsuCourante, TravailSpec periodeFct)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    ProduitAsuSpec produitRelatifFctCourante = determinerProduitRelatifAuSinistre(periodeFct, dossierAffectationCourant);
    
    verifierPeriodeCertifieEnConflit(periodeFct);
    
    Chronologie passeProfessionnel = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    Chronologie chronoChomageSansRupture = passeProfessionnel.copier(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    
    Damj dateFinRecherche = periodeFct.getDateFin();
    
    Damj dateDebutRecherche = ((Demande)demandeAsuCourante).getDateFaitGenerateurOdPrecedente();
    if (dateDebutRecherche == null) {
      dateDebutRecherche = Damj.NUIT_DES_TEMPS;
    } else {
      dateDebutRecherche = dateDebutRecherche.lendemain();
    }
    if (dateDebutRecherche.estAvantOuCoincideAvec(dateFinRecherche))
    {
      Periode periodeRecherche = new Periode(dateDebutRecherche, dateFinRecherche);
      Chronologie chronoChomageSansRuptureDansPeriodeRecherche = chronoChomageSansRupture.copier(new FiltreChevauchePeriode(periodeRecherche));
      leverAlerteA8MB6(chronoChomageSansRuptureDansPeriodeRecherche, demandeAsuCourante, periodeFct.getDateFin());
    }
    ProduitAsuSpec produitDernierSinistre = determinerProduitRelatifAuSinistre(dossierAffectationCourant.getSinistre(), dossierAffectationCourant);
    if (((periodeFct instanceof ActiviteSalarie)) && (!((ActiviteSalarie)periodeFct).estAtteste()) && (((ActiviteSalarie)periodeFct).estQualifiable()))
    {
      dossierAffectationCourant.setJustificationAffectation(6);
      
      dossierAffectationCourant.setProduitSecours(produitDernierSinistre);
      produitAffecte = true;
      
      dossierAffectationCourant.setDerniereFctEtudiee(periodeFct);
    }
    if (((periodeFct instanceof ActiviteSalarie)) && (verifierPopulationsNonTraitees((ActiviteSalarie)periodeFct)))
    {
      dossierAffectationCourant.setJustificationAffectation(6);
      dossierAffectationCourant.setProduitSecours(determinerProduitParDefaut(demandeAsuCourante));
      produitAffecte = true;
      
      dossierAffectationCourant.setDerniereFctEtudiee(periodeFct);
    }
    leverAlerteEtudeMandataire(demandeAsuCourante, periodeFct);
    
    boolean estCertifieNonSalarie = ((periodeFct instanceof CertifieSpec)) && (!(periodeFct instanceof ActiviteSalarie));
    boolean estSalarieNonAttesteNonQualifiable = ((periodeFct instanceof ActiviteSalarie)) && (!((ActiviteSalarie)periodeFct).estAtteste()) && (!((ActiviteSalarie)periodeFct).estQualifiable());
    if ((!produitAffecte) && ((estCertifieNonSalarie) || (estSalarieNonAttesteNonQualifiable)))
    {
      dossierAffectationCourant.setJustificationAffectation(6);
      
      dossierAffectationCourant.setProduitSecours(produitDernierSinistre);
      produitAffecte = true;
      
      dossierAffectationCourant.setDerniereFctEtudiee(periodeFct);
    }
    if ((!produitAffecte) && ((periodeFct instanceof DeclareSpec)) && (!((DeclareSpec)periodeFct).estJustifie()))
    {
      dossierAffectationCourant.setJustificationAffectation(6);
      
      dossierAffectationCourant.setProduitSecours(produitDernierSinistre);
      produitAffecte = true;
      
      dossierAffectationCourant.setDerniereFctEtudiee(periodeFct);
    }
    if ((periodeFct instanceof ActiviteSalarie)) {
      ControleAlertesBloquantesReglementsNonGeres.controleFctEtudiee((ActiviteSalarie)periodeFct);
    }
    if (!produitAffecte)
    {
      ValidationProduit validationProduit = (ValidationProduit)produitRelatifFctCourante.obtenirValidationProduit((ActiviteSalarie)periodeFct, demandeAsuCourante.getDemandeur(), demandeAsuCourante, false);
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        dossierAffectationCourant.setJustificationAffectation(1);
        validationProduit.setProduitValide(produitRelatifFctCourante);
        produitAffecte = true;
        
        dossierAffectationCourant.setValidationProduit(validationProduit);
      }
      else
      {
        if (validationProduit != null) {
          dossierAffectationCourant.setValidationProduit(validationProduit);
        }
        validationProduit = (ValidationProduit)produitRelatifFctCourante.obtenirValidationProduit((ActiviteSalarie)periodeFct, demandeAsuCourante.getDemandeur(), demandeAsuCourante, true);
        if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
        {
          FiltresTemporel listeFiltresDernierePNA = new FiltresTemporel();
          listeFiltresDernierePNA.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(periodeFct.getDateFin()));
          listeFiltresDernierePNA.ajouterFiltre(new FiltrePeriodesAttestees(false));
          Chronologie listePNA = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltresDernierePNA);
          
          Temporel periodeNonAttesteeRetenue = listePNA.dernierElement();
          
          Damj dateFCTDamj = periodeNonAttesteeRetenue.getDateFin();
          String dateFCTString = "ouverte";
          if (!dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
            dateFCTString = "du " + dateFCTDamj.formater();
          }
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB5", new String[] { dateFCTString });
        }
        else if (validationProduit != null)
        {
          dossierAffectationCourant.setValidationProduit(validationProduit);
        }
        boolean presencePeriodesDeclareesNonjustifiees = verifierOriginePeriodesPraLaPlusLongue(demandeAsuCourante, (ActiviteSalarie)periodeFct);
        if (!presencePeriodesDeclareesNonjustifiees) {
          if ((((DomLiquidationAssurance)getDom()).isContexteOuvertureDroitAuPlusTot()) && (!((DomLiquidationAssurance)getDom()).isEtudeDerniereFct())) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_INTERR_FONCT_PARCOURS_AFFECT_ASU");
          }
        }
        produitAffecte = false;
      }
      verifierReglesNonConnuesPeriodesPraLaPlusLongue(demandeAsuCourante, (ActiviteSalarie)periodeFct);
    }
    return produitAffecte;
  }
  
  protected boolean verifierOriginePeriodesPraLaPlusLongue(DemandeAssuranceSpec demandeAsuCourante, ActiviteSalarie periodeFctCourante)
    throws CoucheLogiqueException
  {
    boolean presencePeriodesDeclareesNonjustifiees = false;
    
    Periode praLaPlusLongue = determinerPraLaPlusLongue(demandeAsuCourante, periodeFctCourante);
    
    Chronologie chronoPeriodesPraLaPlusLongue = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreChevauchePeriode(praLaPlusLongue));
    
    FiltresTemporel filtreCertifieeConflit = new FiltresTemporel();
    filtreCertifieeConflit.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtreCertifieeConflit.ajouterFiltre(new FiltrePeriodesAvecConflit());
    if (!chronoPeriodesPraLaPlusLongue.copier(filtreCertifieeConflit).estVide()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB1");
    }
    if (!chronoPeriodesPraLaPlusLongue.copier(new FiltrePeriodesJustifiees(false)).estVide()) {
      presencePeriodesDeclareesNonjustifiees = true;
    }
    return presencePeriodesDeclareesNonjustifiees;
  }
  
  private Periode determinerPraLaPlusLongue(DemandeAssuranceSpec demandeAsuCourante, ActiviteSalarie periodeFctCourante)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    ProduitAsuSpec produitRelatifFctCourante = determinerProduitRelatifAuSinistre(periodeFctCourante, dossierAffectationCourant);
    
    return produitRelatifFctCourante.determinerPraLaPlusLongue(demandeAsuCourante, periodeFctCourante);
  }
  
  protected void verifierReglesNonConnuesPeriodesPraLaPlusLongue(DemandeAssuranceSpec demandeAsuCourante, ActiviteSalarie periodeFctCourante)
    throws CoucheLogiqueException
  {
    Periode praLaPlusLongue = determinerPraLaPlusLongue(demandeAsuCourante, periodeFctCourante);
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(praLaPlusLongue));
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
    Chronologie chronoPeriodesPraLaPlusLongue = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    ControleAlertesBloquantesReglementsNonGeres.controlePeriodesDansPra(chronoPeriodesPraLaPlusLongue);
  }
  
  private ProduitAsuSpec determinerProduitClauseSauvegardeEffectif(DecorReglementaire decorReglementaireCourant)
  {
    ProduitAsuSpec produitClauseSauvegardeEffectif = (ProduitAsuSpec)decorReglementaireCourant.determinerProduitEffectifDeLaLigne(LigneAsuCsa06.getInstance());
    
    return produitClauseSauvegardeEffectif;
  }
  
  protected boolean verifierPopulationsNonTraitees(ActiviteSalarie pas)
  {
    boolean populationNonTraitee = (ControleAlertesBloquantesReglementsNonGeres.verifiePopulationsNonTraitees(pas)) || (ControleAlertesBloquantesReglementsNonGeres.verifiePopulationsNonTraiteesCasParticuliers(pas));
    
    return populationNonTraitee;
  }
  
  private void leverAlerteA8MB6(Chronologie chronoChomageSansRuptureDansPeriodeRecherche, DemandeSpec demandeAsuCourante, Damj fct)
    throws CoucheLogiqueException
  {
    boolean leverAlerteA8MB6 = false;
    if (!chronoChomageSansRuptureDansPeriodeRecherche.estVide())
    {
      chronoChomageSansRuptureDansPeriodeRecherche.setComparateur(new ComparateurTemporelsSurDateDebut());
      Chronologie listeDemandesPrecedentes = null;
      chronoChomageSansRuptureDansPeriodeRecherche.iterer();
      while ((chronoChomageSansRuptureDansPeriodeRecherche.encoreSuivant()) && (!leverAlerteA8MB6))
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)chronoChomageSansRuptureDansPeriodeRecherche.elementSuivant();
        
        FiltresTemporel filtre = new FiltresTemporel();
        filtre.ajouterFiltre(new FiltreObjetChronoPeriodeFinAvantDate(fct, ""));
        filtre.ajouterFiltre(new FiltreSuspensionChomageSansRupture());
        
        Chronologie listeIncident = activiteSalarie.getListePeriodesIncident().copier(filtre);
        
        listeIncident.iterer();
        while (listeIncident.encoreSuivant())
        {
          leverAlerteA8MB6 = true;
          IncidentSpec periodeSuspension = (IncidentSpec)listeIncident.elementSuivant();
          
          listeDemandesPrecedentes = OutilRecherche.rechercherDemandesPrecedentes(demandeAsuCourante.getDemandeur().getChronoDemandeAssurance(), periodeSuspension.getDateFin(), null);
          
          listeDemandesPrecedentes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
          if (!listeDemandesPrecedentes.estVide())
          {
            listeDemandesPrecedentes.iterer();
            boolean decisionTrouve = false;
            while ((listeDemandesPrecedentes.encoreSuivant()) && (!decisionTrouve))
            {
              DemandeSpec demande = (DemandeSpec)listeDemandesPrecedentes.elementSuivant();
              if (demande.estDecisionnee())
              {
                decisionTrouve = true;
                if (demande.getDateExamen().estApresOuCoincideAvec(periodeSuspension.getDateDebut())) {
                  leverAlerteA8MB6 = false;
                }
              }
            }
          }
        }
      }
    }
    if (leverAlerteA8MB6) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB6");
    }
  }
  
  protected void leverAlerteEtudeMandataire(DemandeAssuranceSpec demandeAsuCourante, TravailSpec periodeFctCourante)
    throws CoucheLogiqueException
  {
    if ((periodeFctCourante instanceof ActiviteSalarie))
    {
      Periode pra = determinerPraLaPlusLongue(demandeAsuCourante, (ActiviteSalarie)periodeFctCourante);
      if (pra != null)
      {
        Chronologie listePas = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
        
        FiltresTemporel filtres = new FiltresTemporel();
        filtres.ajouterFiltre(new FiltreChevauchePeriode(pra));
        filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
        filtres.ajouterFiltre(new FiltreActiviteSalarie());
        Chronologie chronoPeriodes = listePas.copier(filtres);
        if (!chronoPeriodes.estVide())
        {
          chronoPeriodes.iterer();
          while (chronoPeriodes.encoreSuivant())
          {
            ActiviteSalarie pas = (ActiviteSalarie)chronoPeriodes.elementSuivant();
            boolean estStatutParticulierRenseigne = (pas.getContrat().getStatutParticulier() != 9) && (pas.getContrat().getStatutParticulier() != 0);
            
            boolean estEtudeMandataireEnCoursOuAEtudier = ("1".equals(pas.getContrat().getEtudeMandataire())) || ("2".equals(pas.getContrat().getEtudeMandataire()));
            if ((estStatutParticulierRenseigne) && (estEtudeMandataireEnCoursOuAEtudier)) {
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB16", new String[] { pas.getDateFin().toString() });
            }
          }
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeASUClassique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */