package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuCve13P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;

public class AffectationDemandeAtp
  extends AffectationDemandeASUClassique
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    affecterDemandeAtp(p_contexte);
    OutilTrace.tracerFinParcours();
    return new Resultat(0);
  }
  
  private void affecterDemandeAtp(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demandeAssuranceExistante = getDemande(p_contexte);
    
    DossierAffectation dossierAffectation = preTraitementAffectationDemandeAsu(demandeAssuranceExistante);
    
    boolean estDernierSinistre = false;
    if (demandeAssuranceExistante.estUneDemandeAtpBasculeCrp())
    {
      estDernierSinistre = true;
      AttributionAssuranceSpec attributionAsrPrecedente = (AttributionAssuranceSpec)OutilAsr.rechercherAttributionAsrPrecedent(demandeAssuranceExistante);
      if (attributionAsrPrecedente == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ATP_ATP_BASCULE_SANS_CRP");
      }
      TravailSpec dernierSinistre = ((DossierAffectation)attributionAsrPrecedente.getDemande().getDossierAffectation()).getSinistre();
      dossierAffectation.setSinistre(dernierSinistre);
    }
    else
    {
      Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demandeAssuranceExistante);
      
      Chronologie chronoPeriodesParticipantesRechercherDernierSinistreAS = chronoPeriodesParticipantesRechercherDernierSinistre.copier(new FiltreActiviteSalarie());
      
      estDernierSinistre = rechercherDernierSinistre(demandeAssuranceExistante, chronoPeriodesParticipantesRechercherDernierSinistreAS);
    }
    TravailSpec dernierSinistre = dossierAffectation.getSinistre();
    
    ProduitAsuSpec produit = ProduitAsuCve13P01.getInstance();
    
    ValidationProduit validationProduit = new ValidationProduit();
    validationProduit.setProduitValide(produit);
    dossierAffectation.setValidationProduit(validationProduit);
    if (estDernierSinistre)
    {
      if (dossierAffectation.getDecorReglementaire() == null)
      {
        ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
        conteneur.setDateRecherche(dernierSinistre.getDateFin());
        conteneur.setDateFinContrat(dernierSinistre.getDateFin());
        conteneur.setBesoinCritereQualif(true);
        conteneur.setDemande(demandeAssuranceExistante);
        conteneur.setDernierSinistre(dernierSinistre);
        DecorReglementaire decorRecupere = ConstitutionDecorReglementaire.recupererDecor(conteneur);
        if (decorRecupere == null) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_NE_PROPOSE_PAS_DECOR");
        }
        dossierAffectation.setDecorReglementaire(decorRecupere);
      }
      validationProduit.setPeriodeValidationProduit((ActiviteSalarie)dernierSinistre);
      validationProduit.setReglementApplicable(((ActiviteSalarie)dernierSinistre).getReglement());
    }
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeAtp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */