package fr.unedic.cali.asu.parcours;

import fr.pe.cali.crem.dom.ObjetMetierCrem;
import fr.pe.cali.crem.outils.OutilGenerationObjetMetierDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.ForcageAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionCommentaireDemande;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.EnregistrerDemande;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.List;

public class EnregistrerDemandeAssurance
  extends EnregistrerDemande
{
  public DemandeSpec mettreAJourOuCreerDemandeGamme(IndividuSpec individu, String idDemandeAMettreAJour, DemandeSpec demandeTemporaire, Damj dateTraitement)
    throws ApplicativeException
  {
    DemandeSpec demandeExistante = rechercherDemande(individu, idDemandeAMettreAJour, demandeTemporaire);
    
    boolean demandeDeneutralisee = mettreAJourDonneesDemandeMigree(demandeExistante, demandeTemporaire);
    
    boolean bDemandeEstSansObjet = false;
    if ((((Demande)demandeTemporaire).getClassementAdministratif() != null) && (((Demande)demandeTemporaire).getClassementAdministratif().getTypeClassement() == "SO")) {
      bDemandeEstSansObjet = true;
    }
    if (!demandeDeneutralisee)
    {
      mettreAJourDonneesDemande(demandeExistante, demandeTemporaire);
      if (!bDemandeEstSansObjet)
      {
        VerificationDonneesForcees.getInstance().verifierDonneesForcees((Demande)demandeExistante, dateTraitement);
        VerificationDonneesForcees.getInstance().verifierDonneesForceesSurEnregistrementDemande((Demande)demandeExistante);
      }
    }
    if (!bDemandeEstSansObjet)
    {
      DecorReglementaire decorCourant = AccesDecorReglementaire.getInstance().getDecorParId(((DemandeAssuranceSpec)demandeExistante).getIdDecorDepuisPN());
      if ((decorCourant != null) && (!ForcageAffiliation.controlerCoherenceAffiliationForcee(demandeExistante, decorCourant.getIdDecor()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_UNITE_AFFILATION_FORCEE", 1);
      }
    }
    gestionCommentaireDemande(demandeExistante);
    generationCREM(demandeExistante);
    
    return demandeExistante;
  }
  
  private void generationCREM(DemandeSpec demande)
    throws ApplicativeException
  {
    if ((demande.getClassementAdministratif() != null) && ("SP".equals(demande.getClassementAdministratif().getTypeClassement())))
    {
      OutilGenerationObjetMetierDalLiquidation outil = OutilGenerationObjetMetierDalLiquidation.getInstance();
      ObjetMetierCrem objetMetier = outil.genererObjetMetier(demande, demande.getDemandeur().getContexteService());
      if (objetMetier != null) {
        demande.getDemandeur().getListeCrem().add(objetMetier);
      }
    }
  }
  
  protected DemandeSpec rechercherDemande(IndividuSpec individu, String idDemandeAMettreAJour, DemandeSpec demandeTemporaire)
    throws CoucheLogiqueException
  {
    DemandeSpec demandeExistante = null;
    if ((idDemandeAMettreAJour != null) && (!idDemandeAMettreAJour.equals(""))) {
      demandeExistante = individu.rechercherDemande(idDemandeAMettreAJour);
    }
    if (demandeExistante == null)
    {
      demandeExistante = new Demande();
      individu.ajouterDemande(demandeExistante);
    }
    return demandeExistante;
  }
  
  protected void mettreAJourDonneesDemande(DemandeSpec pDemandeAMettreAJour, DemandeSpec pDemandeTemporaire)
  {
    Demande demandeAMettreAJour = (Demande)pDemandeAMettreAJour;
    Demande demandeTemporaire = (Demande)pDemandeTemporaire;
    
    demandeAMettreAJour.setSaisieAntecedent(demandeTemporaire.getSaisieAntecedent());
    
    demandeAMettreAJour.setDonneesTemporaires(demandeTemporaire.getDonneesTemporaires());
    
    demandeAMettreAJour.setDonneesDAL(demandeTemporaire.getDonneesDAL());
    
    demandeAMettreAJour.setClassementAdministratif(demandeTemporaire.getClassementAdministratif());
    
    demandeAMettreAJour.setNotifieeCourrier(demandeTemporaire.estNotifieeCourrier());
    
    demandeAMettreAJour.setIdDecorDepuisPN(demandeTemporaire.getIdDecorDepuisPN());
    
    demandeAMettreAJour.setCommentaire(demandeTemporaire.getCommentaire());
    if ((demandeTemporaire.getDonneesDemandeAssociee() != null) && (demandeAMettreAJour.getDonneesDemandeAssociee().getDemandeAssociee() != null))
    {
      Demande demandeFinancement = demandeAMettreAJour.getDonneesDemandeAssociee().getDemandeAssociee();
      if (demandeTemporaire.getDonneesDemandeAssociee().getDemandeAssociee() != null) {
        demandeFinancement.setDonneesTemporaires(demandeTemporaire.getDonneesDemandeAssociee().getDemandeAssociee().getDonneesTemporaires());
      }
    }
  }
  
  protected void mettreAJourDonneesIndividu(IndividuSpec pIndividu, DemandeSpec pDemandeTemporaire, DomLiquidationDemande donnees)
  {
    Individu individu = (Individu)pIndividu;
    Demande demandeTemporaire = (Demande)pDemandeTemporaire;
    
    SaisieAntecedent saisieAntecedent = demandeTemporaire.getSaisieAntecedent();
    if (saisieAntecedent != null) {
      if ((saisieAntecedent.getCodeProduit().intValue() == 3) || (saisieAntecedent.getCodeProduit().intValue() == 4))
      {
        individu.setDernierJourIndemnisableAreSpe(donnees.getDernierJourIndemnisableDroitAreSpe());
        individu.setOrigineSaisieDernierJourIndemnisableAreSpe("2");
      }
      else
      {
        individu.setDernierJourIndemnisableAreSpe(null);
        individu.setOrigineSaisieDernierJourIndemnisableAreSpe(null);
      }
    }
    Demande demandeAvantMiseAJour = (Demande)donnees.getDemandeAvantReexamen();
    if ((demandeAvantMiseAJour != null) && (demandeAvantMiseAJour.getSaisieAntecedent() != null))
    {
      SaisieAntecedent saisieAntecedentAvant = demandeAvantMiseAJour.getSaisieAntecedent();
      if (((saisieAntecedentAvant.getCodeProduit().intValue() == 3) || (saisieAntecedentAvant.getCodeProduit().intValue() == 4)) && (pDemandeTemporaire.getClassementAdministratif() != null))
      {
        individu.setDernierJourIndemnisableAreSpe(null);
        individu.setOrigineSaisieDernierJourIndemnisableAreSpe(null);
      }
    }
  }
  
  protected void gestionCommentaireDemande(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilGestionCommentaireDemande.gererCommentaireDemande(demande);
  }
}

/* Location:
 * Qualified Name:     EnregistrerDemandeAssurance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */