package fr.unedic.cali.asu.parcours;

import fr.pe.cali.liquidation.outilsfonctionnels.dom.ResultatImputationSuiteArce;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.spec.IProduitAsuSansDuree;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.outilsfonctionnels.OutilAtp;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.cali.parcours.ResultatExecutionCalcul;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class ParcoursContexteExamen
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    IndividuSpec individu = getIndividu(contexte);
    DomLiquidationDemande dom = (DomLiquidationDemande)contexte.getDonnees();
    if (dom.getDemandeSpec() == null)
    {
      DemandeAssuranceSpec demandeAssuranceCourante = (DemandeAssuranceSpec)individu.rechercherDemande(recupererIdDemande(contexte));
      dom.setDemande(demandeAssuranceCourante);
      if (demandeAssuranceCourante == null) {
        throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit.", null);
      }
    }
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    DemandeAssuranceSpec demandeAssuranceCourante = (DemandeAssuranceSpec)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    ResultatContexteExamen resultatContexte = creationResultatParcours();
    if (demandeAssuranceCourante.estEnContexteDroitAnterieurSecteurPublic())
    {
      initialisationContexteAntecedentSP(demandeAssuranceCourante, resultatContexte);
    }
    else
    {
      ((Demande)demandeAssuranceCourante).createReliquat();
      
      AttributionAssuranceSpec attributionAssurancePrecedente = rechercherAttributionPrecedente(demandeAssuranceCourante);
      if ((attributionAssurancePrecedente == null) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeAssuranceCourante, "SORTIECRA"))) {
        resultatContexte.setContexteExamen(1);
      } else {
        traitementCasGeneral(demandeAssuranceCourante, resultatContexte, attributionAssurancePrecedente);
      }
      traitementCasParticulier(attributionAssurancePrecedente, demandeAssuranceCourante, resultatContexte);
    }
    rechercheDernierSinistre(demandeAssuranceCourante, resultatContexte);
    
    OutilTrace.tracerFinParcours();
    return resultatContexte;
  }
  
  protected AttributionAssuranceSpec rechercherAttributionPrecedente(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    return demande.rechercherAttributionPrecedenteDuMemeType();
  }
  
  private void traitementCasGeneral(DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte, AttributionAssuranceSpec attributionAssurancePrecedente)
    throws ApplicativeException
  {
    ResultatExecutionCalculSpec resultatCalcul = appelCalcul(demandeAssuranceCourante, attributionAssurancePrecedente);
    
    miseAjourReliquat((Demande)demandeAssuranceCourante, resultatCalcul);
    
    determinerContexteExamen(resultatCalcul, resultatContexte);
    
    attributionAssurancePrecedente.setUnJourDiffereConsomme(resultatCalcul.isDiffereEntame());
    
    resultatContexte.copieEtat((ResultatExecutionCalcul)resultatCalcul);
    
    resultatContexte.setResultatExecutionCalculDroitPrecedent(resultatCalcul);
    
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursPmvsReconduit(demandeAssuranceCourante, attributionAssurancePrecedente, demandeAssuranceCourante.getDateExamen());
  }
  
  private void traitementCasParticulier(AttributionAssuranceSpec attributionAssurancePrecedente, DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws ApplicativeException
  {
    if (OutilDemande.estUneDemandeAtp(demandeAssuranceCourante)) {
      traitementdemandeAtp(attributionAssurancePrecedente, demandeAssuranceCourante, resultatContexte);
    }
    if (OutilDemande.estUneDemandeAsp(demandeAssuranceCourante)) {
      traitementdemandeAsp(attributionAssurancePrecedente, demandeAssuranceCourante, resultatContexte);
    }
    if ((attributionAssurancePrecedente != null) && (((ProduitAsuSpec)attributionAssurancePrecedente.getProduit()).estUnProduitSansDuree())) {
      traiterAttributionSansDuree(attributionAssurancePrecedente, demandeAssuranceCourante, resultatContexte);
    }
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeAssuranceCourante, "SORTIECRA")) {
      traiterDemandeSortieClauseRattrapage((Demande)demandeAssuranceCourante, resultatContexte);
    }
  }
  
  private void traiterAttributionSansDuree(AttributionAssuranceSpec attributionAssurancePrecedente, DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws ApplicativeException
  {
    Reliquat reliquat = ((Demande)demandeAssuranceCourante).getReliquat();
    if (reliquat.estReliquatValide())
    {
      Damj dateLimiteIndemnisationAttribPrecedente = null;
      ConstitutionDateLimiteIndemnisation cep = ((Attribution)attributionAssurancePrecedente).getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation();
      if (cep != null)
      {
        dateLimiteIndemnisationAttribPrecedente = cep.getDateLimiteIndemnisation();
        ResultatImputationSuiteArce resultat = ((IProduitAsuSansDuree)attributionAssurancePrecedente.getProduit()).traiterImputationSuiteArce(attributionAssurancePrecedente, demandeAssuranceCourante.getDateExamen().veille());
        
        resultatContexte.setResultatImputationArce(resultat);
        if (resultat.isDateLimiteImputee()) {
          dateLimiteIndemnisationAttribPrecedente = resultat.getNouvelleDateLimiteIndemnisation();
        }
      }
      determinerContexteExamenAttributionSansDuree(dateLimiteIndemnisationAttribPrecedente, demandeAssuranceCourante.getDateExamen(), resultatContexte, reliquat);
    }
  }
  
  private void traiterDemandeSortieClauseRattrapage(Demande demande, ResultatContexteExamen resultatContexte)
  {
    Reliquat reliquat = demande.getReliquat();
    reliquat.setReliquatValide(false);
    resultatContexte.setContexteExamen(2);
    resultatContexte.setCauseNonValidite(1);
  }
  
  protected void determinerContexteExamenAttributionSansDuree(Damj dateLimiteIndemnisationAttribPrecedente, Damj dateExamenCourante, ResultatContexteExamen resultatContexte, Reliquat reliquat)
    throws CoucheLogiqueException
  {
    if ((dateExamenCourante != null) && (dateLimiteIndemnisationAttribPrecedente != null) && (dateExamenCourante.estAvantOuCoincideAvec(dateLimiteIndemnisationAttribPrecedente)))
    {
      reliquat.setReliquatValide(true);
      resultatContexte.setContexteExamen(3);
    }
    else
    {
      reliquat.setReliquatValide(false);
      resultatContexte.setContexteExamen(2);
      resultatContexte.setCauseNonValidite(2);
    }
  }
  
  private void traitementdemandeAtp(AttributionAssuranceSpec attributionAssurancePrecedente, DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws CoucheLogiqueException
  {
    Reliquat reliquat = ((Demande)demandeAssuranceCourante).getReliquat();
    if (OutilAtp.estFinDroitAtpNonInstalle(demandeAssuranceCourante, attributionAssurancePrecedente))
    {
      if ((attributionAssurancePrecedente != null) && (((DemandeAssuranceSpec)attributionAssurancePrecedente.getDemande()).estUneDemandeAtp()))
      {
        if (attributionAssurancePrecedente.getDateLimiteIndemnisation().estAvantOuCoincideAvec(demandeAssuranceCourante.getDateRecherche()))
        {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_A5MB5_MANQUE_FIN_ATP ");
        }
        else
        {
          resultatContexte.setContexteExamen(3);
          reliquat.setReliquatValide(true);
        }
      }
      else
      {
        reliquat.setReliquatValide(true);
        resultatContexte.setContexteExamen(1);
      }
    }
    else
    {
      reliquat.setReliquatValide(false);
      resultatContexte.setContexteExamen(1);
    }
  }
  
  private void traitementdemandeAsp(AttributionAssuranceSpec attributionAssurancePrecedente, DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws CoucheLogiqueException
  {
    Reliquat reliquat = ((Demande)demandeAssuranceCourante).getReliquat();
    if ((attributionAssurancePrecedente != null) && (!ProduitAbstrait.estDuType(5, attributionAssurancePrecedente.getProduit()))) {
      if (OutilAsp.estFinDroitAspNonInstalle(demandeAssuranceCourante, attributionAssurancePrecedente))
      {
        if (((((DemandeAssuranceSpec)attributionAssurancePrecedente.getDemande()).estUneDemandeAsp()) && (attributionAssurancePrecedente.getDateLimiteIndemnisation().estAvantOuCoincideAvec(demandeAssuranceCourante.getDateRecherche()))) || (!reliquat.estReliquatValide())) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_A5MB5_MANQUE_FIN_ASP");
        }
      }
      else
      {
        reliquat.setReliquatValide(false);
        resultatContexte.setContexteExamen(1);
      }
    }
  }
  
  private ResultatExecutionCalculSpec appelCalcul(DemandeAssuranceSpec demandeAssuranceCourante, AttributionAssuranceSpec attributionAssurancePrecedente)
    throws ApplicativeException
  {
    attributionAssurancePrecedente.setDemandeSuivantePourTraitementReliquat(demandeAssuranceCourante);
    
    Damj dateRecherche = demandeAssuranceCourante.getDateRecherche().veille();
    if ((OutilsActiviteConserve.estUneDemandeDeRevision(demandeAssuranceCourante)) && (demandeAssuranceCourante.getDonneesTemporaires().getDateEffetActConserveeDonneesTemporaire() != null)) {
      dateRecherche = demandeAssuranceCourante.getDonneesTemporaires().getDateEffetActConserveeDonneesTemporaire().veille();
    }
    return AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAssurancePrecedente, dateRecherche, true, true);
  }
  
  private void rechercheDernierSinistre(DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws CoucheLogiqueException
  {
    ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)demandeAssuranceCourante, 3);
    if (contexteDemande != null)
    {
      resultatContexte.setDernierSinistre(contexteDemande.getDerniereAeCspVolontaire());
    }
    else if ("ASU_22".equals(demandeAssuranceCourante.getEvenementReferenceExamen().getTypeExamen()))
    {
      TravailSpec dernierSinistre = null;
      if (((Demande)demandeAssuranceCourante).getSaisieAntecedent() != null)
      {
        String idfaitGenerateur = ((Demande)demandeAssuranceCourante).getSaisieAntecedent().getIdentifiantFaitGenerateur();
        if (idfaitGenerateur != null) {
          dernierSinistre = (TravailSpec)demandeAssuranceCourante.getDemandeur().rechercherPeriodePasseProfessionnel(idfaitGenerateur);
        }
      }
      if (dernierSinistre == null) {
        dernierSinistre = rechercheDernierSinistreClassique(demandeAssuranceCourante);
      }
      resultatContexte.setDernierSinistre(dernierSinistre);
    }
    else if (!OutilsActiviteConserve.estUneDemandeDeRevision(demandeAssuranceCourante))
    {
      TravailSpec dernierSinistre = rechercheDernierSinistreClassique(demandeAssuranceCourante);
      
      resultatContexte.setDernierSinistre(dernierSinistre);
    }
  }
  
  private TravailSpec rechercheDernierSinistreClassique(DemandeAssuranceSpec demandeAssuranceCourante)
    throws CoucheLogiqueException
  {
    return RechercherDernierSinistre.rechercherDernierSinistrePourQualificationPeriode(demandeAssuranceCourante.getDateRecherche().veille(), demandeAssuranceCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), demandeAssuranceCourante);
  }
  
  private ResultatContexteExamen creationResultatParcours()
  {
    ResultatContexteExamen resultatContexte = new ResultatContexteExamen();
    resultatContexte.setEtat(0);
    resultatContexte.setContexteExamen(1);
    resultatContexte.setCauseNonValidite(0);
    return resultatContexte;
  }
  
  private void initialisationContexteAntecedentSP(DemandeAssuranceSpec demandeAssuranceCourante, ResultatContexteExamen resultatContexte)
    throws CoucheLogiqueException
  {
    if (demandeAssuranceCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      resultatContexte.setContexteExamen(4);
      if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeAssuranceCourante, "ANTSPAUTOM"))
      {
        ResultatTraitementReliquatSpec resultatTraitementReliquatSP = OutilTraitementReliquat.traiterReliquatSecteurPublic(demandeAssuranceCourante, demandeAssuranceCourante.getDateRecherche().veille());
        
        resultatContexte.setContexteExamen(resultatTraitementReliquatSP.getContexteExamen());
        resultatContexte.setCauseNonValidite(resultatTraitementReliquatSP.getCauseNonvalidite());
      }
    }
    else
    {
      resultatContexte.setContexteExamen(2);
    }
  }
  
  private void miseAjourReliquat(Demande demandeAssuranceCourante, ResultatExecutionCalculSpec resultatCalcul)
    throws CoucheLogiqueException
  {
    Reliquat reliquat = demandeAssuranceCourante.getReliquat();
    reliquat.setReliquatValide(resultatCalcul.getEtatAttribution() == 3);
    reliquat.setQuantiteReliquat(resultatCalcul.getReliquatAREAvecMaintien());
    reliquat.setQuantiteAide(resultatCalcul.getQuantiteAide());
    reliquat.setTypeAide(resultatCalcul.getTypeAide());
    reliquat.setQuantiteFormation(resultatCalcul.getQuantiteFormation());
    reliquat.setDateFinDispositifCSP(resultatCalcul.recupererDateFinDispositifCSP());
    reliquat.setQuantiteJourImputationDonneesForcees(resultatCalcul.getQuantiteJourImputationDonneesForcees());
    if (resultatCalcul.getReliquatDureeProlongation() != null) {
      reliquat.setReliquatAllongementArefPossible(resultatCalcul.getReliquatDureeProlongation().getValeurEntiere());
    }
    if (resultatCalcul.getQuantiteReliquatRenouvellement() != null) {
      reliquat.setQuantiteReliquatRenouvellement(resultatCalcul.getQuantiteReliquatRenouvellement());
    }
    reliquat.setDureePostPrime(resultatCalcul.getReliquatDureeProlongation());
  }
  
  private String recupererIdDemande(Contexte contexte)
  {
    return ((DomLiquidationDemande)contexte.getDonnees()).getIdDemande();
  }
  
  private void determinerContexteExamen(ResultatExecutionCalculSpec resultatCalcul, ResultatContexteExamen contexte)
  {
    if (resultatCalcul.getEtatAttribution() == 3)
    {
      contexte.setContexteExamen(3);
      contexte.setCauseNonValidite(0);
    }
    else
    {
      contexte.setContexteExamen(2);
      contexte.setCauseNonValidite(resultatCalcul.getEtatAttribution());
    }
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 0;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
}

/* Location:
 * Qualified Name:     ParcoursContexteExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */