package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreGammeAsu;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.fabriques.FabriqueBlocageDemandeExpresseAvecReliquatValide;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieConventionGestionPE;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCodeRessortissantAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilPasseProfessionelAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationPreconditions;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationauto.OutilFonctionnelTraitementsErreurs;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieBlocageDemandeExpresseAvecReliquatValideSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieConventionGestionPESpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSolCge01P01;
import fr.unedic.cali.dom.affectation.ProduitSolSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.exception.BlocageObjectifException;
import fr.unedic.cali.liquidation.pnds.StrategieDeterminationPNDSSpec;
import fr.unedic.cali.liquidation.pnds.outilsfonctionnels.FabriqueStrategieDeterminationPNDS;
import fr.unedic.cali.outilsfonctionnels.OutilFluxInstruction;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.parcours.ResultatServiceDemande;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Temporel;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public abstract class ParcoursLiquidationAssurance
  extends ParcoursLiquidation
{
  protected static final Damj DATE_PIVOT_MAYOTTE = new Damj(2013, 1, 1);
  protected static final int MOTIF_AIDE_RECLASSEMENT = 4;
  private static final int NB_ANNEE_BORNAGE_PNDS_SUR_PREMIERE_OD = 5;
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    super.traitementPreLiquidation(contexte);
    
    initialiserDonnees(contexte);
    Resultat resultat = demarrerTraitement(contexte);
    
    alimenterDonneesComplementairesDossierExamen(contexte);
    traitementPNDSDossiersLourds(contexte, resultat);
    traitementPostLiquidation(contexte);
    return resultat;
  }
  
  public void traitementPNDSDossiersLourds(Contexte contexte, Resultat resultat)
    throws ApplicativeException
  {
    DomLiquidationDemande domCourant = (DomLiquidationDemande)contexte.getDonnees();
    DemandeSpec demandeCourante;
    if (domCourant.getDemandeSpec() == null)
    {
      DemandeSpec demandeCourante = getIndividu(contexte).rechercherDemande(domCourant.getIdDemande());
      if (demandeCourante == null) {
        throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Demande inexistante en base");
      }
      domCourant.setDemande(demandeCourante);
    }
    else
    {
      demandeCourante = domCourant.getDemandeSpec();
    }
    if ((demandeCourante instanceof Demande)) {
      ((ResultatLiquidationAssurance)resultat).setAbsencePNDS(!((Demande)demandeCourante).isPresencePNDS());
    }
  }
  
  public abstract Resultat demarrerTraitement(Contexte paramContexte)
    throws ApplicativeException;
  
  public void deternminerQuantiteTravailPourCourrierASS(DemandeSpec demande)
    throws ApplicativeException
  {
    ProduitSolSpec produitASS = ProduitSolCge01P01.getInstance();
    if (((DemandeAssuranceSpec)demande).getOdAcquise() != null)
    {
      AttributionSpec attributionCourante = (AttributionSpec)demande.getDossierAffectation().getDossierExamen();
      ((AttributionAssuranceSpec)attributionCourante).setNbJoursActiviteCourrierASS(produitASS.determinerNbJoursActiviteAcquisePourCourrierAss(demande.getDemandeur(), attributionCourante));
    }
  }
  
  protected void constaterContexteInitial(Contexte contexte)
    throws ApplicativeException
  {
    verifierRecevabiliteDAL((DemandeAssuranceSpec)getDemande(contexte));
    
    controlerDonneesSecteurPublic(getIndividu(contexte), (DemandeAssuranceSpec)getDemande(contexte));
  }
  
  protected void determinerContexteExamen(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemandeAsu(contexte);
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    ResultatContexteExamen resultat = (ResultatContexteExamen)produit.determinerContexteExamen(contexte);
    
    getDom(contexte).setContexteExamen(resultat.getContexteExamen());
    getDom(contexte).setCauseNonValidite(resultat.getCauseNonValidite());
    
    getDom(contexte).setResultatExecutionCalculDroitPrecedent(resultat.getResultatExecutionCalculDroitPrecedent());
    getDom(contexte).setResultatImputationArce(resultat.getResultatImputationArce());
    if (3 == resultat.getContexteExamen())
    {
      controleAlerteA9MB1(contexte);
      
      verifierConventionGestion(resultat, demande);
    }
  }
  
  private void controleDemandeExpresse(Demande demande, DomLiquidationAssurance dom)
    throws ApplicativeException
  {
    if ((!ProduitAbstrait.estDuType(6, dom.getProduitPrecedent())) && ("ASU_02".equals(demande.getEvenementReferenceExamen().getTypeExamen())))
    {
      FabriqueBlocageDemandeExpresseAvecReliquatValide fabrique = new FabriqueBlocageDemandeExpresseAvecReliquatValide();
      CritereStrategie criteres = new CritereStrategie();
      criteres.setDatePivot(demande.getDateDepot());
      StrategieBlocageDemandeExpresseAvecReliquatValideSpec strategie = (StrategieBlocageDemandeExpresseAvecReliquatValideSpec)fabrique.getStrategie(criteres);
      
      strategie.leverBlocage(demande);
    }
  }
  
  private void verifierConventionGestion(ResultatContexteExamen resultat, Demande demande)
    throws CoucheLogiqueException
  {
    if ((resultat.getResultatExecutionCalculDroitPrecedent() != null) && (resultat.getResultatExecutionCalculDroitPrecedent().getAttributionEtudiee() != null))
    {
      CompetenceSpec competenceFinanciereEtAdministrative = ((DossierExamenAssuranceSpec)resultat.getResultatExecutionCalculDroitPrecedent().getAttributionEtudiee()).getCompetence();
      if (competenceFinanciereEtAdministrative != null)
      {
        ConventionGestionSpec conventionGestion = competenceFinanciereEtAdministrative.getConventionGestion();
        if (conventionGestion != null)
        {
          CritereStrategie criterePE = new CritereStrategie();
          criterePE.setDatePivot(demande.getDateExamen());
          FabriqueStrategieConventionGestionPE fabriquePE = new FabriqueStrategieConventionGestionPE();
          StrategieConventionGestionPESpec strategiePE = (StrategieConventionGestionPESpec)fabriquePE.getStrategie(criterePE);
          strategiePE.verifierConventionGestionPoleEmploi(conventionGestion);
        }
      }
    }
  }
  
  private void controleAlerteA9MB1(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = getDemandeAsu(contexte);
    Damj dateExamen = demande.getDateExamen();
    if ((dateExamen != null) && (dateExamen.estApresOuCoincideAvec(DATE_PIVOT_MAYOTTE)))
    {
      ObjetChronoPeriodePriseEnCharge dernierePec = OutillagePEC.getPecIndemnisablePrecedente(demande.getDemandeur(), dateExamen);
      
      boolean estPecPrecedenteMayotte = OutillagePEC.estPecMayotte(dernierePec);
      
      AttributionAssuranceSpec attributionPrec = ((DomLiquidationAssurance)contexte.getDonnees()).getAttributionPrecedente();
      
      estPecPrecedenteMayotte = (estPecPrecedenteMayotte) && (attributionPrec.getDateAttribution() != null) && (attributionPrec.getDateAttribution().estAvant(dernierePec.getDateDebut()));
      if (estPecPrecedenteMayotte)
      {
        Demande demandePrec = (Demande)attributionPrec.getDemande();
        
        boolean estDemandePrecAntecedentMayotte = ("ASU_23".equals(demandePrec.getEvenementReferenceExamen().getTypeExamen())) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandePrec.getListContexteDemande(), "AREMAYOTTE"));
        if ((!estDemandePrecAntecedentMayotte) && (4 != demande.getDonneesTemporaires().getNatureMontantAide())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A9MB1");
        }
      }
    }
  }
  
  protected void determinationContexteParticulier(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcoursContexteParticulier = new ParcoursDeterminationContexteParticulier();
    parcoursContexteParticulier.effectuerParcours(contexte);
  }
  
  protected void miseAJourDemandeAssurance(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcours = new ParcoursMiseAJourDemandeAssurance();
    parcours.effectuerParcours(contexte);
  }
  
  protected abstract void controlerDonneesSecteurPublic(IndividuSpec paramIndividuSpec, DemandeAssuranceSpec paramDemandeAssuranceSpec)
    throws ContexteException;
  
  protected DomLiquidationAssurance getDom(Contexte contexte)
  {
    return (DomLiquidationAssurance)contexte.getDonnees();
  }
  
  protected void affecterProduit(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemandeAsu(contexte);
    IndividuSpec individu = demande.getDemandeur();
    
    positionnerPasseProRevisionAvecExclusionFctReviseesAre14(demande);
    activerExclusionChronoPasseProPourLiquidationFCTRevision(individu);
    Parcours parcours = new AffectationDemandeAsu();
    parcours.effectuerParcours(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(individu);
  }
  
  protected void positionnerPasseProRevisionAvecExclusionFctReviseesAre14(Demande demande)
  {
    OutilPasseProfessionelAsu.positionnerPasseProRevisionAvecExclusionFctReviseesAre14(demande);
  }
  
  protected void activerExclusionChronoPasseProPourLiquidationFCTRevision(IndividuSpec individu)
  {
    individu.activerExclusionChronoPasseProPourLiquidationFCTRevision();
  }
  
  protected void desactiverExclusionChronoPasseProPourLiquidationFCTRevision(IndividuSpec individu)
  {
    individu.desactiverExclusionChronoPasseProPourLiquidationFCTRevision();
  }
  
  protected Demande getDemandeAsu(Contexte contexte)
  {
    return (Demande)super.getDemande(contexte);
  }
  
  protected boolean lancerParcoursObjectif(Contexte contexte, ObjectifExamen objectifCourant)
    throws ApplicativeException
  {
    Resultat resultat = null;
    try
    {
      Demande demandeCourante = getDemandeAsu(contexte);
      
      demandeCourante.setObjectifCourant(objectifCourant);
      
      initialiserDemande(contexte, objectifCourant);
      
      Parcours parcours = objectifCourant.creerParcoursObjectif();
      resultat = parcours.effectuerParcours(contexte);
      if (resultat.estSatisfait()) {
        objectifCourant.setEtat(21);
      } else {
        objectifCourant.setEtat(22);
      }
    }
    catch (BlocageObjectifException blocage)
    {
      objectifCourant.setEtat(22);
      if (verifierExistenceObjectifNonTraite(contexte) == null) {
        throw blocage;
      }
      return false;
    }
    return resultat.estSatisfait();
  }
  
  private void initialiserDemande(Contexte contexte, ObjectifExamen objectifCourant)
    throws CoucheLogiqueException
  {
    getDemandeAsu(contexte).setDemandeOrigine(null);
    switch (objectifCourant.getType())
    {
    case 1: 
    case 4: 
      initialiserDossierExamenAdmission(contexte);
      break;
    case 2: 
    case 5: 
    case 6: 
      intialiserDossierExamenReprise(contexte);
      break;
    }
  }
  
  private void initialiserDossierExamenAdmission(Contexte contexte)
  {
    Demande demande = getDemandeAsu(contexte);
    
    AttributionSpec attributionPrecedente = getDom(contexte).getAttributionPrecedente();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    
    produit.initialiserDossierExamen(getDemandeAsu(contexte).getDossierAffectation());
    
    produit.miseAJourDossierExamen(getDemandeAsu(contexte).getDossierAffectation().getDossierExamen(), attributionPrecedente);
    
    alimenterCodeProduitExecution((DossierAffectation)getDemandeAsu(contexte).getDossierAffectation(), demande);
  }
  
  private void affecterProduitPrecedent(AttributionSpec attributionPrecedente, DossierAffecte dossierAffecte)
  {
    dossierAffecte.setProduitForce(attributionPrecedente.getDossierAffecte().getProduit());
    
    dossierAffecte.setDecorReglementaire(((DossierAffectation)attributionPrecedente.getDossierAffecte()).getDecorReglementaire());
    
    ((ProduitAsuSpec)attributionPrecedente.getDossierAffecte().getProduit()).initialiserDossierExamen(dossierAffecte);
    
    ((ProduitAsuSpec)attributionPrecedente.getDossierAffecte().getProduit()).miseAJourDossierExamen(dossierAffecte.getDossierExamen(), attributionPrecedente);
  }
  
  private void affecterProduitCourant(Demande demande, DossierAffecte dossierAffecte)
  {
    demande.setDossierAffectationReprise(dossierAffecte);
    
    ProduitAsuSpec produit = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(demande.getDateExamen());
    produit.initialiserDossierExamen(dossierAffecte);
    dossierAffecte.setProduitForce(produit);
  }
  
  private void alimenterCodeProduitExecution(DossierAffectation dossierAffectation, Demande demande)
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 6))
    {
      ProduitSpec produitExecution = OutilAsp.getInstance().recupererProduitReglementaire(demande);
      dossierAffectation.setCodeProduitExecutable(produitExecution.getCode());
    }
    else
    {
      dossierAffectation.getProduit();
    }
  }
  
  private void intialiserDossierExamenReprise(Contexte contexte)
  {
    Demande demande = getDemandeAsu(contexte);
    demande.supprimerDossierAffectationReprise();
    
    AttributionSpec attributionPrecedente = getDom(contexte).getAttributionPrecedente();
    
    DossierAffecte dossierAffectationReprise = new DossierAffecte(2);
    if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      affecterProduitPrecedent(attributionPrecedente, dossierAffectationReprise);
    } else {
      affecterProduitCourant(demande, dossierAffectationReprise);
    }
    getDemandeAsu(contexte).setDossierAffectationReprise(dossierAffectationReprise);
    
    alimenterCodeProduitExecution(dossierAffectationReprise, demande);
  }
  
  protected ObjectifExamen verifierExistenceObjectifNonTraite(Contexte contexte)
  {
    ObjectifExamen objectifNonTraite = null;
    
    Collection<?> listeObjectifs = getDemandeAsu(contexte).getListeObjectifsExamen();
    for (Iterator<?> iter = listeObjectifs.iterator(); iter.hasNext();)
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if (objectif.getEtat() == 20)
      {
        objectifNonTraite = objectif;
        break;
      }
    }
    return objectifNonTraite;
  }
  
  protected void controlerDonneesForcees(Contexte contexte)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = getProduit(contexte);
    produit.controlerContexteDonneesForcees(contexte);
  }
  
  protected void controlerDonneesForceesPostLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = getProduit(contexte);
    produit.controlerContexteDonneesForceesPostLiquidation(contexte);
  }
  
  private ProduitAsuSpec getProduit(Contexte contexte)
  {
    DemandeAssuranceSpec demande = getDemandeAsu(contexte);
    if (demande == null) {
      return null;
    }
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  protected void chargermentListePNDSIndividu(DemandeSpec demandeCourante, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)demandeCourante;
    DonneesTemporaires donneesForcees = demande.getDonneesTemporaires();
    
    boolean chargementPNDS = ((donneesForcees.getSripSpectacle() == null) && (donneesForcees.getSjr() == null)) || (donneesForcees.getQuantiteAffiliation() == null);
    
    demande.setPndsChargees(chargementPNDS);
    if ((estDemandeEligibleASaisineIPR(demande)) && (donneesForcees.isEstDesactivationPnds() != null) && (donneesForcees.isEstDesactivationPnds().booleanValue())) {
      demande.getDemandeur().desactiverPNDS();
    }
    if (chargementPNDS)
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(determinerDateExamenPourPnds(demande, dateExamen));
      StrategieDeterminationPNDSSpec strategie = FabriqueStrategieDeterminationPNDS.determinerStrategieDeterminationPNDS(critere);
      desactiverPndsSIExamenIpr(strategie, demande.getDemandeur(), demande);
      
      Damj dateDebutRecherche = demande.getDateFaitGenerateurOdPrecedente();
      if (dateDebutRecherche == null) {
        dateDebutRecherche = dateExamen.deplacerVersArriere(new DureeCalendaire(5));
      }
      strategie.determinationPNDSPourIndividuSurPeriode(demandeCourante.getDemandeur(), dateDebutRecherche, dateExamen, demandeCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), false);
      
      verifierBesoinReinitialisationDifferentsCachePNDS(demande, strategie.getNomStrategie(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    }
  }
  
  private Damj determinerDateExamenPourPnds(Demande demande, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateExamenARetourner = dateExamen;
    if ((!demande.estMigree()) && ("ASU_04".equals(demande.getEvenementReferenceExamen().getTypeExamen()))) {
      dateExamenARetourner = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande).getDateExamen();
    }
    return dateExamenARetourner;
  }
  
  private void desactiverPndsSIExamenIpr(StrategieDeterminationPNDSSpec strategie, IndividuSpec individu, Demande demande)
  {
    if (("ASU_04".equals(demande.getEvenementReferenceExamen().getTypeExamen())) && ("StrategieDeterminationPNDSDesactives".equals(strategie.getNomStrategie()))) {
      individu.desactiverPNDS();
    }
  }
  
  private boolean estDemandeEligibleASaisineIPR(Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateReactivationPNDS = GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS");
    boolean estDemandeElligible;
    boolean estDemandeElligible;
    if (demande.getDateExamen().estApresOuCoincideAvec(dateReactivationPNDS)) {
      estDemandeElligible = true;
    } else {
      estDemandeElligible = "ASU_29".equals(demande.getEvenementReferenceExamen().getTypeExamen());
    }
    return estDemandeElligible;
  }
  
  private void verifierBesoinReinitialisationDifferentsCachePNDS(Demande demande, String nomNouvelleStrategiePNDS, Chronologie passePro)
  {
    if (!demande.getDerniereStrategiePNDSUtilisee().equals(nomNouvelleStrategiePNDS))
    {
      demande.supprimerCachePNDS();
      demande.setDerniereStrategiePNDSUtilisee(nomNouvelleStrategiePNDS);
      passePro.iterer();
      while (passePro.encoreSuivant())
      {
        Temporel elementCourant = passePro.elementSuivant();
        if ((elementCourant instanceof ActiviteSalarie))
        {
          ((ActiviteSalarie)elementCourant).setListePeriodeElementaire(null);
          ((ActiviteSalarie)elementCourant).setPndsSpectacleCharge(false);
        }
      }
    }
  }
  
  protected void initialiserDonnees(Contexte contexte)
    throws CoucheLogiqueException
  {
    DemandeAssuranceSpec demande = getDemandeAsu(contexte);
    
    reinitialiserCacheDemande(demande);
    if ((((DomLiquidationDemande)contexte.getDonnees()).isLiquidationTP()) && (!((DomLiquidationDemande)contexte.getDonnees()).isModeSimulation())) {
      demande.setDroitOptionReadmission(((DomLiquidationDemande)contexte.getDonnees()).isLiquidationAvecDroitOptionReadmission());
    }
  }
  
  protected void reinitialiserCacheDemande(DemandeAssuranceSpec demande)
  {
    demande.setAttributionPrecedenteDuMemeType(null);
    demande.setOuvertureDroitPrecedenteDuMemeType(null);
    demande.reinitialiserBlocageLiquidation();
  }
  
  protected void initialisationPasseProfessionnelLiquidation(Contexte contexte)
  {
    IndividuSpec individu = getIndividu(contexte);
    
    ((Individu)individu).setCriteresQualificationPositionnes(false);
    individu.setChronoPeriodePasseProfessionnelLiquidation(OutilPasseProfessionelAsu.trouverChronoPasseProfessionelAvecFiltrageE301etDNJ(individu, getDemandeAsu(contexte).getDonneesTemporaires().isEstCoordCee()));
  }
  
  private void alimenterDonneesComplementairesDossierExamen(Contexte contexte)
  {
    ProduitAsuSpec produit = getProduit(contexte);
    if (produit != null)
    {
      DemandeAssuranceSpec demande = getDemandeAsu(contexte);
      DossierExamenSpec dossierExamen = demande.getDossierExamen();
      if (dossierExamen != null) {
        produit.alimenterDonneesComplementairesDossierExamen(dossierExamen);
      }
    }
  }
  
  protected void alimenterDecisionsReexamen(Contexte contexte, ResultatServiceDemande resultat)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande(contexte);
    if (!demande.estUneDemandeFinDroit()) {
      super.alimenterDecisionsReexamen(contexte, resultat);
    }
  }
  
  protected void alimenterTranchesExecutables(Contexte contexte)
    throws ApplicativeException
  {
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    produitCourant.constituerTranchesExecutables(contexte);
  }
  
  protected void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = getDemandeAsu(contexte);
    ((EreGammeAsu)demandeCourante.getEvenementReferenceExamen()).determinerContextesLiquidation(contexte);
    determinerEligibiliteDemandeExamen(contexte);
  }
  
  protected void determinerEligibiliteDemandeExamen(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance dom = getDom(contexte);
    Demande demande = dom.getDemande();
    if (3 == dom.getContexteExamen()) {
      controleDemandeExpresse(demande, dom);
    }
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    super.controlerContexte(contexte);
    Demande demandeCourante = getDemandeAsu(contexte);
    demandeCourante.setModeSimulation(getDom(contexte).isModeSimulation());
  }
  
  protected void traitementPostLiquidation(Contexte contexte)
    throws CoucheLogiqueException
  {
    super.traitementPostLiquidation(contexte);
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    if (!dom.estContexteAppelServiceSimulationDroit())
    {
      Demande demande = getDemandeAsu(contexte);
      detecterIncoherenceRessortissant(demande);
      if (!dom.isLiquidationManuelleEnTP()) {
        detecterSituationAEBatimentAvecICCPConservatoire(demande);
      }
    }
    detecterBlocageRejetDVClauseRattrapage(contexte);
  }
  
  protected void detecterBlocageRejetDVClauseRattrapage(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = getDemandeAsu(contexte);
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "SORTIECRA")) && (((DossierExamenAssuranceSpec)demande.getDossierExamen()).estRejetDV())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CRA_REJET_DV_PENDANT_CRA");
    }
  }
  
  protected void detecterIncoherenceRessortissant(Demande demande)
  {
    OutilCodeRessortissantAsu.getInstance().verifierIncoherenceRessortissant(demande);
  }
  
  protected void detecterSituationAEBatimentAvecICCPConservatoire(Demande demande)
    throws CoucheLogiqueException
  {
    if (demande.getAlertesNonBloquantes().containsKey("ICCP_CONSERVATOIRE_BATIMENT"))
    {
      String idPeriodeGaec = ((ProduitAsuSpec)demande.getDossierAffectation().getProduit()).recupererIdAeBatimentPourICCPConservatoire(demande.getAttribution());
      OutilFluxInstruction.creerTraceTrackerPourD12DalAjoutPieceJustificative(demande.getDemandeur(), idPeriodeGaec, demande.getFormulaire().getReferenceExterne());
      
      demande.setLiquideeEnEtat(true);
    }
  }
  
  protected void verifierPreconditions(Contexte contexte)
    throws CoucheLogiqueException
  {
    OutilVerificationPreconditions.getInstance().verifierPreconditions(getDemande(contexte));
  }
  
  protected void effectuerControlesEligibiliteSurDecisionAuto(Contexte contexte, DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    if (getDom(contexte).isEffectuerControlesEligiliteSurDecisionAuto())
    {
      OutilFonctionnelTraitementsErreurs outilTraitementErreurs = OutilFonctionnelTraitementsErreurs.getInstance();
      outilTraitementErreurs.controlesPostLiquidationAutomatique(demandeCourante);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationAssurance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */