package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilReferenceExterne;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import java.util.ArrayList;
import java.util.Hashtable;

public class ParcoursObjectifAdmission
  extends ParcoursCali
{
  protected Resultat resultatCapa09 = null;
  
  protected DemandeAssuranceSpec getDemande(Contexte contexte)
  {
    return DomLiquidationAssurance.getDemande(contexte);
  }
  
  protected ProduitAsuSpec getProduit(Contexte contexte)
  {
    DemandeAssuranceSpec demande = getDemande(contexte);
    if (demande == null) {
      return null;
    }
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  protected void changerEtatDossierExamenEnAttribution(DemandeAssuranceSpec demandeCourante)
    throws CoucheLogiqueException
  {
    switch (demandeCourante.getObjectifCourant().getSousType())
    {
    case 10: 
    case 12: 
    case 32: 
    case 40: 
    case 44: 
      demandeCourante.getDossierExamen().changerEtat(10);
      break;
    case 11: 
      demandeCourante.getDossierExamen().changerEtat(11);
      break;
    case 26: 
      demandeCourante.getDossierExamen().changerEtat(26);
      break;
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifAdmission = new Resultat();
    resultatObjectifAdmission.setEtat(1);
    
    DemandeAssuranceSpec demandeCourante = getDemande(contexte);
    
    ObjectifExamenAssuranceSpec objectifExamenCourant = OutilObjectifExamen.recupererObjectifCourant(contexte);
    
    boolean capaSatisfaites = ((ProduitAsuSpec)demandeCourante.getDossierAffectation().getProduit()).verifierCapasPreliminaires(contexte);
    
    capaSatisfaites = (capaSatisfaites) && (verifierCapa(contexte));
    if (capaSatisfaites)
    {
      executerCepa(contexte, objectifExamenCourant);
      
      determinationReferenceExterne(contexte);
      if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeCourante, "ARESJASPDC")) {
        capaSatisfaites = verifierCapaSupplementaires(contexte);
      }
      if (capaSatisfaites)
      {
        resultatObjectifAdmission.setEtat(0);
      }
      else
      {
        demandeCourante.getDossierExamen().changerEtat(16);
        gestionAlertePopIccpConservatoireBatiment(demandeCourante);
      }
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(16);
      gestionAlertePopIccpConservatoireBatiment(demandeCourante);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifAdmission;
  }
  
  protected boolean verifierCapa(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    IndividuSpec individu = demande.getDemandeur();
    
    boolean capaSatisfaites = false;
    
    Resultat resultatCapa04 = null;
    Resultat resultatCapa06 = null;
    Resultat resultatCapa07 = null;
    Resultat resultatCapa14 = null;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    Resultat resultatCapa01 = produitCourant.verifierConditionRechercheEmploi(contexte);
    if (resultatCapa01.estSatisfait())
    {
      resultatCapa04 = produitCourant.verifierConditionFaitGenerateur(contexte);
      
      resultatCapa06 = produitCourant.verifierConditionAge(contexte);
      if (!resultatCapa04.estSatisfait())
      {
        resultatCapa07 = new Resultat();
        resultatCapa07.setEtat(2);
      }
      else
      {
        activerExclusionChronoPasseProPourLiquidationFCTRevision(demande, individu);
        resultatCapa07 = produitCourant.verifierConditionQuantiteAffiliation(contexte);
        desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demande, individu);
      }
      resultatCapa14 = produitCourant.verifierConditionBeneficeAutreProduit(contexte);
      if ((resultatCapa04.estSatisfait()) && (resultatCapa07.estSatisfait()))
      {
        resultatCapa09 = produitCourant.verifierConditionChomageInvolontaire(contexte);
      }
      else
      {
        resultatCapa09 = new Resultat();
        resultatCapa09.setEtat(2);
      }
    }
    if ((resultatCapa01.estSatisfait()) && (resultatCapa04.estSatisfait()) && (resultatCapa06.estSatisfait()) && ((resultatCapa07.estSatisfait()) || (resultatCapa07.getEtat() == 2)) && (resultatCapa14.estSatisfait())) {
      capaSatisfaites = true;
    }
    return capaSatisfaites;
  }
  
  protected void executerCepa(Contexte contexte, ObjectifExamenAssuranceSpec objectifExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)getDemande(contexte);
    IndividuSpec individu = demandeCourante.getDemandeur();
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    changerEtatDossierExamenEnAttribution(demandeCourante);
    
    produitCourant.constituerDateAttribution(contexte);
    
    produitCourant.constituerReglementApplicable(contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerQuantiteAffiliation(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.constituerNbHeuresTravaillees(contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerSalaireJournalierDeReference(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.liquiderDemandeAssociee(contexte);
    
    produitCourant.constituerSalaireJournalierConserve(contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerCoefficientTempsPartiel(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.constituerCaractereSaisonnier(contexte);
    
    produitCourant.constituerCoefficientSaisonnier(contexte);
    
    produitCourant.constituerDateLimiteIndemnisation(contexte);
    
    produitCourant.constituerDureesReglementaires(contexte);
    
    effectuerParcours(objectifExamenCourant.creerParcoursConstitutionDureePostPrime(), contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.determinerCompetencesDroitCourant(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.constituerMontantsBruts(contexte);
    
    produitCourant.constituerRevisionAutomatique(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    produitCourant.constituerProduitResultant(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerDelaisReports(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.constituerPointDeDepart(contexte);
    
    nettoyerTrancheExecutable(contexte);
    
    produitCourant.constituerDureeEffective(contexte);
    
    produitCourant.constituerCapitalAvecDureeEffective(contexte);
  }
  
  protected Resultat effectuerParcours(Parcours parcours, Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = null;
    if (parcours != null) {
      resultat = parcours.effectuerParcours(contexte);
    }
    return resultat;
  }
  
  private boolean verifierCapaSupplementaires(Contexte contexte)
    throws ApplicativeException
  {
    boolean capaSupplementairesSatisfaites = false;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    Resultat resultatCapa18 = produitCourant.verifierConditionMontant(contexte);
    
    Resultat resultatCapa17 = produitCourant.verifierConditionCumulPrestationFamiliale(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    Resultat resultatCapa12 = produitCourant.verifierConditionCumulActiviteConservee(contexte);
    
    nettoyerTrancheExecutable(contexte);
    
    Resultat resultatCapa05 = produitCourant.verifierConditionChomageTotal(contexte);
    
    Resultat resultatCapaCSRAccorsCP = produitCourant.verifierConditionCSRAccordCP(contexte);
    
    Resultat resultatCapaCSRDateAttribution = produitCourant.verifierConditionCSRDateAttributionPendantSuspension(contexte);
    
    Resultat resultatCapaCSR28JoursSuspension = produitCourant.verifierCondition28JoursSuspension(contexte);
    
    Resultat resultatCapa26 = verifierConditionAnciennete(contexte, produitCourant);
    if ((resultatCapa12.estSatisfait()) && (resultatCapa05.estSatisfait()) && (resultatCapa17.estSatisfait()) && (resultatCapa18.estSatisfait()) && (resultatCapaCSRAccorsCP.estSatisfait()) && (resultatCapaCSRDateAttribution.estSatisfait()) && (resultatCapaCSR28JoursSuspension.estSatisfait()) && (resultatCapa26.estSatisfait()) && (estCapa09provoqueUneAdmission(contexte)))
    {
      capaSupplementairesSatisfaites = true;
      
      Resultat capaDureeNonNulle = produitCourant.verifierConditionDureeNonNulle(contexte);
      if ((capaDureeNonNulle != null) && (capaDureeNonNulle.estSatisfait()))
      {
        alimenterTrancheExecutable(contexte);
        produitCourant.constituerNouvelleRevisionAutomatique(contexte);
        nettoyerTrancheExecutable(contexte);
      }
    }
    return capaSupplementairesSatisfaites;
  }
  
  public boolean estCapa09provoqueUneAdmission(Contexte contexte)
  {
    Demande demandeCourante = (Demande)getDemande(contexte);
    boolean retour;
    boolean retour;
    if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(demandeCourante)) {
      retour = true;
    } else {
      retour = (resultatCapa09.estSatisfait()) || (resultatCapa09.getEtat() == 2);
    }
    return retour;
  }
  
  protected Resultat verifierConditionAnciennete(Contexte contexte, ProduitAsuSpec produitCourant)
    throws ApplicativeException
  {
    return produitCourant.verifierConditionAnciennete(contexte);
  }
  
  protected void determinationReferenceExterne(Contexte contexte)
    throws CoucheLogiqueException
  {
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(contexte), "ARESJREV")) {
      OutilReferenceExterne.determinationReferenceExterneAdmission(contexte);
    }
  }
  
  protected void alimenterTrancheExecutable(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getAttribution().getProduit();
      produit.constituerTranchesExecutables(contexte);
    }
  }
  
  protected void nettoyerTrancheExecutable(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null) && (((ProduitAsuSpec)demande.getAttribution().getProduit()).estTrancheActivee(demande)))
    {
      Attribution attribution = (Attribution)demande.getAttribution();
      attribution.setListeTranchesExecutables(new ArrayList());
    }
    if (demande.getAttribution() != null)
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      attribution.viderCacheElementsChomageSansRupture();
    }
  }
  
  protected void activerExclusionChronoPasseProPourLiquidationFCTRevision(Demande demandeCourante, IndividuSpec pIndividu)
  {
    boolean estContexteAreSousJacentPourRevision = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARESJREV");
    if (!estContexteAreSousJacentPourRevision) {
      pIndividu.activerExclusionChronoPasseProPourLiquidationFCTRevision();
    }
  }
  
  protected void desactiverExclusionChronoPasseProPourLiquidationFCTRevision(Demande demandeCourante, IndividuSpec pIndividu)
  {
    boolean estContexteAreSousJacentPourRevision = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARESJREV");
    if (!estContexteAreSousJacentPourRevision) {
      pIndividu.desactiverExclusionChronoPasseProPourLiquidationFCTRevision();
    }
  }
  
  protected void gestionAlertePopIccpConservatoireBatiment(DemandeAssuranceSpec demandeCourante)
  {
    demandeCourante.getAlertesNonBloquantes().remove("ICCP_CONSERVATOIRE_BATIMENT");
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */