package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationCompetencesRepriseSecteurPublic;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilObjectifExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.AlgorithmesIdentifiantSigma;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;

public class ParcoursObjectifReprise
  extends ParcoursCali
{
  private Resultat resultatCapr09 = null;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifReprise = new Resultat();
    resultatObjectifReprise.setEtat(1);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide()) {
      traitementSecteurPublic(contexte, resultatObjectifReprise);
    } else {
      traitementStandard(contexte, resultatObjectifReprise);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifReprise;
  }
  
  protected DemandeAssuranceSpec getDemande(Contexte contexte)
  {
    return DomLiquidationAssurance.getDemande(contexte);
  }
  
  protected void determinationReferenceExterne(Contexte contexte)
    throws CoucheLogiqueException
  {
    String rsrp = null;
    DossierExamenSpec dossierExamenCourant = (DossierExamenSpec)getDemande(contexte).getListeDossiersExamen().get(0);
    AttributionSpec attribution = (AttributionSpec)dossierExamenCourant;
    rsrp = Integer.toString(AlgorithmesIdentifiantSigma.getIdentifiantReprise(attribution));
    attribution.setReferenceExterne(rsrp);
  }
  
  protected boolean verifierCapr(Contexte contexte)
    throws ApplicativeException
  {
    boolean caprSatisfaites = false;
    Resultat resultatCapr01 = null;
    Resultat resultatCapr06 = null;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    Resultat resultatCapr27 = produitCourant.verifierConditionValiditeReliquat(contexte);
    if (resultatCapr27.estSatisfait())
    {
      resultatCapr01 = produitCourant.verifierConditionRechercheEmploi(contexte);
      
      resultatCapr06 = produitCourant.verifierConditionAge(contexte);
      
      setResultatCapr09(produitCourant.verifierConditionChomageInvolontaire(contexte));
    }
    if ((resultatCapr27.estSatisfait()) && (resultatCapr01.estSatisfait()) && (resultatCapr06.estSatisfait())) {
      caprSatisfaites = true;
    }
    return caprSatisfaites;
  }
  
  protected void changerEtatDossierExamen(DossierExamenAssuranceSpec dossierExamenCourant)
    throws CoucheLogiqueException
  {
    dossierExamenCourant.changerEtat(3);
  }
  
  protected void executerCepr(Contexte contexte, ObjectifExamenAssuranceSpec objectifExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = ((DomLiquidationAssurance)contexte.getDonnees()).getDemande();
    ProduitAsuSpec produitCourant = getProduit(contexte);
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)demandeCourante.getDossierExamen();
    
    changerEtatDossierExamen(dossierExamenCourant);
    
    produitCourant.constituerDateAttribution(contexte);
    
    produitCourant.constituerDateLimiteIndemnisation(contexte);
    
    produitCourant.constituerDureesReglementaires(contexte);
    
    effectuerParcours(objectifExamenCourant.creerParcoursConstitutionDureePostPrime(), contexte);
    
    produitCourant.constituerSalaireJournalierDeReference(contexte);
    
    produitCourant.constituerRevisionAutomatique(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    produitCourant.determinerCompetencesDroitResultant(contexte);
    
    produitCourant.constituerMontantsBruts(contexte);
    
    produitCourant.constituerDelaisReports(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    produitCourant.constituerReglementApplicable(contexte);
    
    produitCourant.constituerPointDeDepart(contexte);
    
    produitCourant.constituerDureeEffective(contexte);
    
    nettoyerTrancheExecutable(contexte);
    
    produitCourant.constituerCapitalAvecDureeEffective(contexte);
  }
  
  protected Resultat effectuerParcours(Parcours parcours, Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = null;
    if (parcours != null) {
      resultat = parcours.effectuerParcours(contexte);
    }
    return resultat;
  }
  
  protected boolean verifierCaprSupplementaires(Contexte contexte)
    throws ApplicativeException
  {
    boolean caprSupplementairesSatisfaites = false;
    
    Resultat resultatCapr12 = null;
    Resultat resultatCapr18 = null;
    Resultat resultatCapr17 = null;
    Resultat resultatCapaCSRAccorsCP = null;
    Resultat resultatCapaCSR28JoursSuspension = null;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    resultatCapr18 = produitCourant.verifierConditionMontant(contexte);
    
    resultatCapr17 = produitCourant.verifierConditionCumulPrestationFamiliale(contexte);
    
    resultatCapr12 = produitCourant.verifierConditionCumulActiviteConservee(contexte);
    if (resultatCapr12 == null) {
      resultatCapr12 = new Resultat(0);
    }
    resultatCapaCSRAccorsCP = produitCourant.verifierConditionCSRAccordCP(contexte);
    
    resultatCapaCSR28JoursSuspension = produitCourant.verifierCondition28JoursSuspension(contexte);
    if ((getResultatCapr09().estSatisfait()) && (resultatCapr12.estSatisfait()) && (resultatCapr17.estSatisfait()) && (resultatCapr18.estSatisfait()) && (resultatCapaCSRAccorsCP.estSatisfait()) && (resultatCapaCSR28JoursSuspension.estSatisfait()))
    {
      caprSupplementairesSatisfaites = true;
      if (!OutilFinDroit.estCasParticulierFinDroitEnAttributionAvecDuree0Jour(DomLiquidationAssurance.getDemande(contexte)))
      {
        alimenterTrancheExecutable(contexte);
        produitCourant.constituerNouvelleRevisionAutomatique(contexte);
        nettoyerTrancheExecutable(contexte);
      }
    }
    return caprSupplementairesSatisfaites;
  }
  
  protected ProduitAsuSpec getProduit(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  protected void controleExistenceFG(Demande demande, AttributionAssuranceSpec attributionPrecedente)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec odOrigine = attributionPrecedente;
    if (!(attributionPrecedente instanceof OdSpec)) {
      odOrigine = (AttributionAssuranceSpec)attributionPrecedente.getOuvertureDroit();
    }
    if ((odOrigine.getFaitGenerateur() == null) || (odOrigine.getFaitGenerateur().getPeriodeFaitGenerateur() == null)) {
      controleExistenceDernierSinistre(demande);
    }
  }
  
  protected void controleExistenceDernierSinistre(Demande demande)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    if (dernierSinistre == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_REPRISE_SANS_FGD");
    }
  }
  
  protected void alimenterTrancheExecutable(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getAttribution().getProduit();
      produit.constituerTranchesExecutables(contexte);
    }
  }
  
  protected void nettoyerTrancheExecutable(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null) && (((ProduitAsuSpec)demande.getAttribution().getProduit()).estTrancheActivee(demande)))
    {
      Attribution attribution = (Attribution)demande.getAttribution();
      attribution.setListeTranchesExecutables(new ArrayList());
    }
    if (demande.getAttribution() != null)
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      attribution.viderCacheElementsChomageSansRupture();
    }
  }
  
  protected void traitementStandard(Contexte contexte, Resultat resultatObjectifReprise)
    throws ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    ObjectifExamenAssuranceSpec objectifExamenCourant = OutilObjectifExamen.recupererObjectifCourant(contexte);
    
    demandeCourante.setDemandeOrigine((DemandeAssuranceSpec)dom.getAttributionPrecedente().getDemande());
    
    controleExistenceFG(demandeCourante, dom.getAttributionPrecedente());
    
    boolean caprSatisfaites = verifierCapr(contexte);
    if (caprSatisfaites)
    {
      executerCepr(contexte, objectifExamenCourant);
      
      determinationReferenceExterne(contexte);
      if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARESJASPDC")) {
        caprSatisfaites = verifierCaprSupplementaires(contexte);
      }
      if (caprSatisfaites)
      {
        resultatObjectifReprise.setEtat(0);
      }
      else
      {
        demandeCourante.getDossierExamen().changerEtat(16);
        gestionAlertePopIccpConservatoireBatiment(demandeCourante);
      }
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(16);
      gestionAlertePopIccpConservatoireBatiment(demandeCourante);
    }
  }
  
  private void traitementSecteurPublic(Contexte contexte, Resultat resultatObjectifReprise)
    throws ApplicativeException
  {
    Demande demandeCourante = ((DomLiquidationAssurance)contexte.getDonnees()).getDemande();
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)demandeCourante.getDossierExamen();
    dossierExamenCourant.changerEtat(50);
    
    DeterminationCompetencesRepriseSecteurPublic parcours = new DeterminationCompetencesRepriseSecteurPublic();
    parcours.demarrer(contexte);
    
    resultatObjectifReprise.setEtat(0);
  }
  
  public void setResultatCapr09(Resultat resultatCapr09)
  {
    this.resultatCapr09 = resultatCapr09;
  }
  
  public Resultat getResultatCapr09()
  {
    return resultatCapr09;
  }
  
  protected void gestionAlertePopIccpConservatoireBatiment(DemandeAssuranceSpec demandeCourante)
  {
    demandeCourante.getAlertesNonBloquantes().remove("ICCP_CONSERVATOIRE_BATIMENT");
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */