package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilReferenceExterne;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import java.util.ArrayList;

public class ParcoursObjectifRevisionAdmission
  extends ParcoursCali
{
  Resultat m_resultatCapa09 = null;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifRevision = new Resultat();
    resultatObjectifRevision.setEtat(1);
    
    DemandeAssuranceSpec demandeCourante = getDemande(contexte);
    
    ObjectifExamenAssuranceSpec objectifExamenCourant = OutilObjectifExamen.recupererObjectifCourant(contexte);
    if (verifierCapa(contexte))
    {
      demandeCourante.setDemandeOrigine((DemandeAssuranceSpec)((DomLiquidationAssurance)contexte.getDonnees()).getAttributionPrecedente().getDemande());
      
      executerCepa(contexte, objectifExamenCourant);
      
      determinationReferenceExterne(contexte);
      if (verifierCapaSupplementaires(contexte)) {
        resultatObjectifRevision.setEtat(0);
      } else {
        demandeCourante.getDossierExamen().changerEtat(29);
      }
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(29);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifRevision;
  }
  
  private void executerCepa(Contexte contexte, ObjectifExamenAssuranceSpec objectifExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)getDemande(contexte);
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    changerEtatDossierExamenEnRevision(demandeCourante);
    
    produitCourant.constituerDateAttribution(contexte);
    
    produitCourant.constituerReglementApplicable(contexte);
    
    produitCourant.determinerCompetencesDroitCourant(contexte);
    
    produitCourant.constituerCoefficientTempsPartiel(contexte);
    
    produitCourant.constituerDateLimiteIndemnisation(contexte);
    
    produitCourant.constituerCapitalDroitCourant(contexte);
    
    effectuerParcours(objectifExamenCourant.creerParcoursConstitutionDureePostPrime(), contexte);
    
    produitCourant.constituerMontantsBruts(contexte);
    
    produitCourant.constituerDureesReglementaires(contexte);
    
    produitCourant.constituerSalaireJournalierDeReference(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    produitCourant.constituerDelaisReports(contexte);
    
    produitCourant.constituerPointDeDepart(contexte);
    
    nettoyerTrancheExecutable(contexte);
    
    produitCourant.constituerMontantsEffectifs(contexte);
    
    produitCourant.constituerCapitalAvecDureeEffective(contexte);
    
    produitCourant.constituerDureeEffective(contexte);
  }
  
  protected Resultat effectuerParcours(Parcours parcours, Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = null;
    if (parcours != null) {
      resultat = parcours.effectuerParcours(contexte);
    }
    return resultat;
  }
  
  private boolean verifierCapa(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean capaSatisfaites = false;
    Resultat resultatCapAffi = null;
    Resultat resultatCapaAge = null;
    
    ProduitAsuSpec produitCourant = getProduit(p_contexte);
    
    resultatCapaAge = produitCourant.verifierConditionAge(p_contexte);
    
    produitCourant.liquiderDemandeAssociee(p_contexte);
    
    produitCourant.verifierConditionFaitGenerateur(p_contexte);
    
    resultatCapAffi = produitCourant.verifierConditionQuantiteAffiliation(p_contexte);
    if (resultatCapAffi.estSatisfait()) {
      m_resultatCapa09 = produitCourant.verifierConditionChomageInvolontaire(p_contexte);
    }
    if ((resultatCapAffi != null) && (resultatCapAffi.estSatisfait()) && (resultatCapaAge != null) && (resultatCapaAge.estSatisfait())) {
      capaSatisfaites = true;
    }
    return capaSatisfaites;
  }
  
  private boolean verifierCapaSupplementaires(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean capaSupplementairesSatisfaites = false;
    
    Resultat resultatCapaMontant = null;
    Resultat resultatCapaCumulPrestationFamiliale = null;
    
    ProduitAsuSpec produitCourant = getProduit(p_contexte);
    
    resultatCapaMontant = produitCourant.verifierConditionMontant(p_contexte);
    
    resultatCapaCumulPrestationFamiliale = produitCourant.verifierConditionCumulPrestationFamiliale(p_contexte);
    if ((resultatCapaMontant.estSatisfait()) && (resultatCapaCumulPrestationFamiliale.estSatisfait()) && (estCapa09provoqueUneAdmission(p_contexte))) {
      capaSupplementairesSatisfaites = true;
    }
    return capaSupplementairesSatisfaites;
  }
  
  public boolean estCapa09provoqueUneAdmission(Contexte p_contexte)
  {
    boolean retour = false;
    Demande demandeCourante = (Demande)getDemande(p_contexte);
    if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(demandeCourante)) {
      retour = true;
    } else {
      retour = (m_resultatCapa09.estSatisfait()) || (m_resultatCapa09.getEtat() == 2);
    }
    return retour;
  }
  
  private void changerEtatDossierExamenEnRevision(DemandeAssuranceSpec p_demandeCourante)
    throws CoucheLogiqueException
  {
    p_demandeCourante.getDossierExamen().changerEtat(45);
  }
  
  private ProduitAsuSpec getProduit(Contexte p_contexte)
  {
    DemandeAssuranceSpec demande = getDemande(p_contexte);
    if (demande == null) {
      return null;
    }
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  private DemandeAssuranceSpec getDemande(Contexte p_contexte)
  {
    return DomLiquidationAssurance.getDemande(p_contexte);
  }
  
  private void alimenterTrancheExecutable(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getAttribution().getProduit();
      produit.constituerTranchesExecutables(p_contexte);
    }
  }
  
  private void nettoyerTrancheExecutable(Contexte p_contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null) && (((ProduitAsuSpec)demande.getAttribution().getProduit()).estTrancheActivee(demande)))
    {
      Attribution attribution = (Attribution)demande.getAttribution();
      attribution.setListeTranchesExecutables(new ArrayList());
    }
    if (demande.getAttribution() != null)
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      attribution.viderCacheElementsChomageSansRupture();
    }
  }
  
  protected void determinationReferenceExterne(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (!"REVAUTO".equals(((EreRevisionConvention2014)getDemande(p_contexte).getEvenementReferenceExamen()).getContexteDemande())) {
      OutilReferenceExterne.determinationReferenceExterneAdmission(p_contexte);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifRevisionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */