package fr.unedic.cali.asu.parcours.prechargement;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.prechargement.OutilLectureContexteExamen;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.pivot.Decision;
import fr.unedic.cali.dom.prechargement.DomLectureContexteExamen;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.utilitaire.comparateurs.ComparateurDecisionPivotAssuranceDecroissante;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.Collections;
import java.util.List;

public class ParcoursLectureContexteExamen
  extends ParcoursLiquidation
{
  protected Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    ResultatLectureContexteExamen resultat = new ResultatLectureContexteExamen();
    DomLectureContexteExamen dom = (DomLectureContexteExamen)contexte.getDonnees();
    
    OutilLectureContexteExamen outil = OutilLectureContexteExamen.getInstance();
    Damj dateRecherche = dom.getDateEtude();
    List<Decision> listeDecisionPivot = DomManager.getDecisionsPivot();
    listeDecisionPivot = outil.filtrerDemandeClasserOuNonAssurance(listeDecisionPivot);
    Collections.sort(listeDecisionPivot, new ComparateurDecisionPivotAssuranceDecroissante());
    
    Decision attributionPrecedente = outil.recupererAttributionPrecedente(listeDecisionPivot, dateRecherche);
    
    boolean estReliquatValide = false;
    boolean estReliquatSpectacle = false;
    AttributionSpec domAttributionPrecedente = null;
    if (attributionPrecedente != null) {
      if ("SP".equals(attributionPrecedente.getCompetenceAdministrative()))
      {
        estReliquatValide = true;
        estReliquatSpectacle = false;
      }
      else
      {
        DemandeSpec demandePrecedente = outil.chargerDemandeAssurance(attributionPrecedente.getReferenceExterneDemande());
        if (demandePrecedente == null) {
          demandePrecedente = outil.chargerDemandeAri(attributionPrecedente.getIdentifiantDemandeCali());
        }
        domAttributionPrecedente = (AttributionSpec)demandePrecedente.getDossierAffectation().getDossierExamen();
        estReliquatValide = outil.recherchePresenceReliquatValide(domAttributionPrecedente, dateRecherche);
        estReliquatSpectacle = outil.estReliquatSpectacle(attributionPrecedente, estReliquatValide);
      }
    }
    Damj dateFgOd = outil.rechercheDateFgdOd(listeDecisionPivot, dateRecherche);
    Damj dateFgRejetDv = outil.rechercheDateFctDernierRejetDvPostFgd(listeDecisionPivot, dateRecherche, dateFgOd);
    
    boolean estPresenceDemandeAttenteDecision = outil.recherchePresenceDemandeAttenteDecision(listeDecisionPivot);
    Damj dateExamenDerniereDemandeAssurance = outil.recupererDateExamenDerniereDemandeAssurance(listeDecisionPivot, dateRecherche);
    if (!estPresenceDemandeAttenteDecision) {
      if ((estReliquatValide) && (estReliquatSpectacle)) {
        estPresenceDemandeAttenteDecision = outil.estUnDroitAMoinsDe15JoursDuTerme(domAttributionPrecedente, dateRecherche);
      } else if (!estReliquatValide) {
        estPresenceDemandeAttenteDecision = outil.verifierAbsenceDemandeFinDroit(domAttributionPrecedente, dateRecherche, listeDecisionPivot);
      }
    }
    resultat.setDateFctDernierRejetDvPostFgd(dateFgRejetDv);
    resultat.setDateFgd(dateFgOd);
    resultat.setPresenceReliquatAreValide(estReliquatValide);
    resultat.setReliquatSpectacle(estReliquatSpectacle);
    resultat.setDateExamenDerniereDemandeAssurance(dateExamenDerniereDemandeAssurance);
    resultat.setPresenceDemandeAttenteDecision(estPresenceDemandeAttenteDecision);
    
    resultat.setEtat(0);
    return resultat;
  }
  
  protected void preAlimenterAgregatGaec(Individu individu, String idDemande) {}
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 0;
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    DomLectureContexteExamen dom = (DomLectureContexteExamen)contexte.getDonnees();
    
    IndividuSpec individuCourant = getIndividu(contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent du contexte");
    }
    if (dom.getDateEtude() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Date absente ");
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursLectureContexteExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */