package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuIdSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class BaseCarence
  implements ObjetMetierSpec
{
  private static final long serialVersionUID = -1384064099526403086L;
  protected ActiviteSalarie m_periodeActiviteSalarieOrigine = null;
  private boolean m_licenciementEconomique = false;
  private QuantiteJourTravailDansSemaineSpec m_quantiteJourIccp = null;
  private QuantiteEuro m_quantiteEuroIccp = null;
  private QuantiteEuro m_quantiteEuroIslr = null;
  private QuantiteEuro m_quantiteEuroIndemniteLicenciementTotale = null;
  
  public BaseCarence() {}
  
  public BaseCarence(QuantiteJourTravailDansSemaineSpec p_quantiteJourIccp, QuantiteEuro p_quantiteEuroIccp, QuantiteEuro p_quantiteEuroIslr)
  {
    setQuantiteJourIccp(p_quantiteJourIccp);
    setQuantiteEuroIccp(p_quantiteEuroIccp);
    setQuantiteEuroIslr(p_quantiteEuroIslr);
  }
  
  public BigDecimal calculerIndemniteLicenciementLegale()
  {
    BigDecimal valeurIndemniteLegaleCalculee = new BigDecimal("0");
    
    Attribution odCourante = (Attribution)((Demande)m_periodeActiviteSalarieOrigine.getIdentifiantIndividu().getIndividu().getChronoDemandeAssurance().dernierElement()).getOdAcquise();
    if ((odCourante != null) && (odCourante.getConstitutionSjr() != null) && (odCourante.getConstitutionSjr().getSjrip() != null))
    {
      Sjrip sjripCourant = odCourante.getConstitutionSjr().getSjrip();
      BigDecimal nominateur1 = new BigDecimal("365.0");
      BigDecimal nominateur2 = sjripCourant.getSjrip();
      BigDecimal denominateur = new BigDecimal("12.0");
      BigDecimal valeurSalaireMensuel = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      
      Periode periodeActiviteSalarieeCourante = new Periode(m_periodeActiviteSalarieOrigine.getDateDebut(), m_periodeActiviteSalarieOrigine.getDateFin());
      
      BigDecimal nombreAnneesAnciennete = new BigDecimal(String.valueOf(periodeActiviteSalarieeCourante.getDureeCalendaire().getAnnees()));
      BigDecimal periodeActiviteSalarieeBigDecimal = new BigDecimal(String.valueOf(periodeActiviteSalarieeCourante.getDureeCalendaire().getMois()));
      
      nombreAnneesAnciennete = nombreAnneesAnciennete.add(Mathematiques.diviseParDefaut(periodeActiviteSalarieeBigDecimal, new BigDecimal("12")));
      if (nombreAnneesAnciennete.compareTo(new BigDecimal("2")) >= 0)
      {
        nominateur1 = valeurSalaireMensuel;
        nominateur2 = nombreAnneesAnciennete;
        denominateur = new BigDecimal("10.0");
        valeurIndemniteLegaleCalculee = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
        if (nombreAnneesAnciennete.compareTo(new BigDecimal("11")) >= 0)
        {
          nominateur1 = valeurSalaireMensuel;
          nominateur2 = nombreAnneesAnciennete.subtract(new BigDecimal("10.0"));
          denominateur = new BigDecimal("15.0");
          
          valeurIndemniteLegaleCalculee = valeurIndemniteLegaleCalculee.add(Mathematiques.proratiser(nominateur1, nominateur2, denominateur));
        }
        if (isLicenciementEconomique()) {
          valeurIndemniteLegaleCalculee = new BigDecimal(String.valueOf(2)).multiply(valeurIndemniteLegaleCalculee);
        }
        valeurIndemniteLegaleCalculee = Mathematiques.arrondiASup(valeurIndemniteLegaleCalculee, 2);
      }
    }
    return valeurIndemniteLegaleCalculee;
  }
  
  public ActiviteSalarie getPeriodeActiviteSalarieOrigine()
  {
    return m_periodeActiviteSalarieOrigine;
  }
  
  public QuantiteEuro getQuantiteEuroIccp()
  {
    return m_quantiteEuroIccp;
  }
  
  public QuantiteEuro getQuantiteEuroIndemniteLicenciementTotale()
  {
    return m_quantiteEuroIndemniteLicenciementTotale;
  }
  
  public QuantiteEuro getQuantiteEuroIslr()
  {
    QuantiteEuro quantiteIslr = null;
    if ((m_quantiteEuroIndemniteLicenciementTotale != null) && (!m_quantiteEuroIndemniteLicenciementTotale.getValeurMontant().equals(new BigDecimal("0"))))
    {
      BigDecimal valeurIndemniteLicenciementTotale = m_quantiteEuroIndemniteLicenciementTotale.getValeurMontant();
      BigDecimal valeurIndemniteLicenciementLegaleCalculee = calculerIndemniteLicenciementLegale();
      BigDecimal valeurIslr = valeurIndemniteLicenciementTotale.subtract(valeurIndemniteLicenciementLegaleCalculee);
      
      valeurIslr = valeurIslr.max(new BigDecimal(String.valueOf(0)));
      
      valeurIslr = Mathematiques.arrondiASup(valeurIslr, 2);
      quantiteIslr = new QuantiteEuro(valeurIslr);
    }
    else
    {
      quantiteIslr = m_quantiteEuroIslr;
    }
    return quantiteIslr;
  }
  
  public QuantiteJourTravailDansSemaineSpec getQuantiteJourIccp()
  {
    return m_quantiteJourIccp;
  }
  
  public boolean isLicenciementEconomique()
  {
    return m_licenciementEconomique;
  }
  
  public void setLicenciementEconomique(boolean p_licenciementEconomique)
  {
    m_licenciementEconomique = p_licenciementEconomique;
  }
  
  public void setPeriodeActiviteSalarieOrigine(ActiviteSalarie p_periodeActiviteSalarieOrigine)
  {
    m_periodeActiviteSalarieOrigine = p_periodeActiviteSalarieOrigine;
  }
  
  public void setQuantiteEuroIccp(QuantiteEuro p_quantiteEuroIccp)
  {
    m_quantiteEuroIccp = p_quantiteEuroIccp;
  }
  
  public void setQuantiteEuroIndemniteLicenciementTotale(QuantiteEuro p_quantiteEuroIndemniteLicenciementTotale)
  {
    m_quantiteEuroIndemniteLicenciementTotale = p_quantiteEuroIndemniteLicenciementTotale;
  }
  
  public void setQuantiteEuroIslr(QuantiteEuro p_quantiteEuroIslr)
  {
    m_quantiteEuroIslr = p_quantiteEuroIslr;
  }
  
  public void setQuantiteJourIccp(QuantiteJourTravailDansSemaineSpec p_quantiteJourIccp)
  {
    m_quantiteJourIccp = p_quantiteJourIccp;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    
    chaineRetour.append("\n\t Nombre de jours ICCP :" + m_quantiteJourIccp);
    chaineRetour.append("\n\t Montant ICCP : " + m_quantiteEuroIccp);
    chaineRetour.append("\n\t Licenciement économique : " + m_licenciementEconomique);
    chaineRetour.append("\n\t Montant Indemnité licenciement totale : " + m_quantiteEuroIndemniteLicenciementTotale);
    chaineRetour.append("\n\t Montant ISLR : " + m_quantiteEuroIslr);
    
    return chaineRetour.toString();
  }
  
  public QuantiteEuro getQuantiteEuroCarence()
  {
    return getQuantiteEuroIccp();
  }
  
  public QuantiteJourTravailDansSemaineSpec getQuantiteJourCarence()
  {
    return getQuantiteJourIccp();
  }
  
  public void setQuantiteEuroCarence(QuantiteEuro p_quantiteEuroCarence)
  {
    setQuantiteEuroIccp(p_quantiteEuroCarence);
  }
  
  public void setQuantiteJourCarence(QuantiteJourTravailDansSemaineSpec p_quantiteJourCarence)
  {
    setQuantiteJourIccp(p_quantiteJourCarence);
  }
  
  public ObjetMetierSpec copie()
  {
    BaseCarence copie = new BaseCarence();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    BaseCarence copie = (BaseCarence)p_copie;
    
    copie.setLicenciementEconomique(isLicenciementEconomique());
    copie.setPeriodeActiviteSalarieOrigine(getPeriodeActiviteSalarieOrigine());
    copie.setQuantiteEuroIccp(getQuantiteEuroIccp());
    copie.setQuantiteEuroIndemniteLicenciementTotale(getQuantiteEuroIndemniteLicenciementTotale());
    copie.setQuantiteEuroIslr(getQuantiteEuroIslr());
    copie.setQuantiteJourIccp(getQuantiteJourIccp());
  }
}

/* Location:
 * Qualified Name:     BaseCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */