package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.NovationGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.NovationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.List;

public class Novation
  extends NovationGen
  implements NovationSpec
{
  private static final long serialVersionUID = 1L;
  public static final String MONTANT_RETENU_ASP = "1";
  public static final String MONTANT_RETENU_ARE_SOUS_JACENT = "2";
  
  public Novation(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Novation() {}
  
  public Novation(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = "";
    if (getAttributionPrecedente() != null) {
      situationParticuliere = getAttributionPrecedente().getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() == null) {
      return false;
    }
    return getAttributionPrecedente().isInvestigationFraude();
  }
  
  public String getRsod()
  {
    return getReferenceExterne();
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return null;
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    return getAttributionPrecedente().getElementBaseActiviteReduite();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getProduitMontantRetenu();
    }
    return null;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    Demande demandePrecedente = (Demande)getAttributionPrecedente().getDemande();
    if ((estDemandeEnContexteAreASP((Demande)getDemande())) || ((estDemandeEnContexteAreASP(demandePrecedente)) && (!estDemandeEnContexteAreASP((Demande)getDemande())))) {
      return super.getFormuleMontant(code);
    }
    return getAttributionPrecedente().getFormuleMontant(code);
  }
  
  private boolean estDemandeEnContexteAreASP(Demande demande)
  {
    return (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((maintienEuropeen == null) && (getAttributionPrecedente() != null)) {
      if (getAttributionPrecedente().getMaintienEuropeen() == null) {
        maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
      } else {
        maintienEuropeen = getAttributionPrecedente().getMaintienEuropeen();
      }
    }
    return maintienEuropeen;
  }
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public Collection getListePlafonnementAffiliation()
  {
    return (getAttributionPrecedente() instanceof Attribution) ? ((Attribution)getAttributionPrecedente()).getListePlafonnementAffiliation() : null;
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getAttributionPrecedente().getDemandeMontantRetenu();
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    throw new UnsupportedOperationException("HG_PR_L_METHODE_NON_IMPLEMENTEE_ATTRIBUTION");
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return false;
  }
  
  public Collection getListePensionInvalidite()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getListePensionInvalidite();
    }
    return null;
  }
  
  protected ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisationAttributionOrigine()
  {
    return getConstitutionDateLimiteIndemnisation();
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConservee()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConservee();
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConserveePerdue()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConserveePerdue();
  }
  
  public List<TravailSpec> getListeActiviteConserveePerduesRevisees()
  {
    return ((Decision)getOuvertureDroit()).getListeActiviteConserveePerduesRevisees();
  }
  
  public ObjetMetierSpec copie()
  {
    Novation copie = new Novation();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Novation novation = (Novation)copie;
    super.copieElements(copie);
    novation.setSituationParticuliere(getSituationParticuliere());
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    return getConstitutionElementsActifs().getConstitutionCaractereSaisonnier();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsActifs().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    return getConstitutionElementsActifs().getConstitutionCoefficientSaisonnier();
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getDateDebutDelaiDecheance();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     Novation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */