package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.datelimite.asp.OutilAllongementDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.datelimite.asp.OutilDecalageDateLimiteIndemnisation;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilGestionDate;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationDateLimiteIndemnisation
{
  public static ResultatDeterminationDateLimiteIndemnisation determinerDateLimiteIndemnisation(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatDeterminationDateLimiteIndemnisation resultat = null;
    
    boolean estDateLimiteForcee = demande.getDonneesTemporaires().getDateLimiteIndemnisationDonneeForcee() != null;
    if (estDateLimiteForcee) {
      resultat = determinerDateLimiteIndemnisationForcee(demande);
    } else if (OutilAsp.getInstance().estDeTypeOD(demande)) {
      resultat = determinerDateLimiteIndemnisationAdmission(demande);
    } else {
      resultat = determinerDateLimiteIndemnisationHorsAdmission(demande);
    }
    return resultat;
  }
  
  private static ResultatDeterminationDateLimiteIndemnisation determinerDateLimiteIndemnisationHorsAdmission(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatDeterminationDateLimiteIndemnisation resultat = new ResultatDeterminationDateLimiteIndemnisation();
    Damj dateLimiteIndemnisation = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP"))
    {
      Damj dateEntreDispo = OutilAsp.getInstance().calculerPointDepartCSP(demande);
      
      dateLimiteIndemnisation = calculerDecalage12mois(dateEntreDispo);
      resultat.setDateLimiteIndemnisation(dateLimiteIndemnisation);
      resultat.setContexteDateLimiteIndemnisation("IDEASP");
    }
    else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"))
    {
      determinerDateLimiteEnCoursCSP(demande, resultat);
    }
    return resultat;
  }
  
  protected static void determinerDateLimiteEnCoursCSP(Demande demande, ResultatDeterminationDateLimiteIndemnisation resultat)
    throws CoucheLogiqueException
  {
    Damj dateLimiteIndem;
    Damj dateLimiteIndem;
    if (estDemandeAvecAllongementDateLimite(demande))
    {
      int allongement = 0;
      Damj pointDepartCSP = OutilAsp.getInstance().calculerPointDepartCSP(demande);
      try
      {
        AttributionAssuranceSpec attributionEnCours = demande.getAttribution();
        allongement = calculerAllongementAuto(demande, attributionEnCours.getAttributionPrecedente(), pointDepartCSP);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex);
      }
      Damj dateLimiteCourante = demande.getReliquat().getDateFinDispositifCSP();
      if (dateLimiteCourante == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRODUIT_DL_REPRISE_ANTECEDENT");
      }
      dateLimiteIndem = OutilDecalageDateLimiteIndemnisation.decalerDateLimite(pointDepartCSP, dateLimiteCourante, allongement);
    }
    else
    {
      AttributionAssuranceSpec attributionEnEntreeDeCSP = (AttributionAssuranceSpec)OutilAsp.getInstance().recupererAttributionEntreeCsp(demande.getAttribution());
      
      dateLimiteIndem = attributionEnEntreeDeCSP.getDateLimiteIndemnisation();
    }
    resultat.setDateLimiteIndemnisation(dateLimiteIndem);
  }
  
  protected static boolean estDemandeAvecAllongementDateLimite(Demande demande)
  {
    ProduitSpec produit = demande.getAttribution().getProduitExecution();
    boolean estProduitCSP = ProduitAbstrait.estDuType(2, produit);
    
    boolean estContextePap = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 10);
    
    return (!estContextePap) && (estProduitCSP) && (((ProduitSecurisationProfessionnelleSpec)produit).estUnProduitGerantAllongementDispositif());
  }
  
  private static int calculerAllongementAuto(Demande demande, AttributionAssuranceSpec attributionPrecedente, Damj pointDepartCSP)
    throws ApplicativeException
  {
    int allongement = 0;
    ProduitSpec produit = demande.getAttribution().getProduitExecution();
    boolean estProduitCSP = ProduitAbstrait.estDuType(2, produit);
    if ((estProduitCSP) && (((ProduitSecurisationProfessionnelleSpec)produit).estUnProduitGerantAllongementDispositif()))
    {
      ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionPrecedente, demande.getDateRecherche().veille(), true, true);
      
      Damj dji = resultatCalcul.getDernierJourIndemnisable();
      if (dji != null)
      {
        Periode periodeRecherche = new Periode();
        periodeRecherche.setDebut(dji.lendemain());
        periodeRecherche.setFin(demande.getDateExamen().veille());
        
        Chronologie periodesParticipantes = OutilAllongementDateLimiteIndemnisation.recupererChronoPeriodesParticipantes(pointDepartCSP, demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
        
        allongement = OutilAllongementDateLimiteIndemnisation.determinerAllongement(pointDepartCSP, periodesParticipantes, periodeRecherche);
      }
    }
    return allongement;
  }
  
  private static ResultatDeterminationDateLimiteIndemnisation determinerDateLimiteIndemnisationAdmission(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatDeterminationDateLimiteIndemnisation resultat = new ResultatDeterminationDateLimiteIndemnisation();
    
    Damj dateAttribution = demande.getDateAttribution();
    Damj dateLimiteIndemnisation = null;
    ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent(demande, 2);
    if (contexteDemande != null)
    {
      dateLimiteIndemnisation = contexteDemande.getDateFinJustifContexte();
      resultat.setDateLimiteIndemnisation(dateLimiteIndemnisation);
      resultat.setContexteDateLimiteIndemnisation("CRSPMVS");
    }
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP"))
    {
      Damj dateLimiteAsp = determinerDateLimiteIndemnisationSpecifiqueAsr(demande);
      if ((dateLimiteIndemnisation == null) || (dateLimiteAsp.estApresOuCoincideAvec(dateLimiteIndemnisation)))
      {
        resultat.setDateLimiteIndemnisation(dateLimiteAsp);
        resultat.setContexteDateLimiteIndemnisation("IDEASP");
      }
    }
    else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"))
    {
      determinerDateLimiteEnCoursCSP(demande, resultat);
    }
    resultat.setDateDebutIndemnisation(dateAttribution);
    
    return resultat;
  }
  
  public static Damj determinerDateLimiteIndemnisationSpecifiqueAsr(Demande demande)
  {
    Damj dateCalculDateLimite = OutilAsp.getInstance().calculerPointDepartCSP(demande);
    return calculerDecalage12mois(dateCalculDateLimite);
  }
  
  protected static Damj calculerDecalage12mois(Damj dateCalculDateLimite)
  {
    return OutilGestionDate.getInstance().calculerDecalage12moisVersAvant(dateCalculDateLimite);
  }
  
  public static void controleValiditeDateLimiteIndemnisation(Demande demande, Damj dateLimiteIndemnisation)
    throws CoucheLogiqueException
  {
    Damj dateExamen = demande.getDateExamen();
    if ((dateLimiteIndemnisation != null) && (dateExamen.estApres(dateLimiteIndemnisation))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB37", new String[] { dateExamen.toString(), dateLimiteIndemnisation.toString() });
    }
  }
  
  private static ResultatDeterminationDateLimiteIndemnisation determinerDateLimiteIndemnisationForcee(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatDeterminationDateLimiteIndemnisation resultat = new ResultatDeterminationDateLimiteIndemnisation();
    Damj dateLimiteAsp = demande.getDonneesTemporaires().getDateLimiteIndemnisationDonneeForcee();
    
    controleValiditeDateLimiteIndemnisationForcee(demande, dateLimiteAsp);
    
    resultat.setDateLimiteIndemnisation(dateLimiteAsp);
    resultat.setContexteDateLimiteIndemnisation("IDEASP");
    return resultat;
  }
  
  public static void controleValiditeDateLimiteIndemnisationForcee(Demande demande, Damj dateLimiteIndemnisation)
    throws CoucheLogiqueException
  {
    ProduitSpec produitAffecte = demande.getDossierAffectation().getProduit();
    Demande demandeEntreeCsp = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"))
    {
      demandeEntreeCsp = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
    }
    else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP"))
    {
      if (!estProduitAre2003ou2006(produitAffecte)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_LIMITE_ENTR_CSP");
      }
      demandeEntreeCsp = demande;
    }
    if (demandeEntreeCsp != null)
    {
      Damj pointDepart = OutilAsp.getInstance().calculerPointDepartCSP(demandeEntreeCsp);
      OutilDecalageDateLimiteIndemnisation.controlerDateLimiteForcee(pointDepart, dateLimiteIndemnisation);
    }
  }
  
  private static boolean estProduitAre2003ou2006(ProduitSpec produitAffecte)
  {
    return (produitAffecte.getCode() == 1) || (produitAffecte.getCode() == 13);
  }
}

/* Location:
 * Qualified Name:     DeterminationDateLimiteIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */