package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class OutilSjrPnds
{
  public static Chronologie determinerChronoPeriodesSalaire(IndividuSpec p_individu, ActiviteSalarie p_pas, Damj p_dateFaitGenerateur, Damj p_dateExamen)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesSalaireRetournee = null;
    
    Chronologie chronoSalairesActiviteCourante = p_pas.getListeSalaires();
    
    ChronologiePeriodes chronoPeriodesPnds = null;
    try
    {
      PeriodeNonDeclareeSanction pnds = OutilDeterminationPNDS.determinerPNDS(p_individu, p_pas, p_pas.getDateDebut(), p_pas.getDateFin(), p_dateFaitGenerateur, p_dateExamen);
      if (pnds != null) {
        chronoPeriodesPnds = pnds.getChronoPeriodePNDS();
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
    if ((chronoPeriodesPnds != null) && (!chronoPeriodesPnds.estVide()))
    {
      chronoPeriodesSalaireRetournee = construireChronoPeriodesSalaireHorsPnds(chronoSalairesActiviteCourante, chronoPeriodesPnds);
      
      chronoPeriodesSalaireRetournee.ajouter(construireChronoPeriodesSalairePnds(chronoPeriodesPnds));
    }
    else
    {
      chronoPeriodesSalaireRetournee = p_pas.getListeSalaires();
    }
    return chronoPeriodesSalaireRetournee;
  }
  
  public static Chronologie determinerChronoPeriodesSalaire(Demande p_demande, ActiviteSalarie p_pas)
    throws CoucheLogiqueException
  {
    return determinerChronoPeriodesSalaire(p_demande.getDemandeur(), p_pas, p_demande.getFaitGenerateur().getDateFaitGenerateur(), p_demande.getDateExamen());
  }
  
  private static Chronologie construireChronoPeriodesSalaireHorsPnds(Chronologie p_chronoSalairesActivite, ChronologiePeriodes p_chronoPeriodesPnds)
  {
    Chronologie chronoPeriodesSalaireRetournee = new ChronologiePeriodes();
    
    Salaire salaireCourant = null;
    Periode periodeReferenceSalaireCourant = null;
    ChronologiePeriodes chronoPeriodesHorsPnds = null;
    ObjetChronoPeriode periodeHorsPndsCourante = null;
    Salaire salaireHorsPndsCourant = null;
    
    p_chronoSalairesActivite.iterer();
    while (p_chronoSalairesActivite.encoreSuivant())
    {
      salaireCourant = (Salaire)p_chronoSalairesActivite.elementSuivant();
      
      periodeReferenceSalaireCourant = new Periode(salaireCourant.getDateDebut(), salaireCourant.getDateFin());
      if (periodeReferenceSalaireCourant.inter(p_chronoPeriodesPnds) > 0)
      {
        chronoPeriodesHorsPnds = OutillageChronologiePeriodes.donnerPeriodesComplementaires(p_chronoPeriodesPnds, periodeReferenceSalaireCourant);
        if ((chronoPeriodesHorsPnds != null) && (chronoPeriodesHorsPnds.getTaille() > 0))
        {
          chronoPeriodesHorsPnds.iterer();
          while (chronoPeriodesHorsPnds.encoreSuivant())
          {
            periodeHorsPndsCourante = (ObjetChronoPeriode)chronoPeriodesHorsPnds.elementSuivant();
            
            salaireHorsPndsCourant = construireSalaireHorsPnds(periodeHorsPndsCourante, salaireCourant);
            
            chronoPeriodesSalaireRetournee.ajouter(salaireHorsPndsCourant);
          }
        }
      }
      else
      {
        chronoPeriodesSalaireRetournee.ajouter(salaireCourant);
      }
    }
    return chronoPeriodesSalaireRetournee;
  }
  
  private static ChronologiePeriodes construireChronoPeriodesSalairePnds(ChronologiePeriodes p_chronoPeriodesPnds)
  {
    ChronologiePeriodes chronoPeriodesSalaireRetournee = new ChronologiePeriodes();
    
    ObjetChronoPeriode periodePndsCourante = null;
    Salaire salairePndsCourant = null;
    
    p_chronoPeriodesPnds.iterer();
    while (p_chronoPeriodesPnds.encoreSuivant())
    {
      periodePndsCourante = (ObjetChronoPeriode)p_chronoPeriodesPnds.elementSuivant();
      
      salairePndsCourant = new Salaire(periodePndsCourante.getDateDebut(), periodePndsCourante.getDateFin());
      
      salairePndsCourant.setDatePaie(periodePndsCourante.getDateFin());
      salairePndsCourant.setMontantBrutBase(new QuantiteEuro("0"));
      salairePndsCourant.setMontantSoumisAContribution(new QuantiteEuro("0"));
      salairePndsCourant.setMontantIccp(new QuantiteEuro("0"));
      
      salairePndsCourant.setExclus(false);
      salairePndsCourant.setQuantiteAbsence(new Quantite(periodePndsCourante.getDuree(), Unite.get("jour")));
      
      chronoPeriodesSalaireRetournee.ajouter(salairePndsCourant);
    }
    return chronoPeriodesSalaireRetournee;
  }
  
  private static Salaire construireSalaireHorsPnds(ObjetChronoPeriode p_periodeHorsPnds, Salaire p_salaireOrigine)
  {
    Salaire salaireHorsPndsRetourne = null;
    BigDecimal valeurProratisee = null;
    BigDecimal nominateur1Proratisation = null;
    BigDecimal nominateur2Proratisation = null;
    BigDecimal denominateurProratisation = null;
    
    salaireHorsPndsRetourne = new Salaire(p_periodeHorsPnds.getDateDebut(), p_periodeHorsPnds.getDateFin());
    
    nominateur1Proratisation = new BigDecimal(String.valueOf(p_periodeHorsPnds.getDuree()));
    denominateurProratisation = new BigDecimal(String.valueOf(p_salaireOrigine.getDuree()));
    if (p_salaireOrigine.getMontantBrutBase() != null)
    {
      nominateur2Proratisation = p_salaireOrigine.getMontantBrutBase().getValeurMontant();
      valeurProratisee = Mathematiques.proratiser(nominateur1Proratisation, nominateur2Proratisation, denominateurProratisation);
      salaireHorsPndsRetourne.setMontantBrutBase(new QuantiteEuro(valeurProratisee));
    }
    if (p_salaireOrigine.getMontantSoumisAContribution() != null)
    {
      nominateur2Proratisation = p_salaireOrigine.getMontantSoumisAContribution().getValeurMontant();
      valeurProratisee = Mathematiques.proratiser(nominateur1Proratisation, nominateur2Proratisation, denominateurProratisation);
      salaireHorsPndsRetourne.setMontantSoumisAContribution(new QuantiteEuro(valeurProratisee));
    }
    if (p_salaireOrigine.getMontantIccp() != null)
    {
      nominateur2Proratisation = p_salaireOrigine.getMontantIccp().getValeur();
      valeurProratisee = Mathematiques.proratiser(nominateur1Proratisation, nominateur2Proratisation, denominateurProratisation);
      salaireHorsPndsRetourne.setMontantIccp(new QuantiteEuro(valeurProratisee));
    }
    if (p_salaireOrigine.getQuantiteAbsence() != null)
    {
      nominateur2Proratisation = p_salaireOrigine.getQuantiteAbsence().getValeur();
      valeurProratisee = Mathematiques.proratiser(nominateur1Proratisation, nominateur2Proratisation, denominateurProratisation);
      
      valeurProratisee = Mathematiques.arrondiASup(valeurProratisee, 2);
      salaireHorsPndsRetourne.setQuantiteAbsence(new Quantite(valeurProratisee, p_salaireOrigine.getQuantiteAbsence().getUnite()));
    }
    salaireHorsPndsRetourne.setCollectionPND(p_salaireOrigine.getCollectionPND());
    salaireHorsPndsRetourne.setDatePaie(p_salaireOrigine.getDatePaie());
    salaireHorsPndsRetourne.setExclus(p_salaireOrigine.estExclus());
    salaireHorsPndsRetourne.setTauxAbattementFraisProfessionnel(p_salaireOrigine.getTauxAbattementFraisProfessionnel());
    salaireHorsPndsRetourne.setTauxIccp(p_salaireOrigine.getTauxIccp());
    salaireHorsPndsRetourne.setTauxIndemnisationPrecarite(p_salaireOrigine.getTauxIndemnisationPrecarite());
    
    salaireHorsPndsRetourne.setPeriodeActiviteSalarieGaec(p_salaireOrigine.getPeriodeActiviteSalarieGaec());
    
    return salaireHorsPndsRetourne;
  }
}

/* Location:
 * Qualified Name:     OutilSjrPnds
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */