package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.datelimite.asp;

import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDureePeriodeAuMoins;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltreDebutAvantDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ListIterator;

public final class OutilAllongementDateLimiteIndemnisation
{
  private static final int TROIS = 3;
  private static final int SIX = 6;
  private static final int QUINZE = 15;
  private static final int FEVRIER = 2;
  private static final int VINGT_NEUF = 29;
  private static final DureeCalendaire DELAI_DEPART_ALLONGEMENT = new DureeCalendaire(0, 6);
  private static final DureeCalendaire DELAI_MAX_ALLONGEMENT = new DureeCalendaire(0, 15);
  
  public static int determinerAllongement(Damj entreeDispositif, Chronologie periodesParticipantes, Periode periodeRecherche)
  {
    int nombreJours = 0;
    Damj departAllongement = recupererDateDepartCalculAllongement(entreeDispositif);
    
    departAllongement = Damj.max(departAllongement, periodeRecherche.getDebut());
    periodeRecherche.setDebut(departAllongement);
    if (periodeRecherche.getDebut().estAvantOuCoincideAvec(periodeRecherche.getFin())) {
      nombreJours = determinerAllongement(periodeRecherche, periodesParticipantes);
    }
    return nombreJours;
  }
  
  private static int determinerAllongement(Periode periodeRecherche, Chronologie periodesParticipantes)
  {
    int nombreJours = 0;
    if ((periodesParticipantes != null) && (periodesParticipantes.getTaille() > 0))
    {
      ChronologiePeriodes chrono = ((ChronologiePeriodes)periodesParticipantes).fusionnerChevauchementPeriodes();
      nombreJours = periodeRecherche.inter(chrono);
    }
    return nombreJours;
  }
  
  public static Damj decalerDate(Damj date, DureeCalendaire duree)
  {
    if ((date.getMois() == 2) && (date.getJour() == 29)) {
      return date.deplacerVersAvant(duree);
    }
    return date.deplacerVersAvant(duree).veille();
  }
  
  public static Chronologie recupererChronoPeriodesParticipantes(Damj entreeDispositif, Chronologie passePro)
  {
    Damj finPeriode = recupererDateFinAllongementMax(entreeDispositif);
    return recupererSalairesContrat(passePro, entreeDispositif, finPeriode);
  }
  
  private static Chronologie recupererSalairesContrat(Chronologie passePro, Damj dateEntreeDispositif, Damj dateFinDispositif)
  {
    Chronologie chronoSalaires = new ChronologiePeriodes();
    
    FiltresTemporel filtreContrats = new FiltresTemporel();
    filtreContrats.ajouterFiltre(new FiltreActiviteSalarie());
    filtreContrats.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtreContrats.ajouterFiltre(new FiltrePeriodesQualifiables());
    filtreContrats.ajouterFiltre(new FiltreDebutApresDate(dateEntreeDispositif));
    filtreContrats.ajouterFiltre(new FiltreDebutAvantDate(dateFinDispositif.lendemain()));
    filtreContrats.ajouterFiltre(new FiltreDureePeriodeAuMoins(3));
    
    Chronologie contrats = passePro.copier(filtreContrats);
    
    ListIterator<ActiviteSalarie> it = contrats.iterer();
    while (it.hasNext())
    {
      ActiviteSalarie activite = (ActiviteSalarie)it.next();
      chronoSalaires.ajouter(activite.getListeSalaires());
    }
    return chronoSalaires;
  }
  
  public static Damj recupererDateDepartCalculAllongement(Damj dateDebutCsp)
  {
    return dateDebutCsp.deplacerVersAvant(DELAI_DEPART_ALLONGEMENT);
  }
  
  public static Damj recupererDateFinAllongementMax(Damj dateDebutCsp)
  {
    return decalerDate(dateDebutCsp, DELAI_MAX_ALLONGEMENT);
  }
}

/* Location:
 * Qualified Name:     OutilAllongementDateLimiteIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */