package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.CodesMotifsEchec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieDroitOption;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMotifEchec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieDroitOptionSpec;
import fr.unedic.cali.asu.parcours.ParcoursRechercheAlertesNonBloquantes;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.OutilRecuperationMontantSP;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.spec.StrategieDroitOptionElargiSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.ProduitAsuAbstrait;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Map;

public class StrategieDroitOptionElargiApres
  implements StrategieDroitOptionElargiSpec
{
  private static final BigDecimal MAJORATION = BigDecimal.valueOf(1.3D);
  
  public void afficherBilanDroitOption(Demande demande)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = demande.getAttribution();
    if ((attribution != null) && (attribution.getNatureDecision() == 12) && (demande.getDonneesTemporaires().isDroitOptionForce()))
    {
      GammeAsu gamme = GammeAsu.getInstance();
      BigDecimal montantAvant;
      BigDecimal montantAvant;
      if ((attribution.getAttributionPrecedente() == null) && (demande.estEnContexteDroitAnterieurSecteurPublic()))
      {
        OutilRecuperationMontantSP outilSP = OutilRecuperationMontantSP.getInstance();
        MontantBaseSpec montant = outilSP.recupererMontantSP(demande);
        montantAvant = montant.getMontantPrecompteEffectif().getValeur();
      }
      else
      {
        DonneesEntreesRecuperationMontant donneesMontant = gamme.mapperDonneesEntreesRecuperationMontant(attribution.getAttributionPrecedente());
        
        donneesMontant.setDateCalculMontant(attribution.getDateAttribution());
        MontantBaseSpec montant = AppelCalculParLiquidationAsu.determinerMontant(donneesMontant);
        montantAvant = montant.getMontantPrecompteEffectif().getValeur();
      }
      BigDecimal montantApres = attribution.getMontantJournalierBrut().getValeur();
      BigDecimal montantMajore = MAJORATION.multiply(montantAvant).setScale(2, 4);
      
      StringBuffer libelle = new StringBuffer();
      libelle.append("Vérifier que les éléments ci-dessous permettent de valider le droit d'option &lt;br&gt; Montant issu de la reprise : ");
      
      libelle.append(montantAvant.toPlainString());
      libelle.append(" euros&lt;br&gt;Montant issu de la réadmission : ");
      libelle.append(montantApres.toPlainString());
      libelle.append(" euros&lt;br&gt;Montant issu de la reprise + 30% : ");
      libelle.append(montantMajore.toPlainString());
      libelle.append(" euros");
      
      Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes alerte = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      alerte.setLibelleErreur(libelle.toString());
      listePeriodes.add(alerte);
      demande.getAlertesNonBloquantes().put("BILAN_DROIT_OPTION", listePeriodes);
    }
  }
  
  public boolean estDroitOptionForce(Demande demande)
    throws CoucheLogiqueException
  {
    return demande.getDonneesTemporaires().isDroitOptionForce();
  }
  
  public void estDroitOptionPossible(Demande demande)
    throws ApplicativeException
  {
    boolean contexteAspDcPapDc = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9);
    if ((!contexteAspDcPapDc) && (!estDroitOptionApprenti(demande)))
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      if ((attribution != null) && (NaturesDecisions.estdeTypeReprise(attribution.getNatureDecision())) && (!ProduitAsuAbstrait.estDuType(6, attribution.getProduit())))
      {
        ValidationProduit validation = demande.getDossierAffectationAdmission().getValidationProduit();
        leverAlerteDroitOptionPossible(demande, validation);
      }
    }
  }
  
  protected void leverAlerteDroitOptionPossible(Demande demande, ValidationProduit validation)
    throws ApplicativeException
  {
    if ((validation != null) && (validation.isEstProduitValide()))
    {
      enregistrerAlerteDroitOptionPossible(demande);
    }
    else
    {
      Chronologie chronoPnds = demande.getChronologiePNDS(determinerPraLaPlusLongue(demande));
      if ((chronoPnds != null) && (!chronoPnds.estVide())) {
        enregistrerAlerteDroitOptionPossible(demande);
      }
    }
  }
  
  protected Periode determinerPraLaPlusLongue(Demande demande)
    throws CoucheLogiqueException
  {
    ParcoursRechercheAlertesNonBloquantes parcoursRechercheAlertesNonBloquantes = new ParcoursRechercheAlertesNonBloquantes();
    return parcoursRechercheAlertesNonBloquantes.determinerPraLaPlusLongue(demande);
  }
  
  protected void enregistrerAlerteDroitOptionPossible(Demande demande)
  {
    Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
    
    ObjetAlertesNonBloquantes alerte = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
    
    listePeriodes.add(alerte);
    demande.getAlertesNonBloquantes().put("DROIT_OPTION_POSSIBLE", listePeriodes);
  }
  
  public Damj getDateExtinctionReliquat(DemandeSpec demande)
  {
    return demande.getDateRecherche().veille();
  }
  
  public void verifierDroitOptionForce(Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    int natureDecision = ((DecisionSpec)dossierExamen).getNatureDecision();
    if ((demande.getDonneesTemporaires().isDroitOptionForce()) && (NaturesDecisions.estdeTypeRejet(natureDecision)) && (!dossierExamen.estRejetDV()) && (!estRejetAffiliationEtAffiliationValideSansPNDSOuSuiteIPR(dossierExamen)))
    {
      int codeEchec = OutilMotifEchec.retournerPremierMotifEchec(dossierExamen.getListConditionsAttribution());
      String rubrique = (String)CodesMotifsEchec.getLibelleRubriqueEchecCap().get(BigDecimal.valueOf(codeEchec));
      String libelle = "";
      if (rubrique != null) {
        libelle = " (" + rubrique + ")";
      }
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_DROIT_OPTION_REJET", "Le résultat de la liquidation aboutit à un rejet, allez décocher le droit d'option dans l'écran contexte de la demande." + libelle);
    }
  }
  
  protected boolean estRejetAffiliationEtAffiliationValideSansPNDSOuSuiteIPR(DossierExamenAssuranceSpec dossierExamen)
  {
    ConditionQuantiteAffiliationSpec conditionQuantiteAffiliation = dossierExamen.getConditionQuantiteAffiliation();
    return (conditionQuantiteAffiliation != null) && (!conditionQuantiteAffiliation.estSatisfait()) && (("P".equals(conditionQuantiteAffiliation.getEtatPndsPourCalculAffi())) || ("N".equals(conditionQuantiteAffiliation.getEtatPndsPourCalculAffi())));
  }
  
  public boolean estDroitOptionApprenti(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    StrategieDroitOptionSpec strategie = (StrategieDroitOptionSpec)FabriqueStrategieDroitOption.getInstance().getStrategie(critere);
    
    return strategie.estDetectionAutoDroitOption(demande);
  }
}

/* Location:
 * Qualified Name:     StrategieDroitOptionElargiApres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */