package fr.unedic.cali.asu.spe02.p03.avant.outilsfonctionnels;

import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.ConsommationPeriodes;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class TraitementPeriodesAnalyseAvant
{
  public static void traitementDesPeriodesAnalyses(AttributionSpec attribution, UniteTraitementAvant utAvant, ChronologiePeriodes periodesAnalyse, QualificationPeriodes qualificationPeriodes, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    Quantite quantiteAImputerSurLaPA = null;
    PeriodeAnalyseSpec pa = null;
    Damj dateDebutConsommationSurPa = null;
    
    DureeConsommableAvant dureePmc = (DureeConsommableAvant)utAvant.getDureePmcEnDebutUT().copie();
    DureeConsommableAvant dureeDiffereStandard = (DureeConsommableAvant)utAvant.getDureeDiffereStandardEnDebutUT().copie();
    DureeConsommableAvant dureeDiffereSpecifique = (DureeConsommableAvant)utAvant.getDureeDiffereSpecifiqueEnDebutUT().copie();
    DureeConsommableAvant dureeDelaiAttente = (DureeConsommableAvant)utAvant.getDureeDelaiAttenteEnDebutUT().copie();
    
    periodesAnalyse.iterer();
    while (periodesAnalyse.encoreSuivant())
    {
      Quantite quantiteRestante = null;
      pa = (PeriodeAnalyseSpec)periodesAnalyse.elementSuivant();
      pa.setQuantiteIndemnisable(new QuantiteJour(new BigDecimal(pa.getDuree())));
      dateDebutConsommationSurPa = pa.getDateDebut();
      quantiteAImputerSurLaPA = pa.getQuantiteIndemnisable().soustraire(pa.getQuantiteNonIndemnisee());
      quantiteRestante = new Quantite(quantiteAImputerSurLaPA.getValeur(), quantiteAImputerSurLaPA.getUnite());
      
      quantiteRestante = gestionPmcNonEpuisee(utAvant, quantiteAImputerSurLaPA, dureePmc, dateDebutConsommationSurPa, quantiteRestante);
      if (verificationDiffStandardNonEpuise(dureeDiffereStandard, quantiteRestante))
      {
        DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerSurLaPA.soustraire(quantiteRestante).getValeurEntiere());
        dateDebutConsommationSurPa = pa.getDateDebut().deplacerVersAvant(d);
        if (dateDebutConsommationSurPa.estAvant(attribution.getDateAttribution()))
        {
          if (attribution.getDateAttribution().estContenueDans(pa.getPeriode()))
          {
            quantiteRestante = quantiteRestante.soustraire(new QuantiteJour(BigDecimal.valueOf(attribution.getDateAttribution().joursEntre(dateDebutConsommationSurPa))));
            dateDebutConsommationSurPa = attribution.getDateAttribution();
          }
        }
        else
        {
          gestionDiffStandardNonActif(utAvant, dureeDiffereStandard, dateDebutConsommationSurPa);
          
          quantiteRestante = consommationDiffStandard(utAvant, qualificationPeriodes, pa, dateDebutConsommationSurPa, dureeDiffereStandard, quantiteRestante);
        }
      }
      else
      {
        quantiteRestante = gestionDiffereSpecifique(utAvant, quantiteAImputerSurLaPA, dureeDiffereSpecifique, pa, quantiteRestante);
        if ((quantiteRestante.getValeur().compareTo(BigDecimal.valueOf(0L)) > 0) && (dureeDelaiAttente.getEtat() != 2))
        {
          DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerSurLaPA.soustraire(quantiteRestante).getValeurEntiere());
          dateDebutConsommationSurPa = pa.getDateDebut().deplacerVersAvant(d);
          if (dateDebutConsommationSurPa.estAvant(attribution.getDateAttribution()))
          {
            if (!attribution.getDateAttribution().estContenueDans(pa.getPeriode())) {
              continue;
            }
            quantiteRestante = quantiteRestante.soustraire(new QuantiteJour(BigDecimal.valueOf(attribution.getDateAttribution().joursEntre(dateDebutConsommationSurPa))));
            dateDebutConsommationSurPa = attribution.getDateAttribution();
          }
          if (doitTraiterDA(utAvant, qualificationPeriodes, dureeDelaiAttente, pa, dateDebutConsommationSurPa)) {
            gestionImputationDA(utAvant, arretProduitAvecRaison, dureeDelaiAttente, pa, dateDebutConsommationSurPa, quantiteRestante);
          }
        }
        postTraitementPa(utAvant, pa);
      }
    }
    utAvant.setDureePmcEnFinUT(dureePmc);
    utAvant.setDureeDiffereStandardEnFinUT(dureeDiffereStandard);
    utAvant.setDureeDiffereSpecifiqueEnFinUT(dureeDiffereSpecifique);
    utAvant.setDureeDelaiAttenteEnFinUT(dureeDelaiAttente);
    
    utAvant.setPmcConsomme(pmcConsomme(utAvant));
    utAvant.setDiffereStandardConsomme(differeStandardConsomme(utAvant));
    utAvant.setDiffereSpecifiqueConsomme(differeSpecifiqueConsomme(utAvant));
    utAvant.setDelaiAttenteConsomme(delaiAttenteConsomme(utAvant));
  }
  
  private static Quantite consommationDiffStandard(UniteTraitementAvant utAvant, QualificationPeriodes qualificationPeriodes, PeriodeAnalyseSpec pa, Damj dateDebutConsommationSurPa, DureeConsommableAvant dureeDiffereStandard, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (!TraitementPeriodesAvant.traitementPeriodesSuspensives(pa, qualificationPeriodes)) {
      quantiteRestanteTmp = TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantite(quantiteRestanteTmp, dureeDiffereStandard, utAvant, dateDebutConsommationSurPa);
    } else {
      quantiteRestanteTmp = new QuantiteJour("0");
    }
    return quantiteRestanteTmp;
  }
  
  private static Quantite gestionPmcNonEpuisee(UniteTraitementAvant utAvant, Quantite quantiteAImputerSurLaPA, DureeConsommableAvant dureePmc, Damj dateDebutConsommationSurPa, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (dureePmc.getEtat() != 2) {
      quantiteRestanteTmp = TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantite(quantiteAImputerSurLaPA, dureePmc, utAvant, dateDebutConsommationSurPa);
    }
    return quantiteRestanteTmp;
  }
  
  private static boolean verificationDiffStandardNonEpuise(DureeConsommableAvant dureeDiffereStandard, Quantite quantiteRestante)
  {
    return (quantiteRestante.getValeur().compareTo(BigDecimal.valueOf(0L)) > 0) && (dureeDiffereStandard.getQuantiteInitial().getValeurEntiere() > 0) && (dureeDiffereStandard.getEtat() != 2);
  }
  
  private static void gestionDiffStandardNonActif(UniteTraitementAvant utAvant, DureeConsommableAvant dureeDiffereStandard, Damj dateDebutConsommationSurPa)
  {
    if (dureeDiffereStandard.getEtat() != 1)
    {
      dureeDiffereStandard.activer();
      if (dureeDiffereStandard.getQuantiteInitial().getValeurEntiere() > 0) {
        utAvant.getConsommationPeriodes().setPeriodeDiffereStandard(new Periode(dateDebutConsommationSurPa));
      }
    }
  }
  
  private static boolean doitTraiterDA(UniteTraitementAvant utAvant, QualificationPeriodes qualificationPeriodes, DureeConsommableAvant dureeDelaiAttente, PeriodeAnalyseSpec pa, Damj dateDebutConsommationSurPa)
    throws CoucheLogiqueException
  {
    return (!TraitementPeriodesAvant.traitementPeriodesSuspensivesPourDebutConsommationDelaiAttente(pa, qualificationPeriodes, utAvant.getConsommationPeriodes().getPeriodeDelaiAttente() == null ? dateDebutConsommationSurPa : utAvant.getConsommationPeriodes().getPeriodeDelaiAttente().getDebut())) || (verificationQuantiteDA(dureeDelaiAttente));
  }
  
  private static void gestionImputationDA(UniteTraitementAvant utAvant, ArretProduitAvecRaison arretProduitAvecRaison, DureeConsommableAvant dureeDelaiAttente, PeriodeAnalyseSpec pa, Damj dateDebutConsommationSurPa, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    if (dureeDelaiAttente.getEtat() != 1)
    {
      dureeDelaiAttente.activer();
      if (dureeDelaiAttente.getQuantiteInitial().getValeurEntiere() > 0)
      {
        Periode p = new Periode(dateDebutConsommationSurPa);
        utAvant.getConsommationPeriodes().setPeriodeDelaiAttente(p);
      }
    }
    TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantiteEtTerminerProduit(quantiteRestante, pa, dureeDelaiAttente, utAvant, dateDebutConsommationSurPa, arretProduitAvecRaison);
  }
  
  private static Quantite gestionDiffereSpecifique(UniteTraitementAvant utAvant, Quantite quantiteAImputerSurLaPA, DureeConsommableAvant dureeDiffereSpecifique, PeriodeAnalyseSpec pa, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (verificationDiffStandardNonEpuise(dureeDiffereSpecifique, quantiteRestanteTmp))
    {
      DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerSurLaPA.soustraire(quantiteRestanteTmp).getValeurEntiere());
      Damj dateDebutConsommationSurPa = pa.getDateDebut().deplacerVersAvant(d);
      if (dureeDiffereSpecifique.getEtat() != 1)
      {
        dureeDiffereSpecifique.activer();
        if (dureeDiffereSpecifique.getQuantiteInitial().getValeurEntiere() > 0)
        {
          Periode p = new Periode(dateDebutConsommationSurPa);
          utAvant.getConsommationPeriodes().setPeriodeDiffereSpecifique(p);
        }
      }
      quantiteRestanteTmp = TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantite(quantiteRestanteTmp, dureeDiffereSpecifique, utAvant, dateDebutConsommationSurPa);
    }
    return quantiteRestanteTmp;
  }
  
  private static boolean verificationQuantiteDA(DureeConsommableAvant dureeDelaiAttente)
  {
    return (dureeDelaiAttente != null) && (dureeDelaiAttente.getQuantiteInitial() != null) && (dureeDelaiAttente.getQuantiteCourante() != null) && (dureeDelaiAttente.getQuantiteInitial().getValeurEntiere() != dureeDelaiAttente.getQuantiteCourante().getValeurEntiere());
  }
  
  private static void postTraitementPa(UniteTraitementAvant utAvant, PeriodeAnalyseSpec pa)
    throws CoucheLogiqueException
  {
    if (pa.isProduitATerminerApresPA()) {
      utAvant.setProduitATerminerApresUT(pa.isProduitATerminerApresPA());
    }
  }
  
  private static Quantite pmcConsomme(UniteTraitementAvant utAvant)
  {
    Quantite pmcConsomme;
    Quantite pmcConsomme;
    if (utAvant.getDureePmcEnFinUT().getEtat() == 0)
    {
      pmcConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite pmcConsomme;
      if (utAvant.getDureePmcEnDebutUT().getEtat() == 0) {
        pmcConsomme = utAvant.getDureePmcEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureePmcEnFinUT().getQuantiteCourante());
      } else {
        pmcConsomme = utAvant.getDureePmcEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureePmcEnFinUT().getQuantiteCourante());
      }
    }
    return pmcConsomme;
  }
  
  private static Quantite differeStandardConsomme(UniteTraitementAvant utAvant)
  {
    Quantite differeStandardConsomme;
    Quantite differeStandardConsomme;
    if (utAvant.getDureeDiffereStandardEnFinUT().getEtat() == 0)
    {
      differeStandardConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite differeStandardConsomme;
      if (utAvant.getDureeDiffereStandardEnDebutUT().getEtat() == 0) {
        differeStandardConsomme = utAvant.getDureeDiffereStandardEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDiffereStandardEnFinUT().getQuantiteCourante());
      } else {
        differeStandardConsomme = utAvant.getDureeDiffereStandardEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDiffereStandardEnFinUT().getQuantiteCourante());
      }
    }
    return differeStandardConsomme;
  }
  
  private static Quantite differeSpecifiqueConsomme(UniteTraitementAvant utAvant)
  {
    Quantite differeSpecifiqueConsomme;
    Quantite differeSpecifiqueConsomme;
    if (utAvant.getDureeDiffereSpecifiqueEnFinUT().getEtat() == 0)
    {
      differeSpecifiqueConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite differeSpecifiqueConsomme;
      if (utAvant.getDureeDiffereSpecifiqueEnDebutUT().getEtat() == 0) {
        differeSpecifiqueConsomme = utAvant.getDureeDiffereSpecifiqueEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDiffereSpecifiqueEnFinUT().getQuantiteCourante());
      } else {
        differeSpecifiqueConsomme = utAvant.getDureeDiffereSpecifiqueEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDiffereSpecifiqueEnFinUT().getQuantiteCourante());
      }
    }
    return differeSpecifiqueConsomme;
  }
  
  private static Quantite delaiAttenteConsomme(UniteTraitementAvant utAvant)
  {
    Quantite delaiAttenteConsomme;
    Quantite delaiAttenteConsomme;
    if (utAvant.getDureeDelaiAttenteEnFinUT().getEtat() == 0)
    {
      delaiAttenteConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite delaiAttenteConsomme;
      if (utAvant.getDureeDelaiAttenteEnDebutUT().getEtat() == 0) {
        delaiAttenteConsomme = utAvant.getDureeDelaiAttenteEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDelaiAttenteEnFinUT().getQuantiteCourante());
      } else {
        delaiAttenteConsomme = utAvant.getDureeDelaiAttenteEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDelaiAttenteEnFinUT().getQuantiteCourante());
      }
    }
    return delaiAttenteConsomme;
  }
}

/* Location:
 * Qualified Name:     TraitementPeriodesAnalyseAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */