package fr.unedic.cali.asu.spe02.p03.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsAlimentationDonneesCalculMontant;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjm;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.FormuleMontantAREF;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantSpectacle;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.parcours.DomAvantPilotage;
import fr.unedic.cali.parcours.ParcoursAvantPilotageElementsIndemnisation;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final String LIB_ERREUR = "La condition de durée d’indemnisation n’est pas applicable à l’ARE SPE 06 R07";
  private static final int DIX = 10;
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, true);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    StringBuffer message = new StringBuffer("Erreur inconnue dans l'exécution de l'application");
    message.append(" : ");
    message.append("La condition de durée d’indemnisation n’est pas applicable à l’ARE SPE 06 R07");
    throw new CoucheLogiqueException("HG_PR_CALI_L_ERR_GENERIQUE", message.toString(), null);
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return null;
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return false;
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneral();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantAREF();
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    DomAvantPilotage domAvantPilotage = null;
    Contexte contexteCalcul = null;
    Parcours parcoursAvant = null;
    ResultatAvant resultat = null;
    Damj premierJourAvantPourLiquidation = null;
    
    domAvantPilotage = new DomAvantPilotage(attribution);
    contexteCalcul = new Contexte();
    contexteCalcul.setDonnees(domAvantPilotage);
    
    parcoursAvant = new ParcoursAvantPilotageElementsIndemnisation();
    
    resultat = (ResultatAvant)parcoursAvant.effectuerParcours(contexteCalcul);
    
    premierJourAvantPourLiquidation = resultat.getPremierJourAvant();
    if ((premierJourAvantPourLiquidation != null) && (premierJourAvantPourLiquidation.estAvant(attribution.getDateAttribution()))) {
      premierJourAvantPourLiquidation = attribution.getDateAttribution();
    }
    if ((premierJourAvantPourLiquidation == null) || (resultat.getDernierJourAvant().estAvant(premierJourAvantPourLiquidation))) {
      return null;
    }
    return new Periode(premierJourAvantPourLiquidation, resultat.getDernierJourAvant());
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    Damj dateAttribution = null;
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    DonneesCalculMontantSpectacle donneesCalculMontantSpectacle = donneesEntreesRecuperationMontant.getDonneesCalculMontantSpectacle();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    OutilsAlimentationDonneesCalculMontant.alimenterDonneesEbiSpectacle(donneesCalculMontantSpectacle, elementBaseIndemnisationCourant);
    
    BigDecimal plafondSR = recupererPlafondSR(dateCalcul, elementBaseIndemnisationCourant);
    
    BigDecimal sr = RevalorisationSalaire.revaloriserSrip(elementBaseIndemnisationCourant.getSalaireReference(), plafondSR, dateCalcul);
    SalaireReference srRevalorise = new SalaireReference(sr, dateCalcul);
    elementBaseIndemnisationCourant.setSalaireReference(srRevalorise);
    
    SalaireReference srrp = RevalorisationSalaire.determinerSrrp(elementBaseIndemnisationCourant.getSalaireReference(), elementBaseIndemnisationCourant.getNbJoursEmploiSurPrc(), dateCalcul);
    
    Sjm sjmrp = recupereSJM(elementBaseIndemnisationCourant, srrp, dateCalcul);
    if (elementBaseIndemnisationCourant.isClauseRattrapage()) {
      elementBaseIndemnisationCourant.setSalaireJournalier(donneesCalculMontant.getSalaireJournalier());
    }
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      Boolean gerePensionInvalidite = donneesCalculMontant.getEstProduitGerantPensionInvalidite();
      if ((gerePensionInvalidite != null) && (gerePensionInvalidite.booleanValue()))
      {
        elementBaseIndemnisationCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
        
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, individu, dateCalcul, dateAttribution));
      }
      else
      {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = BigDecimal.ZERO;
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjmrp != null) && (sjmrp.getSalaire() != null) && (!sjmrp.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjmrp.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjmrp.getSalaire()));
      
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal("0.00"));
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.TRUE);
    }
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
  
  protected BigDecimal recupererPlafondSR(Damj dateCalcul, ElementBaseIndemnisation elementBaseIndemnisationCourant)
  {
    return DeterminationSalaireReference.determinerPlafondSrr(elementBaseIndemnisationCourant.getNbJoursEmploiSurPrc(), dateCalcul);
  }
  
  protected Sjm recupereSJM(ElementBaseIndemnisation elementBaseIndemnisationCourant, SalaireReference srrp, Damj dateCalcul)
  {
    Sjm sjmrp = RevalorisationSalaire.determinerSjmrp(srrp, elementBaseIndemnisationCourant.getCoefficientHoraireJour(), elementBaseIndemnisationCourant.getNombreHeuresTravailleesPlafonnees(), dateCalcul);
    
    return sjmrp;
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec attribution, Damj dateCalcul)
  {
    return null;
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec fm = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      fm = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      fm = getFormuleMontantEnFormation();
    } else {
      fm = getFormuleMontant();
    }
    return fm.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */