package fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclareeSanction;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ActiviteReduite
{
  private static final BigDecimal NB_HEURE_ANNEXE_8 = new BigDecimal("8");
  private static final BigDecimal NB_HEURE_ANNEXE_10 = BigDecimal.TEN;
  private static final BigDecimal COEF_ANNEXE_8 = new BigDecimal("1.4").divide(NB_HEURE_ANNEXE_8);
  private static final BigDecimal COEF_ANNEXE_10 = new BigDecimal("1.3").divide(NB_HEURE_ANNEXE_10);
  public static final int CUMUL_AR_DUREE_INDEMNISATION_MAX = 15;
  public static final int CUMUL_AR_TREIZIEME_MOIS = 13;
  
  public static BigDecimal calculerGainRetenu(Chronologie periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    
    Chronologie chronoFiltree = periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (!(periodeCourante instanceof PansNonInstallee)) {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu;
  }
  
  public ResultatActiviteReduite genererEvenementActiviteReduite(Chronologie periodeEmploi, UniteTraitement ut, String reglementAttribution)
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    BigDecimal cumulNbHeures = BigDecimal.ZERO;
    
    BigDecimal cumulGainActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    BigDecimal cumulHeureActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    BigDecimal cumulGainPNDS = BigDecimal.ZERO;
    BigDecimal cumulNbJourTravail = BigDecimal.ZERO;
    BigDecimal cumulGain = BigDecimal.ZERO;
    Chronologie periodesEmploiCourantes = periodeEmploi.copier(new FiltrePeriodeTravailCalcul());
    PeriodeTravail periodeCourante = null;
    if (contientPeriodeEmploiCourante(periodesEmploiCourantes))
    {
      periodesEmploiCourantes.iterer();
      while (periodesEmploiCourantes.encoreSuivant())
      {
        periodeCourante = (PeriodeTravail)periodesEmploiCourantes.elementSuivant();
        if ((periodeCourante instanceof PeriodeNonDeclareeSanction)) {
          cumulGainPNDS = cumulGainPNDS.add(((PeriodeNonDeclareeSanction)periodeCourante).getGain());
        }
        if ((periodeCourante instanceof PeriodeTravailJustifiee))
        {
          cumulGainJustifie = cumulGainJustifie.add(periodeCourante.getGain());
          cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeCourante.getNombreHeures());
        }
        if (((periodeCourante instanceof PansNonInstallee)) || ((periodeCourante instanceof Pans)))
        {
          if ((periodeCourante.getNombreHeures() == null) || (periodeCourante.getNombreHeures().compareTo(BigDecimal.ZERO) == 0)) {
            cumulHeureActiviteNonSalarieeNonInstallee = cumulHeureActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain().divide(getSmicHoraire(ut.getDateDebut()), 4));
          } else {
            cumulHeureActiviteNonSalarieeNonInstallee = cumulHeureActiviteNonSalarieeNonInstallee.add(periodeCourante.getNombreHeures());
          }
          cumulGainActiviteNonSalarieeNonInstallee = cumulGainActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain());
        }
        else
        {
          cumulNbJourTravail = cumulNbJourTravail.add(new BigDecimal(periodeCourante.getDuree()));
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          cumulGain = cumulGain.add(periodeCourante.getGain());
        }
      }
    }
    cumulNbHeures = cumulNbHeures.add(cumulHeureActiviteNonSalarieeNonInstallee);
    
    BigDecimal nbJoursDecalage = null;
    BigDecimal nbjourTravaille = null;
    if (reglementAttribution.equalsIgnoreCase("A8"))
    {
      nbjourTravaille = Mathematiques.tronque(cumulNbHeures.divide(NB_HEURE_ANNEXE_8), 0);
      nbJoursDecalage = Mathematiques.tronque(cumulNbHeures.multiply(COEF_ANNEXE_8), 0);
      evtRetour.setCoefJourMajore(COEF_ANNEXE_8);
    }
    else
    {
      nbjourTravaille = Mathematiques.tronque(cumulNbHeures.divide(NB_HEURE_ANNEXE_10), 0);
      nbJoursDecalage = Mathematiques.tronque(cumulNbHeures.multiply(COEF_ANNEXE_10), 0);
      evtRetour.setCoefJourMajore(COEF_ANNEXE_10);
    }
    valorisationNeutralisation(reglementAttribution, evtRetour, nbjourTravaille);
    
    evtRetour.setCreditDecalage(nbJoursDecalage);
    
    evtRetour.setNbHeuresPrisesEnCompte(cumulNbHeures);
    
    evtRetour.setCumulGainJustifie(cumulGainJustifie.setScale(2, 0));
    evtRetour.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    
    evtRetour.setCumulJourDeTravail(cumulNbJourTravail);
    evtRetour.setGainPrisEnCompte(cumulGain.add(cumulGainActiviteNonSalarieeNonInstallee).setScale(2, 0));
    
    evtRetour.setCumulGainPNDS(cumulGainPNDS);
    return evtRetour;
  }
  
  private void valorisationNeutralisation(String reglementAttribution, ResultatActiviteReduite evtRetour, BigDecimal nbJoursDecalage)
  {
    boolean estneutralise = verificationSeuilNeutralisant(nbJoursDecalage, reglementAttribution);
    evtRetour.setNeutralise(estneutralise);
    if (estneutralise) {
      evtRetour.setTypeNeutralisation(13);
    }
  }
  
  private boolean contientPeriodeEmploiCourante(Chronologie periodesEmploiCourantes)
  {
    return (periodesEmploiCourantes != null) && (!periodesEmploiCourantes.estVide());
  }
  
  protected static BigDecimal getSmicHoraire(Damj date)
  {
    return ParametresIndemnisation.getParametresIndemnisation().getElementActif(date.getDebutMois()).getSmicHoraire();
  }
  
  protected boolean verificationSeuilNeutralisant(BigDecimal nbJoursDecalage, String reglementAttribution)
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */