package fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjm;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class RevalorisationSalaire
{
  private static final int SIX_MOIS = 6;
  
  public static BigDecimal revaloriserSrip(SalaireReference srip, BigDecimal montantPlafond, Damj dateRevalorisation)
  {
    BigDecimal montantSrrp = srip.getSalaire();
    if (dateRevalorisation.estApres(srip.getDateDepart())) {
      montantSrrp = appliquerRevalorisation(montantSrrp, srip, dateRevalorisation);
    }
    montantSrrp = montantSrrp.min(montantPlafond);
    
    return montantSrrp;
  }
  
  private static BigDecimal appliquerRevalorisation(BigDecimal srrp, SalaireReference srip, Damj dateRevalorisation)
  {
    BigDecimal montantSrrp = srrp;
    
    ParametresIndemnisation param = ParametresIndemnisation.getParametresIndemnisation();
    Chronologie chronoParam = param.getParametresActifs(new Periode(srip.getDateDepart(), dateRevalorisation));
    if (!chronoParam.estVide())
    {
      BigDecimal revalAAppliquer = new BigDecimal("1");
      chronoParam.iterer();
      while (chronoParam.encoreSuivant())
      {
        EvenementParametre evtCourant = (EvenementParametre)chronoParam.elementSuivant();
        if ((evtCourant.isNouveauRevalorisationSjr()) && (!srip.getDateDepart().deplacerVersAvant(new DureeCalendaire(0, 6, 1)).estApres(evtCourant.getDateEffet()))) {
          revalAAppliquer = revalAAppliquer.multiply(new BigDecimal("1").add(evtCourant.getRevalorisationSjr()));
        }
      }
      montantSrrp = srip.getSalaire().multiply(revalAAppliquer);
      montantSrrp = Mathematiques.tronque(montantSrrp, 2);
    }
    return montantSrrp;
  }
  
  public static SalaireReference determinerSrrp(SalaireReference srip, int nbJoursEmploiPrc, Damj dateRevalorisation)
  {
    BigDecimal plafondSrr = DeterminationSalaireReference.determinerPlafondSrr(nbJoursEmploiPrc, dateRevalorisation);
    
    BigDecimal srrp = revaloriserSrip(srip, plafondSrr, dateRevalorisation);
    
    SalaireReference srrpRetourne = new SalaireReference(srrp, srip.getDateDepart());
    
    return srrpRetourne;
  }
  
  public static Sjm determinerSjmrp(SalaireReference srrp, int coefficientHoraireJour, BigDecimal nbreHeuresTravailleesPlafonnees, Damj dateRevalorisation)
  {
    QuantiteEuro sjmr = DeterminationSalaireJournalierMoyen.getInstance().determinerSalaireJournalierMoyenRevalorise(new QuantiteEuro(srrp.getMontant().getValeur()), coefficientHoraireJour, nbreHeuresTravailleesPlafonnees);
    
    QuantiteEuro plafondSjmr = DeterminationSalaireJournalierMoyen.getInstance().determinerPlafondSjmr(dateRevalorisation);
    
    BigDecimal valeurSjmrp = sjmr.getValeurMontant().min(plafondSjmr.getValeurMontant());
    Sjm sjmrpRetourne = new Sjm(valeurSjmrp, srrp.getDateDepart());
    sjmrpRetourne.setRevalorise(true);
    return sjmrpRetourne;
  }
  
  public static Sjm revaloriserSjr(ElementBaseIndemnisation ebi, ProduitAsuSpec produit, Damj date)
  {
    return OutilMappingSjmSjr.convertirSjm(produit.revaloriserSalaireJournalier(ebi, date));
  }
  
  public static Sjm revaloriserSjrTranche(AttributionSpec attribution, Damj date)
  {
    TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attribution);
    
    SalaireReference srrp = determinerSrrp(tranche.getSalaireReferenceInitialSpectacle(), tranche.getNombreJoursEmploiDansPRC(), date);
    
    Sjm sjmrp = determinerSjmrp(srrp, tranche.getCoefficientHoraireJour(), tranche.getNombreHeuresTravailleesPlafonne(), date);
    
    return OutilMappingSjmSjr.convertirSjm(sjmrp);
  }
}

/* Location:
 * Qualified Name:     RevalorisationSalaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */