package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.asu.dom.ConditionMontantNonNulSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.ConditionValiditeReliquatSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.DossierExamenGen;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.List;

public abstract class DossierExamen
  extends DossierExamenGen
  implements DossierExamenAssuranceSpec
{
  private transient AccesseurDroits m_accesseurDroits;
  private transient AttributionAssuranceSpec m_attributionPrecedente;
  private transient CompetenceSpec m_competence;
  
  public DossierExamen(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public DossierExamen()
  {
    setConditionAttributionAdmission(new ConditionsAttributionAdmission());
    setConditionAttributionReprise(new ConditionsAttributionReprise());
    setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    setConstitutionElementsReprise(new ConstitutionElementsReprise());
  }
  
  public DossierExamen(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
    setConditionAttributionAdmission(new ConditionsAttributionAdmission());
    setConditionAttributionReprise(new ConditionsAttributionReprise());
    setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    setConstitutionElementsReprise(new ConstitutionElementsReprise());
  }
  
  protected void copie(DossierExamen p_source)
  {
    if (p_source == null) {
      return;
    }
    if (p_source.getConditionAttributionAdmission() == null) {
      p_source.setConditionAttributionAdmission(new ConditionsAttributionAdmission());
    }
    p_source.getConditionAttributionAdmission().copieElements(getConditionAttributionAdmission());
    if (p_source.getConstitutionElementsAdmission() == null) {
      p_source.setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    p_source.getConstitutionElementsAdmission().copieElements(getConstitutionElementsAdmission());
    if (p_source.getConditionAttributionReprise() == null) {
      p_source.setConditionAttributionReprise(new ConditionsAttributionReprise());
    }
    p_source.getConditionAttributionReprise().copieElements(getConditionAttributionReprise());
    if (p_source.getConstitutionElementsReprise() == null) {
      p_source.setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    p_source.getConstitutionElementsReprise().copieElements(getConstitutionElementsReprise());
    
    setAttributionPrecedente(p_source.getAttributionPrecedente());
    setDossierAffecte(p_source.getDossierAffecte());
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    DossierExamen copie = (DossierExamen)p_copie;
    super.copieElements(copie);
    copie.setMotifRejetNotifie(getMotifRejetNotifie());
    if (getConditionAttributionAdmission() == null) {
      setConditionAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionAttributionAdmission().copieElements(copie.getConditionAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copie.getConstitutionElementsAdmission());
    if (getConditionAttributionReprise() == null) {
      setConditionAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionAttributionReprise().copieElements(copie.getConditionAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copie.getConstitutionElementsReprise());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(getConditionAttributionAdmission());
    DomManager.persisterEnProfondeur(getConditionAttributionReprise());
    DomManager.persisterEnProfondeur(getConstitutionElementsAdmission());
    DomManager.persisterEnProfondeur(getConstitutionElementsReprise());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public DossierExamenSpec changerEtat(int p_typeDossierExamen)
    throws CoucheLogiqueException
  {
    DossierExamen nouveauDossier = null;
    switch (p_typeDossierExamen)
    {
    case 0: 
      nouveauDossier = new Examen();
      break;
    case 10: 
    case 35: 
      nouveauDossier = new Od();
      break;
    case 11: 
    case 26: 
      nouveauDossier = new Readmission();
      break;
    case 16: 
    case 28: 
    case 33: 
    case 36: 
      nouveauDossier = new Rejet();
      break;
    case 3: 
      nouveauDossier = new Reprise();
      break;
    case 1: 
    case 2: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 12: 
    case 13: 
    case 14: 
    case 15: 
    case 17: 
    case 18: 
    case 19: 
    case 20: 
    case 21: 
    case 22: 
    case 23: 
    case 24: 
    case 25: 
    case 27: 
    case 29: 
    case 30: 
    case 31: 
    case 32: 
    case 34: 
    default: 
      throw new UnsupportedOperationException("Impossible de changer l'etat du dossier d'examen vers le nouvel etat : " + p_typeDossierExamen);
    }
    nouveauDossier.copie(this);
    return nouveauDossier;
  }
  
  public Damj getDateAttribution()
  {
    if (getConstitutionElementsActifs().getConstitutionDateAttribution() != null) {
      return getConstitutionElementsActifs().getConstitutionDateAttribution().getDateAttribution();
    }
    return null;
  }
  
  public DemandeSpec getDemande()
  {
    return getDossierAffecte().getDemande();
  }
  
  public boolean estDroitSaisonnier()
  {
    return false;
  }
  
  public boolean estRejetDV()
  {
    return (getConditionsAttributionActives().getConditionChomageInvolontaire() != null) && (!getConditionsAttributionActives().getConditionChomageInvolontaire().estSatisfait());
  }
  
  public AccesseurDroitsSpec getAccesseurDroits()
  {
    return m_accesseurDroits != null ? m_accesseurDroits : new AccesseurDroits(this);
  }
  
  public AttributionAssuranceSpec getAttributionPrecedente()
  {
    if (((Demande)getDemande()).getDemandeOrigine() != null) {
      setAttributionPrecedente(((Demande)getDemande()).getDemandeOrigine().getAttribution());
    }
    return m_attributionPrecedente;
  }
  
  public void setAttributionPrecedente(AttributionAssuranceSpec p_decisionPrecedente)
  {
    m_attributionPrecedente = p_decisionPrecedente;
  }
  
  public CompetenceSpec getCompetence()
  {
    if (m_competence == null) {
      m_competence = new Competence();
    }
    return m_competence;
  }
  
  public ConditionQuantiteAffiliationSpec getConditionQuantiteAffiliation()
  {
    if ((getConditionAttributionAdmission().getConditionQuantiteAffiliation() != null) && (getConditionAttributionAdmission().getConditionQuantiteAffiliation().getValidationProduit() == null)) {
      getConditionAttributionAdmission().getConditionQuantiteAffiliation().setValidationProduit(getValidationProduit());
    }
    return getConditionAttributionAdmission().getConditionQuantiteAffiliation();
  }
  
  public ContributionParticuliereSpec getContributionParticuliere()
  {
    return null;
  }
  
  public FaitGenerateurSpec getFaitGenerateur()
  {
    return getConditionFaitGenerateur();
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    if (getValidationProduit() != null) {
      return getValidationProduit().getJustificationAffiliation();
    }
    return null;
  }
  
  public ReglementApplicableSpec getReglementApplicable()
  {
    return getConstitutionReglementApplicable();
  }
  
  public void setContributionParticuliere(ContributionParticuliereSpec p_contributionParticuliere) {}
  
  public abstract ConditionsAttributionSpec getConditionsAttributionActives();
  
  public abstract ConstitutionElementsSpec getConstitutionElementsActifs();
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    return getConditionAttributionAdmission().getConditionFaitGenerateur();
  }
  
  public ConditionValiditeReliquatSpec getConditionValiditeReliquat()
  {
    return getConditionAttributionReprise().getConditionValiditeReliquat();
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    return getConstitutionElementsAdmission().getConstitutionReglementApplicable();
  }
  
  public ConstitutionNbHeuresTravaillees getConstitutionNbHeuresTravaillees()
  {
    return getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees();
  }
  
  public ConstitutionSalaireReference getConstitutionSalaireReference()
  {
    return getConstitutionElementsAdmission().getConstitutionSalaireReference();
  }
  
  public ConstitutionSalaireJournalierMoyen getConstitutionSalaireJournalierMoyen()
  {
    return getConstitutionElementsAdmission().getConstitutionSalaireJournalierMoyen();
  }
  
  public ValidationProduit getValidationProduit()
  {
    return (ValidationProduit)((DossierAffecte)getDossierAffecte()).getValidationProduit();
  }
  
  public void setDossierAffecte(DossierAffectationSpec p_dossierAffectation)
  {
    super.setDossierAffecte(p_dossierAffectation);
    if ((p_dossierAffectation != null) && (p_dossierAffectation.getDossierExamen() != this)) {
      p_dossierAffectation.setDossierExamen(this);
    }
  }
  
  public Damj getDateEvenement()
  {
    return getDateAttribution();
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsActifs().getConstitutionMontantsBruts();
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsActifs().getConstitutionDurees();
  }
  
  public Quantite getDureeRestanteAImputerFinCSP()
  {
    return null;
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsActifs().getConstitutionDateAttribution();
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation();
  }
  
  public ConstitutionDelaisReport getConstitutionDelaisReport()
  {
    return getConstitutionElementsActifs().getConstitutionDelaisReport();
  }
  
  public ConditionMontantNonNulSpec getConditionMontantNonNul()
  {
    return null;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public ConditionBeneficeAutreProduit getConditionBeneficeAutreProduit()
  {
    return getConditionAttributionAdmission().getConditionBeneficeAutreProduit();
  }
  
  public Integer getDureeAnciennete()
  {
    if (getConditionBeneficeAutreProduit() != null) {
      return getConditionBeneficeAutreProduit().getDureeAncienneteIntermittant();
    }
    return null;
  }
  
  public List getListConditionsAttribution()
  {
    return getConditionsAttributionActives().getListeConditionsAttribution();
  }
  
  public void setDateFinPerteActiviteConservee(Damj p_dateFinPerteActiviteConservee)
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public void setMotifFinPerteActiviteConservee(String p_motifFinPerteActiviteConservee)
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public Damj getDateFinPerteActiviteConservee()
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public String getMotifFinPerteActiviteConservee()
  {
    throw new UnsupportedOperationException("Cette méthode n'a de sens que pour l'ARE 2006 et 2009");
  }
  
  public boolean isEstSinistreOuCalamiteNaturelle()
  {
    return false;
  }
  
  public DemandeAssuranceSpec getDemandeAssurance()
  {
    return (DemandeAssuranceSpec)getDemande();
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
  }
  
  public OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
  }
  
  public ConditionChomageInvolontaireSpec getConditionChomageInvolontaire()
  {
    return getConditionsAttributionActives().getConditionChomageInvolontaire();
  }
  
  public CompetenceSpec getCompetenceSousJacente()
  {
    return null;
  }
  
  public void setCompetence(CompetenceSpec competence) {}
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifAdmission()
  {
    return getConditionAttributionAdmission();
  }
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifReprise()
  {
    return getConditionAttributionReprise();
  }
  
  public void setConditionAttributionAdmission(ConditionsAttributionAdmission conditionAttributionAdmission)
  {
    DomManager.supprimer(super.getConditionAttributionAdmission(), conditionAttributionAdmission);
    super.setConditionAttributionAdmission(conditionAttributionAdmission);
  }
  
  public void setConditionAttributionReprise(ConditionsAttributionReprise conditionAttributionReprise)
  {
    DomManager.supprimer(super.getConditionAttributionReprise(), conditionAttributionReprise);
    super.setConditionAttributionReprise(conditionAttributionReprise);
  }
  
  public void setConstitutionElementsAdmission(ConstitutionElementsAdmission constitutionElementsAdmission)
  {
    DomManager.supprimer(super.getConstitutionElementsAdmission(), constitutionElementsAdmission);
    super.setConstitutionElementsAdmission(constitutionElementsAdmission);
  }
  
  public void setConstitutionElementsReprise(ConstitutionElementsReprise constitutionElementsReprise)
  {
    DomManager.supprimer(super.getConstitutionElementsReprise(), constitutionElementsReprise);
    super.setConstitutionElementsReprise(constitutionElementsReprise);
  }
}

/* Location:
 * Qualified Name:     DossierExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */