package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.PeriodeQuantite;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.dom.spec.PeriodeElementaireAffiliationSpec;
import fr.unedic.cali.liquidation.outilsfonctionnels.spec.OutilPeriodeElementaireSpectacleSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRepartitionQuantite;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeTravailDeclareAvecUnite;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilPeriodeElementaire
  implements OutilFonctionnel, OutilPeriodeElementaireSpectacleSpec
{
  private static OutilPeriodeElementaire instance = null;
  protected static final Unite UNITE_HEURE = Unite.getParCode("18");
  protected static final Unite UNITE_CACHET_GROUPE = Unite.getParCode("13");
  protected static final Unite UNITE_CACHET_ISOLE = Unite.getParCode("14");
  private static final BigDecimal FACTEUR_MULTIPLICATION_RELIQUAT_PLAFOND = new BigDecimal(12);
  private static final int ARRONDI_AFFILIATION_A_RETENIR = 0;
  private static final int ARRONDI_AFFILIATION_A_RETENIR_HEURE = 2;
  
  public static synchronized OutilPeriodeElementaire getInstance()
  {
    if (instance == null) {
      instance = new OutilPeriodeElementaire();
    }
    return instance;
  }
  
  public void calculerQuantiteTravail(IndividuSpec individu, PeriodeElementaireAffiliation periodeElementaire, ActiviteSalarie activite, Damj dateCalcul, Collection<?> collectionAlertesNonBloquante, Damj dateExamen)
    throws CoucheLogiqueException
  {
    PeriodeNonDeclareeSanction pnds = determinerPNDS(individu, activite, dateCalcul, dateExamen);
    if ((pnds != null) && (pnds.getChronoPeriodePNDS() != null) && (!pnds.getChronoPeriodePNDS().estVide()))
    {
      OutilPeriodeAffiliation.alimenterCollectionAlertesPNDS(pnds.getChronoPeriodePNDS(), collectionAlertesNonBloquante);
      activite.setPresencePNDSDetectee(true);
    }
    FiltrePeriodeTravailDeclareAvecUnite filtreTravailExclusivementDeclareEnHeure = new FiltrePeriodeTravailDeclareAvecUnite(periodeElementaire.getMois(), true);
    
    filtreTravailExclusivementDeclareEnHeure.ajouterUnite(UNITE_HEURE);
    boolean activiteUniquementEnHeureSurPeriodeTempsEtudiee = filtreTravailExclusivementDeclareEnHeure.accepter(activite);
    
    String libelleCourtReglement = activite.getReglement().getLibelleCourt();
    
    Chronologie listePeriodeMesureActivite = decouperPMAPourMoisCivil(activite.getListePeriodesMesureActivite(), periodeElementaire.getMois());
    
    Iterator<?> itPeriodeMesureActivite = listePeriodeMesureActivite.iterer();
    while (itPeriodeMesureActivite.hasNext())
    {
      PeriodeMesureActivite pma = (PeriodeMesureActivite)itPeriodeMesureActivite.next();
      if (pma.getPeriode().chevauche(periodeElementaire.getMois()))
      {
        Hashtable<?, ?> listeQuantiteAffi = pma.getListeQuantitesAffiliation();
        Enumeration<?> enumQuantiteAffi = listeQuantiteAffi.elements();
        while (enumQuantiteAffi.hasMoreElements())
        {
          Quantite quantiteAffi = (Quantite)enumQuantiteAffi.nextElement();
          
          BigDecimal quantiteARetenirSurPeriode = determinerQuantiteSurPeriode(pma, periodeElementaire, pnds, quantiteAffi);
          if (libelleCourtReglement.equals("A8"))
          {
            if (quantiteAffi.getUnite().equals(UNITE_HEURE)) {
              periodeElementaire.ajouterQuantiteHeureA8(quantiteARetenirSurPeriode);
            } else if (quantiteAffi.getUnite().equals(UNITE_CACHET_GROUPE)) {
              periodeElementaire.ajouterQuantiteCachetGroupeA8(quantiteARetenirSurPeriode);
            } else if (quantiteAffi.getUnite().equals(UNITE_CACHET_ISOLE)) {
              periodeElementaire.ajouterQuantiteCachetIsoleA8(quantiteARetenirSurPeriode);
            }
          }
          else if (libelleCourtReglement.equals("A10"))
          {
            if (quantiteAffi.getUnite().equals(UNITE_HEURE))
            {
              if (activiteUniquementEnHeureSurPeriodeTempsEtudiee) {
                periodeElementaire.ajouterQuantiteHeureA10(quantiteARetenirSurPeriode);
              } else {
                periodeElementaire.ajouterQuantiteHeureA10Complementaire(quantiteARetenirSurPeriode);
              }
            }
            else if (quantiteAffi.getUnite().equals(UNITE_CACHET_GROUPE)) {
              periodeElementaire.ajouterQuantiteCachetGroupeA10(quantiteARetenirSurPeriode);
            } else if (quantiteAffi.getUnite().equals(UNITE_CACHET_ISOLE)) {
              periodeElementaire.ajouterQuantiteCachetIsoleA10(quantiteARetenirSurPeriode);
            }
          }
          else {
            OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "\t\t         Cette activité ne possède pas un règlement A8/A10 ", "et ne devrait donc pas être prise dans le calcul affiliation ", "         \n" });
          }
        }
      }
    }
  }
  
  public Chronologie decouperPMAPourMoisCivil(Chronologie listePeriodeMesureActivite, Periode periodeRecherche)
  {
    Chronologie resultat = new ChronologiePeriodes();
    
    Iterator<?> itPeriodeMesureActivite = listePeriodeMesureActivite.iterer();
    while (itPeriodeMesureActivite.hasNext())
    {
      PeriodeMesureActivite pma = (PeriodeMesureActivite)itPeriodeMesureActivite.next();
      if (pma.getPeriode().chevauche(periodeRecherche))
      {
        ArrayList<Periode> listeMoisCivil = pma.getPeriode().decouperEnMoisCivils();
        if (listeMoisCivil.size() > 1)
        {
          Chronologie chronoSousPMA = creerPMAPourPeriodes(listeMoisCivil);
          
          Hashtable<?, ?> listeQuantiteAffi = pma.getListeQuantitesAffiliation();
          Enumeration<?> enumQuantiteAffi = listeQuantiteAffi.elements();
          while (enumQuantiteAffi.hasMoreElements())
          {
            Quantite quantiteAffiTotal = (Quantite)enumQuantiteAffi.nextElement();
            
            List<?> listePeriodeQuantite = OutilRepartitionQuantite.repartirQuantiteSurMoisCivils(pma.getPeriode(), quantiteAffiTotal);
            
            chronoSousPMA.iterer();
            int numeroMoisCourant = 0;
            while (chronoSousPMA.encoreSuivant())
            {
              PeriodeMesureActivite pmaMoisCivil = (PeriodeMesureActivite)chronoSousPMA.elementSuivant();
              
              PeriodeQuantite periodeQuantiteCourantes = (PeriodeQuantite)listePeriodeQuantite.get(numeroMoisCourant++);
              
              pmaMoisCivil.ajouterQuantiteAffiliation(periodeQuantiteCourantes.getQuantite());
            }
          }
          ajouterPMASurChronologieResultat(resultat, chronoSousPMA, periodeRecherche);
        }
        else
        {
          resultat.ajouter(pma);
        }
      }
    }
    return resultat;
  }
  
  private void ajouterPMASurChronologieResultat(Chronologie chronoResultat, Chronologie chronoSousPMA, Periode periodeRecherche)
  {
    if (chronoSousPMA != null)
    {
      chronoSousPMA.iterer();
      while (chronoSousPMA.encoreSuivant())
      {
        PeriodeMesureActivite pma = (PeriodeMesureActivite)chronoSousPMA.elementSuivant();
        if ((pma.chevauche(periodeRecherche)) && (pma.getListeQuantitesAffiliation().size() > 0)) {
          chronoResultat.ajouter(pma);
        }
      }
    }
  }
  
  private Chronologie creerPMAPourPeriodes(List<Periode> listePeriodes)
  {
    Chronologie listePMA = new ChronologiePeriodes();
    for (int i = 0; i < listePeriodes.size(); i++)
    {
      Periode moisPourPMA = (Periode)listePeriodes.get(i);
      PeriodeMesureActivite pmaMoisCivil = new PeriodeMesureActivite(moisPourPMA);
      listePMA.ajouter(pmaMoisCivil);
    }
    return listePMA;
  }
  
  protected PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec individu, ActiviteSalarie activite, Damj dateCalcul, Damj dateExamen)
    throws CoucheLogiqueException
  {
    try
    {
      PeriodeNonDeclareeSanction periodesNonDeclareeSanction = null;
      if ((dateExamen.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Activation des nouvelles sanctions pour les PND Spectacle en 17SI2"))) || (dateExamen.estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS")))) {
        if (activite.estPndsSpectacleCharge())
        {
          periodesNonDeclareeSanction = activite.getPndsSpectacle();
        }
        else
        {
          periodesNonDeclareeSanction = OutilDeterminationPNDS.determinerPNDS(individu, activite, activite.getDateDebut(), activite.getDateFin(), dateCalcul, dateExamen);
          
          activite.setPndsSpectacleCharge(true);
          activite.setPndsSpectacle(periodesNonDeclareeSanction);
        }
      }
      return periodesNonDeclareeSanction;
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  protected BigDecimal determinerQuantiteSurPeriode(PeriodeMesureActivite pma, PeriodeElementaireAffiliation periodeElementaire, PeriodeNonDeclareeSanction pnds, Quantite quantiteTotale)
  {
    Periode intersectionPMAAvecPeriodeElementaire = pma.getPeriode().periodeIntersection(periodeElementaire.getMois());
    
    int nombreJoursTravailTotalDansMois = intersectionPMAAvecPeriodeElementaire.getDuree();
    
    int nombreJoursHorsPNDS = nombreJoursTravailTotalDansMois;
    if (pnds != null) {
      nombreJoursHorsPNDS -= intersectionPMAAvecPeriodeElementaire.inter(pnds.getChronoPeriodePNDS());
    }
    return ParametresAffiliation.proratiser(pma.getPeriode().getDuree(), nombreJoursHorsPNDS, quantiteTotale.getValeur());
  }
  
  private BigDecimal arrondirValeurHeures(BigDecimal valeur)
  {
    if (valeur != null) {
      return Mathematiques.arrondiASup(valeur, 2);
    }
    return valeur;
  }
  
  private BigDecimal arrondirValeurCachet(BigDecimal valeur)
  {
    if (valeur != null) {
      return Mathematiques.arrondiASup(valeur, 0);
    }
    return valeur;
  }
  
  public Quantite calculerQuantiteAppartenanceARetenir(PeriodeElementaireAffiliationSpec periodeElementaireSpec, Convertisseur convertisseurUniteAffiliation)
  {
    PeriodeElementaireAffiliation periodeElementaire = (PeriodeElementaireAffiliation)periodeElementaireSpec;
    
    periodeElementaire.setCachetGroupeA10(arrondirValeurCachet(periodeElementaire.getCachetGroupeA10()));
    periodeElementaire.setCachetGroupeA8(arrondirValeurCachet(periodeElementaire.getCachetGroupeA8()));
    periodeElementaire.setCachetIsoleA10(arrondirValeurCachet(periodeElementaire.getCachetIsoleA10()));
    periodeElementaire.setCachetIsoleA8(arrondirValeurCachet(periodeElementaire.getCachetIsoleA8()));
    
    BigDecimal quantiteHeureARetenir = calculerQuantiteHeureARetenir(periodeElementaire, convertisseurUniteAffiliation);
    
    BigDecimal quantiteCachetARetenir = calculerQuantiteCachetARetenir(periodeElementaire, convertisseurUniteAffiliation);
    
    BigDecimal quantiteTotalARetenir = BigDecimal.ZERO;
    if (quantiteHeureARetenir != null) {
      quantiteTotalARetenir = quantiteTotalARetenir.add(quantiteHeureARetenir);
    }
    if (quantiteCachetARetenir != null) {
      quantiteTotalARetenir = quantiteTotalARetenir.add(quantiteCachetARetenir);
    }
    periodeElementaire.setAffiliationRetenue(new Quantite(arrondirValeurHeures(quantiteTotalARetenir), UNITE_HEURE));
    
    periodeElementaire.setHeuresA10(arrondirValeurHeures(periodeElementaire.getHeuresA10()));
    periodeElementaire.setHeuresA8(arrondirValeurHeures(periodeElementaire.getHeuresA8()));
    periodeElementaire.setHeuresComplementairesA10(arrondirValeurHeures(periodeElementaire.getHeuresComplementairesA10()));
    
    return new Quantite(arrondirValeurHeures(quantiteTotalARetenir), UNITE_HEURE);
  }
  
  protected BigDecimal calculerQuantiteHeureARetenir(PeriodeElementaireAffiliation periodeElementaire, Convertisseur convertisseurUniteAffiliation)
  {
    BigDecimal quantiteHeureExercee = BigDecimal.ZERO;
    
    BigDecimal heuresA8 = periodeElementaire.getHeuresA8();
    BigDecimal heuresA10 = periodeElementaire.getHeuresA10();
    BigDecimal heuresCachetGroupeA8 = convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetGroupeA8());
    BigDecimal heuresCachetIsoleA8 = convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetIsoleA8());
    if (heuresA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresA8);
    }
    if (heuresA10 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresA10);
    }
    if (heuresCachetGroupeA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresCachetGroupeA8);
    }
    if (heuresCachetIsoleA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresCachetIsoleA8);
    }
    periodeElementaire.setQuantiteHeureExercee(quantiteHeureExercee);
    return determinerQuantiteHeureARetenir(periodeElementaire);
  }
  
  private BigDecimal calculerQuantiteCachetARetenir(PeriodeElementaireAffiliation periodeElementaire, Convertisseur convertisseurUniteAffiliation)
  {
    BigDecimal quantiteCachetEnHeureExercee = BigDecimal.ZERO;
    BigDecimal heuresCachetGroupeA10 = convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetGroupeA10());
    BigDecimal heuresCachetIsoleA10 = convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetIsoleA10());
    if (heuresCachetGroupeA10 != null) {
      quantiteCachetEnHeureExercee = quantiteCachetEnHeureExercee.add(heuresCachetGroupeA10);
    }
    if (heuresCachetIsoleA10 != null) {
      quantiteCachetEnHeureExercee = quantiteCachetEnHeureExercee.add(heuresCachetIsoleA10);
    }
    if (periodeElementaire.getHeuresComplementairesA10() != null) {
      quantiteCachetEnHeureExercee = quantiteCachetEnHeureExercee.add(periodeElementaire.getHeuresComplementairesA10());
    }
    periodeElementaire.setQuantiteCachetGroupeIsoleHeureExercee(quantiteCachetEnHeureExercee);
    
    BigDecimal sommeCachetA10 = periodeElementaire.getSommeCachetA10();
    BigDecimal quantiteARetenir = BigDecimal.ZERO;
    
    BigDecimal differenceSommeAvecPlafond = sommeCachetA10.subtract(periodeElementaire.getMontantPlafondCachets());
    if (differenceSommeAvecPlafond.intValue() == 0)
    {
      if (heuresCachetGroupeA10 != null) {
        quantiteARetenir = quantiteARetenir.add(heuresCachetGroupeA10);
      }
      if (heuresCachetIsoleA10 != null) {
        quantiteARetenir = quantiteARetenir.add(heuresCachetIsoleA10);
      }
    }
    else if (differenceSommeAvecPlafond.intValue() < 0)
    {
      BigDecimal heureCachetARetenir = null;
      if (periodeElementaire.getHeuresComplementairesA10() != null)
      {
        BigDecimal reliquatPlafond = periodeElementaire.getMontantPlafondCachets().subtract(sommeCachetA10).multiply(FACTEUR_MULTIPLICATION_RELIQUAT_PLAFOND);
        
        heureCachetARetenir = reliquatPlafond.min(periodeElementaire.getHeuresComplementairesA10());
      }
      if (heuresCachetGroupeA10 != null) {
        quantiteARetenir = quantiteARetenir.add(heuresCachetGroupeA10);
      }
      if (heuresCachetIsoleA10 != null) {
        quantiteARetenir = quantiteARetenir.add(heuresCachetIsoleA10);
      }
      if (heureCachetARetenir != null) {
        quantiteARetenir = quantiteARetenir.add(heureCachetARetenir);
      }
    }
    else if (periodeElementaire.getCachetIsoleA10() == null)
    {
      quantiteARetenir = convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, periodeElementaire.getMontantPlafondCachets());
    }
    else if (periodeElementaire.getCachetGroupeA10() == null)
    {
      quantiteARetenir = convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, periodeElementaire.getMontantPlafondCachets());
    }
    else
    {
      BigDecimal cachetIsoleARetenir = BigDecimal.valueOf(periodeElementaire.getCachetIsoleA10().doubleValue() / sommeCachetA10.doubleValue() * periodeElementaire.getMontantPlafondCachets().doubleValue());
      
      cachetIsoleARetenir = Mathematiques.arrondiASup(cachetIsoleARetenir, 0);
      BigDecimal cachetGroupeARetenir = periodeElementaire.getMontantPlafondCachets().subtract(cachetIsoleARetenir);
      quantiteARetenir = convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, cachetGroupeARetenir).add(convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, cachetIsoleARetenir));
    }
    return quantiteARetenir;
  }
  
  protected BigDecimal determinerQuantiteHeureARetenir(PeriodeElementaireAffiliation periodeElementaire)
  {
    periodeElementaire.setEstPlafonneMultiEmployeur(false);
    if (periodeElementaire.getQuantiteHeureExercee().compareTo(periodeElementaire.getMontantPlafondHeures()) > 0) {
      periodeElementaire.setEstPlafonneMultiEmployeur(true);
    }
    return periodeElementaire.getQuantiteHeureExercee().min(periodeElementaire.getMontantPlafondHeures());
  }
  
  protected BigDecimal convertirCachetGroupeEnHeure(Convertisseur convertisseurUniteAffiliation, BigDecimal quantite)
  {
    if (quantite != null) {
      return convertisseurUniteAffiliation.convertir(new Quantite(quantite, UNITE_CACHET_GROUPE), UNITE_HEURE).getValeur();
    }
    return null;
  }
  
  protected BigDecimal convertirCachetIsoleEnHeure(Convertisseur convertisseurUniteAffiliation, BigDecimal quantite)
  {
    if (quantite != null) {
      return convertisseurUniteAffiliation.convertir(new Quantite(quantite, UNITE_CACHET_ISOLE), UNITE_HEURE).getValeur();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     OutilPeriodeElementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */