package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;

public class DeterminationDateOdTheorique
  implements OutilFonctionnel
{
  public static Damj determinerDateAttributionTheoriquePourAdmission(DemandeAssuranceSpec demande)
    throws ApplicativeException
  {
    Damj dateOdTheorique;
    Damj dateOdTheorique;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "SORTIECRA")) {
      dateOdTheorique = determinerDateAttributionEnSortieClauseRattrapage(demande);
    } else {
      dateOdTheorique = demande.getDateExamen();
    }
    return dateOdTheorique;
  }
  
  public static Damj determinerDateAttributionTheoriquePourReprise(DemandeAssuranceSpec demande)
  {
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    Damj dateOdTheorique;
    Damj dateOdTheorique;
    if ((ere instanceof EreInscriptionDemandeurEmploi)) {
      dateOdTheorique = recupererDateInscriptionDemandeurEmploi(demande);
    } else {
      dateOdTheorique = demande.getDateExamen();
    }
    return dateOdTheorique;
  }
  
  private static Damj recupererDateInscriptionDemandeurEmploi(DemandeAssuranceSpec demande)
  {
    Damj dateIde = null;
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
    if (periodePEC != null) {
      dateIde = periodePEC.getDateDebut();
    }
    return dateIde;
  }
  
  private static Damj determinerDateAttributionEnSortieClauseRattrapage(DemandeAssuranceSpec demandeCourante)
    throws ApplicativeException
  {
    FiltreET filtreOdCra = new FiltreET();
    filtreOdCra.ajouterFiltre(new FiltreAttributionSurDecisions(true));
    filtreOdCra.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("ENTREECRA"));
    
    AttributionSpec odCra = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante.getDateExamen(), filtreOdCra);
    Damj dateAttribution;
    Damj dateAttribution;
    if ("ASU_22".equals(odCra.getDemande().getEvenementReferenceExamen().getTypeExamen())) {
      dateAttribution = calculerDateAttributionSurSortieAntecedent((Demande)odCra.getDemande());
    } else {
      dateAttribution = odCra.getDateAttribution();
    }
    return dateAttribution;
  }
  
  private static Damj calculerDateAttributionSurSortieAntecedent(Demande demandeCourante)
    throws ApplicativeException
  {
    Damj dateDJC = demandeCourante.getSaisieAntecedent().getDateDernierJourCalcule();
    Damj dateAttribution = OutillagePEC.getPremierJourPECDemandeur(demandeCourante.getDemandeur(), dateDJC);
    bloquerSiRepriseCRAAMemeDate(dateAttribution, demandeCourante.getDemandeur());
    return dateAttribution;
  }
  
  private static void bloquerSiRepriseCRAAMemeDate(Damj dateAttribution, IndividuSpec individu)
    throws ApplicativeException
  {
    FiltreET filtreRepriseCRA = new FiltreET();
    filtreRepriseCRA.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("ENCOURSCRA"));
    DecisionSpec repriseCRA = OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandeAssurance(), dateAttribution.lendemain(), filtreRepriseCRA);
    if ((repriseCRA != null) && (repriseCRA.getDateEffetDecision() != null) && (repriseCRA.getDateEffetDecision().coincideAvec(dateAttribution))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SORTIE_CRA_SUITE_ANTECEDENT", new Object[] { dateAttribution });
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationDateOdTheorique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */