package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.NatureAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ComportementCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class DeterminationPeriodeReference
{
  private static DeterminationPeriodeReference instance;
  
  public static DeterminationPeriodeReference getInstance()
  {
    if (instance == null) {
      instance = new DeterminationPeriodeReference();
    }
    return instance;
  }
  
  public Periode determinerPeriodeDeReference(ConteneurDeterminationPeriodeReference conteneur)
  {
    Periode periodeReference = null;
    
    DureeCalendaire dureePeriodeReference = conteneur.getDureeInitialePeriodeReference();
    
    Damj termePeriodeReference = null;
    if (conteneur.isEstContexteEntreeClauseDeRattrapage()) {
      termePeriodeReference = conteneur.getDateExamen().veille();
    } else {
      termePeriodeReference = conteneur.getTermePeriodeReference();
    }
    Periode periodeReferenceSansReport = CalculDelais.determinerDelaiCalendaire(termePeriodeReference, dureePeriodeReference);
    
    boolean verifierANouveauAllongement = true;
    periodeReference = periodeReferenceSansReport;
    ComportementAffiliationSpec comportement = new ComportementCalculAffiliation();
    comportement.setPeriodeRecherche(periodeReference);
    comportement.setEstPrimo(conteneur.isPrimo());
    while (verifierANouveauAllongement)
    {
      verifierANouveauAllongement = false;
      
      ConstructionChronologieSpec constructionChronologie = conteneur.getConstructionChronologie();
      IndividuSpec individu = conteneur.getIndividu();
      Chronologie chronoActiviteAllongementPeriodesReference = constructionChronologie.determinerActivitesAllongementPeriodeReference(individu, comportement);
      
      Chronologie chronoActiviteAffiliationBase = determinerPeriodeParticipantAffiliationBase(individu, periodeReference, constructionChronologie);
      
      Iterator itChronoActiviteAllongementPeriodesReference = chronoActiviteAllongementPeriodesReference.iterer();
      int nombreJoursTotalAReporter = 0;
      while (itChronoActiviteAllongementPeriodesReference.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itChronoActiviteAllongementPeriodesReference.next();
        int nombreJoursAReporter = determinerNombreJoursAReporterPourIncident(pep, conteneur.getListeAllongementPRA(), chronoActiviteAffiliationBase, periodeReference, conteneur.getJustifierAffiliation());
        if (nombreJoursAReporter > 0) {
          nombreJoursTotalAReporter += nombreJoursAReporter;
        }
      }
      if (nombreJoursTotalAReporter > 0)
      {
        DureeCalendaire dureeAllongement = new DureeCalendaire(0, 0, nombreJoursTotalAReporter);
        Damj nouvelleDateDebut = periodeReference.getDebut().deplacerVersArriere(dureeAllongement);
        periodeReference.setDebut(nouvelleDateDebut);
        verifierANouveauAllongement = true;
      }
    }
    Damj dateBornePRA = conteneur.getDateBornePRA();
    boolean estContexteSortieClauseRattrapage = conteneur.isEstContexteSortieClauseRattrapage();
    if ((dateBornePRA != null) && ((periodeReference.getDebut().estAvant(dateBornePRA)) || (estContexteSortieClauseRattrapage))) {
      periodeReference.setDebut(dateBornePRA);
    }
    return periodeReference;
  }
  
  private Chronologie determinerPeriodeParticipantAffiliationBase(IndividuSpec individu, Periode periodeReference, ConstructionChronologieSpec constructionChronologie)
  {
    ComportementCalculAffiliation comportement = new ComportementCalculAffiliation();
    comportement.setPeriodeRecherche(periodeReference);
    List<Reglement> listeReglementsPrisEnCompte = new ArrayList();
    listeReglementsPrisEnCompte.add(RechercheValiditeProduit.getInstance().getReglementA10());
    listeReglementsPrisEnCompte.add(RechercheValiditeProduit.getInstance().getReglementA8());
    comportement.setListeReglementPrisEnCompte(listeReglementsPrisEnCompte);
    comportement.setChronologieActivitesParticipantes(RechercheValiditeProduit.getInstance().recupererChronologiePourCalculAffiliation(individu));
    return constructionChronologie.determinerChronologiePourAffiliationBase(comportement);
  }
  
  protected int determinerNombreJoursAReporterPourIncident(PeriodeEvenementPersonnel pep, List listeAllongementPeriode, Chronologie chronoActviteAffiliationBase, Periode periodeReference, JustifierAffiliationSpec justifierAffiliation)
  {
    int nombreJoursSupplementairesAReporter = 0;
    
    int nombreJoursTotalARetenir = determinerNombreJoursARetenir(pep, periodeReference, chronoActviteAffiliationBase);
    
    AllongementPra allongementExistant = justifierAffiliation.trouverAllongementPourPeriodeEvenementPersonnel(listeAllongementPeriode, pep);
    if (allongementExistant != null)
    {
      nombreJoursSupplementairesAReporter = nombreJoursTotalARetenir - allongementExistant.getDuree().getJours();
      justifierAffiliation.augmenterPeriodeAllongementPra(allongementExistant, nombreJoursSupplementairesAReporter);
    }
    else if (nombreJoursTotalARetenir > 0)
    {
      nombreJoursSupplementairesAReporter = nombreJoursTotalARetenir;
      
      DureeCalendaire duree = new DureeCalendaire(0, 0, nombreJoursSupplementairesAReporter);
      int nature = NatureAffiliation.determinerNatureActivite(pep);
      justifierAffiliation.ajouterAllongementPra(listeAllongementPeriode, duree, nature, pep.getPeriode());
    }
    return nombreJoursSupplementairesAReporter;
  }
  
  protected int determinerNombreJoursARetenir(PeriodeEvenementPersonnel pep, Periode periodeReference, Chronologie chronoActviteAffiliationBase)
  {
    Periode periodePriseEnCompte = pep.getPeriode().periodeIntersection(periodeReference);
    
    int nombreJoursChevaucheAvecActiviteBase = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(chronoActviteAffiliationBase, periodePriseEnCompte);
    
    return periodePriseEnCompte.getDuree() - nombreJoursChevaucheAvecActiviteBase;
  }
}

/* Location:
 * Qualified Name:     DeterminationPeriodeReference
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */