package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalaireMoisCivil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalairePeriodeActiviteSurMois;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationSRPeriodeActivite;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationSRPeriodeRemuneration;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeElementaire;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Prime;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.ConstantesPeriodeActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.RemunerationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class DeterminationSalaireReference
  implements OutilFonctionnel
{
  protected static final BigDecimal NBRE_MOIS_ANNEE = new BigDecimal(12);
  protected static final BigDecimal NBRE_JOURS_ANNEE = new BigDecimal(365);
  protected static final BigDecimal CONVERSION_HEURES_CACHETS = new BigDecimal(12);
  protected static final int ARRONDI_COEFF_QUATRE_DECIMALES = 4;
  protected static final int ARRONDI_COEFF_DEUX_DECIMALES = 2;
  
  public ConstitutionSalaireReference determinerSalaireReference(Demande demande, boolean estCalculSurPrf)
    throws CoucheLogiqueException
  {
    ConstitutionSalaireReference constitutionSalaireReference = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionSalaireReference();
    
    Periode periodePrc = determinerPeriodeReference(demande, estCalculSurPrf);
    constitutionSalaireReference.setPrc(periodePrc);
    
    Chronologie chronoActivitesSalariesParticipantSr = ConstructionChronologie.determinerChronoActivitesSalarieesSr(periodePrc, demande.getFaitGenerateur().getDateFaitGenerateur(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    constitutionSalaireReference.setCollectionActiviteSalarieParticipantSr(chronoActivitesSalariesParticipantSr.mapperVersCollection());
    
    QuantiteEuro sripForce = demande.getDonneesTemporaires().getSripSpectacle();
    determinerSrip(sripForce, demande, constitutionSalaireReference, chronoActivitesSalariesParticipantSr);
    
    Damj dateRevalorisation = ((DossierExamen)demande.getDossierExamen()).getDateAttribution();
    determinerPlafondPSrr(constitutionSalaireReference, demande, chronoActivitesSalariesParticipantSr, dateRevalorisation);
    
    QuantiteEuro srrp = determinerSrrp(constitutionSalaireReference, dateRevalorisation);
    constitutionSalaireReference.setSalaireReferenceRevalorisePlafonne(srrp);
    
    return constitutionSalaireReference;
  }
  
  protected void determinerSrip(QuantiteEuro sripForce, Demande demande, ConstitutionSalaireReference constitutionSalaireReference, Chronologie chronoActivitesSalariesParticipantSr)
    throws CoucheLogiqueException
  {
    if (sripForce != null) {
      constitutionSalaireReference.setSalaireReferenceInitialPlafonne(sripForce);
    } else {
      determinerSrip(constitutionSalaireReference, demande, chronoActivitesSalariesParticipantSr);
    }
  }
  
  public static QuantiteEuro determinerSrrp(ConstitutionSalaireReference constitutionSalaireReference, Damj dateRevalorisation)
  {
    SalaireReference srip = new SalaireReference(constitutionSalaireReference.getSalaireReferenceInitialPlafonne().getValeurMontant(), constitutionSalaireReference.getPrc().getFin());
    
    BigDecimal srrp = RevalorisationSalaire.revaloriserSrip(srip, constitutionSalaireReference.getMontantPlafond().getValeurMontant(), dateRevalorisation);
    
    return new QuantiteEuro(srrp);
  }
  
  protected Periode determinerPeriodeReference(Demande demande, boolean estCalculSurPrf)
  {
    Periode periodePrc = null;
    if (demande.getDossierAffectationAdmission().getValidationProduit() != null)
    {
      fr.unedic.cali.asu.dom.ValidationProduit validationProduit = demande.getDossierAffectationAdmission().getValidationProduit();
      periodePrc = (Periode)validationProduit.getPeriodePra().copie();
    }
    return periodePrc;
  }
  
  protected void determinerSrip(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Chronologie chronoActivitesSalaries)
    throws CoucheLogiqueException
  {
    BigDecimal sripCumule = BigDecimal.ZERO;
    BigDecimal sriCumule = BigDecimal.ZERO;
    
    Periode periodePrc = constitutionSalaireReference.getPrc();
    
    alimenterJustificationReductionSalaire(constitutionSalaireReference, demande, chronoActivitesSalaries);
    
    chronoActivitesSalaries.iterer();
    while (chronoActivitesSalaries.encoreSuivant())
    {
      ActiviteSalarie activiteSalarieCourante = (ActiviteSalarie)chronoActivitesSalaries.elementSuivant();
      
      JustificationSRPeriodeActivite justifSRPeriodeActivite = new JustificationSRPeriodeActivite();
      justifSRPeriodeActivite.setPeriode(activiteSalarieCourante.getPeriode());
      justifSRPeriodeActivite.setRaisonSociale(activiteSalarieCourante.getEntreprise().getLibelleEntreprise());
      justifSRPeriodeActivite.setReglement(activiteSalarieCourante.getReglement().getNomReglement());
      constitutionSalaireReference.getJustificationSalaireReference().ajouterPeriodeActivite(justifSRPeriodeActivite);
      
      QuantiteEuro sriParActivite = determinerSriParActivite(constitutionSalaireReference, demande, periodePrc, activiteSalarieCourante, justifSRPeriodeActivite);
      
      sriCumule = sriCumule.add(sriParActivite.getValeurMontant());
      
      justifSRPeriodeActivite.setMontantSalaireNonPlafonne(sriParActivite);
      
      QuantiteEuro plafondParActivite = determinerPlafondParActivite(periodePrc, activiteSalarieCourante);
      
      justifSRPeriodeActivite.setMontantPlafond(plafondParActivite);
      
      QuantiteEuro sripParActivite = (QuantiteEuro)sriParActivite.min(plafondParActivite);
      
      justifSRPeriodeActivite.setMontantSalairePlafonne(sripParActivite);
      
      sripCumule = sripCumule.add(sripParActivite.getValeurMontant());
    }
    sriCumule = Mathematiques.arrondiASup(sriCumule, 2);
    sripCumule = Mathematiques.arrondiASup(sripCumule, 2);
    constitutionSalaireReference.setSalaireReferenceInitial(new QuantiteEuro(sriCumule));
    constitutionSalaireReference.setSalaireReferenceInitialPlafonne(new QuantiteEuro(sripCumule));
  }
  
  protected void alimenterJustificationReductionSalaire(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Chronologie chronoActivitesSalaries)
    throws CoucheLogiqueException
  {
    JustificationAffiliation justificationAffiliation = ((fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)demande.getDossierAffectationAdmission().getValidationProduit()).getJustificationAffiliation();
    Iterator<PeriodeElementaireAffiliation> iterateurPeriodeElemAffi;
    if (justificationAffiliation != null)
    {
      Collection<PeriodeElementaireAffiliation> collectionPeriodeElementaireAffiliation = justificationAffiliation.getCollectionPeriodeElementaireAffiliation();
      for (iterateurPeriodeElemAffi = collectionPeriodeElementaireAffiliation.iterator(); iterateurPeriodeElemAffi.hasNext();)
      {
        PeriodeElementaireAffiliation periodeElementaireAffiliationCourante = (PeriodeElementaireAffiliation)iterateurPeriodeElemAffi.next();
        if ((periodeElementaireAffiliationCourante.isPlafondHeuresDepasse()) || (periodeElementaireAffiliationCourante.isPlafondCachetsDepasse()))
        {
          JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivilCourant = new JustificationReductionSalaireMoisCivil();
          justifReductionSalaireMoisCivilCourant.setPeriode(periodeElementaireAffiliationCourante.getMois());
          constitutionSalaireReference.getJustificationReductionSalaire().ajouterMoisCivils(justifReductionSalaireMoisCivilCourant);
          if (periodeElementaireAffiliationCourante.isPlafondHeuresDepasse()) {
            determinerCoefficientEcretementHeures(periodeElementaireAffiliationCourante, justifReductionSalaireMoisCivilCourant);
          }
          if (periodeElementaireAffiliationCourante.isPlafondCachetsDepasse()) {
            determinerCoefficientEcretementCachets(periodeElementaireAffiliationCourante, justifReductionSalaireMoisCivilCourant);
          }
          alimenterJustificationReductionSalairePeriodesActivite(justifReductionSalaireMoisCivilCourant, periodeElementaireAffiliationCourante, demande.getDemandeur(), chronoActivitesSalaries, demande.getDateFaitGenerateurOuDernierSinistre(), demande.getDateExamen());
        }
      }
    }
  }
  
  private void alimenterJustificationReductionSalairePeriodesActivite(JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivil, PeriodeElementaireAffiliation periodeElementaireAffiliationCourante, IndividuSpec individu, Chronologie chronoActivitesSalaries, Damj dateCalcul, Damj dateExamen)
    throws CoucheLogiqueException
  {
    JustificationReductionSalairePeriodeActiviteSurMois justifReductionSalairePeriodeActiviteSurMoisCivilCourant = null;
    
    BigDecimal nombreHeuresActivite = BigDecimal.ZERO;
    BigDecimal nombreCachetsIsolesActivite = BigDecimal.ZERO;
    BigDecimal nombreCachetsGroupesActivite = BigDecimal.ZERO;
    
    chronoActivitesSalaries.iterer();
    while (chronoActivitesSalaries.encoreSuivant())
    {
      ActiviteSalarie activiteSalarieCourante = (ActiviteSalarie)chronoActivitesSalaries.elementSuivant();
      if (activiteSalarieCourante.getPeriode().chevauche(periodeElementaireAffiliationCourante.getMois()))
      {
        PeriodeElementaireAffiliation nouvellePeriodeElementaireAffiliation = new PeriodeElementaireAffiliation();
        nouvellePeriodeElementaireAffiliation.setMois(periodeElementaireAffiliationCourante.getMois());
        OutilPeriodeElementaire.getInstance().calculerQuantiteTravail(individu, nouvellePeriodeElementaireAffiliation, activiteSalarieCourante, dateCalcul, null, dateExamen);
        
        nombreHeuresActivite = BigDecimal.ZERO;
        if (nouvellePeriodeElementaireAffiliation.getHeuresA8() != null) {
          nombreHeuresActivite = nombreHeuresActivite.add(nouvellePeriodeElementaireAffiliation.getHeuresA8());
        }
        if (nouvellePeriodeElementaireAffiliation.getHeuresA10() != null) {
          nombreHeuresActivite = nombreHeuresActivite.add(nouvellePeriodeElementaireAffiliation.getHeuresA10());
        }
        if (nouvellePeriodeElementaireAffiliation.getHeuresComplementairesA10() != null) {
          nombreHeuresActivite = nombreHeuresActivite.add(nouvellePeriodeElementaireAffiliation.getHeuresComplementairesA10());
        }
        nombreCachetsIsolesActivite = BigDecimal.ZERO;
        if (nouvellePeriodeElementaireAffiliation.getCachetIsoleA8() != null) {
          nombreCachetsIsolesActivite = nombreCachetsIsolesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetIsoleA8());
        }
        if (nouvellePeriodeElementaireAffiliation.getCachetIsoleA10() != null) {
          nombreCachetsIsolesActivite = nombreCachetsIsolesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetIsoleA10());
        }
        nombreCachetsGroupesActivite = BigDecimal.ZERO;
        if (nouvellePeriodeElementaireAffiliation.getCachetGroupeA8() != null) {
          nombreCachetsGroupesActivite = nombreCachetsGroupesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetGroupeA8());
        }
        if (nouvellePeriodeElementaireAffiliation.getCachetGroupeA10() != null) {
          nombreCachetsGroupesActivite = nombreCachetsGroupesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetGroupeA10());
        }
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant = new JustificationReductionSalairePeriodeActiviteSurMois();
        
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setPeriode(activiteSalarieCourante.getPeriode().periodeIntersection(periodeElementaireAffiliationCourante.getMois()));
        
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setRaisonSociale(activiteSalarieCourante.getEntreprise().getLibelleEntreprise());
        
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setNombreHeures(arrondirValeurPourPersistenceEtJustification(nombreHeuresActivite, 2));
        
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setNombreCachetsIsoles(arrondirValeurPourPersistenceEtJustification(nombreCachetsIsolesActivite, 2));
        
        justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setNombreCachetsGroupes(arrondirValeurPourPersistenceEtJustification(nombreCachetsGroupesActivite, 2));
        
        justifReductionSalaireMoisCivil.ajouterPeriodeActiviteSurMois(justifReductionSalairePeriodeActiviteSurMoisCivilCourant);
      }
    }
  }
  
  private QuantiteEuro determinerSriParActivite(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Periode periodePrc, ActiviteSalarie activiteSalarie, JustificationSRPeriodeActivite justifSRPeriodeActivite)
    throws CoucheLogiqueException
  {
    BigDecimal sriParActiviteCalcule = BigDecimal.ZERO;
    
    QuantiteEuro montantRemunerationsRetenues = null;
    
    JustificationSalaireReference justifSalaireReference = constitutionSalaireReference.getJustificationSalaireReference();
    Collection collectionJustifReductionSalaireMoisCivil = constitutionSalaireReference.getJustificationReductionSalaire().getCollectionMoisCivils();
    
    montantRemunerationsRetenues = determinerRemunerationSalaires(demande, periodePrc, activiteSalarie, justifSRPeriodeActivite, collectionJustifReductionSalaireMoisCivil);
    
    sriParActiviteCalcule = sriParActiviteCalcule.add(montantRemunerationsRetenues.getValeurMontant());
    if (justifSalaireReference.getMontantTotalSalairesRetenus() == null) {
      justifSalaireReference.setMontantTotalSalairesRetenus(montantRemunerationsRetenues);
    } else {
      justifSalaireReference.setMontantTotalSalairesRetenus(new QuantiteEuro(justifSalaireReference.getMontantTotalSalairesRetenus().ajouter(montantRemunerationsRetenues).getValeur()));
    }
    montantRemunerationsRetenues = determinerRemunerationPrimesNormales(periodePrc, activiteSalarie, justifSRPeriodeActivite, collectionJustifReductionSalaireMoisCivil);
    
    sriParActiviteCalcule = sriParActiviteCalcule.add(montantRemunerationsRetenues.getValeurMontant());
    if (justifSalaireReference.getMontantTotalPrimesNormalesRetenues() == null) {
      justifSalaireReference.setMontantTotalPrimesNormalesRetenues(montantRemunerationsRetenues);
    } else {
      justifSalaireReference.setMontantTotalPrimesNormalesRetenues(new QuantiteEuro(justifSalaireReference.getMontantTotalPrimesNormalesRetenues().ajouter(montantRemunerationsRetenues).getValeur()));
    }
    montantRemunerationsRetenues = determinerRemunerationPrimesExceptionnelles(periodePrc, activiteSalarie, justifSRPeriodeActivite, collectionJustifReductionSalaireMoisCivil);
    
    sriParActiviteCalcule = sriParActiviteCalcule.add(montantRemunerationsRetenues.getValeurMontant());
    if (justifSalaireReference.getMontantTotalPrimesExceptionnellesRetenues() == null) {
      justifSalaireReference.setMontantTotalPrimesExceptionnellesRetenues(montantRemunerationsRetenues);
    } else {
      justifSalaireReference.setMontantTotalPrimesExceptionnellesRetenues(new QuantiteEuro(justifSalaireReference.getMontantTotalPrimesExceptionnellesRetenues().ajouter(montantRemunerationsRetenues).getValeur()));
    }
    montantRemunerationsRetenues = determinerRemunerationPrimesICRS(demande, periodePrc, activiteSalarie, justifSRPeriodeActivite, collectionJustifReductionSalaireMoisCivil);
    
    sriParActiviteCalcule = sriParActiviteCalcule.add(montantRemunerationsRetenues.getValeurMontant());
    
    justifSalaireReference.setMontantTotalSalairesRetenus(new QuantiteEuro(justifSalaireReference.getMontantTotalSalairesRetenus().ajouter(montantRemunerationsRetenues).getValeur()));
    
    return new QuantiteEuro(arrondirValeurPourPersistenceEtJustification(sriParActiviteCalcule, 2));
  }
  
  private QuantiteEuro determinerPlafondParActivite(Periode periodePrc, ActiviteSalarie activiteSalarie)
  {
    BigDecimal cumulPlafondParActivite = BigDecimal.ZERO;
    
    BigDecimal plafondMensuelApplicable = BigDecimal.ZERO;
    
    Periode periodeMoisCivilCourant = null;
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    Periode periodeIntersectionActivitePrc = periodePrc.periodeIntersection(activiteSalarie.getPeriode());
    
    ArrayList listePeriodesMoisCivils = periodeIntersectionActivitePrc.decouperEnMoisCivils();
    for (int boucle = 0; boucle < listePeriodesMoisCivils.size(); boucle++)
    {
      periodeMoisCivilCourant = (Periode)listePeriodesMoisCivils.get(boucle);
      
      plafondMensuelApplicable = parametresIndemnisation.getElementActif(periodeMoisCivilCourant.getDebut()).getPlafond();
      if ((!periodeMoisCivilCourant.getDebut().estLeDebutDuMois()) || (!periodeMoisCivilCourant.getFin().estLaFinDuMois()))
      {
        BigDecimal nominateur1 = plafondMensuelApplicable.multiply(NBRE_MOIS_ANNEE);
        BigDecimal nominateur2 = BigDecimal.valueOf(periodeMoisCivilCourant.getDuree());
        BigDecimal denominateur = NBRE_JOURS_ANNEE;
        plafondMensuelApplicable = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      }
      cumulPlafondParActivite = cumulPlafondParActivite.add(plafondMensuelApplicable);
    }
    return new QuantiteEuro(arrondirValeurPourPersistenceEtJustification(cumulPlafondParActivite, 2));
  }
  
  private QuantiteEuro determinerRemunerationSalaires(Demande demande, Periode periodePrc, ActiviteSalarie activiteSalarie, JustificationSRPeriodeActivite justificationSRPeriodeActivite, Collection collectionJustifReductionSalaireMoisCivil)
    throws CoucheLogiqueException
  {
    BigDecimal cumulSalairesCalcule = BigDecimal.ZERO;
    
    PeriodeNonDeclareeSanction periodesNonDeclareeSanction = determinerPnds(demande, periodePrc, activiteSalarie);
    
    Chronologie chronoSalaires = activiteSalarie.getListeSalaires();
    Salaire salaireCourant = null;
    Periode periodeIntersectionSalairePrc = null;
    BigDecimal montantSalaireBrutAbattuEtProratise = BigDecimal.ZERO;
    BigDecimal montantSalaireReduit = BigDecimal.ZERO;
    BigDecimal montantSalaireRetenu = BigDecimal.ZERO;
    JustificationSRPeriodeRemuneration justifSRPeriodeRemuneration = null;
    chronoSalaires.iterer();
    while (chronoSalaires.encoreSuivant())
    {
      salaireCourant = (Salaire)chronoSalaires.elementSuivant();
      if (salaireCourant.chevauche(periodePrc))
      {
        montantSalaireBrutAbattuEtProratise = DeterminationRemuneration.determinerRemunerationProratiseeDansPeriodeRef(salaireCourant, periodePrc);
        if (!salaireCourant.estExclus())
        {
          periodeIntersectionSalairePrc = periodePrc.periodeIntersection(salaireCourant.getPeriode());
          
          montantSalaireReduit = determinerMontantRemunerationReduitParEcretement(activiteSalarie, collectionJustifReductionSalaireMoisCivil, periodeIntersectionSalairePrc, montantSalaireBrutAbattuEtProratise, 1, null);
          
          montantSalaireRetenu = determinerMontantRemunerationParDeductionPnds(periodeIntersectionSalairePrc, montantSalaireReduit, periodesNonDeclareeSanction);
          
          cumulSalairesCalcule = cumulSalairesCalcule.add(montantSalaireRetenu);
          if (ConstantesPeriodeActivite.AEXCLURE_INCOHERENT.equals(salaireCourant.getNatureAExclure())) {
            leverAlerteNonBloquante(demande, activiteSalarie, "A11MNB5");
          }
          justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
          justifSRPeriodeRemuneration.setPeriode(salaireCourant.getPeriode());
          justifSRPeriodeRemuneration.setNature(1);
          justifSRPeriodeRemuneration.setDatePaie(salaireCourant.getDatePaie());
          
          justifSRPeriodeRemuneration.setMontantBrut(salaireCourant.getMontantSoumisAContribution());
          
          justifSRPeriodeRemuneration.setMontantReduit(new QuantiteEuro(montantSalaireReduit));
          
          justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro(montantSalaireRetenu));
          justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
        }
        else
        {
          if (!ConstantesPeriodeActivite.AEXCLURE_EXCLU_MANUEL.equals(salaireCourant.getNatureAExclure())) {
            leverAlerteNonBloquante(demande, activiteSalarie, "A11MNB5");
          }
          justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
          justifSRPeriodeRemuneration.setPeriode(salaireCourant.getPeriode());
          justifSRPeriodeRemuneration.setNature(1);
          justifSRPeriodeRemuneration.setDatePaie(salaireCourant.getDatePaie());
          
          justifSRPeriodeRemuneration.setMontantBrut(salaireCourant.getMontantSoumisAContribution());
          
          justifSRPeriodeRemuneration.setMontantReduit(salaireCourant.getMontantSoumisAContribution());
          
          justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro("0"));
          justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
        }
      }
    }
    Periode periodeIntersectionActivitePrc = periodePrc.periodeIntersection(activiteSalarie.getPeriode());
    ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires((ChronologiePeriodes)chronoSalaires, periodeIntersectionActivitePrc);
    if ((chronoPeriodesComplementaires != null) && (chronoPeriodesComplementaires.getTaille() > 0))
    {
      leverAlerteNonBloquante(demande, activiteSalarie, "A11MNB5");
      
      ObjetChronoPeriode periodeComplementaireCourante = null;
      chronoPeriodesComplementaires.iterer();
      while (chronoPeriodesComplementaires.encoreSuivant())
      {
        periodeComplementaireCourante = (ObjetChronoPeriode)chronoPeriodesComplementaires.elementSuivant();
        
        justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
        justifSRPeriodeRemuneration.setPeriode(new Periode(periodeComplementaireCourante.getDateDebut(), periodeComplementaireCourante.getDateFin()));
        
        justifSRPeriodeRemuneration.setNature(4);
        
        justifSRPeriodeRemuneration.setMontantBrut(new QuantiteEuro("0"));
        justifSRPeriodeRemuneration.setMontantReduit(new QuantiteEuro("0"));
        justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro("0"));
        justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
      }
    }
    return new QuantiteEuro(cumulSalairesCalcule);
  }
  
  private QuantiteEuro determinerRemunerationPrimesNormales(Periode periodePrc, ActiviteSalarie activiteSalarie, JustificationSRPeriodeActivite justificationSRPeriodeActivite, Collection collectionJustifReductionSalaireMoisCivil)
  {
    BigDecimal cumulPrimesNormalesCalcule = BigDecimal.ZERO;
    
    Chronologie chronoPrimesNormales = activiteSalarie.getListePrimesNormales();
    
    BigDecimal montantPrimeBrutAbattuEtProratise = BigDecimal.ZERO;
    BigDecimal montantPrimeReduit = BigDecimal.ZERO;
    BigDecimal montantPrimeRetenu = BigDecimal.ZERO;
    
    chronoPrimesNormales.iterer();
    while (chronoPrimesNormales.encoreSuivant())
    {
      Prime primeNormaleCourante = (Prime)chronoPrimesNormales.elementSuivant();
      Periode periodePrimeNormaleCourante = new Periode(primeNormaleCourante.getDateDebut(), primeNormaleCourante.getDateFin());
      if (primeNormaleCourante.chevauche(periodePrc))
      {
        montantPrimeBrutAbattuEtProratise = DeterminationRemuneration.determinerRemunerationProratiseeDansPeriodeRef(primeNormaleCourante, periodePrc);
        
        Periode periodeIntersectionPrimePrc = periodePrc.periodeIntersection(periodePrimeNormaleCourante);
        
        montantPrimeReduit = determinerMontantRemunerationReduitParEcretement(activiteSalarie, collectionJustifReductionSalaireMoisCivil, periodeIntersectionPrimePrc, montantPrimeBrutAbattuEtProratise, 2, null);
        
        montantPrimeRetenu = montantPrimeReduit;
        
        cumulPrimesNormalesCalcule = cumulPrimesNormalesCalcule.add(montantPrimeRetenu);
        
        JustificationSRPeriodeRemuneration justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
        justifSRPeriodeRemuneration.setPeriode(periodePrimeNormaleCourante);
        justifSRPeriodeRemuneration.setNature(2);
        justifSRPeriodeRemuneration.setDatePaie(primeNormaleCourante.getDatePaie());
        
        justifSRPeriodeRemuneration.setMontantBrut(primeNormaleCourante.getMontantSoumisAContribution());
        
        justifSRPeriodeRemuneration.setMontantReduit(new QuantiteEuro(montantPrimeReduit));
        
        justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro(montantPrimeRetenu));
        justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
      }
    }
    return new QuantiteEuro(cumulPrimesNormalesCalcule);
  }
  
  private QuantiteEuro determinerRemunerationPrimesExceptionnelles(Periode periodePrc, ActiviteSalarie activiteSalarie, JustificationSRPeriodeActivite justificationSRPeriodeActivite, Collection collectionJustifReductionSalaireMoisCivil)
  {
    BigDecimal cumulPrimesExceptionnellesCalcule = BigDecimal.ZERO;
    
    Chronologie chronoPrimesExceptionnelles = activiteSalarie.getListePrimesExceptionnelles();
    
    BigDecimal montantPrimeBrutAbattu = BigDecimal.ZERO;
    BigDecimal montantPrimeBrutAbattuPrc = BigDecimal.ZERO;
    BigDecimal montantPrimeReduit = BigDecimal.ZERO;
    BigDecimal montantPrimeRetenu = BigDecimal.ZERO;
    
    chronoPrimesExceptionnelles.iterer();
    while (chronoPrimesExceptionnelles.encoreSuivant())
    {
      Prime primeExceptionnelleCourante = (Prime)chronoPrimesExceptionnelles.elementSuivant();
      
      Periode periodePrimeExceptionnelleCourante = new Periode(primeExceptionnelleCourante.getDatePaie(), primeExceptionnelleCourante.getDatePaie());
      if (periodePrc.contient(primeExceptionnelleCourante.getDatePaie()))
      {
        montantPrimeBrutAbattu = DeterminationRemuneration.determinerRemuneration(primeExceptionnelleCourante);
        
        Periode periodeIntersectionPrimePrc = periodePrc.periodeIntersection(activiteSalarie.getPeriode());
        montantPrimeBrutAbattuPrc = Mathematiques.proratiser(montantPrimeBrutAbattu, BigDecimal.valueOf(periodeIntersectionPrimePrc.getDuree()), BigDecimal.valueOf(activiteSalarie.getPeriode().getDuree()));
        
        montantPrimeReduit = determinerMontantRemunerationReduitParEcretement(activiteSalarie, collectionJustifReductionSalaireMoisCivil, periodeIntersectionPrimePrc, montantPrimeBrutAbattuPrc, 3, primeExceptionnelleCourante.getDatePaie());
        
        montantPrimeRetenu = montantPrimeReduit;
        
        cumulPrimesExceptionnellesCalcule = cumulPrimesExceptionnellesCalcule.add(montantPrimeRetenu);
        
        JustificationSRPeriodeRemuneration justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
        justifSRPeriodeRemuneration.setPeriode(periodePrimeExceptionnelleCourante);
        justifSRPeriodeRemuneration.setNature(3);
        justifSRPeriodeRemuneration.setDatePaie(primeExceptionnelleCourante.getDatePaie());
        
        justifSRPeriodeRemuneration.setMontantBrut(primeExceptionnelleCourante.getMontantSoumisAContribution());
        
        justifSRPeriodeRemuneration.setMontantReduit(new QuantiteEuro(montantPrimeReduit));
        
        justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro(montantPrimeRetenu));
        justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
      }
    }
    return new QuantiteEuro(cumulPrimesExceptionnellesCalcule);
  }
  
  private QuantiteEuro determinerRemunerationPrimesICRS(Demande demande, Periode periodePrc, ActiviteSalarie activiteSalarie, JustificationSRPeriodeActivite justificationSRPeriodeActivite, Collection collectionJustifReductionSalaireMoisCivil)
    throws CoucheLogiqueException
  {
    BigDecimal cumulPrimesICRSCalcule = BigDecimal.ZERO;
    
    PeriodeNonDeclareeSanction periodesNonDeclareeSanction = determinerPnds(demande, periodePrc, activiteSalarie);
    
    Chronologie chronoPrimesICRS = activiteSalarie.getListePrimesICRS();
    Prime primeICRSCourante = null;
    chronoPrimesICRS.iterer();
    while (chronoPrimesICRS.encoreSuivant())
    {
      primeICRSCourante = (Prime)chronoPrimesICRS.elementSuivant();
      
      BigDecimal montantPrimesICRSBrutAbattuEtProratise = DeterminationRemuneration.determinerRemunerationProratiseeDansPeriodeRef(primeICRSCourante, periodePrc);
      
      Periode periodeIntersectionSalairePrc = periodePrc.periodeIntersection(new Periode(primeICRSCourante.getDateDebut(), primeICRSCourante.getDateFin()));
      
      BigDecimal montantPrimesICRSReduit = determinerMontantRemunerationReduitParEcretement(activiteSalarie, collectionJustifReductionSalaireMoisCivil, periodeIntersectionSalairePrc, montantPrimesICRSBrutAbattuEtProratise, 5, null);
      
      BigDecimal montantPrimesICRSRetenu = determinerMontantRemunerationParDeductionPnds(periodeIntersectionSalairePrc, montantPrimesICRSReduit, periodesNonDeclareeSanction);
      
      cumulPrimesICRSCalcule = cumulPrimesICRSCalcule.add(montantPrimesICRSRetenu);
      
      JustificationSRPeriodeRemuneration justifSRPeriodeRemuneration = new JustificationSRPeriodeRemuneration();
      justifSRPeriodeRemuneration.setPeriode(new Periode(primeICRSCourante.getDateDebut(), primeICRSCourante.getDateFin()));
      justifSRPeriodeRemuneration.setNature(5);
      justifSRPeriodeRemuneration.setDatePaie(primeICRSCourante.getDatePaie());
      
      justifSRPeriodeRemuneration.setMontantBrut(primeICRSCourante.getMontantSoumisAContribution());
      
      justifSRPeriodeRemuneration.setMontantReduit(new QuantiteEuro(montantPrimesICRSReduit));
      
      justifSRPeriodeRemuneration.setMontantRetenu(new QuantiteEuro(montantPrimesICRSRetenu));
      justificationSRPeriodeActivite.ajouterPeriodeRemuneration(justifSRPeriodeRemuneration);
    }
    return new QuantiteEuro(cumulPrimesICRSCalcule);
  }
  
  private void leverAlerteNonBloquante(Demande demande, ActiviteSalarie activiteSalarie, String codeAlerteNonBloquante)
  {
    Collection listeActivitesSalariees = null;
    if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(activiteSalarie);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(activiteSalarie));
      demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
  
  private BigDecimal determinerMontantRemunerationReduitParEcretement(ActiviteSalarie activite, Collection collectionJustifReductionSalaireMoisCivil, Periode periodeRemunerationDansPrc, BigDecimal montantRemuneration, int natureRemuneration, Damj datePaiePrimeExceptionnelle)
  {
    BigDecimal montantRemunerationReduitCumule = BigDecimal.ZERO;
    boolean applicationCoefficientReducteur = false;
    JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivilCourant = null;
    RemunerationSpec remunerationSurMoisCivilCourant;
    Periode periodeRemunerationSurMoisCivilCourant;
    BigDecimal montantRemunerationSurMoisCivilCourant;
    Iterator iterateurRemunerations;
    Iterator iterJustifMoisCivil;
    if ((natureRemuneration == 1) || (natureRemuneration == 2) || (natureRemuneration == 5))
    {
      Collection collectionRemunerationsSurMoisCivils = DeterminationRemuneration.decouperRemunerationSurMoisCivils(periodeRemunerationDansPrc, montantRemuneration, natureRemuneration);
      
      remunerationSurMoisCivilCourant = null;
      periodeRemunerationSurMoisCivilCourant = null;
      montantRemunerationSurMoisCivilCourant = BigDecimal.ZERO;
      for (iterateurRemunerations = collectionRemunerationsSurMoisCivils.iterator(); iterateurRemunerations.hasNext();)
      {
        remunerationSurMoisCivilCourant = (RemunerationSpec)iterateurRemunerations.next();
        periodeRemunerationSurMoisCivilCourant = new Periode(remunerationSurMoisCivilCourant.getDateDebut(), remunerationSurMoisCivilCourant.getDateFin());
        
        montantRemunerationSurMoisCivilCourant = remunerationSurMoisCivilCourant.getMontantSoumisAContribution().getValeurMontant();
        
        boolean estMontantReduit = false;
        for (Iterator iterJustifMoisCivil = collectionJustifReductionSalaireMoisCivil.iterator(); iterJustifMoisCivil.hasNext();)
        {
          justifReductionSalaireMoisCivilCourant = (JustificationReductionSalaireMoisCivil)iterJustifMoisCivil.next();
          if (justifReductionSalaireMoisCivilCourant.getPeriode().chevauche(periodeRemunerationSurMoisCivilCourant))
          {
            if (getCoefficientEcretementHeures(justifReductionSalaireMoisCivilCourant, activite).compareTo(BigDecimal.ONE) < 0)
            {
              applicationCoefficientReducteur = true;
              estMontantReduit = true;
              montantRemunerationSurMoisCivilCourant = montantRemunerationSurMoisCivilCourant.multiply(getCoefficientEcretementHeures(justifReductionSalaireMoisCivilCourant, activite));
            }
            if (justifReductionSalaireMoisCivilCourant.getCoefficientEcretementCachets().compareTo(BigDecimal.ONE) < 0)
            {
              estMontantReduit = true;
              applicationCoefficientReducteur = true;
              montantRemunerationSurMoisCivilCourant = montantRemunerationSurMoisCivilCourant.multiply(justifReductionSalaireMoisCivilCourant.getCoefficientEcretementCachets());
            }
            montantRemunerationReduitCumule = montantRemunerationReduitCumule.add(montantRemunerationSurMoisCivilCourant);
          }
        }
        if (!estMontantReduit) {
          montantRemunerationReduitCumule = montantRemunerationReduitCumule.add(montantRemunerationSurMoisCivilCourant);
        }
      }
    }
    else if (natureRemuneration == 3)
    {
      for (iterJustifMoisCivil = collectionJustifReductionSalaireMoisCivil.iterator(); iterJustifMoisCivil.hasNext();)
      {
        justifReductionSalaireMoisCivilCourant = (JustificationReductionSalaireMoisCivil)iterJustifMoisCivil.next();
        if (justifReductionSalaireMoisCivilCourant.getPeriode().contient(datePaiePrimeExceptionnelle))
        {
          montantRemunerationReduitCumule = montantRemuneration;
          if (getCoefficientEcretementHeures(justifReductionSalaireMoisCivilCourant, activite).compareTo(BigDecimal.ONE) < 0)
          {
            applicationCoefficientReducteur = true;
            montantRemunerationReduitCumule = montantRemunerationReduitCumule.multiply(getCoefficientEcretementHeures(justifReductionSalaireMoisCivilCourant, activite));
          }
          if (justifReductionSalaireMoisCivilCourant.getCoefficientEcretementCachets().compareTo(BigDecimal.ONE) < 0)
          {
            applicationCoefficientReducteur = true;
            montantRemunerationReduitCumule = montantRemunerationReduitCumule.multiply(justifReductionSalaireMoisCivilCourant.getCoefficientEcretementCachets());
          }
        }
      }
    }
    if (applicationCoefficientReducteur) {
      return arrondirValeurPourPersistenceEtJustification(montantRemunerationReduitCumule, 2);
    }
    return montantRemuneration;
  }
  
  protected BigDecimal getCoefficientEcretementHeures(JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivilCourant, ActiviteSalarie activite)
  {
    return justifReductionSalaireMoisCivilCourant.getCoefficientEcretementHeures();
  }
  
  private BigDecimal determinerCoefficientEcretementHeures(PeriodeElementaireAffiliation periodeElementaireAffiliation, JustificationReductionSalaireMoisCivil justificationReductionSalaireMoisCivil)
  {
    BigDecimal coefficientEcretementHeures = BigDecimal.ONE;
    
    BigDecimal nominateur = periodeElementaireAffiliation.getMontantPlafondHeures();
    BigDecimal denominateur = periodeElementaireAffiliation.getQuantiteHeureExercee();
    coefficientEcretementHeures = Mathematiques.diviseParDefaut(nominateur, denominateur);
    
    coefficientEcretementHeures = arrondirValeurPourPersistenceEtJustification(coefficientEcretementHeures, 4);
    
    coefficientEcretementHeures = coefficientEcretementHeures.min(BigDecimal.ONE);
    
    justificationReductionSalaireMoisCivil.setCoefficientEcretementHeures(coefficientEcretementHeures);
    
    justificationReductionSalaireMoisCivil.setMontantPlafondHeures(arrondirValeurPourPersistenceEtJustification(nominateur, 2));
    
    justificationReductionSalaireMoisCivil.setTotalHeures(arrondirValeurPourPersistenceEtJustification(denominateur, 2));
    
    return coefficientEcretementHeures;
  }
  
  protected BigDecimal determinerCoefficientEcretementCachets(PeriodeElementaireAffiliation periodeElementaireAffiliation, JustificationReductionSalaireMoisCivil justificationReductionSalaireMoisCivil)
  {
    BigDecimal coefficientEcretementCachets = BigDecimal.ONE;
    
    BigDecimal nominateur = periodeElementaireAffiliation.getMontantPlafondCachets();
    BigDecimal denominateur = periodeElementaireAffiliation.getSommeCachetA10();
    if (periodeElementaireAffiliation.getHeuresComplementairesA10() != null) {
      denominateur = denominateur.add(Mathematiques.diviseParDefaut(periodeElementaireAffiliation.getHeuresComplementairesA10(), CONVERSION_HEURES_CACHETS));
    }
    coefficientEcretementCachets = Mathematiques.diviseParDefaut(nominateur, denominateur);
    
    coefficientEcretementCachets = arrondirValeurPourPersistenceEtJustification(coefficientEcretementCachets, 4);
    
    coefficientEcretementCachets = coefficientEcretementCachets.min(BigDecimal.ONE);
    
    justificationReductionSalaireMoisCivil.setCoefficientEcretementCachets(coefficientEcretementCachets);
    
    justificationReductionSalaireMoisCivil.setMontantPlafondCachets(arrondirValeurPourPersistenceEtJustification(nominateur, 2));
    
    justificationReductionSalaireMoisCivil.setTotalCachets(arrondirValeurPourPersistenceEtJustification(denominateur, 2));
    
    return coefficientEcretementCachets;
  }
  
  private BigDecimal determinerMontantRemunerationParDeductionPnds(Periode periodeIntersectionSalairePrc, BigDecimal montantSalaire, PeriodeNonDeclareeSanction periodesNonDeclareeSanction)
  {
    BigDecimal montantSalaireRetourne = montantSalaire;
    if (periodesNonDeclareeSanction != null)
    {
      ChronologiePeriodes chronoPeriodesPnds = periodesNonDeclareeSanction.getChronoPeriodePNDS();
      if ((chronoPeriodesPnds != null) && (periodeIntersectionSalairePrc.inter(chronoPeriodesPnds) > 0))
      {
        int nombrejoursSalaire = periodeIntersectionSalairePrc.getDuree();
        int nombreJoursHorsPNDS = nombrejoursSalaire - periodeIntersectionSalairePrc.inter(chronoPeriodesPnds);
        
        montantSalaireRetourne = arrondirValeurPourPersistenceEtJustification(Mathematiques.proratiser(montantSalaire, BigDecimal.valueOf(nombreJoursHorsPNDS), BigDecimal.valueOf(nombrejoursSalaire)), 2);
      }
    }
    return montantSalaireRetourne;
  }
  
  public static BigDecimal determinerPlafondSrr(int nombreJoursEmploiPrc, Damj dateRevalorisation)
  {
    BigDecimal plafondSrr = BigDecimal.ZERO;
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    BigDecimal plafondMensuelApplicable = parametresIndemnisation.getElementActif(dateRevalorisation).getPlafond();
    BigDecimal plafondJournalierApplicable = Mathematiques.proratiser(NBRE_MOIS_ANNEE, plafondMensuelApplicable, NBRE_JOURS_ANNEE);
    
    plafondSrr = plafondJournalierApplicable.multiply(BigDecimal.valueOf(nombreJoursEmploiPrc));
    
    return Mathematiques.tronque(plafondSrr, 2);
  }
  
  protected void determinerPlafondPSrr(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Chronologie chronoActivitesSalariesParticipantSr, Damj dateRevalorisation)
  {
    int nbJoursEmploiPRC = determinerNbJoursEmploiDansPrc(demande.getDonneesTemporaires().getNbJourContratSurPraSpectacle(), constitutionSalaireReference.getPrc(), chronoActivitesSalariesParticipantSr);
    
    constitutionSalaireReference.setNombreJoursEmploiDansPRC(nbJoursEmploiPRC);
    
    BigDecimal plafondSrr = determinerPlafondSrr(nbJoursEmploiPRC, dateRevalorisation);
    
    constitutionSalaireReference.setMontantPlafond(new QuantiteEuro(plafondSrr));
  }
  
  private PeriodeNonDeclareeSanction determinerPnds(Demande demande, Periode periodePrc, ActiviteSalarie activiteSalarie)
    throws CoucheLogiqueException
  {
    PeriodeNonDeclareeSanction periodesNonDeclareeSanction = null;
    try
    {
      Damj dateExamen = demande.getDateExamen();
      if ((dateExamen.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Activation des nouvelles sanctions pour les PND Spectacle en 17SI2"))) || (dateExamen.estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS")))) {
        if (activiteSalarie.estPndsSpectacleCharge())
        {
          periodesNonDeclareeSanction = activiteSalarie.getPndsSpectacle();
        }
        else
        {
          periodesNonDeclareeSanction = OutilDeterminationPNDS.determinerPNDS(demande.getDemandeur(), activiteSalarie, activiteSalarie.getDateDebut(), activiteSalarie.getDateFin(), demande.getDateFaitGenerateurOuDernierSinistre(), demande.getDateExamen());
          
          activiteSalarie.setPndsSpectacleCharge(true);
          activiteSalarie.setPndsSpectacle(periodesNonDeclareeSanction);
        }
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
    if (periodesNonDeclareeSanction != null)
    {
      ChronologiePeriodes chronoPeriodesPnds = periodesNonDeclareeSanction.getChronoPeriodePNDS();
      if (periodePrc.inter(chronoPeriodesPnds) > 0) {
        leverAlerteNonBloquanteA11MNB10(demande, chronoPeriodesPnds);
      }
    }
    return periodesNonDeclareeSanction;
  }
  
  public static int determinerNbJoursEmploiDansPrc(Quantite nbJourContratSurPraSpectacleForce, Periode prc, Chronologie chronoActivitesSalariesParticipantSr)
  {
    int nombreJoursEmploiPrc = 0;
    Quantite nombreJoursEmploiPrcForce = nbJourContratSurPraSpectacleForce;
    if (nombreJoursEmploiPrcForce != null)
    {
      nombreJoursEmploiPrc = nombreJoursEmploiPrcForce.getValeurEntiere();
    }
    else
    {
      Periode periodePrc = prc;
      
      ChronologiePeriodes chronoActivitesSalariesParticipantSrSansChevauchement = null;
      if (chronoActivitesSalariesParticipantSr.contientChevauchementElements()) {
        chronoActivitesSalariesParticipantSrSansChevauchement = ((ChronologiePeriodes)chronoActivitesSalariesParticipantSr).fusionnerChevauchementPeriodes();
      } else {
        chronoActivitesSalariesParticipantSrSansChevauchement = (ChronologiePeriodes)chronoActivitesSalariesParticipantSr;
      }
      nombreJoursEmploiPrc = periodePrc.inter(chronoActivitesSalariesParticipantSrSansChevauchement);
    }
    return nombreJoursEmploiPrc;
  }
  
  private void leverAlerteNonBloquanteA11MNB10(Demande demande, Chronologie chronoPnds)
  {
    String codeAlerteNonBloquante = "A11MNB10";
    
    Collection listeObjetAlerteNonBloquante = new ArrayList();
    for (Iterator iterPnds = chronoPnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listeObjetAlerteNonBloquante.add(objetAlerteNonBloquante);
    }
    demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeObjetAlerteNonBloquante);
  }
  
  protected BigDecimal arrondirValeurPourPersistenceEtJustification(BigDecimal valeur, int puissance)
  {
    return Mathematiques.arrondiASup(valeur, puissance);
  }
}

/* Location:
 * Qualified Name:     DeterminationSalaireReference
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */