package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeAreEfe;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieContexteRepriseSystematique;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.StrategieContexteRepriseSystematiqueSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieObjectifAntecedentSPApres;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieObjectifAntecedentSPAvant;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieObjectifAntecedentSPSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import java.util.ArrayList;
import java.util.List;

public class OutilDeterminationOrdreObjectifs
{
  private static final int NUMERO_PREMIER_OBJECTIF = 1;
  private static OutilDeterminationOrdreObjectifs instance = null;
  
  public static OutilDeterminationOrdreObjectifs getInstance()
  {
    if (instance == null) {
      instance = new OutilDeterminationOrdreObjectifs();
    }
    return instance;
  }
  
  public void determinerObjectifs(Demande demande, int contexteExamen)
    throws ApplicativeException
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ENTREECRA")) {
      determinerObjectifsReadmission(listeTypesObjectifs);
    } else {
      switch (contexteExamen)
      {
      case 1: 
        determinerObjectifsSansAntecedent(listeTypesObjectifs);
        break;
      case 2: 
        determinerObjectifsAvecAntecedentNonValide(demande, listeTypesObjectifs);
        break;
      case 3: 
        determinerObjectifsAvecAntecedentValide(demande, listeTypesObjectifs);
        break;
      case 4: 
        determinerObjectifsAntecedentSecteurPublic(demande, listeTypesObjectifs);
      }
    }
    int numeroOrdre = 1;
    
    demande.viderListeObjectifsExamen();
    for (int i = 0; i < listeTypesObjectifs.size(); i++)
    {
      int sousTypeObjectif = ((Integer)listeTypesObjectifs.get(i)).intValue();
      ObjectifExamen objectif = demande.creerObjectifExamen(sousTypeObjectif, getProduit(sousTypeObjectif, demande));
      
      numeroOrdre = ajouteObjectifSurDemande(objectif, demande, numeroOrdre);
    }
  }
  
  private static int ajouteObjectifSurDemande(ObjectifExamen objectif, Demande demandeCourante, int numeroOrdre)
  {
    objectif.setNumeroOrdre(numeroOrdre);
    demandeCourante.ajouterObjectifExamen(objectif);
    
    return numeroOrdre + 1;
  }
  
  private static ProduitAsuSpec getProduit(int sousTypeObjectif, Demande demande)
  {
    ProduitAsuSpec produit = null;
    if ((sousTypeObjectif == 13) || (sousTypeObjectif == 15) || (sousTypeObjectif == 34) || (sousTypeObjectif == 48))
    {
      AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      produit = (ProduitAsuSpec)odOrigine.getProduit();
    }
    else if ((sousTypeObjectif == 12) || (sousTypeObjectif == 10))
    {
      produit = (ProduitAsuSpec)demande.getDossierAffectationAdmission().getProduit();
    }
    else if (sousTypeObjectif == 50)
    {
      produit = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(demande.getDateExamen());
    }
    return produit;
  }
  
  protected void determinerObjectifsSansAntecedent(List<Integer> listeTypesObjectifs)
  {
    listeTypesObjectifs.add(Integer.valueOf(10));
  }
  
  protected void determinerObjectifsReadmission(List<Integer> listeTypesObjectifs)
  {
    listeTypesObjectifs.add(Integer.valueOf(12));
  }
  
  protected void determinerObjectifsAvecAntecedentNonValide(Demande demande, List<Integer> listeTypesObjectifs)
  {
    listeTypesObjectifs.add(Integer.valueOf(12));
    if ((!demande.estEnContexteDroitAnterieurSecteurPublic()) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "SORTIECRA"))) {
      listeTypesObjectifs.add(Integer.valueOf(13));
    }
  }
  
  protected void determinerObjectifsAvecAntecedentValide(Demande demande, List<Integer> listeTypesObjectifs)
    throws CoucheLogiqueException
  {
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (estUneLiquidationAvecDroitOptionReadmission(demande))
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    else
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(demande.getDateExamen());
      
      StrategieContexteRepriseSystematiqueSpec strategie = (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
      
      AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      if (((ere instanceof EreDemandeExpresse)) || ((ere instanceof EreDemandeAreEfe)))
      {
        listeTypesObjectifs.add(Integer.valueOf(12));
      }
      else if (strategie.determinerContexteRepriseSystematique(odOrigine))
      {
        ajouterObjectifReprise(demande, listeTypesObjectifs, 15);
        listeTypesObjectifs.add(Integer.valueOf(12));
      }
      else
      {
        listeTypesObjectifs.add(Integer.valueOf(12));
        ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
      }
    }
  }
  
  protected static void determinerObjectifsAntecedentSecteurPublic(Demande demande, List<Integer> listeTypesObjectifs)
    throws CoucheLogiqueException
  {
    StrategieObjectifAntecedentSPSpec strategie = (StrategieObjectifAntecedentSPSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Blocage antecedent SP pour spectacle.", new StrategieObjectifAntecedentSPAvant(), new StrategieObjectifAntecedentSPApres());
    
    strategie.determinerObjectifsAntecedentSecteurPublic(demande, listeTypesObjectifs);
  }
  
  public static boolean estUneLiquidationAvecDroitOptionReadmission(Demande demande)
  {
    return demande.estDroitOptionReadmission();
  }
  
  public static void ajouterObjectifReprise(Demande demande, List<Integer> listeTypesObjectifs, int typeReprise)
  {
    boolean estContexteAdmissionSortieCsp = ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPDC")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPARE"))) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "PREPOSTCSP"));
    
    boolean estContexteAdmissionSortiePap = ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPDC")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPARE"))) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "PREPOSTCSP"));
    if ("S".equalsIgnoreCase(demande.getModeLiquidation())) {
      listeTypesObjectifs.add(Integer.valueOf(34));
    } else if ((estContexteAdmissionSortieCsp) || (estContexteAdmissionSortiePap)) {
      listeTypesObjectifs.add(Integer.valueOf(48));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(typeReprise));
    }
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationOrdreObjectifs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */