package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ConstructionChronologie;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.JustifierAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ResultatValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.FacadeLiquidationProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreLigne;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreODValidee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreOu;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourNumeroGamme;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class RechercheValiditeProduit
  implements OutilFonctionnel
{
  private static final JustifierAffiliationSpec JUSTIFIER_AFFILIATION = new JustifierAffiliation();
  private static final ParametresAffiliationSpec PARAMETRES_AFFILIATION = new ParametresAffiliation();
  private static final ConstructionChronologieSpec CONSTRUCTION_CHRONOLOGIE = new ConstructionChronologie();
  
  public static RechercheValiditeProduit getInstance()
  {
    return new RechercheValiditeProduit();
  }
  
  public ValidationProduitSpec validerProduit(ActiviteSalarie activiteSalarie, DemandeAssuranceSpec demandeAssurance)
    throws ApplicativeException
  {
    ResultatValidationProduit resultatValidation = executerValidationProduit(activiteSalarie, demandeAssurance);
    
    ValidationProduit validationProduit = new ValidationProduit();
    alimenterValidationProduit(validationProduit, resultatValidation);
    
    return validationProduit;
  }
  
  public ResultatValidationProduit executerValidationProduit(ActiviteSalarie activiteSalarie, DemandeAssuranceSpec demandeAssurance)
    throws ApplicativeException
  {
    ResultatValidationProduit resultatValidation = new ResultatValidationProduit();
    Damj dateAttributionPrecedente = determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance);
    Damj dateBornePRA = determinerDateBornePRA(demandeAssurance);
    if (dateBornePRA == null) {
      dateAttributionPrecedente = null;
    }
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    parametres.setFaitGenerateurDroit(activiteSalarie);
    
    parametres.setDateExamen(demandeAssurance.getDateExamen());
    if (presenceDonneesForceesValidationProduit(demandeAssurance)) {
      traitementAffiliationForcee(resultatValidation, demandeAssurance, parametres, dateBornePRA, activiteSalarie);
    } else {
      traitementAutomatiqueAffiliation(resultatValidation, demandeAssurance, parametres, dateBornePRA, activiteSalarie, dateAttributionPrecedente);
    }
    return resultatValidation;
  }
  
  private void traitementAffiliationForcee(ResultatValidationProduit resultatValidation, DemandeAssuranceSpec demandeAssurance, ParametresCalculAffiliation parametres, Damj dateBornePRA, ActiviteSalarie activiteSalarie)
  {
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    
    Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
    
    parametres.setReglementEtudie(determinerReglementApplicableDonneesForcees(demandeAssurance));
    if (demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle() != null) {
      parametres.setRangEtude(demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle().intValue());
    }
    List<AllongementPra> listeAllongementPeriodeAJustifier = new ArrayList();
    ConteneurDeterminationPeriodeReference conteneur = new ConteneurDeterminationPeriodeReference();
    conteneur.setIndividu(individu);
    conteneur.setConstructionChronologie(getOutilConstructionChrono());
    conteneur.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
    conteneur.setTermePeriodeReference(activiteSalarie.getDateFin());
    conteneur.setDateBornePRA(dateBornePRA);
    conteneur.setListeAllongementPRA(listeAllongementPeriodeAJustifier);
    conteneur.setJustifierAffiliation(getJustifAffi());
    conteneur.setPrimo(determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance) == null);
    conteneur.setEstContexteSortieClauseRattrapage(false);
    Periode pra = DeterminationPeriodeReference.getInstance().determinerPeriodeDeReference(conteneur);
    
    Quantite quantiteAffiliationRequise = determinerQuantiteAffiliationRequise(parametres);
    
    Quantite quantiteAppartenanceARetenir = demandeAssurance.getDonneesTemporaires().getQuantiteAffiliation();
    if ((demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle() == null) || (demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle().intValue() == 0))
    {
      resultatValidation.setQuantiteAcquiseAuRangInitial(quantiteAppartenanceARetenir);
      resultatValidation.setPraAuRangInitial(pra);
      resultatValidation.setHeuresRequisesAuRangInitial(quantiteAffiliationRequise);
    }
    if (quantiteAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, null)) {
      produitValide = true;
    }
    alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteSalarie, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, null, produitValide);
    
    getJustifAffi().justifierAllongementPeriodeReference(resultatValidation.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
    
    alimenterAlertesNonBloquantesPourDemande(demandeAssurance, listeAlertesNonBloquantes);
  }
  
  private void traitementAutomatiqueAffiliation(ResultatValidationProduit resultatValidation, DemandeAssuranceSpec demandeAssurance, ParametresCalculAffiliation parametres, Damj dateBornePRA, ActiviteSalarie activiteSalarie, Damj dateAttributionPrecedente)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    Periode pra = null;
    Quantite quantiteAffiliationRequise = null;
    Quantite quantiteAppartenanceARetenir = null;
    Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
    List<AllongementPra> listeAllongementPeriodeAJustifier = null;
    JustificationAffiliation justification = null;
    
    parametres.setRangEtude(0);
    
    boolean poursuivreEtude = true;
    while ((poursuivreEtude) && (!produitValide))
    {
      parametres.setReglementEtudie(getReglementA8());
      List<AllongementPra> listeAllongementPRAA8 = new ArrayList();
      
      ConteneurDeterminationPeriodeReference conteneurA8 = new ConteneurDeterminationPeriodeReference();
      conteneurA8.setIndividu(individu);
      conteneurA8.setConstructionChronologie(getOutilConstructionChrono());
      conteneurA8.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
      conteneurA8.setTermePeriodeReference(activiteSalarie.getDateFin());
      conteneurA8.setDateBornePRA(dateBornePRA);
      conteneurA8.setListeAllongementPRA(listeAllongementPRAA8);
      conteneurA8.setJustifierAffiliation(getJustifAffi());
      conteneurA8.setPrimo(determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance) == null);
      conteneurA8.setEstContexteSortieClauseRattrapage(false);
      Periode periodeReferenceA8 = DeterminationPeriodeReference.getInstance().determinerPeriodeDeReference(conteneurA8);
      
      parametres.setDemande((Demande)demandeAssurance);
      
      Quantite quantiteReglementA8 = determinerQuantiteActiviteAuTitreDuReglement(individu, parametres, periodeReferenceA8);
      
      parametres.setReglementEtudie(getReglementA10());
      List<AllongementPra> listeAllongementPRAA10 = new ArrayList();
      
      ConteneurDeterminationPeriodeReference conteneurA10 = new ConteneurDeterminationPeriodeReference();
      conteneurA10.setIndividu(individu);
      conteneurA10.setConstructionChronologie(getOutilConstructionChrono());
      conteneurA10.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
      conteneurA10.setTermePeriodeReference(activiteSalarie.getDateFin());
      conteneurA10.setDateBornePRA(dateBornePRA);
      conteneurA10.setListeAllongementPRA(listeAllongementPRAA10);
      conteneurA10.setJustifierAffiliation(getJustifAffi());
      conteneurA10.setPrimo(determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance) == null);
      conteneurA10.setEstContexteSortieClauseRattrapage(false);
      Periode periodeReferenceA10 = DeterminationPeriodeReference.getInstance().determinerPeriodeDeReference(conteneurA10);
      
      Quantite quantiteReglementA10 = determinerQuantiteActiviteAuTitreDuReglement(individu, parametres, periodeReferenceA10);
      
      Reglement reglementApplicable = determinerReglementApplicable(quantiteReglementA8, quantiteReglementA10, activiteSalarie);
      parametres.setReglementEtudie(reglementApplicable);
      
      pra = trouverPeriodeReferenceAffiliationRetenir(periodeReferenceA8, periodeReferenceA10, reglementApplicable);
      
      quantiteAffiliationRequise = determinerQuantiteAffiliationRequise(parametres);
      
      ValidationProduit validationProduit = new ValidationProduit();
      justification = validationProduit.createJustificationAffiliation();
      
      parametres.setDemande((Demande)demandeAssurance);
      quantiteAppartenanceARetenir = calculerQuantiteGlobaleAffiliation(individu, justification, parametres, pra, quantiteAffiliationRequise, listeAlertesNonBloquantes);
      if (0 == parametres.getRangEtude())
      {
        resultatValidation.setQuantiteAcquiseAuRangInitial(quantiteAppartenanceARetenir);
        resultatValidation.setPraAuRangInitial(pra);
        resultatValidation.setHeuresRequisesAuRangInitial(quantiteAffiliationRequise);
        if (justification != null) {
          resultatValidation.setJustificationAssimilationAuRangInitial(justification.getCollectionAssimilation());
        }
      }
      listeAllongementPeriodeAJustifier = determinerListeAllongementPeriodePourJustification(reglementApplicable, listeAllongementPRAA8, listeAllongementPRAA10);
      if (quantiteAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, justification)) {
        produitValide = true;
      } else {
        poursuivreEtude = verifierConditionsPoursuiteEtude(parametres, dateAttributionPrecedente, dateBornePRA, pra);
      }
    }
    alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteSalarie, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
    
    getJustifAffi().justifierAllongementPeriodeReference(resultatValidation.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
    
    alimenterAlertesNonBloquantesPourDemande(demandeAssurance, listeAlertesNonBloquantes);
  }
  
  protected void alimenterAlertesNonBloquantesPourDemande(DemandeAssuranceSpec demande, Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes)
  {
    if (listeAlertesNonBloquantes != null)
    {
      List<ObjetAlertesNonBloquantes> listeAlertePNDS = new ArrayList();
      
      Iterator<ObjetAlertesNonBloquantes> itAlertesNonBloquantes = listeAlertesNonBloquantes.iterator();
      while (itAlertesNonBloquantes.hasNext())
      {
        ObjetAlertesNonBloquantes alerteNonBloquantes = (ObjetAlertesNonBloquantes)itAlertesNonBloquantes.next();
        if (alerteNonBloquantes.getTypeNature() == 7) {
          listeAlertePNDS.add(alerteNonBloquantes);
        }
      }
      if (!listeAlertePNDS.isEmpty()) {
        demande.getAlertesNonBloquantes().put("A11MNB9", listeAlertePNDS);
      }
    }
  }
  
  protected void alimenterValidationProduit(ValidationProduit validation, ResultatValidationProduit resultatValidationProduit)
  {
    validation.setCatEmploiPart(resultatValidationProduit.getCatEmploiPart());
    validation.setCodeProduitValide(resultatValidationProduit.getCodeProduitValide());
    validation.setDateFinPeriode(resultatValidationProduit.getDateFinPeriode());
    validation.setDjtpPeriode(resultatValidationProduit.getDjtpPeriode());
    validation.setIdentifiantPeriodeValidationProduit(resultatValidationProduit.getIdentifiantPeriodeValidationProduit());
    validation.setMotifFinPeriode(resultatValidationProduit.getMotifFinPeriode());
    validation.setNomReglementApplicable(resultatValidationProduit.getNomReglementApplicable());
    validation.setPeriodePra(resultatValidationProduit.getPeriodePra());
    validation.setPeriodeValidationProduit(resultatValidationProduit.getPeriodeValidationProduit());
    validation.setPopOccHorsFrance(resultatValidationProduit.getPopOccHorsFrance());
    validation.setProduitValide(resultatValidationProduit.getProduitValide());
    validation.setQteAcquise(resultatValidationProduit.getQteAcquise());
    validation.setQuantiteAcquise(resultatValidationProduit.getQuantiteAcquise());
    validation.setReglementApplicable(resultatValidationProduit.getReglementApplicable());
    validation.setHeuresRequises(resultatValidationProduit.getHeuresRequises());
    validation.setRangAllongement(resultatValidationProduit.getRangAllongement());
    validation.setEstProduitValide(resultatValidationProduit.isProduitValide());
    validation.setQuantiteAffiAcquiseRangInitial(resultatValidationProduit.getQuantiteAcquiseAuRangInitial());
    validation.setPraAuRangInitial(resultatValidationProduit.getPraAuRangInitial());
    validation.setHeuresRequisesAuRangInitial(resultatValidationProduit.getHeuresRequisesAuRangInitial());
    validation.setJustificationAssimilationAuRangInitial(resultatValidationProduit.getJustificationAssimilationAuRangInitial());
    JustificationAffiliation justification = resultatValidationProduit.getJustificationAffiliation();
    if (justification != null)
    {
      JustificationAffiliation justificationPourValidation = validation.createJustificationAffiliation();
      justification.copieElements(justificationPourValidation);
    }
  }
  
  protected Reglement determinerReglementApplicableDonneesForcees(DemandeAssuranceSpec demandeAssurance)
  {
    return getProduit().getReglement(demandeAssurance.getDonneesTemporaires().getReglementApplicableSpectacle());
  }
  
  protected List<AllongementPra> determinerListeAllongementPeriodePourJustification(Reglement reglementApplicable, List<AllongementPra> listeAllongementPRAA8, List<AllongementPra> listeAllongementPRAA10)
  {
    if (reglementApplicable.equals(getReglementA10())) {
      return listeAllongementPRAA10;
    }
    return listeAllongementPRAA8;
  }
  
  protected boolean quantiteAcquiseSuffisante(Quantite quantiteAppartenanceAcquise, Quantite quantiteRequise, JustificationAffiliation justification)
  {
    if (justification != null)
    {
      Iterator<?> itPeriodeElementaireAffi = justification.getListPeriodeElementaireAffiliation().iterator();
      BigDecimal totalAffiliationBase = BigDecimal.ZERO;
      while (itPeriodeElementaireAffi.hasNext())
      {
        PeriodeElementaireAffiliation periodeElementaire = (PeriodeElementaireAffiliation)itPeriodeElementaireAffi.next();
        totalAffiliationBase = totalAffiliationBase.add(periodeElementaire.getAffiliationRetenue((ProduitAsuSpec)getProduit()).getValeur());
      }
      if (totalAffiliationBase.equals(BigDecimal.ZERO)) {
        return false;
      }
    }
    return quantiteAppartenanceAcquise.max(quantiteRequise).equals(quantiteAppartenanceAcquise);
  }
  
  protected boolean presenceDonneesForceesValidationProduit(DemandeAssuranceSpec demande)
  {
    return demande.getDonneesTemporaires().getReglementApplicableSpectacle() != null;
  }
  
  protected Damj determinerDateAttributionProduitSpectaclePrecedent(DemandeAssuranceSpec demande)
  {
    AttributionSpec attribution = demande.rechercherAttributionPrecedenteDuMemeType();
    if (attribution == null) {
      return null;
    }
    ReglementApplicableSpec reglementApplicable = ((DossierExamenAssuranceSpec)attribution).getReglementApplicable();
    if ((reglementApplicable != null) && ((reglementApplicable.getReglement().estNomReglementIdentique("A8")) || (reglementApplicable.getReglement().estNomReglementIdentique("A10")))) {
      return attribution.getDateAttribution();
    }
    return null;
  }
  
  protected Damj determinerDateBornePRA(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateBornePRA = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ARESJREV")) {
      return null;
    }
    FiltrePeriodesSurFiltresExclusifs filtreElementsAExclure = new FiltrePeriodesSurFiltresExclusifs();
    filtreElementsAExclure.ajouterFiltre(new FiltreLigne(LigneAsuSsp07.getInstance()));
    
    filtreElementsAExclure.ajouterFiltre(new FiltreLigne(LigneAsuFds12.getInstance()));
    filtreElementsAExclure.ajouterFiltre(new FiltreNegation(new FiltreODValidee()));
    
    FiltreET filtres = new FiltreET();
    filtres.ajouterFiltre(new FiltreNegation(new FiltreDecisionPourLigne(LigneAsuSsp07.getInstance().getNomUnique())));
    filtres.ajouterFiltre(new FiltreNegation(new FiltreDecisionPourLigne(LigneAsuFds12.getInstance().getNomUnique())));
    filtres.ajouterFiltre(new FiltreOuvertureDroitSurDecision(true));
    filtres.ajouterFiltre(new FiltreDemandePourNumeroGamme(1));
    AttributionSpec attributionPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, filtres);
    if (attributionPrecedente != null)
    {
      Damj dateFaitGenerateurDernierSinistre = ((Demande)attributionPrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre();
      if (dateFaitGenerateurDernierSinistre != null) {
        dateBornePRA = dateFaitGenerateurDernierSinistre.lendemain();
      }
    }
    if (gererDonneesForceesSPpourDateBornePra(dateBornePRA, demande)) {
      dateBornePRA = demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().lendemain();
    }
    return dateBornePRA;
  }
  
  protected boolean gererDonneesForceesSPpourDateBornePra(Damj dateBornePRA, DemandeAssuranceSpec demande)
  {
    boolean doitGererDonneesForceesSP = false;
    if (demande.getDonneesTemporaires().getDateFgDroitAnterieurSp() != null)
    {
      boolean estContexteSp = demande.estEnContexteDroitAnterieurSecteurPublic();
      boolean estContexteSpDateFgdApresPra = (estContexteSp) && (dateBornePRA != null) && (demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().estApres(dateBornePRA));
      if (((estContexteSp) && (dateBornePRA == null)) || (estContexteSpDateFgdApresPra)) {
        doitGererDonneesForceesSP = true;
      }
    }
    return doitGererDonneesForceesSP;
  }
  
  protected Periode trouverPeriodeReferenceAffiliationRetenir(Periode periodeReferenceA8, Periode periodeReferenceA10, Reglement reglementApplicable)
  {
    if (reglementApplicable.getLibelleCourt().equals("A8")) {
      return periodeReferenceA8;
    }
    return periodeReferenceA10;
  }
  
  protected boolean verifierConditionsPoursuiteEtude(ParametresCalculAffiliation parametres, Damj dateAttributionPrecedente, Damj dateBornePRA, Periode pra)
  {
    if ((dateAttributionPrecedente == null) || (!parametres.isPoursuivreEtude())) {
      return false;
    }
    if (pra.getDebut().equals(dateBornePRA)) {
      return false;
    }
    parametres.passerAuRangEtudeSuivant();
    return true;
  }
  
  protected void alimenterResultatCalculAffiliation(ResultatValidationProduit resultatCalcul, ParametresCalculAffiliation parametres, ActiviteSalarie activite, Periode pra, Quantite quantiteHeureRequise, Quantite quantiteHeureAcquise, JustificationAffiliation justification, boolean estProduitValide)
  {
    resultatCalcul.setCatEmploiPart(activite.getCategorieEmploiParticulier());
    resultatCalcul.setCodeProduitValide(getProduit().getCode());
    resultatCalcul.setDateFinPeriode(activite.getDateFin());
    resultatCalcul.setDjtpPeriode(activite.getDernierJourTravaillePaye());
    resultatCalcul.setIdentifiantPeriodeValidationProduit(activite.getIdentifiant());
    resultatCalcul.setMotifFinPeriode(activite.getMotifFin());
    resultatCalcul.setNomReglementApplicable(parametres.getReglementEtudie().getLibelleCourt());
    resultatCalcul.setPeriodePra(pra);
    resultatCalcul.setPeriodeValidationProduit(activite);
    resultatCalcul.setPopOccHorsFrance(activite.getContrat().getPohf());
    resultatCalcul.setProduitValide(getProduit());
    resultatCalcul.setQteAcquise(quantiteHeureAcquise);
    resultatCalcul.setQuantiteAcquise(quantiteHeureAcquise);
    resultatCalcul.setReglementApplicable(parametres.getReglementEtudie());
    resultatCalcul.setHeuresRequises(quantiteHeureRequise);
    resultatCalcul.setRangAllongement(parametres.getRangEtude());
    resultatCalcul.setJustificationAffiliation(justification);
    resultatCalcul.setEstProduitValide(estProduitValide);
  }
  
  protected Quantite determinerQuantiteAffiliationRequise(ParametresCalculAffiliation parametres)
  {
    BigDecimal quantiteAffiliationRequise = getParametresAffiliation().determinerQuantiteAffiliationRequise(parametres);
    return new Quantite(quantiteAffiliationRequise, CalculAppartenance.UNITE_HEURE);
  }
  
  protected Reglement determinerReglementApplicable(Quantite quantiteA8, Quantite quantiteA10, ActiviteSalarie activiteReference)
  {
    if (quantiteA8.equals(quantiteA10)) {
      return activiteReference.getReglement();
    }
    if (quantiteA10.max(quantiteA8).equals(quantiteA8)) {
      return getReglementA8();
    }
    return getReglementA10();
  }
  
  protected Quantite determinerQuantiteActiviteAuTitreDuReglement(IndividuSpec individu, ParametresCalculAffiliation parametres, Periode periodeReference)
    throws CoucheLogiqueException
  {
    List<Reglement> listeReglementPrisEnCompte = new ArrayList();
    listeReglementPrisEnCompte.add(parametres.getReglementEtudie());
    
    ComportementAffiliationSpec comportement = creerComportementAffiliation();
    
    comportement.setCalculTouteAffiliation(false);
    comportement.setCalculAffiliationDeBase(true);
    comportement.setChronologieActivitesParticipantes(recupererChronologiePourCalculAffiliation(individu));
    comportement.setFaitGenerateur(parametres.getFaitGenerateurDroit());
    comportement.setListeReglementPrisEnCompte(listeReglementPrisEnCompte);
    comportement.setPeriodeRecherche(periodeReference);
    comportement.setReglementCandidat(parametres.getReglementEtudie());
    
    comportement.setDateExamen(parametres.getDateExamen());
    
    comportement.setConvertisseurUniteAffiliation(((ProduitAsuSpec)getProduit()).determinerConvertisseurUniteAffiliation());
    
    comportement.setDemande(parametres.getDemande());
    comportement.setEstPrimo(determinerDateAttributionProduitSpectaclePrecedent(parametres.getDemande()) == null);
    
    return CalculAppartenance.calculerQuantiteAffiliation(individu, comportement, null, null);
  }
  
  protected Quantite calculerQuantiteGlobaleAffiliation(IndividuSpec individu, JustificationAffiliation justification, ParametresCalculAffiliation parametres, Periode periodeReference, Quantite quantiteAffiliationRequise, Collection<ObjetAlertesNonBloquantes> collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    List<Reglement> listeReglementPrisEnCompte = new ArrayList();
    listeReglementPrisEnCompte.add(getReglementA8());
    listeReglementPrisEnCompte.add(getReglementA10());
    ComportementAffiliationSpec comportement = creerComportementAffiliation();
    
    comportement.setCalculTouteAffiliation(true);
    comportement.setChronologieActivitesParticipantes(recupererChronologiePourCalculAffiliation(individu));
    comportement.setFaitGenerateur(parametres.getFaitGenerateurDroit());
    
    comportement.setDateExamen(parametres.getDateExamen());
    comportement.setListeReglementPrisEnCompte(listeReglementPrisEnCompte);
    comportement.setPeriodeRecherche(periodeReference);
    comportement.setQuantiteAffiliationRequise(quantiteAffiliationRequise);
    comportement.setReglementCandidat(parametres.getReglementEtudie());
    comportement.setJustifierPeriodesSansAffiliation(false);
    
    comportement.setConvertisseurUniteAffiliation(((ProduitAsuSpec)getProduit()).determinerConvertisseurUniteAffiliation());
    
    comportement.setDemande(parametres.getDemande());
    comportement.setEstPrimo(determinerDateAttributionProduitSpectaclePrecedent(parametres.getDemande()) == null);
    
    return CalculAppartenance.calculerQuantiteAffiliation(individu, comportement, justification, collectionAlertesNonBloquantes);
  }
  
  public Chronologie recupererChronologiePourCalculAffiliation(IndividuSpec individu)
  {
    Chronologie pasPeriodePasseProfessionnel = individu.getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltreOu elementsAPrendreEnCompte = new FiltreOu();
    FiltreNegation nonTravail = new FiltreNegation(new FiltreTravailSpec());
    FiltrePeriodesLiquidables travailLiquidable = new FiltrePeriodesLiquidables();
    elementsAPrendreEnCompte.ajouterFiltre(travailLiquidable);
    elementsAPrendreEnCompte.ajouterFiltre(nonTravail);
    return pasPeriodePasseProfessionnel.copier(elementsAPrendreEnCompte);
  }
  
  protected ProduitSpec getProduit()
  {
    return ProduitAsuSpe02P03.getInstance();
  }
  
  protected Reglement getReglementA8()
  {
    return getProduit().getReglement("A8");
  }
  
  protected Reglement getReglementA10()
  {
    return getProduit().getReglement("A10");
  }
  
  protected JustifierAffiliationSpec getJustifAffi()
  {
    return JUSTIFIER_AFFILIATION;
  }
  
  protected ConstructionChronologieSpec getOutilConstructionChrono()
  {
    return CONSTRUCTION_CHRONOLOGIE;
  }
  
  protected ParametresAffiliationSpec getParametresAffiliation()
  {
    return PARAMETRES_AFFILIATION;
  }
  
  protected ComportementAffiliationSpec creerComportementAffiliation()
  {
    return (ComportementAffiliationSpec)((FacadeLiquidationProduitAsuSpectacleSpec)getProduit()).getComportementAffiliation();
  }
}

/* Location:
 * Qualified Name:     RechercheValiditeProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */