package fr.unedic.cali.asu.spe02.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilPeriodesElementaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RechercheConditionAffiliation;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;

public class DeterminationConditionAffiliation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    IndividuSpec individu = ((DomCali)contexte.getDonnees()).getIndividu();
    DonneesTemporaires donneesForcees = demandeCourante.getDonneesTemporaires();
    
    Resultat resultatCapa07 = new Resultat(1);
    
    boolean estDemandeElligileIPR = estDemandeEligibleASaisineIPR(demandeCourante);
    boolean estDecisionIprPrise = donneesForcees.isEstDesactivationPnds() != null;
    
    String reglementApplicableForcee = donneesForcees.getReglementApplicableSpectacle();
    ConditionQuantiteAffiliation conditionQuantiteAffiliation;
    ConditionQuantiteAffiliation conditionQuantiteAffiliation;
    if ((estDemandeElligileIPR) && (!estDecisionIprPrise) && (reglementApplicableForcee == null))
    {
      conditionQuantiteAffiliation = traitementPourDetectionIPR(demandeCourante, individu);
    }
    else
    {
      ConditionQuantiteAffiliation conditionQuantiteAffiliation;
      if (estDemandeElligileIPR) {
        conditionQuantiteAffiliation = traitementIPR(demandeCourante, individu);
      } else {
        conditionQuantiteAffiliation = traitementStandard(demandeCourante, individu);
      }
    }
    if (conditionQuantiteAffiliation.estSatisfait())
    {
      if (dossierExamenCourant.getConditionFaitGenerateur().estSatisfait()) {
        resultatCapa07.setEtat(0);
      } else {
        resultatCapa07.setEtat(2);
      }
    }
    else
    {
      resultatCapa07.setEtat(1);
      resultatCapa07.setMessageErreur(Integer.toString(conditionQuantiteAffiliation.getCodeMotifEchec()));
    }
    return resultatCapa07;
  }
  
  protected ConditionQuantiteAffiliation traitementStandard(Demande demandeCourante, IndividuSpec individu)
    throws ApplicativeException
  {
    return RechercheConditionAffiliation.rechercherConditionAffiliation(demandeCourante, individu);
  }
  
  protected boolean estDemandeEligibleASaisineIPR(Demande demande)
    throws CoucheLogiqueException
  {
    boolean estDemandeEligible = false;
    Damj dateReactivationPNDS = GestionnaireDateApplication.getInstance().recupererDateApplication("Activation des nouvelles sanctions pour les PND Spectacle en 17SI2");
    if ((demande.getDateExamen().estApresOuCoincideAvec(dateReactivationPNDS)) && (!estDemandeEnContexteClauseDeRattrapage(demande))) {
      estDemandeEligible = true;
    }
    return estDemandeEligible;
  }
  
  protected boolean estDemandeEnContexteClauseDeRattrapage(Demande demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 8);
  }
  
  protected ConditionQuantiteAffiliation traitementIPR(Demande demande, IndividuSpec individu)
    throws ApplicativeException
  {
    ConditionQuantiteAffiliation capa = traitementStandard(demande, individu);
    
    Boolean desactivationPnd = demande.getDonneesTemporaires().isEstDesactivationPnds();
    if ((!capa.estSatisfait()) && (desactivationPnd != null) && (!desactivationPnd.booleanValue())) {
      capa.setEtatPndsPourCalculAffi("N");
    } else if ((capa.estSatisfait()) && (desactivationPnd != null) && (desactivationPnd.booleanValue())) {
      capa.setEtatPndsPourCalculAffi("V");
    }
    return capa;
  }
  
  protected ConditionQuantiteAffiliation traitementPourDetectionIPR(Demande demande, IndividuSpec individu)
    throws ApplicativeException
  {
    ConditionQuantiteAffiliation capa = traitementStandard(demande, individu);
    if (!capa.estSatisfait())
    {
      ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
      
      Periode pra = null;
      if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
        pra = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getJustificationCalculAffiliation().getPeriodeRechercheAffiliation();
      }
      if (pra == null) {
        pra = determinerPra(demande);
      }
      Chronologie chronoPnds = demande.getChronologiePNDS(pra);
      if ((chronoPnds != null) && (!chronoPnds.estVide())) {
        traiterEnDesactivantPnds(demande, individu, capa);
      }
    }
    return capa;
  }
  
  protected Periode determinerPra(Demande demande)
  {
    Damj dateFgPrecedent = demande.getDateFaitGenerateurOdPrecedente();
    Damj dateFin = demande.getDateExamen();
    Damj dateDebut = demande.getDateExamen().deplacerVersArriere(new DureeCalendaire(0, 36, 0));
    if (dateFgPrecedent != null) {
      dateDebut = Damj.max(dateDebut, dateFgPrecedent.lendemain());
    }
    Periode pra = new Periode(dateDebut, dateFin);
    return pra;
  }
  
  protected void traiterEnDesactivantPnds(Demande demande, IndividuSpec individu, ConditionQuantiteAffiliation capa)
    throws ApplicativeException
  {
    OutilPeriodesElementaires.viderCachePeriodesElementaires(individu);
    
    Demande copieDemande = (Demande)demande.copie();
    copieDemande.getDonneesTemporaires().setEstDesactivationPnds(Boolean.valueOf(true));
    try
    {
      lancerLiquidation(copieDemande);
      if (copieDemande.getAttribution() != null) {
        capa.setEtatPndsPourCalculAffi("P");
      }
    }
    finally
    {
      OutilPeriodesElementaires.viderCachePeriodesElementaires(individu);
      individu.activerPNDS();
    }
  }
  
  protected void lancerLiquidation(Demande copieDemande)
    throws ApplicativeException
  {
    Contexte contexte = new Contexte();
    DomLiquidationAssurance domLiq = new DomLiquidationAssurance();
    domLiq.setContexteService(copieDemande.getDemandeur().getContexteService());
    domLiq.setDemande(copieDemande);
    domLiq.setIdDemande(copieDemande.getIdentifiant());
    domLiq.setIndividu(copieDemande.getDemandeur());
    
    contexte.setDonnees(domLiq);
    
    ParcoursLiquidation parcoursLiquidationDemande = copieDemande.getGamme().getParcoursLiquidation(copieDemande);
    
    parcoursLiquidationDemande.effectuerParcours(contexte);
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */