package fr.unedic.cali.asu.spe02.p03.parametres;

import fr.unedic.cali.calcul.dom.EvenementCalculSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoEvenementDebut;
import java.math.BigDecimal;

public class EvenementParametre
  extends ObjetChronoEvenementDebut
  implements EvenementCalculSpec
{
  private static final long serialVersionUID = 7103703795521053035L;
  private BigDecimal m_allocationMinimale = null;
  private boolean m_nouveauAllocationMinimale = false;
  private BigDecimal m_allocationMaximale = null;
  private boolean m_nouveauAllocationMaximale = false;
  private BigDecimal m_cotisationRetraiteComplementaire = null;
  private boolean m_nouveauCotisationRetraiteComplementaire = false;
  private Damj m_dateDeRecherche;
  private static final String ALLOCATION_MINIMALE = "Allocation minimale";
  private static final String ALLOCATION_MAXIMALE = "Allocation maximale";
  private static final String COTISATION_RETRAITE_COMPLEMENTAIRE = "Cotisation retraite complémentaire";
  
  private EvenementParametre() {}
  
  public EvenementParametre(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
    
    setDateDeRecherche(p_dateEvenement);
  }
  
  public BigDecimal getAllocationMinimale()
  {
    return getAllocationMinimale(true);
  }
  
  private void leverApplicativeRuntimeException(String p_nomParametre)
  {
    try
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("PR_CALI_L_ALERTE_A11MB12", new String[] { p_nomParametre, getDateDeRecherche().toString() }, 3);
    }
    catch (CoucheLogiqueException ex) {}
  }
  
  public BigDecimal getAllocationMinimale(boolean p_leverException)
  {
    if ((m_allocationMinimale == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Allocation minimale");
    }
    return m_allocationMinimale;
  }
  
  public BigDecimal getCotisationRetraiteComplementaire()
  {
    return getCotisationRetraiteComplementaire(true);
  }
  
  public BigDecimal getCotisationRetraiteComplementaire(boolean p_leverException)
  {
    if ((m_cotisationRetraiteComplementaire == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Cotisation retraite complémentaire");
    }
    return m_cotisationRetraiteComplementaire;
  }
  
  public boolean isNouveauAllocationMinimale()
  {
    return m_nouveauAllocationMinimale;
  }
  
  public boolean isNouveauCotisationRetraiteComplementaire()
  {
    return m_nouveauCotisationRetraiteComplementaire;
  }
  
  public void repercuter(EvenementParametre p_evtSource)
  {
    boolean memeDateEffet = getDateEffet().equals(p_evtSource.getDateEffet());
    if (m_allocationMinimale == null)
    {
      m_allocationMinimale = p_evtSource.getAllocationMinimale(false);
      if (memeDateEffet) {
        m_nouveauAllocationMinimale = p_evtSource.isNouveauAllocationMinimale();
      }
    }
    else
    {
      m_nouveauAllocationMinimale = true;
    }
    if (m_cotisationRetraiteComplementaire == null)
    {
      m_cotisationRetraiteComplementaire = p_evtSource.getCotisationRetraiteComplementaire(false);
      if (memeDateEffet) {
        m_nouveauCotisationRetraiteComplementaire = p_evtSource.isNouveauCotisationRetraiteComplementaire();
      }
    }
    else
    {
      m_nouveauCotisationRetraiteComplementaire = true;
    }
    if (m_allocationMaximale == null)
    {
      m_allocationMaximale = p_evtSource.getAllocationMaximale(false);
      if (memeDateEffet) {
        m_nouveauAllocationMaximale = p_evtSource.isNouveauAllocationMaximale();
      }
    }
    else
    {
      m_nouveauAllocationMaximale = true;
    }
  }
  
  public void setAllocationMinimale(BigDecimal p_allocationMinimale)
  {
    m_allocationMinimale = p_allocationMinimale;
  }
  
  public void setNouveauAllocationMinimale(boolean p_nouveauAllocationMinimale)
  {
    m_nouveauAllocationMinimale = p_nouveauAllocationMinimale;
  }
  
  public void setNouveauCotisationRetraiteComplementaire(boolean p_nouveauCotisationRetraiteComplementaire)
  {
    m_nouveauCotisationRetraiteComplementaire = p_nouveauCotisationRetraiteComplementaire;
  }
  
  public void setCotisationRetraiteComplementaire(BigDecimal p_cotisationRetraiteComplementaire)
  {
    m_cotisationRetraiteComplementaire = p_cotisationRetraiteComplementaire;
  }
  
  public ObjetMetierSpec copie()
  {
    EvenementParametre copie = new EvenementParametre();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    EvenementParametre copie = (EvenementParametre)p_copie;
    copie.setDateEvenement(getDateEvenement());
    copie.setAllocationMinimale(getAllocationMinimale(false));
    copie.setNouveauAllocationMinimale(isNouveauAllocationMinimale());
    copie.setCotisationRetraiteComplementaire(getCotisationRetraiteComplementaire(false));
    copie.setNouveauCotisationRetraiteComplementaire(isNouveauCotisationRetraiteComplementaire());
    copie.setAllocationMaximale(getAllocationMaximale(false));
    copie.setNouveauAllocationMaximale(isNouveauAllocationMaximale());
  }
  
  public Damj getDateDeRecherche()
  {
    return m_dateDeRecherche;
  }
  
  public void setDateDeRecherche(Damj p_dateDeRecherche)
  {
    m_dateDeRecherche = p_dateDeRecherche;
  }
  
  public BigDecimal getAllocationMaximale()
  {
    return getAllocationMaximale(true);
  }
  
  public BigDecimal getAllocationMaximale(boolean p_leverException)
  {
    if ((m_allocationMaximale == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Allocation maximale");
    }
    return m_allocationMaximale;
  }
  
  public void setAllocationMaximale(BigDecimal p_allocationMaximale)
  {
    m_allocationMaximale = p_allocationMaximale;
  }
  
  public void setNouveauAllocationMaximale(boolean p_nouveauAllocationMaximale)
  {
    m_nouveauAllocationMaximale = p_nouveauAllocationMaximale;
  }
  
  public boolean isNouveauAllocationMaximale()
  {
    return m_nouveauAllocationMaximale;
  }
}

/* Location:
 * Qualified Name:     EvenementParametre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */