package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.EtatDifferePrecedent;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.outils.spec.IOutilFonctionnelRechercheDiffere;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.DiffereSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P06;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionAssuranceAvecDiffere;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;
import java.util.List;

public class RechercheDiffere
  implements IOutilFonctionnelRechercheDiffere
{
  private static final int VALEUR_DIFFERE_TOTAL = 7;
  private DemandeSpec pointDepartRecherche = null;
  private Chronologie chronoDemandes;
  
  public EtatDifferePrecedent rechercherEtatDifferePrecedent()
  {
    EtatDifferePrecedent retour = new EtatDifferePrecedent();
    
    AttributionSpec odPrecedente = rechercherOdPrecedenteAvecDiffere(getChronoDemandes(), pointDepartRecherche);
    if (odPrecedente != null)
    {
      ResultatExecutionCalculSpec resultatAvantCalcul = executerCalcul(odPrecedente);
      
      boolean estDiffereEntame = estDiffereEntame(odPrecedente, resultatAvantCalcul);
      retour.setDifferePrecedentEntame(estDiffereEntame);
      if (estDiffereEntame)
      {
        Periode differe = recupererDelaiAttenteEffectif(odPrecedente, resultatAvantCalcul);
        retour.setPeriodeApplicationDiffere(differe);
      }
    }
    return retour;
  }
  
  protected AttributionSpec rechercherOdPrecedenteAvecDiffere(Chronologie chronoDemande, DemandeSpec demande)
  {
    FiltreCaliSpec filtreOdPrecedente = new FiltreDecisionARESurDecision();
    
    FiltreET listeFiltres = new FiltreET();
    listeFiltres.ajouterFiltre(filtreOdPrecedente);
    listeFiltres.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, getPointDepartRecherche()));
    listeFiltres.ajouterFiltre(new FiltreAttributionAssuranceAvecDiffere());
    listeFiltres.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
    if (demande.estEnContexteDemande("SORTIECRA")) {
      listeFiltres.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande(8)));
    }
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(chronoDemande, getPointDepartRecherche(), listeFiltres);
  }
  
  protected ResultatExecutionCalculSpec executerCalcul(AttributionSpec odPrecedente)
  {
    ResultatExecutionCalculSpec resultatAvantCalcul;
    try
    {
      resultatAvantCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(odPrecedente, null, false);
    }
    catch (ApplicativeException ex)
    {
      resultatAvantCalcul = null;
    }
    return resultatAvantCalcul;
  }
  
  private boolean estDiffereEntame(AttributionSpec odPrecedente, ResultatExecutionCalculSpec resultatAvantCalcul)
  {
    boolean retour = false;
    if (resultatAvantCalcul != null) {
      if ((ProduitAsuSpe02P05.getInstance().equals(odPrecedente.getProduit())) || (ProduitAsuSpe02P06.getInstance().equals(odPrecedente.getProduit())))
      {
        Quantite reliquatDiffere = resultatAvantCalcul.getReliquatDelaiAttente();
        if (reliquatDiffere != null) {
          retour = reliquatDiffere.getValeurEntiere() < 7;
        }
      }
      else
      {
        retour = resultatAvantCalcul.isDiffereEntame();
      }
    }
    return retour;
  }
  
  private Periode recupererDelaiAttenteEffectif(AttributionSpec odPrecedente, ResultatExecutionCalculSpec resultatAvantCalcul)
  {
    Periode retour = null;
    if (resultatAvantCalcul != null) {
      if ((ProduitAsuSpe02P05.getInstance().equals(odPrecedente.getProduit())) || (ProduitAsuSpe02P06.getInstance().equals(odPrecedente.getProduit())))
      {
        retour = resultatAvantCalcul.getPeriodeApplicationDelaiAttente();
      }
      else
      {
        CarenceSpec differePrecedent = null;
        
        List<CarenceSpec> listeCarencesAttributionPrecedente = resultatAvantCalcul.getListeCarencesEffectives();
        for (Iterator<CarenceSpec> iterator = listeCarencesAttributionPrecedente.iterator(); iterator.hasNext();)
        {
          CarenceSpec carence = (CarenceSpec)iterator.next();
          if ((carence instanceof DiffereSpec))
          {
            differePrecedent = carence;
            break;
          }
        }
        if (differePrecedent != null) {
          retour = differePrecedent.getPeriodeApplicationCarence();
        }
      }
    }
    return retour;
  }
  
  public DemandeSpec getPointDepartRecherche()
  {
    return pointDepartRecherche;
  }
  
  public void setPointDepartRecherche(DemandeSpec pointDepartRecherche)
  {
    this.pointDepartRecherche = pointDepartRecherche;
  }
  
  public void setChronoDemandes(Chronologie chronoDemandes)
  {
    this.chronoDemandes = chronoDemandes;
  }
  
  public Chronologie getChronoDemandes()
  {
    return chronoDemandes;
  }
}

/* Location:
 * Qualified Name:     RechercheDiffere
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */