package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ResultatValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.ConteneurDeterminationPeriodeReference;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation.ConstructionChronologie;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class RechercheValiditeProduit
  extends fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RechercheValiditeProduit
{
  private static final ParametresAffiliationSpec PARAMETRES_AFFILIATION = new ParametresAffiliation();
  private static final ConstructionChronologieSpec CONSTRUCTION_CHRONOLOGIE = new ConstructionChronologie();
  
  protected ConstructionChronologieSpec getOutilConstructionChrono()
  {
    return CONSTRUCTION_CHRONOLOGIE;
  }
  
  public static RechercheValiditeProduit getInstance()
  {
    return new RechercheValiditeProduit();
  }
  
  public ResultatValidationProduit executerValidationProduit(ActiviteSalarie activiteSalarie, DemandeAssuranceSpec demandeAssurance)
    throws ApplicativeException
  {
    ResultatValidationProduit resultatValidation = new ResultatValidationProduit();
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    List<AllongementPra> listeAllongementPeriodeAJustifier = new ArrayList();
    Quantite quantiteAffiliationRequise = null;
    Quantite quantiteAppartenanceARetenir = null;
    JustificationAffiliation justification = null;
    Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
    
    Damj dateAttributionPrecedente = determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance);
    
    boolean estDemandeEnSortieClauseRattrapage = estContexteSortieClauseRattrapage(demandeAssurance);
    boolean estDemandeEnEntreeClauseRattrapage = estContexteEntreeClauseRattrapage(demandeAssurance);
    Damj dateBornePRA = initialiserDateBornePRA(demandeAssurance, estDemandeEnSortieClauseRattrapage);
    
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    parametres.setFaitGenerateurDroit(activiteSalarie);
    parametres.setDateExamen(demandeAssurance.getDateExamen());
    parametres.setDemande((Demande)demandeAssurance);
    if (estDemandeClauseRattrapage(demandeAssurance)) {
      parametres.setPoursuivreEtude(false);
    }
    ConteneurDeterminationPeriodeReference conteneur = new ConteneurDeterminationPeriodeReference();
    conteneur.setIndividu(individu);
    conteneur.setConstructionChronologie(getOutilConstructionChrono());
    conteneur.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
    conteneur.setTermePeriodeReference(activiteSalarie.getDateFin());
    conteneur.setDateExamen(demandeAssurance.getDateExamen());
    conteneur.setDateBornePRA(dateBornePRA);
    conteneur.setListeAllongementPRA(listeAllongementPeriodeAJustifier);
    conteneur.setJustifierAffiliation(getJustifAffi());
    conteneur.setPrimo(dateAttributionPrecedente == null);
    conteneur.setEstContexteSortieClauseRattrapage(estDemandeEnSortieClauseRattrapage);
    conteneur.setEstContexteEntreeClauseDeRattrapage(estDemandeEnEntreeClauseRattrapage);
    Periode pra = DeterminationPeriodeReferenceSPE02P05.getInstance().determinerPeriodeDeReference(conteneur);
    if (presenceDonneesForceesValidationProduit(demandeAssurance))
    {
      parametres.setReglementEtudie(determinerReglementApplicableDonneesForcees(demandeAssurance));
      
      quantiteAffiliationRequise = determinerQuantiteAffiliationRequise(parametres);
      
      quantiteAppartenanceARetenir = demandeAssurance.getDonneesTemporaires().getQuantiteAffiliation();
      if ((demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle() == null) || (demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle().intValue() == 0))
      {
        resultatValidation.setQuantiteAcquiseAuRangInitial(quantiteAppartenanceARetenir);
        resultatValidation.setPraAuRangInitial(pra);
        resultatValidation.setHeuresRequisesAuRangInitial(quantiteAffiliationRequise);
      }
      if (quantiteAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, null)) {
        produitValide = true;
      }
    }
    else
    {
      parametres.setRangEtude(0);
      
      boolean poursuivreEtude = true;
      while ((poursuivreEtude) && (!produitValide))
      {
        parametres.setReglementEtudie(getReglementA8());
        
        List<AllongementPra> listeAllongementPRAA8 = new ArrayList();
        ConteneurDeterminationPeriodeReference conteneurA8 = new ConteneurDeterminationPeriodeReference();
        conteneurA8.setIndividu(individu);
        conteneurA8.setConstructionChronologie(getOutilConstructionChrono());
        conteneurA8.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
        conteneurA8.setTermePeriodeReference(activiteSalarie.getDateFin());
        conteneurA8.setDateExamen(demandeAssurance.getDateExamen());
        conteneurA8.setDateBornePRA(dateBornePRA);
        conteneurA8.setListeAllongementPRA(listeAllongementPRAA8);
        conteneurA8.setJustifierAffiliation(getJustifAffi());
        conteneurA8.setPrimo(determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance) == null);
        conteneurA8.setEstContexteSortieClauseRattrapage(estDemandeEnSortieClauseRattrapage);
        conteneurA8.setEstContexteEntreeClauseDeRattrapage(estDemandeEnEntreeClauseRattrapage);
        Periode periodeReferenceA8 = DeterminationPeriodeReferenceSPE02P05.getInstance().determinerPeriodeDeReference(conteneurA8);
        
        parametres.setDemande((Demande)demandeAssurance);
        
        Quantite quantiteReglementA8 = determinerQuantiteActiviteAuTitreDuReglement(individu, parametres, periodeReferenceA8);
        
        parametres.setReglementEtudie(getReglementA10());
        List<AllongementPra> listeAllongementPRAA10 = new ArrayList();
        
        ConteneurDeterminationPeriodeReference conteneurA10 = new ConteneurDeterminationPeriodeReference();
        conteneurA10.setIndividu(individu);
        conteneurA10.setConstructionChronologie(getOutilConstructionChrono());
        conteneurA10.setDureeInitialePeriodeReference(getParametresAffiliation().determinerDureePeriodeReference(parametres));
        conteneurA10.setTermePeriodeReference(activiteSalarie.getDateFin());
        conteneurA10.setDateExamen(demandeAssurance.getDateExamen());
        conteneurA10.setDateBornePRA(dateBornePRA);
        conteneurA10.setListeAllongementPRA(listeAllongementPRAA10);
        conteneurA10.setJustifierAffiliation(getJustifAffi());
        conteneurA10.setPrimo(determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance) == null);
        conteneurA10.setEstContexteSortieClauseRattrapage(estDemandeEnSortieClauseRattrapage);
        conteneurA10.setEstContexteEntreeClauseDeRattrapage(estDemandeEnEntreeClauseRattrapage);
        Periode periodeReferenceA10 = DeterminationPeriodeReferenceSPE02P05.getInstance().determinerPeriodeDeReference(conteneurA10);
        
        Quantite quantiteReglementA10 = determinerQuantiteActiviteAuTitreDuReglement(individu, parametres, periodeReferenceA10);
        
        Reglement reglementApplicable = determinerReglementApplicable(quantiteReglementA8, quantiteReglementA10, activiteSalarie);
        parametres.setReglementEtudie(reglementApplicable);
        
        pra = trouverPeriodeReferenceAffiliationRetenir(periodeReferenceA8, periodeReferenceA10, reglementApplicable);
        
        quantiteAffiliationRequise = determinerQuantiteAffiliationRequise(parametres);
        
        fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduit = new fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit();
        justification = validationProduit.createJustificationAffiliation();
        
        parametres.setDemande((Demande)demandeAssurance);
        
        quantiteAppartenanceARetenir = calculerQuantiteGlobaleAffiliation(individu, justification, parametres, periodeReferenceA8, quantiteAffiliationRequise, listeAlertesNonBloquantes);
        if (0 == parametres.getRangEtude())
        {
          resultatValidation.setQuantiteAcquiseAuRangInitial(quantiteAppartenanceARetenir);
          resultatValidation.setPraAuRangInitial(pra);
          resultatValidation.setHeuresRequisesAuRangInitial(quantiteAffiliationRequise);
          if (justification != null) {
            resultatValidation.setJustificationAssimilationAuRangInitial(justification.getCollectionAssimilation());
          }
        }
        listeAllongementPeriodeAJustifier = determinerListeAllongementPeriodePourJustification(reglementApplicable, listeAllongementPRAA8, listeAllongementPRAA10);
        if (quantiteAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, justification)) {
          produitValide = true;
        } else {
          poursuivreEtude = verifierConditionsPoursuiteEtude(parametres, dateAttributionPrecedente, dateBornePRA, periodeReferenceA8);
        }
      }
    }
    alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteSalarie, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
    
    getJustifAffi().justifierAllongementPeriodeReference(resultatValidation.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
    
    alimenterAlertesNonBloquantesPourDemande(demandeAssurance, listeAlertesNonBloquantes);
    
    return resultatValidation;
  }
  
  protected boolean estContexteSortieClauseRattrapage(DemandeAssuranceSpec demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "SORTIECRA");
  }
  
  protected boolean estContexteEntreeClauseRattrapage(DemandeAssuranceSpec demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ENTREECRA");
  }
  
  protected boolean estDemandeClauseRattrapage(DemandeAssuranceSpec demande)
  {
    boolean estContexteEnCoursClauseRattrapage = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ENCOURSCRA");
    
    return (estContexteEntreeClauseRattrapage(demande)) || (estContexteEnCoursClauseRattrapage);
  }
  
  protected Damj initialiserDateBornePRA(DemandeAssuranceSpec demandeAssurance, boolean estDemandeEnSortieClauseRattrapage)
    throws ApplicativeException
  {
    Damj dateBornePRA = null;
    if (!estDemandeEnSortieClauseRattrapage) {
      dateBornePRA = determinerDateBornePRA(demandeAssurance);
    } else {
      dateBornePRA = recupererDebutPraClauseRattrapagePrecedent(demandeAssurance);
    }
    return dateBornePRA;
  }
  
  protected Damj recupererDebutPraClauseRattrapagePrecedent(DemandeAssuranceSpec demande)
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)demande.rechercherAttributionPrecedenteDuMemeType().getOuvertureDroit();
    return ((DossierAffecte)attribution.getDossierAffecte()).getValidationProduit().getPeriodePra().getDebut();
  }
  
  protected ProduitSpec getProduit()
  {
    return ProduitAsuSpe02P05.getInstance();
  }
  
  protected ParametresAffiliationSpec getParametresAffiliation()
  {
    return PARAMETRES_AFFILIATION;
  }
}

/* Location:
 * Qualified Name:     RechercheValiditeProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */