package fr.unedic.cali.asu.spe02.p05.liquidation.parcours;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.dom.DonneesEntreeDateLimiteSpectacle;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.dom.DonneesSortieDateLimiteSpectacle;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.dom.JustificationDateLimiteDateLimite;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.fabrique.FabriqueCorpsRegleConstitutionDateLimite;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.outils.spec.IOutilConstitutionDateLimiteSpectacle;
import fr.pe.cali.reglementaire.regles.assurance.cep.datelimite.outils.spec.IOutilFonctionnelDateLimiteSpectacle2016;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.datelimite.OutilFonctionnelDateLimiteSpectacle2016;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.List;

public class ParcoursConstitutionDateLimiteIndemnisation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    
    Resultat resultat = new Resultat(0);
    
    calculerDateIndemnisationLimite(attribution);
    
    return resultat;
  }
  
  private void calculerDateIndemnisationLimite(Attribution attribution)
    throws ApplicativeException
  {
    IOutilConstitutionDateLimiteSpectacle outilDateLimite = recupererOutilReglementaire(attribution);
    DonneesEntreeDateLimiteSpectacle donneesEntree = creerConteneurDonneesEntree(attribution);
    DonneesSortieDateLimiteSpectacle resultat = outilDateLimite.calculerDateLimiteIndemnisation(donneesEntree);
    mettreAJourCepDateLimite(attribution.getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation(), resultat);
  }
  
  protected IOutilConstitutionDateLimiteSpectacle recupererOutilReglementaire(Attribution attribution)
  {
    CriteresFabriqueReglementaire criteres = recupererCriteresFabriqueReglementaire(attribution);
    return (IOutilConstitutionDateLimiteSpectacle)FabriqueCorpsRegleConstitutionDateLimite.getInstance().recupererOutilCorpsRegle(criteres);
  }
  
  protected CriteresFabriqueReglementaire recupererCriteresFabriqueReglementaire(Attribution attribution)
  {
    CriteresFabriqueReglementaire criteres = new CriteresFabriqueReglementaire();
    criteres.setCodeProduit(attribution.getProduit().getNomUnique());
    criteres.setDate(attribution.getDateAttribution());
    List<String> contextesReglementaires = new ArrayList();
    if (estContexteEntreeClauseRattrapagePresent(attribution)) {
      contextesReglementaires.add("DateLimiteContexteEntreeClauseRattrapage");
    }
    if (estContexteSortieClauseRattrapagePresent(attribution)) {
      contextesReglementaires.add("DateLimiteContexteReadeSuiteClauseRattrapage");
    }
    criteres.setListeContextesReglementaires(contextesReglementaires);
    return criteres;
  }
  
  protected boolean estContexteEntreeClauseRattrapagePresent(Attribution attribution)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "ENTREECRA");
  }
  
  protected boolean estContexteSortieClauseRattrapagePresent(Attribution attribution)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "SORTIECRA");
  }
  
  private DonneesEntreeDateLimiteSpectacle creerConteneurDonneesEntree(Attribution attribution)
  {
    DonneesEntreeDateLimiteSpectacle donneesEntree = new DonneesEntreeDateLimiteSpectacle();
    Damj dateLimiteIndemnisationForcee = attribution.getDemandeAssurance().getDonneesTemporaires().getDateLimiteIndemnisationDonneeForcee();
    donneesEntree.setDateLimiteIndemnisationForcee(dateLimiteIndemnisationForcee);
    IndividuSpec individu = attribution.getDemandeur();
    donneesEntree.setDateExamen(attribution.getDateExamen());
    donneesEntree.setDateFaitGenerateur(attribution.getDateFaitGenerateur());
    donneesEntree.setDateLiquidationRetraite(individu.getDateLiquidationRetraite());
    donneesEntree.setDateNaissance(individu.getDateNaissance());
    donneesEntree.setDateRetraiteAnticipee(individu.getDateRetraiteAnticipe());
    donneesEntree.setMotifRetraiteAnticipee(individu.getMotifRetraiteAnticipe());
    donneesEntree.setTrimestreRetraite(individu.getTrimestreRetraite());
    IOutilFonctionnelDateLimiteSpectacle2016 outilFonctionnel = OutilFonctionnelDateLimiteSpectacle2016.getInstance();
    ((OutilFonctionnelDateLimiteSpectacle2016)outilFonctionnel).setListeDemandesAsu(attribution.getDemandeur().getChronoDemandeAssurance());
    donneesEntree.setOutilFonctionnel(outilFonctionnel);
    
    return donneesEntree;
  }
  
  private void mettreAJourCepDateLimite(ConstitutionDateLimiteIndemnisation constitution, DonneesSortieDateLimiteSpectacle resultat)
  {
    constitution.setDateLimiteIndemnisation(resultat.getDateLimiteIndemnisation());
    JustificationDateLimiteDateLimite justification = resultat.getJustification();
    constitution.setContexteDateLimiteIndemnisation(justification.getContexteDateLimite());
    constitution.setDureeImputee(justification.getDureeImputeeSuiteArce());
    constitution.setDureeIndemnisation(justification.getDureeUtilisee());
    constitution.setPointDepart(justification.getDatePointDepart());
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionDateLimiteIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */