package fr.unedic.cali.asu.ssp07.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.fps.liquidation.outilsfonctionnels.OutilConditionAffiliationAbstraite;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ResultatValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSsp07P03;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class OutilConditionAffiliation
  extends OutilConditionAffiliationAbstraite
  implements OutilFonctionnel
{
  protected ParametresAffiliationSpec parametresAffiliation;
  
  public OutilConditionAffiliation()
  {
    parametresAffiliation = new ParametresAffiliation();
  }
  
  public ConditionQuantiteAffiliation determinerConditionAffiliation(DemandeAssuranceSpec demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatValidationProduit resultatValidation = new ResultatValidationProduit();
    ResultatValidationProduit resultatValidationPremierEtude = null;
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    Damj dateAttributionPrecedente = determinerDateAttributionProduitSpectaclePrecedent(demandeAssurance);
    Damj dateBornePRA = determinerBornePRA(demandeAssurance);
    List<AllongementPra> listeAllongementPeriodeAJustifier = null;
    ActiviteSalarie activiteReference = null;
    if (dateBornePRA.coincideAvec(Damj.NUIT_DES_TEMPS)) {
      dateAttributionPrecedente = null;
    }
    Periode pra = null;
    Quantite quantiteAffiliationRequise = null;
    Quantite quantiteAppartenanceARetenir = null;
    JustificationAffiliation justification = null;
    Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
    
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    if (presenceDonneesForceesValidationProduit(demandeAssurance))
    {
      resultatValidation = calculerAffiliationForcee(demandeAssurance);
      
      resultatValidationPremierEtude = resultatValidation;
    }
    else
    {
      Chronologie chronoActiviteDansPeriodeReference = determinerChronologieActivitesReference(demandeAssurance);
      
      chronoActiviteDansPeriodeReference.setComparateur(new ComparateurTemporelsSurDateFin());
      
      chronoActiviteDansPeriodeReference.iterer();
      boolean poursuivreEtudeSurAutreActivite = true;
      while ((chronoActiviteDansPeriodeReference.encoreSuivant()) && (!produitValide) && (poursuivreEtudeSurAutreActivite))
      {
        activiteReference = (ActiviteSalarie)chronoActiviteDansPeriodeReference.elementSuivant();
        
        parametres.setRangEtude(0);
        
        boolean poursuivreEtude = true;
        while ((poursuivreEtude) && (!produitValide))
        {
          parametres.setFaitGenerateurDroit(activiteReference);
          
          parametres.setDateExamen(demandeAssurance.getDateExamen());
          parametres.setDemande((Demande)demandeAssurance);
          
          Damj dateTermePra = determinerTermePRA(activiteReference.getDateFin(), parametres.getDateExamen(), demandeAssurance.estEnContexteDemande("APSPOSTCRA"));
          
          parametres.setReglementEtudie(getReglementA8());
          List<AllongementPra> listeAllongementPRAA8 = new ArrayList();
          Periode periodeReferenceA8 = determinerPRA(individu, parametres, dateTermePra, dateBornePRA, listeAllongementPRAA8);
          
          parametres.setDemande((Demande)demandeAssurance);
          
          Quantite quantiteReglementA8 = calculerAffiliationPourReglement(individu, parametres, periodeReferenceA8);
          
          parametres.setReglementEtudie(getReglementA10());
          List<AllongementPra> listeAllongementPRAA10 = new ArrayList();
          Periode periodeReferenceA10 = determinerPRA(individu, parametres, dateTermePra, dateBornePRA, listeAllongementPRAA10);
          
          Quantite quantiteReglementA10 = calculerAffiliationPourReglement(individu, parametres, periodeReferenceA10);
          
          Reglement reglementApplicable = determinerReglementApplicable(quantiteReglementA8, quantiteReglementA10, activiteReference);
          parametres.setReglementEtudie(reglementApplicable);
          
          pra = trouverPeriodeReferenceAffiliationRetenir(periodeReferenceA8, periodeReferenceA10, reglementApplicable);
          
          quantiteAffiliationRequise = determinerAffiliationRequise(parametres);
          
          fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduit = new fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit();
          justification = validationProduit.createJustificationAffiliation();
          
          parametres.setDemande((Demande)demandeAssurance);
          
          quantiteAppartenanceARetenir = calculerAffiliation(individu, justification, parametres, pra, quantiteAffiliationRequise, listeAlertesNonBloquantes);
          
          ProduitAsuSpec produit = (ProduitAsuSpec)demandeAssurance.getDossierAffectation().getProduit();
          if (estAffiliationAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, justification, produit))
          {
            produitValide = true;
            
            listeAllongementPeriodeAJustifier = determinerListeAllongementPeriodePourJustification(reglementApplicable, listeAllongementPRAA8, listeAllongementPRAA10);
          }
          else
          {
            poursuivreEtude = verifierConditionsPoursuiteEtude(parametres, dateAttributionPrecedente, dateBornePRA, pra);
          }
        }
        poursuivreEtudeSurAutreActivite = etudierToutesActivitesReference(demandeAssurance);
        if (resultatValidationPremierEtude == null)
        {
          resultatValidationPremierEtude = new ResultatValidationProduit();
          
          alimenterResultatCalculAffiliation(resultatValidationPremierEtude, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
          
          JUSTIFIER_AFFILIATION.justifierAllongementPeriodeReference(resultatValidationPremierEtude.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
        }
      }
      if (activiteReference != null) {
        alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
      }
    }
    if (produitValide)
    {
      JUSTIFIER_AFFILIATION.justifierAllongementPeriodeReference(resultatValidation.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
      
      alimenterAlertesNonBloquantesPourDemande(demandeAssurance, listeAlertesNonBloquantes);
    }
    else
    {
      resultatValidation = resultatValidationPremierEtude;
    }
    if (resultatValidation == null)
    {
      resultatValidation = new ResultatValidationProduit();
      alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
    }
    return alimenterCAPA07DepuisResultatValidation(demandeAssurance, resultatValidation);
  }
  
  protected boolean etudierToutesActivitesReference(DemandeAssuranceSpec demande)
  {
    return !demande.estUneDemandeEfe();
  }
  
  private static boolean verifierConditionsPoursuiteEtude(ParametresCalculAffiliation parametres, Damj dateAttributionPrecedente, Damj dateBornePRA, Periode pra)
  {
    if (dateAttributionPrecedente == null) {
      return false;
    }
    if (pra.getDebut().equals(dateBornePRA)) {
      return false;
    }
    parametres.passerAuRangEtudeSuivant();
    return true;
  }
  
  private static Damj determinerDateAttributionProduitSpectaclePrecedent(DemandeAssuranceSpec demande)
  {
    AttributionSpec attribution = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionStandardAssurance(true, true, true, false, demande));
    if (attribution == null) {
      return null;
    }
    ReglementApplicableSpec reglementApplicable = ((DossierExamenAssuranceSpec)attribution).getReglementApplicable();
    if ((reglementApplicable != null) && ((reglementApplicable.getReglement().estNomReglementIdentique("A8")) || (reglementApplicable.getReglement().estNomReglementIdentique("A10")))) {
      return attribution.getDateAttribution();
    }
    return null;
  }
  
  protected Quantite determinerAffiliationRequise(ParametresCalculAffiliation parametres)
  {
    return new Quantite(parametresAffiliation.determinerQuantiteAffiliationRequise(parametres), Unite.getParCode("18"));
  }
  
  protected Damj determinerBornePRA(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    FiltreOU filtreElementsAPrendreEnCompte = new FiltreOU();
    filtreElementsAPrendreEnCompte.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuFds12.getInstance().getNomUnique()));
    filtreElementsAPrendreEnCompte.ajouterFiltre(new FiltreNegation(new FiltreOuvertureDroitSurDecision()));
    
    return trouverLendemainFgPourBornePra(demande, filtreElementsAPrendreEnCompte);
  }
  
  protected DureeCalendaire determinerDureePRA(ParametresCalculAffiliation parametres)
  {
    return parametresAffiliation.determinerDureePeriodeReference(parametres);
  }
  
  protected ProduitSpec getProduit()
  {
    return ProduitAsuSsp07P03.getInstance();
  }
  
  protected Damj getTermePeriodeRecherche(DemandeAssuranceSpec demande)
  {
    if (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null)
    {
      Damj fctRetenue = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getDateFinPeriode();
      if (fctRetenue != null) {
        return fctRetenue;
      }
    }
    return demande.getFaitGenerateur().getPeriodeFaitGenerateur().getDateFin();
  }
  
  protected Damj determinerTermePRA(Damj dateFct, Damj dateExamen, boolean estContexteDroitSuiteCRA)
  {
    return dateFct;
  }
}

/* Location:
 * Qualified Name:     OutilConditionAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */