package fr.unedic.cali.asu.ssp07.p05.calcul.pbjc;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Readmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Reprise;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRadiation;
import fr.unedic.cali.calcul.pbjc.dom.PbjcNcp;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Iterator;

public class FacadePBJCProduitImpl
  extends fr.unedic.cali.asu.ssp07.p04.calcul.pbjc.FacadePBJCProduitImpl
{
  protected Quantite dureeIndemnisationTheorique(Attribution attribution)
  {
    return new Quantite(0, Unite.get("jour"));
  }
  
  public Quantite retournerQuantiteIndemnisationInitialeDroit(AttributionSpec attribution, UniteTraitement ut)
  {
    if (ut != null) {
      return new Quantite(ut.getCumulJoursIndemnise(), Unite.get("jour")).soustraire(ut.getQuantiteIndemnisee());
    }
    return new Quantite(0, Unite.get("jour"));
  }
  
  public int retournerReliquatDureeMax(UniteTraitement ut, ChronologiePeriodes chronoPBJCs, AttributionSpec attributionSpec)
  {
    return 0;
  }
  
  public void miseAJourNombreJoursImputes(UniteTraitement ut, PbjcNcp pbjcNcp)
  {
    if ((pbjcNcp.getNbJoursDecalage() == 0) && (!estFranchise(pbjcNcp)) && (pbjcNcp.getQualificationPeriode() != 1)) {
      pbjcNcp.setNbJoursImputes(pbjcNcp.getDuree());
    }
    if ((pbjcNcp.getNbJoursDecalage() > 0) && (!estFranchise(pbjcNcp))) {
      pbjcNcp.setNbJoursDecalage(Math.min(pbjcNcp.getDuree(), pbjcNcp.getNbJoursDecalage()));
    }
  }
  
  private boolean estFranchise(PbjcNcp pbjcNcp)
  {
    return (pbjcNcp.getTypeCarence() != null) && (!pbjcNcp.getTypeCarence().isEmpty()) && (estTypeCarenceValorise(pbjcNcp));
  }
  
  private boolean estTypeCarenceValorise(PbjcNcp pbjcNcp)
  {
    return (pbjcNcp.getTypeCarence().equals("FC")) || (pbjcNcp.getTypeCarence().equals("8F")) || (pbjcNcp.getTypeCarence().equals("10"));
  }
  
  public void traiterPBJCsAPosteriori(ChronologiePeriodes chronoPBJCs, AttributionSpec attribution, Chronologie chronoUT)
    throws CoucheLogiqueException
  {
    PbjcNcp pbjcNcp = null;
    PbjcNcp pbjcNcpAvant = null;
    DossierExamen dossierExamen = null;
    Damj dateMaintien = null;
    
    Chronologie demandes = attribution.getDemandeur().getChronoDemandeMaintien();
    demandes.iterer();
    while (demandes.encoreSuivant())
    {
      DemandeSpec demandeMaintien = (DemandeSpec)demandes.elementSuivant();
      if (((demandeMaintien instanceof DemandeMaintien)) && (!demandeMaintien.estEnReExamen()) && (verificationClassementAdministratif(demandeMaintien)))
      {
        dossierExamen = ((DemandeMaintien)demandeMaintien).getDossierExamen();
        if ((dossierExamen != null) && ((dossierExamen instanceof Accord))) {
          dateMaintien = demandeMaintien.getDateEffet();
        }
      }
    }
    if ((dateMaintien == null) && (((AttributionAssuranceSpec)attribution).getOuvertureDroitCapitalRetenu() != null) && (!((AttributionAssuranceSpec)attribution).getOuvertureDroitCapitalRetenu().estEnReexamen()) && ((((AttributionAssuranceSpec)attribution).getOuvertureDroitCapitalRetenu() instanceof AntecedentSpec)))
    {
      AntecedentSpec attributionMaitre = (AntecedentSpec)((AttributionAssuranceSpec)attribution).getOuvertureDroitCapitalRetenu();
      dateMaintien = attributionMaitre.getCalendrierExecutionCalcul().getDernierJourIndemnisable().veille();
    }
    ChronologiePeriodes chronologiePeriodesRadiationPEC = OutillagePeriodes.recupererPecsRadiationSuiteEntreeFormation(attribution.getDemandeur());
    
    chronoPBJCs.iterer();
    while (chronoPBJCs.encoreSuivant())
    {
      pbjcNcp = (PbjcNcp)chronoPBJCs.elementSuivant();
      if ((dateMaintien != null) && (((AttributionAssuranceSpec)attribution).estMaintenue()))
      {
        if (pbjcNcp.getDateDebut().coincideAvec(dateMaintien)) {
          pbjcNcp.ajouterComplementDeJustification("B1");
        }
        if (pbjcNcp.getDateDebut().estApresOuCoincideAvec(dateMaintien)) {
          pbjcNcp.setEtatReglementaireOd("5");
        }
      }
      chronologiePeriodesRadiationPEC.iterer();
      while (chronologiePeriodesRadiationPEC.encoreSuivant())
      {
        ObjetChronoPeriodeRadiation periodeRadiation = (ObjetChronoPeriodeRadiation)chronologiePeriodesRadiationPEC.elementSuivant();
        if (periodeRadiation.getDateDebut().veille().coincideAvec(pbjcNcp.getDateFin()))
        {
          pbjcNcp.ajouterComplementDeJustification("TD");
          
          pbjcNcp.setCodeRadiationLendemainPeriode("31");
        }
      }
      if (pbjcNcpAvant != null)
      {
        if (pbjcNcpAvant.getDateFin().coincideAvec(pbjcNcp.getDateDebut().veille()))
        {
          if (pbjcNcp.contientComplementDeJustification("FR")) {
            pbjcNcpAvant.ajouterComplementDeJustification("QF");
          }
          if ((pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcpAvant.getInterrupIndemParPensionInvalidite() != null))
          {
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("N"))) {
              pbjcNcp.ajouterComplementDeJustification("FN");
            }
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("N")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("O"))) {
              pbjcNcp.ajouterComplementDeJustification("FO");
            }
          }
        }
        if ((pbjcNcpAvant.getMontantCumuleRevaloriseAV() != null) && (pbjcNcpAvant.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0)) {
          if ((pbjcNcp.getMontantCumuleRevaloriseAV() != null) && (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0) && 
            (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(pbjcNcpAvant.getMontantCumuleRevaloriseAV()) != 0) && (!pbjcNcp.contientComplementDeJustification("DG"))) {
            pbjcNcp.ajouterComplementDeJustification("DH");
          }
        }
      }
      if ((pbjcNcp.contientComplementDeJustification("FR")) && (pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O"))) {
        pbjcNcp.ajouterComplementDeJustification("FN");
      }
      boolean estMoisPJI = false;
      boolean estPremierMoisIndemniseTrouve = false;
      if ((chronoUT != null) && (!chronoUT.estVide()))
      {
        Iterator<UniteTraitement> iteUT = chronoUT.iterer();
        while ((iteUT.hasNext()) && (!estPremierMoisIndemniseTrouve))
        {
          UniteTraitement premiereUTIndemnise = (UniteTraitement)iteUT.next();
          if ((premiereUTIndemnise.getCumulJoursIndemnise() != 0) && (premiereUTIndemnise.getCumulJoursIndemnise() == pbjcNcp.getNbJoursImputes()))
          {
            estMoisPJI = true;
            estPremierMoisIndemniseTrouve = true;
          }
        }
      }
      if (estMoisPJI) {
        positionnerJustificationOuverturePJI(pbjcNcp, attribution);
      }
      if (attribution.getDateAttribution().coincideAvec(pbjcNcp.getDateDebut())) {
        if ((attribution instanceof Reprise)) {
          pbjcNcp.ajouterComplementDeJustification("BO");
        } else if ((attribution instanceof Readmission)) {
          pbjcNcp.ajouterComplementDeJustification("BG");
        } else {
          pbjcNcp.ajouterComplementDeJustification("BB");
        }
      }
      if (pbjcNcpAvant != null) {
        pbjcNcp.setNbJoursAREF(pbjcNcpAvant.getNbJoursAREF());
      }
      if ((pbjcNcp.estEnAref()) && (pbjcNcp.getEtatIndemnisation().compareTo("AVANT") != 0)) {
        pbjcNcp.setNbJoursAREF(pbjcNcp.getNbJoursAREF() + pbjcNcp.getNbJoursImputes());
      }
      pbjcNcpAvant = pbjcNcp;
    }
  }
  
  private boolean verificationClassementAdministratif(DemandeSpec demandeMaintien)
  {
    return (demandeMaintien.getClassementAdministratif() == null) || (((demandeMaintien.getClassementAdministratif() instanceof Prescription)) && (!((Prescription)demandeMaintien.getClassementAdministratif()).isValidite()));
  }
}

/* Location:
 * Qualified Name:     FacadePBJCProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */