package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.autresdoms.cohab.dom.PeriodeSousPensionInvaliditeChainee;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodeSousPensionInvaliditeChaineeSpec;
import fr.unedic.util.temps.Damj;

public class OutilPensionInvalidite
  extends fr.unedic.cali.asu.outilsfonctionnels.OutilPensionInvalidite
{
  public static boolean estUneSousPensionDeductible(AttributionAssuranceSpec p_attribution, PeriodeSousPensionInvaliditeChainee p_sousPiChainee)
  {
    if (OutilsTrancheCalcul.estTrancheActive(p_attribution))
    {
      TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(p_attribution);
      return estUneSousPensionDeductibleTranche(tranche, p_attribution.getDateAttribution(), p_sousPiChainee);
    }
    return estUneSousPensionDeductible(p_attribution.getElementBaseIndemnisation(), p_attribution.getDateAttribution(), p_sousPiChainee);
  }
  
  public static boolean estUneSousPensionDeductible(ElementBaseIndemnisation p_ebi, Damj p_date, PeriodeSousPensionInvaliditeChainee p_sousPiChainee)
  {
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeTrouveeSurLiquidation = null;
    if (!estDeNatureDeductible(p_sousPiChainee)) {
      return false;
    }
    PeriodePensionInvaliditeChaineeSpec piChainee = p_sousPiChainee.getPensionParente();
    pensionInvaliditeTrouveeSurLiquidation = rechercherPensionInvaliditeSurElementBaseIndemnisation(p_ebi, piChainee);
    if (pensionInvaliditeTrouveeSurLiquidation != null) {
      return 1 == pensionInvaliditeTrouveeSurLiquidation.getStatut();
    }
    return true;
  }
  
  public static boolean estUneSousPensionDeductibleTranche(TrancheExecutable p_tranche, Damj p_date, PeriodeSousPensionInvaliditeChainee p_sousPiChainee)
  {
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeTrouveeSurLiquidation = null;
    if (!estDeNatureDeductible(p_sousPiChainee)) {
      return false;
    }
    PeriodePensionInvaliditeChaineeSpec piChainee = p_sousPiChainee.getPensionParente();
    if ((p_date != null) && (piChainee.getDateDebut().estApres(p_date))) {
      return true;
    }
    pensionInvaliditeTrouveeSurLiquidation = rechercherPensionInvalidite(p_tranche.getListPensionsInvalidites(), piChainee);
    if (pensionInvaliditeTrouveeSurLiquidation != null) {
      return 1 == pensionInvaliditeTrouveeSurLiquidation.getStatut();
    }
    return true;
  }
  
  public static boolean estDeNatureDeductible(PeriodeSousPensionInvaliditeChaineeSpec p_sousPiChainee)
  {
    return ("INV2".equals(p_sousPiChainee.getCodeNature())) || ("INV3".equals(p_sousPiChainee.getCodeNature()));
  }
}

/* Location:
 * Qualified Name:     OutilPensionInvalidite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */