package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleDiffereISLR
  implements FormuleDelaiReportSpec
{
  private static final BigDecimal ZERO = new BigDecimal(0);
  private static final Damj DATE01072002 = new Damj(2002, 7, 1);
  public static final int DUREE_DIFFERE_ISLR_MAX = 75;
  public static final int DUREE_DIFFERE_ISLR_TRANSACTION_FINANCIERE = 75;
  
  public Object appliquerFormule(BaseDelaiReportAbstrait p_baseFormule)
    throws CoucheLogiqueException
  {
    QuantiteJour quantiteJourCalculee = null;
    if (p_baseFormule == null) {
      throw new IllegalArgumentException("Impossible d'appliquer la formule du différé ISLR sans BaseDelaiReport.");
    }
    BigDecimal valeurMontant = ZERO;
    QuantiteEuro quantiteEuroIslr = p_baseFormule.getQuantiteEuroIslr();
    if (quantiteEuroIslr == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ISLR", "Impossible d'appliquer la formule du différé ISLR sans montant ISLR.");
    }
    valeurMontant = quantiteEuroIslr.getValeurMontant();
    
    BigDecimal valeurSjrrp = ZERO;
    Sjr salaireJournalierReference = p_baseFormule.getSjrrp();
    if (salaireJournalierReference == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_SJRRP_FORMULE_ISLR", "Impossible d'appliquer la formule du différé ISLR sans montant SJRRP.");
    }
    valeurSjrrp = salaireJournalierReference.getSalaire();
    if (valeurSjrrp.compareTo(ZERO) == 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR08_INCOHERENCE_SJRRP_ISLR", 2);
    }
    BigDecimal resultatFormule = ZERO;
    
    Damj dateFG = p_baseFormule.getDateFg();
    if (dateFG == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_DATE_FG_FORMULE_ISLR", "Impossible d'appliquer la formule du différé ISLR sans date FGD.");
    }
    if (dateFG.estAvant(DATE01072002)) {
      resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, new BigDecimal("2").multiply(valeurSjrrp));
    } else {
      resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
    }
    quantiteJourCalculee = new QuantiteJour(new BigDecimal(75).min(Mathematiques.tronque(resultatFormule, 0)));
    
    return quantiteJourCalculee;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait p_baseFormule)
  {
    return 75;
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereISLR
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */