package fr.unedic.cali.asu.cge01.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.cons.ConstantesRevalorisationSalaire;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class RevalorisationSalaireMayotte
{
  public static Sjr revaloriserSjrMayotte(Sjr sjr, Damj date)
  {
    if (sjr.estRevalorise()) {
      throw new IllegalArgumentException("Le SJR est déjà revalorisé : seul un SJR initial peut être revalorisé");
    }
    if (sjr.getDateDepart().estApres(date)) {
      throw new IllegalArgumentException("La date de fin de PRC doit être antérieure à la date de revalorisation du SJR");
    }
    ParametresIndemnisation param = ParametresIndemnisation.getParametresIndemnisation();
    Chronologie chronoParam = param.getParametresActifs(new Periode(sjr.getDateDepart(), date));
    EvenementParametre evtParam = param.getElementActif(date);
    
    BigDecimal plafond = evtParam.getPlafondMayotte();
    
    BigDecimal plafondTronque = plafond.multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 4);
    
    chronoParam.iterer();
    if (!chronoParam.encoreSuivant()) {
      return new Sjr(sjr.getSalaire().min(plafondTronque), sjr.getDateDepart(), sjr.getContexteParticulier());
    }
    BigDecimal revalAAppliquer = ConstantesRevalorisationSalaire.INIT_REVAL_A_APPLIQUER;
    chronoParam.iterer();
    EvenementParametre evtCourant = null;
    Damj dateFinPrc = sjr.getDateDepart();
    while (chronoParam.encoreSuivant())
    {
      evtCourant = (EvenementParametre)chronoParam.elementSuivant();
      if ((evtCourant.isNouveauRevalorisationSjr()) && (!dateFinPrc.deplacerVersAvant(new DureeCalendaire(0, 6, 1)).estApres(evtCourant.getDateEffet()))) {
        revalAAppliquer = revalAAppliquer.multiply(ConstantesRevalorisationSalaire.COEFF_CENT_POURCENTS.add(evtCourant.getRevalorisationSjr()));
      }
    }
    BigDecimal valeurSjrRevalorise = null;
    valeurSjrRevalorise = sjr.getSalaire().multiply(revalAAppliquer);
    valeurSjrRevalorise = Mathematiques.tronque(valeurSjrRevalorise, 2);
    
    valeurSjrRevalorise = plafondTronque.min(valeurSjrRevalorise);
    Sjr sjrRetour = new Sjr(valeurSjrRevalorise, sjr.getDateDepart(), sjr.getContexteParticulier());
    sjrRetour.setRevalorise(true);
    return sjrRetour;
  }
  
  public static Sjr revaloriserSjrMayotte(AttributionSpec attribution, Damj date)
  {
    Sjr sjr = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getSjr();
    return revaloriserSjrMayotte(sjr, date);
  }
}

/* Location:
 * Qualified Name:     RevalorisationSalaireMayotte
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */