package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatDetailleNotificationProduit;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ConstitutionCapitalAvecDureeEffective
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getAttribution() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution courante est null pour la constitution du capital effectif.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    ResultatDetailleNotificationProduit resultatMontantsBruts = new ResultatDetailleNotificationProduit();
    resultatMontantsBruts.setEtat(1);
    
    Attribution attributionCourante = (Attribution)getAttribution(p_contexte);
    if ((attributionCourante.getNatureDecision() != 11) && (attributionCourante.getNatureDecision() != 26)) {
      alimenterResultatCepa(attributionCourante);
    }
    resultatMontantsBruts.setEtat(0);
    
    OutilTrace.tracerFinParcours();
    return resultatMontantsBruts;
  }
  
  private void alimenterResultatCepa(Attribution p_attribution)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCepa = p_attribution.getConstitutionMontantsBruts();
    
    Quantite nbJourIndemnises = p_attribution.getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    
    Quantite capitalProduitCourant = null;
    if (p_attribution.getDemande().estEnContexteDemande(6))
    {
      MontantAsuSpec montantAAttribution = p_attribution.getConstitutionMontantsBruts().getMontantAAttribution();
      capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(p_attribution, montantAAttribution, p_attribution.getDateAttribution(), nbJourIndemnises);
    }
    else
    {
      capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(p_attribution, p_attribution.getDateAttribution(), p_attribution.getDateAttribution(), nbJourIndemnises);
    }
    resultatCepa.setCapitalInitialBrut(capitalProduitCourant);
  }
  
  private AttributionSpec getAttribution(Contexte p_contexte)
  {
    return DomLiquidationAssurance.getDemande(p_contexte).getAttribution();
  }
}

/* Location:
 * Qualified Name:     ConstitutionCapitalAvecDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */