package fr.unedic.cali.asu.fps.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ConstructionChronologie;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMaladieGrave;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMaladieLongueDuree;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.Map;

public class ConstructionChronologieFPS
  extends ConstructionChronologie
{
  public static final String CHRONO_AFFILIATION_MALADIES_LONGUE_DUREE = "chronoAffiMaladiesLongueDuree";
  public static final String CHRONO_AFFILIATION_MALADIES_GRAVES = "chronoAffiMaladiesGraves";
  
  public Map determinerChronologies(IndividuSpec individu, ComportementAffiliationSpec pcomportement)
  {
    Map resultat = super.determinerChronologies(individu, pcomportement);
    
    ComportementAffiliationFPS comportement = (ComportementAffiliationFPS)pcomportement;
    if (comportement.isCalculAffiliationAssimilableMaladieLongueDuree())
    {
      Chronologie chronoCourante = determinerChronologiePourAssimilationMaladiesLongueDuree(pcomportement);
      
      resultat.put("chronoAffiMaladiesLongueDuree", chronoCourante);
    }
    if (comportement.isCalculAffiliationAssimilableMaladieGrave())
    {
      Chronologie chronoCourante = determinerChronologiePourAssimilationMaladiesGraves(pcomportement);
      
      resultat.put("chronoAffiMaladiesGraves", chronoCourante);
    }
    return resultat;
  }
  
  public Chronologie determinerChronologiePourAssimilationMaladiesLongueDuree(ComportementAffiliationSpec comportement)
  {
    FiltresTemporel fitreChronoAssimilationMaladieLongueDuree = new FiltresTemporel();
    fitreChronoAssimilationMaladieLongueDuree.ajouterFiltre(new FiltreMaladieLongueDuree());
    fitreChronoAssimilationMaladieLongueDuree.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    
    fitreChronoAssimilationMaladieLongueDuree.ajouterFiltre(new FiltreNegation(new FiltreMaladieGrave()));
    
    Chronologie chronologiePourAssimilationMaladieLongueDuree = comportement.getChronologieActivitesParticipantes().copier(fitreChronoAssimilationMaladieLongueDuree);
    
    return chronologiePourAssimilationMaladieLongueDuree;
  }
  
  public Chronologie determinerChronologiePourAssimilationMaladiesGraves(ComportementAffiliationSpec comportement)
  {
    FiltresTemporel fitreChronoAssimilationMaladieGrave = new FiltresTemporel();
    fitreChronoAssimilationMaladieGrave.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    fitreChronoAssimilationMaladieGrave.ajouterFiltre(new FiltreMaladieGrave());
    
    Chronologie chronologiePourAssimilationMaladieGrave = comportement.getChronologieActivitesParticipantes().copier(fitreChronoAssimilationMaladieGrave);
    
    return chronologiePourAssimilationMaladieGrave;
  }
  
  public Chronologie determinerActivitesAllongementPeriodeReference(IndividuSpec individu, ComportementAffiliationSpec comportement)
  {
    Chronologie chronoActiviteAllongementPRAClassique = super.determinerActivitesAllongementPeriodeReference(individu, comportement);
    
    FiltresTemporel filtreElementsAExclure = new FiltresTemporel();
    filtreElementsAExclure.ajouterFiltre(new FiltreNegation(new FiltreMaladieGrave()));
    filtreElementsAExclure.ajouterFiltre(new FiltreNegation(new FiltreMaladieLongueDuree()));
    
    return chronoActiviteAllongementPRAClassique.copier(filtreElementsAExclure);
  }
}

/* Location:
 * Qualified Name:     ConstructionChronologieFPS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */