package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import java.util.ArrayList;
import java.util.List;

public final class OutilDemandeASS
{
  private static List<Integer> listeMotifEchecAdmissionReference = new ArrayList();
  private static List<Integer> listeMotifEchecRepriseReference = new ArrayList();
  
  static
  {
    listeMotifEchecAdmissionReference.add(Integer.valueOf(41));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(45));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(44));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(181));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(71));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(91));
    listeMotifEchecAdmissionReference.add(Integer.valueOf(92));
    
    listeMotifEchecRepriseReference.add(Integer.valueOf(272));
  }
  
  public static boolean estDetecteConditionDemandeASSSuiteDecheance(List<Integer> listeCodeMotifEchecReprise, List<Integer> listeCodeMotifEchecAdmission, int codeProduit, String typeEre)
  {
    boolean motifEchecAdmissionValide = contientMotifEchecDansListeMotifReference(listeCodeMotifEchecAdmission, listeMotifEchecAdmissionReference);
    boolean motifEchecRepriseValide = contientMotifEchecDansListeMotifReference(listeCodeMotifEchecReprise, listeMotifEchecRepriseReference);
    boolean codeProduitValide = estProduitValideDemandeASSSuiteDecheance(codeProduit);
    boolean typeEreValide = estEreValideDemandeASSSuiteDecheance(typeEre);
    
    return (codeProduitValide) && (motifEchecRepriseValide) && (motifEchecAdmissionValide) && (typeEreValide);
  }
  
  public static boolean estDetecteConditionRepriseAssSuiteReinscription(List<Integer> listeCodeMotifEchecAdmission)
  {
    return contientMotifEchecDansListeMotifReference(listeCodeMotifEchecAdmission, listeMotifEchecAdmissionReference);
  }
  
  protected static boolean contientMotifEchecDansListeMotifReference(List<Integer> listeCodeMotifEchec, List<Integer> listeCodeMotifReference)
  {
    boolean motifTrouve = false;
    if ((listeCodeMotifEchec != null) && (!listeCodeMotifEchec.isEmpty()))
    {
      motifTrouve = true;
      for (Integer elementCourant : listeCodeMotifEchec) {
        if (!listeCodeMotifReference.contains(elementCourant))
        {
          motifTrouve = false;
          break;
        }
      }
    }
    return motifTrouve;
  }
  
  protected static boolean estProduitValideDemandeASSSuiteDecheance(int codeProduit)
  {
    return ProduitAbstrait.estDuType(5, codeProduit);
  }
  
  protected static boolean estEreValideDemandeASSSuiteDecheance(String typeEre)
  {
    return ("ASU_01".equals(typeEre)) || ("ASU_27".equals(typeEre));
  }
  
  public static boolean verifierPresenceDossierExamenAdmissionEtReprise(Demande demande)
  {
    DossierAffectation dossierAffectationAdmission = demande.getDossierAffectationAdmission();
    DossierAffectation dossierAffectationReprise = demande.getDossierAffectationReprise();
    boolean resultat = (dossierAffectationAdmission != null) && (dossierAffectationReprise != null) && (dossierAffectationAdmission.getDossierExamen() != null) && (dossierAffectationReprise.getDossierExamen() != null);
    
    return resultat;
  }
}

/* Location:
 * Qualified Name:     OutilDemandeASS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */