package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieChevauchePeriode;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;

public class OutilFinDroitSpectacle
{
  private static OutilFinDroitSpectacle instance;
  
  public static OutilFinDroitSpectacle getInstance()
  {
    if (instance == null) {
      instance = new OutilFinDroitSpectacle();
    }
    return instance;
  }
  
  public Damj gererDateExamenPourDemandeDateAnniversaire(Damj dateExamen, Demande demande)
    throws ApplicativeException
  {
    Damj dateExamenARetourner = dateExamen;
    
    ChronologiePeriodes passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltresTemporel filtreET = new FiltresTemporel();
    if (dateExamen.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Regle de chevauchement date anniversaire"))) {
      filtreET.ajouterFiltre(new FiltreActiviteSalarieChevauchePeriode(new Periode(dateExamen.veille(), dateExamen.veille()), ""));
    } else {
      filtreET.ajouterFiltre(new FiltreActiviteSalarieChevauchePeriode(new Periode(dateExamen, dateExamen), ""));
    }
    Chronologie activiteADateAnniversaireETLendemain = passeProfessionnel.copier(filtreET);
    if ((activiteADateAnniversaireETLendemain != null) && (!activiteADateAnniversaireETLendemain.estVide()))
    {
      dateExamenARetourner = gererDateExamenForcee(demande);
      gererCoherenceDateExamenForcee(dateExamenARetourner, dateExamen);
    }
    else
    {
      verifierSiDateExamenForceeATort(demande);
    }
    return dateExamenARetourner;
  }
  
  private void gererCoherenceDateExamenForcee(Damj dateExamenForcee, Damj dateExamenfinDroitSpectacle)
    throws ApplicativeException
  {
    if (dateExamenForcee.estAvant(dateExamenfinDroitSpectacle)) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_DATE_EXAMEN_FORCE_AVANT_DATE_ANNIV");
    }
  }
  
  private Damj gererDateExamenForcee(Demande demande)
    throws ApplicativeException
  {
    Damj dateExamen = null;
    if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getDateExamenForcee() != null)) {
      dateExamen = demande.getDonneesTemporaires().getDateExamenForcee();
    } else {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_DATE_EXAMEN_DATE_ANNIV");
    }
    return dateExamen;
  }
  
  public void verifierSiDateExamenForceeATort(Demande demande)
    throws ApplicativeException
  {
    if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getDateExamenForcee() != null)) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_DATE_EXAMEN_FORCEE_DATE_ANNIV");
    }
  }
  
  public boolean estDemandeDateAnniversaire(AttributionSpec derniereAttributionAsu)
    throws ApplicativeException
  {
    return ((derniereAttributionAsu instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)derniereAttributionAsu).getDateLimiteIndemnisation() != null);
  }
}

/* Location:
 * Qualified Name:     OutilFinDroitSpectacle
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */