package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecChomageTotalSansRupture;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinApresOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;

public class RechercherDernierSinistreAsu
{
  public static TravailSpec rechercherDernierSinistre(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = null;
    Chronologie chronoPeriodesParticipantesBornee = null;
    
    Damj dateFgdOdPrecedente = demandeAssurance.getDateFaitGenerateurOdPrecedente();
    if ((dateFgdOdPrecedente != null) && (chronoPeriodesParticipantes != null))
    {
      FiltreFinApresOuCoincideAvecDate filtre = new FiltreFinApresOuCoincideAvecDate(dateFgdOdPrecedente.lendemain());
      chronoPeriodesParticipantesBornee = chronoPeriodesParticipantes.copier(filtre);
    }
    else
    {
      chronoPeriodesParticipantesBornee = chronoPeriodesParticipantes;
    }
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demandeAssurance))
    {
      dernierSinistre = determinerDernierSinitrePourChomageSansRCT(demandeAssurance, chronoPeriodesParticipantesBornee, chronoPeriodesParticipantes);
    }
    else
    {
      dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantesBornee);
      while (((dernierSinistre instanceof ActiviteSalarie)) && ((((ActiviteSalarie)dernierSinistre).getChampApplication() == 2) || (!((ActiviteSalarie)dernierSinistre).estUneFct()))) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_HORS_CHAMP_PAS_MORT");
      }
    }
    return dernierSinistre;
  }
  
  public static TravailSpec determinerDernierSinitrePourChomageSansRCT(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantesBornee, Chronologie chronoPeriodesParticipantesNonBornee)
    throws CoucheLogiqueException
  {
    Damj dateRecherche = demandeAssurance.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRecherche == null)
    {
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantesBornee);
      while (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).getChampApplication() == 2)) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_HORS_CHAMP_PAS_MORT");
      }
      return dernierSinistre;
    }
    Chronologie chronoChomageTotalSansRupture = chronoPeriodesParticipantesNonBornee.copier(new FiltreActiviteSalarieAvecChomageTotalSansRupture());
    
    Chronologie chronoChomageTotalSansRuptureAuJourForce = chronoChomageTotalSansRupture.copier(new FiltreFinDansBornes(dateRecherche, dateRecherche));
    if (chronoChomageTotalSansRuptureAuJourForce.estVide()) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_CSR_NON_VALIDE");
    }
    return (TravailSpec)chronoChomageTotalSansRuptureAuJourForce.premierElement();
  }
}

/* Location:
 * Qualified Name:     RechercherDernierSinistreAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */