package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class DeterminationDureeReglementaire
  implements OutilFonctionnel
{
  public static final int DUREE_243_JOURS = 243;
  private static final Quantite DUREE_REGLEMENTAIRE_A8 = new Quantite(243, Unite.getParCode("4"));
  private static final Quantite DUREE_REGLEMENTAIRE_A10 = new Quantite(243, Unite.getParCode("4"));
  private static final Quantite DUREE_ZERO = new Quantite(0, Unite.getParCode("4"));
  public static final Unite UNITE_DEFAUT = UniteDuree.JOUR;
  
  public static ConstitutionDurees determinerDureeReglementaire(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConstitutionDurees dureeIndemnisation = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionDurees();
    
    Quantite qteDureeImputationImposee = determinerQuantiteImputation(p_demande);
    if (p_demande.getAttribution().getReglementApplicable().getReglement().estNomReglementIdentique("A8")) {
      dureeIndemnisation.setDureeTheorique(DUREE_REGLEMENTAIRE_A8);
    } else {
      dureeIndemnisation.setDureeTheorique(DUREE_REGLEMENTAIRE_A10);
    }
    dureeIndemnisation.setDureeImputation(qteDureeImputationImposee);
    
    BigDecimal dureeTheorique = Mathematiques.arrondiASup(dureeIndemnisation.getDureeTheorique().getValeur().subtract(dureeIndemnisation.getDureeImputation().getValeur()), 0);
    
    dureeIndemnisation.setDureeTheorique(new Quantite(dureeTheorique, UNITE_DEFAUT));
    
    dureeIndemnisation.setDureeEffective(DUREE_ZERO);
    
    return dureeIndemnisation;
  }
  
  private static Quantite determinerQuantiteImputation(Demande p_demande)
  {
    Quantite qteDureeImputationImposee = null;
    if (p_demande.getDonneesTemporaires().getNbJourImputer() != null) {
      qteDureeImputationImposee = new Quantite(Mathematiques.arrondiAInf(p_demande.getDonneesTemporaires().getNbJourImputer(), 0), UNITE_DEFAUT);
    } else {
      qteDureeImputationImposee = new Quantite(0, UNITE_DEFAUT);
    }
    return qteDureeImputationImposee;
  }
  
  public static ConstitutionDurees determinerDureeReglementairePourReprise(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConstitutionDurees dureeIndemnisation = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionDurees();
    
    Quantite qteDureeImputationImposee = determinerQuantiteImputation(p_demande);
    
    dureeIndemnisation.setDureeTheorique(p_demande.getReliquat().getQuantiteReliquat());
    
    dureeIndemnisation.setDureeImputation(qteDureeImputationImposee);
    
    BigDecimal dureeTheorique = Mathematiques.arrondiASup(dureeIndemnisation.getDureeTheorique().getValeur().subtract(dureeIndemnisation.getDureeImputation().getValeur()), 0);
    
    dureeIndemnisation.setDureeTheorique(new Quantite(dureeTheorique, UNITE_DEFAUT));
    
    dureeIndemnisation.setDureeEffective(DUREE_ZERO);
    
    return dureeIndemnisation;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */