package fr.unedic.cali.asu.spe02.p04.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleCarenceIndemnisationStandardConvention2014;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleTexteSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.ParametresCarenceIndemnisationStandardConvention2014;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.OutilCalculDiffereStandardSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class OutilCalculDiffereStandard
  implements OutilCalculDiffereStandardSpec
{
  public Quantite calculerDiffereStandard(DemandeAssuranceSpec demande, JustificationDiffere justificationDiffere, BigDecimal montantTotalRemunerationsPrc)
    throws PasAssezInformationException
  {
    ParametresCarenceIndemnisationStandardConvention2014 parametres = new ParametresCarenceIndemnisationStandardConvention2014();
    FormuleTexteSpec formuleCalculCarence = new FormuleCarenceIndemnisationStandardConvention2014();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    if (justificationDiffere != null) {
      justificationDiffere.setFormule(formuleCalculCarence.getFormule(parametres));
    }
    Periode periodeRechercheCalcul = dossierExamen.getConstitutionSalaireReference().getPrc();
    EvenementParametre elementActifAFinPRC = ParametresIndemnisation.getParametresIndemnisation().getElementActif(periodeRechercheCalcul.getFin());
    
    QuantiteEuro montantSJM = dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne();
    
    BigDecimal nombreHeuresTravaillees = dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesEtendu();
    
    parametres.setMontantSMICHoraire(elementActifAFinPRC.getSmicHoraire());
    parametres.setMontantSalaireJournalierMoyen(montantSJM.getValeur());
    parametres.setMontantSalaires(montantTotalRemunerationsPrc);
    parametres.setNombreHeuresTravaillees(nombreHeuresTravaillees);
    if (justificationDiffere != null) {
      justificationDiffere.setTotalSalairesNonPlafonnes(new QuantiteEuro(parametres.getMontantSalaires()));
    }
    Quantite dureeCarenceStandard = (Quantite)formuleCalculCarence.appliquerFormule(parametres);
    return dureeCarenceStandard;
  }
}

/* Location:
 * Qualified Name:     OutilCalculDiffereStandard
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */