package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class OutilDeterminationDureePourArce
  implements OutilFonctionnel
{
  public static OutilDeterminationDureePourArce getInstance()
  {
    return new OutilDeterminationDureePourArce();
  }
  
  public Quantite determinerNombreMaximalJoursAllocationAServir(AttributionAssuranceSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    Damj pji = attribution.getPremierJourIndemnisable();
    Damj dateLimite = attribution.getDateLimiteIndemnisation();
    ResultatExecutionCalculSpec resultatCalcul = getOutilGestionArce().executerAttribution(attribution, dateCalcul);
    int reliquatDelaiAttente = getOutilGestionArce().determinerReliquatDelaiAttente(resultatCalcul, dateCalcul);
    int reliquatFranchiseSalaire = getOutilGestionArce().determinerReliquatFranchiseSalaire(resultatCalcul);
    int reliquatFranchiseCP = getOutilGestionArce().determinerReliquatFranchiseCP(resultatCalcul);
    return determinerNombreMaximalJoursAllocationAServir(dateCalcul, pji, dateLimite, reliquatDelaiAttente, reliquatFranchiseSalaire, reliquatFranchiseCP);
  }
  
  protected Quantite determinerNombreMaximalJoursAllocationAServir(Damj dateCalcul, Damj pji, Damj dateLimite, int reliquatDelaiAttente, int reliquatFranchiseSalaire, int reliquatFranchiseCP)
    throws ApplicativeException
  {
    int dureeIndemnisationRestantACourir = determinerDureeIndemnisationRestantACourir(dateCalcul, pji, dateLimite);
    int dureeNombreMaximalJoursAllocationAServir = dureeIndemnisationRestantACourir - reliquatDelaiAttente - reliquatFranchiseCP - reliquatFranchiseSalaire;
    if (dureeNombreMaximalJoursAllocationAServir < 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CALCUL_CAPITAL_ARCE_SUR_SPEC_16");
    }
    return new QuantiteJour(BigDecimal.valueOf(dureeNombreMaximalJoursAllocationAServir));
  }
  
  protected int determinerDureeIndemnisationRestantACourir(Damj dateCalcul, Damj pji, Damj dateLimite)
  {
    Damj pointDepartIndemnisation = determinerPointDepartIndemnisation(dateCalcul.lendemain(), pji);
    return new Periode(pointDepartIndemnisation, dateLimite).getDuree();
  }
  
  protected Damj determinerPointDepartIndemnisation(Damj dateCalcul, Damj pji)
  {
    return Damj.max(dateCalcul, pji);
  }
  
  protected void controlerCoherenceDemande(Damj dateCalcul, Damj dateLimite)
    throws ApplicativeException
  {
    if (dateLimite.estAvant(dateCalcul)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_DATE_CALCUL_DUREE_RESTANT_INCOHERENTE");
    }
  }
  
  protected OutilGestionArce getOutilGestionArce()
  {
    return OutilGestionArce.getInstance();
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationDureePourArce
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */